-- MariaDB dump 10.19  Distrib 10.5.22-MariaDB, for Linux (x86_64)
--
-- Host: localhost    Database: heat
-- ------------------------------------------------------
-- Server version	10.5.22-MariaDB

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8mb4 */;
/*!40103 SET @OLD_TIME_ZONE=@@TIME_ZONE */;
/*!40103 SET TIME_ZONE='+00:00' */;
/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;
/*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES, SQL_NOTES=0 */;

--
-- Table structure for table `event`
--

DROP TABLE IF EXISTS `event`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `event` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `uuid` varchar(36) DEFAULT NULL,
  `stack_id` varchar(36) NOT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `resource_action` varchar(255) DEFAULT NULL,
  `resource_status` varchar(255) DEFAULT NULL,
  `resource_name` varchar(255) DEFAULT NULL,
  `physical_resource_id` varchar(255) DEFAULT NULL,
  `resource_status_reason` varchar(255) DEFAULT NULL,
  `resource_type` varchar(255) DEFAULT NULL,
  `resource_properties` blob DEFAULT NULL,
  `rsrc_prop_data_id` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `uuid` (`uuid`),
  KEY `stack_id` (`stack_id`),
  KEY `ev_rsrc_prop_data_ref` (`rsrc_prop_data_id`),
  CONSTRAINT `ev_rsrc_prop_data_ref` FOREIGN KEY (`rsrc_prop_data_id`) REFERENCES `resource_properties_data` (`id`),
  CONSTRAINT `event_ibfk_1` FOREIGN KEY (`stack_id`) REFERENCES `stack` (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=1729 DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `event`
--

LOCK TABLES `event` WRITE;
/*!40000 ALTER TABLE `event` DISABLE KEYS */;
INSERT INTO `event` VALUES (1,'425348ac-85f3-418a-a812-60511ab19033','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:34',NULL,'CREATE','IN_PROGRESS','cell1','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2,'3df27d81-3ecf-49fa-8daa-d9a908833a09','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:37',NULL,'CREATE','IN_PROGRESS','ServiceNetMap','cell1-ServiceNetMap-oylirjwmuzbn','state changed','OS::TripleO::ServiceNetMap',NULL,NULL),(3,'7bdae620-4d33-484e-a93b-56693ba85f18','51d8cdba-b9a7-424c-884c-37ea3f5b3bb6','2026-06-12 08:25:37',NULL,'CREATE','IN_PROGRESS','cell1-ServiceNetMap-oylirjwmuzbn','51d8cdba-b9a7-424c-884c-37ea3f5b3bb6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(4,'b7e23ffe-2f97-414d-9bb1-03f0fc8fe85a','51d8cdba-b9a7-424c-884c-37ea3f5b3bb6','2026-06-12 08:25:37',NULL,'CREATE','IN_PROGRESS','ServiceNetMapValue','cell1-ServiceNetMap-oylirjwmuzbn-ServiceNetMapValue-j45zf36oxrrb','state changed','OS::Heat::Value',NULL,1),(5,'59bc4893-b485-4da8-a049-94140f551266','51d8cdba-b9a7-424c-884c-37ea3f5b3bb6','2026-06-12 08:25:37',NULL,'CREATE','COMPLETE','ServiceNetMapValue','cell1-ServiceNetMap-oylirjwmuzbn-ServiceNetMapValue-j45zf36oxrrb','state changed','OS::Heat::Value',NULL,1),(6,'b7fe369d-329d-4942-94f3-b81e04fcbafc','51d8cdba-b9a7-424c-884c-37ea3f5b3bb6','2026-06-12 08:25:37',NULL,'CREATE','COMPLETE','cell1-ServiceNetMap-oylirjwmuzbn','51d8cdba-b9a7-424c-884c-37ea3f5b3bb6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(7,'7a22a1ba-7c4f-425b-8352-b45c0f32a854','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:38',NULL,'CREATE','IN_PROGRESS','BlockStorageRoleUserData','cell1-BlockStorageRoleUserData-2c7jcfpkipu5','state changed','OS::TripleO::BlockStorage::NodeUserData',NULL,NULL),(8,'b529fba9-370b-4a54-8180-e2739df4437b','1d100aff-0e07-4c2c-9435-35b0a942253c','2026-06-12 08:25:38',NULL,'CREATE','IN_PROGRESS','cell1-BlockStorageRoleUserData-2c7jcfpkipu5','1d100aff-0e07-4c2c-9435-35b0a942253c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(9,'30a477ca-9d2d-41e0-ac51-0d862da14858','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:38',NULL,'CREATE','COMPLETE','ServiceNetMap','51d8cdba-b9a7-424c-884c-37ea3f5b3bb6','state changed','OS::TripleO::ServiceNetMap',NULL,NULL),(10,'f4f64470-d11d-42f9-bc7e-0f5380a4f92a','1d100aff-0e07-4c2c-9435-35b0a942253c','2026-06-12 08:25:38',NULL,'CREATE','IN_PROGRESS','userdata','cell1-BlockStorageRoleUserData-2c7jcfpkipu5-userdata-qecghxhh4f2t','state changed','OS::Heat::MultipartMime',NULL,NULL),(11,'b73b1836-1aaf-49fe-af94-85d7b0d137ce','1d100aff-0e07-4c2c-9435-35b0a942253c','2026-06-12 08:25:38',NULL,'CREATE','COMPLETE','userdata','ca5c1ea4-69c0-4658-a611-b1ff6e4a6b3c','state changed','OS::Heat::MultipartMime',NULL,NULL),(12,'281ce218-e876-4581-9420-2f09f3b187ee','1d100aff-0e07-4c2c-9435-35b0a942253c','2026-06-12 08:25:38',NULL,'CREATE','COMPLETE','cell1-BlockStorageRoleUserData-2c7jcfpkipu5','1d100aff-0e07-4c2c-9435-35b0a942253c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(13,'eb97ae4e-2938-4f3c-8e59-556695e2e316','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:38',NULL,'CREATE','IN_PROGRESS','CellControllerServiceNetMapLower','cell1-CellControllerServiceNetMapLower-ytvfzsptu72i','state changed','OS::Heat::Value',NULL,3),(14,'9f95a536-e1a6-4d15-a8a8-df28b1e69b1e','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:38',NULL,'CREATE','COMPLETE','CellControllerServiceNetMapLower','cell1-CellControllerServiceNetMapLower-ytvfzsptu72i','state changed','OS::Heat::Value',NULL,3),(15,'2687645e-80d4-4350-bb7c-293be50f5742','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:38',NULL,'CREATE','IN_PROGRESS','ObjectStorageServiceNetMapLower','cell1-ObjectStorageServiceNetMapLower-l53dz2um7aqo','state changed','OS::Heat::Value',NULL,5),(16,'238ea5a2-455e-4703-9829-3188a5462a60','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:38',NULL,'CREATE','IN_PROGRESS','NetworkerServiceNetMapLower','cell1-NetworkerServiceNetMapLower-p7qgrvf5unyr','state changed','OS::Heat::Value',NULL,6),(17,'31a9571d-728c-4b7a-a6af-7f7a9911c997','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:38',NULL,'CREATE','COMPLETE','NetworkerServiceNetMapLower','cell1-NetworkerServiceNetMapLower-p7qgrvf5unyr','state changed','OS::Heat::Value',NULL,6),(18,'9410a041-ec02-4b14-a816-ac1bd820dbab','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:38',NULL,'CREATE','IN_PROGRESS','CephStorageServiceNetMapLower','cell1-CephStorageServiceNetMapLower-5m66247bgmxa','state changed','OS::Heat::Value',NULL,8),(19,'74e3f805-5978-4951-832b-b43d635bc0e3','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:38',NULL,'CREATE','COMPLETE','CephStorageServiceNetMapLower','cell1-CephStorageServiceNetMapLower-5m66247bgmxa','state changed','OS::Heat::Value',NULL,8),(20,'1c420b32-8766-4321-8a4b-0f3c38d7442c','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:38',NULL,'CREATE','COMPLETE','ObjectStorageServiceNetMapLower','cell1-ObjectStorageServiceNetMapLower-l53dz2um7aqo','state changed','OS::Heat::Value',NULL,5),(21,'afdf689b-8a58-4f69-a2ae-dae81c737ac5','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:38',NULL,'CREATE','IN_PROGRESS','ComputeServiceNetMapLower','cell1-ComputeServiceNetMapLower-rf46r7q5azey','state changed','OS::Heat::Value',NULL,9),(22,'73ab8114-888f-4b6a-be27-131e1ee7c8f0','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:38',NULL,'CREATE','COMPLETE','ComputeServiceNetMapLower','cell1-ComputeServiceNetMapLower-rf46r7q5azey','state changed','OS::Heat::Value',NULL,9),(23,'974370ee-0bc4-4e61-b919-a9f5d32618fc','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:38',NULL,'CREATE','IN_PROGRESS','ControllerServiceNetMapLower','cell1-ControllerServiceNetMapLower-tmzd2b2xb5rg','state changed','OS::Heat::Value',NULL,11),(24,'6ddfc3b0-751c-4d44-adef-0085a2416fa5','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:38',NULL,'CREATE','COMPLETE','ControllerServiceNetMapLower','cell1-ControllerServiceNetMapLower-tmzd2b2xb5rg','state changed','OS::Heat::Value',NULL,11),(25,'7059e1a1-81b7-4410-88a0-793a2172cbee','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:38',NULL,'CREATE','IN_PROGRESS','BlockStorageServiceNetMapLower','cell1-BlockStorageServiceNetMapLower-d275hrsx2q7y','state changed','OS::Heat::Value',NULL,13),(26,'2eec0e51-3d20-4c53-aacf-0b9a9fc77540','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:39',NULL,'CREATE','IN_PROGRESS','ControlVirtualIP','cell1-ControlVirtualIP-ryohbbyfqhjf','state changed','OS::TripleO::Network::Ports::ControlPlaneVipPort',NULL,17),(27,'215a1b01-40f2-4ec7-8824-f6b69526ea3a','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:39',NULL,'CREATE','COMPLETE','BlockStorageServiceNetMapLower','cell1-BlockStorageServiceNetMapLower-d275hrsx2q7y','state changed','OS::Heat::Value',NULL,13),(28,'cb789d5f-bd7d-420e-89d9-2900f8413717','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:39',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServiceNetMapLower','cell1-CellControllerComputeServiceNetMapLower-e4vw42fvxtsq','state changed','OS::Heat::Value',NULL,18),(29,'b2be801d-7912-4a03-93a3-ac90cccba504','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:39',NULL,'CREATE','COMPLETE','CellControllerComputeServiceNetMapLower','cell1-CellControllerComputeServiceNetMapLower-e4vw42fvxtsq','state changed','OS::Heat::Value',NULL,18),(30,'e0c8a10e-476b-4e2a-8aff-9d3254f37a5f','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:39',NULL,'CREATE','IN_PROGRESS','DeploymentServerBlacklistDict','cell1-DeploymentServerBlacklistDict-btxlb6awst7d','state changed','OS::Heat::Value',NULL,21),(31,'57834c25-f6c5-4f24-b227-397ded7810d3','cc583229-e4ca-49d7-82b3-6ec36ef562d6','2026-06-12 08:25:39',NULL,'CREATE','IN_PROGRESS','cell1-ControlVirtualIP-ryohbbyfqhjf','cc583229-e4ca-49d7-82b3-6ec36ef562d6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(32,'e3d92df1-b126-496e-b15e-82beae07b587','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:39',NULL,'CREATE','COMPLETE','DeploymentServerBlacklistDict','cell1-DeploymentServerBlacklistDict-btxlb6awst7d','state changed','OS::Heat::Value',NULL,21),(33,'81c0768b-f041-4f79-bd44-8e7812778402','cc583229-e4ca-49d7-82b3-6ec36ef562d6','2026-06-12 08:25:39',NULL,'CREATE','COMPLETE','cell1-ControlVirtualIP-ryohbbyfqhjf','cc583229-e4ca-49d7-82b3-6ec36ef562d6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(34,'8e73b5cd-4574-4651-8261-65c3073a8f2c','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:39',NULL,'CREATE','COMPLETE','BlockStorageRoleUserData','1d100aff-0e07-4c2c-9435-35b0a942253c','state changed','OS::TripleO::BlockStorage::NodeUserData',NULL,NULL),(35,'3562e275-a24f-4a8f-952b-a8ae6c38cac7','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:40',NULL,'CREATE','IN_PROGRESS','ObjectStorageRoleUserData','cell1-ObjectStorageRoleUserData-mwjexb627zax','state changed','OS::TripleO::ObjectStorage::NodeUserData',NULL,NULL),(36,'7cd5065a-6cca-4a6f-8a35-225da9b03c55','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:40',NULL,'CREATE','COMPLETE','ControlVirtualIP','cc583229-e4ca-49d7-82b3-6ec36ef562d6','state changed','OS::TripleO::Network::Ports::ControlPlaneVipPort',NULL,17),(37,'63474e45-74e4-4d8c-ab52-11ad6564e983','0a8c9f8c-59ce-49a0-bd86-da18f38bb157','2026-06-12 08:25:40',NULL,'CREATE','IN_PROGRESS','cell1-ObjectStorageRoleUserData-mwjexb627zax','0a8c9f8c-59ce-49a0-bd86-da18f38bb157','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(38,'52f90aaa-cfad-47ec-8cd6-5a9fbdd2c30e','0a8c9f8c-59ce-49a0-bd86-da18f38bb157','2026-06-12 08:25:40',NULL,'CREATE','IN_PROGRESS','userdata','cell1-ObjectStorageRoleUserData-mwjexb627zax-userdata-pblsod3nuskw','state changed','OS::Heat::MultipartMime',NULL,NULL),(39,'47f0c24b-3324-4570-b38b-7f1cb0f5c784','0a8c9f8c-59ce-49a0-bd86-da18f38bb157','2026-06-12 08:25:40',NULL,'CREATE','COMPLETE','userdata','159a907b-e20e-4759-9570-51a2f14bac21','state changed','OS::Heat::MultipartMime',NULL,NULL),(40,'28ddd3f5-dc0d-4e0e-bacd-94dfbc1fcb24','0a8c9f8c-59ce-49a0-bd86-da18f38bb157','2026-06-12 08:25:40',NULL,'CREATE','COMPLETE','cell1-ObjectStorageRoleUserData-mwjexb627zax','0a8c9f8c-59ce-49a0-bd86-da18f38bb157','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(41,'0105ac04-0a7c-4fb4-9449-ea53ab49a0d1','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:40',NULL,'CREATE','IN_PROGRESS','Networks','cell1-Networks-g2dfdzeon54u','state changed','OS::TripleO::Network',NULL,24),(42,'ba6a6e09-eb08-4bf9-a9c2-3f3e03808321','2156e4c7-1622-4775-abf0-5881662899de','2026-06-12 08:25:40',NULL,'CREATE','IN_PROGRESS','cell1-Networks-g2dfdzeon54u','2156e4c7-1622-4775-abf0-5881662899de','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(43,'493aee67-99a8-431b-93ea-787efef4f169','2156e4c7-1622-4775-abf0-5881662899de','2026-06-12 08:25:40',NULL,'CREATE','IN_PROGRESS','NetworkExtraConfig','cell1-Networks-g2dfdzeon54u-NetworkExtraConfig-zujcsjm65uam','state changed','OS::TripleO::Network::ExtraConfig',NULL,NULL),(44,'665fd3d4-ae44-466d-be42-be92fa5832b6','2156e4c7-1622-4775-abf0-5881662899de','2026-06-12 08:25:40',NULL,'CREATE','COMPLETE','NetworkExtraConfig','0b73875a-c57e-4b9f-8a68-d36c915cb933','state changed','OS::TripleO::Network::ExtraConfig',NULL,NULL),(45,'0c26468f-807c-4635-a73d-d1aeb9039dd2','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:41',NULL,'CREATE','IN_PROGRESS','CellControllerComputeRoleUserData','cell1-CellControllerComputeRoleUserData-din4k2qn6vhj','state changed','OS::TripleO::CellControllerCompute::NodeUserData',NULL,NULL),(46,'26cda9d1-66cd-4ce1-9cb5-ed9a0f4cc92b','8e8116df-6e99-4dc5-a82f-bda55327c1f8','2026-06-12 08:25:41',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerComputeRoleUserData-din4k2qn6vhj','8e8116df-6e99-4dc5-a82f-bda55327c1f8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(47,'76decee5-f821-4613-8cfc-0eaa96c01fb8','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:41',NULL,'CREATE','COMPLETE','ObjectStorageRoleUserData','0a8c9f8c-59ce-49a0-bd86-da18f38bb157','state changed','OS::TripleO::ObjectStorage::NodeUserData',NULL,NULL),(48,'f60b61ce-2254-49ce-91b1-1d2431b777f4','8e8116df-6e99-4dc5-a82f-bda55327c1f8','2026-06-12 08:25:41',NULL,'CREATE','IN_PROGRESS','userdata','cell1-CellControllerComputeRoleUserData-din4k2qn6vhj-userdata-o5zsycgwcfrk','state changed','OS::Heat::MultipartMime',NULL,NULL),(49,'e16cfb5a-2403-4b16-af21-c4fd957c6082','8e8116df-6e99-4dc5-a82f-bda55327c1f8','2026-06-12 08:25:41',NULL,'CREATE','COMPLETE','userdata','daa065b1-15b9-45c0-a288-7fcfd92ebf5c','state changed','OS::Heat::MultipartMime',NULL,NULL),(50,'8a9fae0f-03a6-4170-b97c-d6ccdf4c3b30','8e8116df-6e99-4dc5-a82f-bda55327c1f8','2026-06-12 08:25:41',NULL,'CREATE','COMPLETE','cell1-CellControllerComputeRoleUserData-din4k2qn6vhj','8e8116df-6e99-4dc5-a82f-bda55327c1f8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(51,'a0d84482-4250-4aab-a268-db39a0bcebb0','2156e4c7-1622-4775-abf0-5881662899de','2026-06-12 08:25:41',NULL,'CREATE','IN_PROGRESS','NetworkAttributesMap','cell1-Networks-g2dfdzeon54u-NetworkAttributesMap-dvb5lwyznyye','state changed','OS::Heat::Value',NULL,27),(52,'a8b45c79-1d0d-488c-ab67-1088e98b422b','2156e4c7-1622-4775-abf0-5881662899de','2026-06-12 08:25:41',NULL,'CREATE','COMPLETE','NetworkAttributesMap','cell1-Networks-g2dfdzeon54u-NetworkAttributesMap-dvb5lwyznyye','state changed','OS::Heat::Value',NULL,27),(53,'6cde033e-7b0b-4613-a439-e4b95fbed7cf','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:42',NULL,'CREATE','IN_PROGRESS','NetworkerRoleUserData','cell1-NetworkerRoleUserData-xl34jdeowsvr','state changed','OS::TripleO::Networker::NodeUserData',NULL,NULL),(54,'9e64752e-3129-46eb-818f-cdabac9c0465','16a8b4a4-8a35-410a-a962-172fc2321672','2026-06-12 08:25:42',NULL,'CREATE','IN_PROGRESS','cell1-NetworkerRoleUserData-xl34jdeowsvr','16a8b4a4-8a35-410a-a962-172fc2321672','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(55,'172569ea-79dd-4d58-98c0-6ad1c8793cc4','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:42',NULL,'CREATE','COMPLETE','CellControllerComputeRoleUserData','8e8116df-6e99-4dc5-a82f-bda55327c1f8','state changed','OS::TripleO::CellControllerCompute::NodeUserData',NULL,NULL),(56,'9b046975-4bac-4222-a26d-047205799969','16a8b4a4-8a35-410a-a962-172fc2321672','2026-06-12 08:25:42',NULL,'CREATE','IN_PROGRESS','userdata','cell1-NetworkerRoleUserData-xl34jdeowsvr-userdata-sx7w5bnvni6q','state changed','OS::Heat::MultipartMime',NULL,NULL),(57,'274083db-c3d7-41d8-901f-1ff1f152a6a2','16a8b4a4-8a35-410a-a962-172fc2321672','2026-06-12 08:25:42',NULL,'CREATE','COMPLETE','userdata','cd1e58d8-4afa-4a63-82d9-92551fe42070','state changed','OS::Heat::MultipartMime',NULL,NULL),(58,'bcf4ca38-b649-4cd3-93a0-84b504f70e40','16a8b4a4-8a35-410a-a962-172fc2321672','2026-06-12 08:25:42',NULL,'CREATE','COMPLETE','cell1-NetworkerRoleUserData-xl34jdeowsvr','16a8b4a4-8a35-410a-a962-172fc2321672','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(59,'c114b809-3d1d-42ba-ba0e-980604f2ad5f','2156e4c7-1622-4775-abf0-5881662899de','2026-06-12 08:25:42',NULL,'CREATE','IN_PROGRESS','NetworkIpVersionMap','cell1-Networks-g2dfdzeon54u-NetworkIpVersionMap-lpx2uec5iglu','state changed','OS::Heat::Value',NULL,29),(60,'591fda37-7884-472d-bd08-b335b3ac721b','2156e4c7-1622-4775-abf0-5881662899de','2026-06-12 08:25:42',NULL,'CREATE','COMPLETE','NetworkIpVersionMap','cell1-Networks-g2dfdzeon54u-NetworkIpVersionMap-lpx2uec5iglu','state changed','OS::Heat::Value',NULL,29),(61,'1ed9b5d6-0066-4a86-95f0-5b3c5dca8ff2','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:43',NULL,'CREATE','IN_PROGRESS','CellControllerRoleUserData','cell1-CellControllerRoleUserData-iclbtv4dgyea','state changed','OS::TripleO::CellController::NodeUserData',NULL,NULL),(62,'bf0e30af-d5f2-4138-b0a6-5bc99f4f17d5','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:43',NULL,'CREATE','COMPLETE','NetworkerRoleUserData','16a8b4a4-8a35-410a-a962-172fc2321672','state changed','OS::TripleO::Networker::NodeUserData',NULL,NULL),(63,'850d7365-8409-41bd-be88-ddef6fa100fb','71baf353-0cfa-48e8-bbff-45da8b6c1ef4','2026-06-12 08:25:43',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerRoleUserData-iclbtv4dgyea','71baf353-0cfa-48e8-bbff-45da8b6c1ef4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(64,'f28b5a99-2395-439e-b2b3-fa1c68e0df68','71baf353-0cfa-48e8-bbff-45da8b6c1ef4','2026-06-12 08:25:43',NULL,'CREATE','IN_PROGRESS','userdata','cell1-CellControllerRoleUserData-iclbtv4dgyea-userdata-mig2mdlx4min','state changed','OS::Heat::MultipartMime',NULL,NULL),(65,'62e1765c-6592-421b-a164-7cd3108a10e1','71baf353-0cfa-48e8-bbff-45da8b6c1ef4','2026-06-12 08:25:43',NULL,'CREATE','COMPLETE','userdata','ab3ab164-85c5-4ce6-b45f-96c96bd6b9a7','state changed','OS::Heat::MultipartMime',NULL,NULL),(66,'694521a9-4f23-4720-b3b7-327e052399cd','71baf353-0cfa-48e8-bbff-45da8b6c1ef4','2026-06-12 08:25:43',NULL,'CREATE','COMPLETE','cell1-CellControllerRoleUserData-iclbtv4dgyea','71baf353-0cfa-48e8-bbff-45da8b6c1ef4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(67,'3ac49d58-634d-46c1-9566-a91a10580c27','2156e4c7-1622-4775-abf0-5881662899de','2026-06-12 08:25:43',NULL,'CREATE','IN_PROGRESS','NetworkCidrMap','cell1-Networks-g2dfdzeon54u-NetworkCidrMap-cxjbf5auw7y2','state changed','OS::Heat::Value',NULL,31),(68,'f5950658-76ec-4faa-acb9-94b03f78294d','2156e4c7-1622-4775-abf0-5881662899de','2026-06-12 08:25:43',NULL,'CREATE','COMPLETE','NetworkCidrMap','cell1-Networks-g2dfdzeon54u-NetworkCidrMap-cxjbf5auw7y2','state changed','OS::Heat::Value',NULL,31),(69,'4325a3cf-5283-457d-858d-a4c6b696950c','2156e4c7-1622-4775-abf0-5881662899de','2026-06-12 08:25:43',NULL,'CREATE','COMPLETE','cell1-Networks-g2dfdzeon54u','2156e4c7-1622-4775-abf0-5881662899de','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(70,'502edd38-4274-43a8-afb5-b1f3d07a55fd','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:44',NULL,'CREATE','IN_PROGRESS','NodeAdminUserData','cell1-NodeAdminUserData-wukqddinumbg','state changed','OS::TripleO::NodeAdminUserData',NULL,NULL),(71,'ae03797f-464b-40a3-84c8-bc8ae25118ac','843d34c1-98be-4115-b358-95b2ec5a83fd','2026-06-12 08:25:44',NULL,'CREATE','IN_PROGRESS','cell1-NodeAdminUserData-wukqddinumbg','843d34c1-98be-4115-b358-95b2ec5a83fd','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(72,'85224feb-6a79-46bb-b563-9d7b638ec63c','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:44',NULL,'CREATE','COMPLETE','CellControllerRoleUserData','71baf353-0cfa-48e8-bbff-45da8b6c1ef4','state changed','OS::TripleO::CellController::NodeUserData',NULL,NULL),(73,'b4e4fb35-655a-401d-8680-c271a7603f70','843d34c1-98be-4115-b358-95b2ec5a83fd','2026-06-12 08:25:44',NULL,'CREATE','IN_PROGRESS','user_config','cell1-NodeAdminUserData-wukqddinumbg-user_config-55lldvevak7d','state changed','OS::Heat::CloudConfig',NULL,32),(74,'12ffe004-5172-46ce-8624-010421c8b034','843d34c1-98be-4115-b358-95b2ec5a83fd','2026-06-12 08:25:44',NULL,'CREATE','COMPLETE','user_config','d8598f48-442e-4187-abe1-3de1781ddada','state changed','OS::Heat::CloudConfig',NULL,32),(75,'19a2abe6-4b28-4acd-a9ac-b6c738786473','843d34c1-98be-4115-b358-95b2ec5a83fd','2026-06-12 08:25:44',NULL,'CREATE','IN_PROGRESS','userdata','cell1-NodeAdminUserData-wukqddinumbg-userdata-yjkvymvweo3i','state changed','OS::Heat::MultipartMime',NULL,34),(76,'a98dafe1-9af2-4051-9a88-b1e785c14e5e','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:44',NULL,'CREATE','COMPLETE','Networks','2156e4c7-1622-4775-abf0-5881662899de','state changed','OS::TripleO::Network',NULL,24),(77,'5e751990-dd0c-4a2f-b880-8a13248fdeaa','843d34c1-98be-4115-b358-95b2ec5a83fd','2026-06-12 08:25:44',NULL,'CREATE','COMPLETE','userdata','9e79f8a0-8d18-4ab5-8d15-8d7c1496cc29','state changed','OS::Heat::MultipartMime',NULL,34),(78,'8a2e0e20-eb2a-4805-a10f-f8bd1799d814','843d34c1-98be-4115-b358-95b2ec5a83fd','2026-06-12 08:25:44',NULL,'CREATE','COMPLETE','cell1-NodeAdminUserData-wukqddinumbg','843d34c1-98be-4115-b358-95b2ec5a83fd','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(79,'5a22fbac-b742-449b-9d0c-5cb3fb3ac7a0','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:44',NULL,'CREATE','IN_PROGRESS','CephStorageNetworkConfig','cell1-CephStorageNetworkConfig-i4njud3iduyg','state changed','OS::TripleO::CephStorage::Net::SoftwareConfig',NULL,NULL),(80,'f27ff1ab-d35c-4c6c-a163-3b3e4ada71a0','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:44',NULL,'CREATE','IN_PROGRESS','InternalApiVirtualIP','cell1-InternalApiVirtualIP-hkmkbczqz2xy','state changed','OS::TripleO::Network::Ports::InternalApiVipPort',NULL,38),(81,'ab0bdb9a-1fe1-4be2-aa34-86381d88ff99','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:44',NULL,'CREATE','COMPLETE','CephStorageNetworkConfig','61aa862d-ac54-49f1-a86f-25d1f41d7057','state changed','OS::TripleO::CephStorage::Net::SoftwareConfig',NULL,NULL),(82,'5c84134c-2a4c-491b-95d9-47ff71c93d35','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:44',NULL,'CREATE','IN_PROGRESS','CellControllerComputeNetworkConfig','cell1-CellControllerComputeNetworkConfig-jmha5kytgvud','state changed','OS::TripleO::CellControllerCompute::Net::SoftwareConfig',NULL,NULL),(83,'2ee6a443-abee-4aa9-8bcc-c7a3a312b753','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:44',NULL,'CREATE','COMPLETE','CellControllerComputeNetworkConfig','7c785d97-b839-4f30-a1ea-8bcdc99ab460','state changed','OS::TripleO::CellControllerCompute::Net::SoftwareConfig',NULL,NULL),(84,'9b66b98b-e719-43d3-b25c-f14fae65ea40','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:44',NULL,'CREATE','IN_PROGRESS','PublicVirtualIP','cell1-PublicVirtualIP-or2mmsnpd7nm','state changed','OS::TripleO::Network::Ports::ExternalVipPort',NULL,40),(85,'70b646ec-baf8-47df-b2cf-69698554e796','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:44',NULL,'CREATE','IN_PROGRESS','NetIpVersionMapValue','cell1-NetIpVersionMapValue-nzwsxhiiohrb','state changed','OS::Heat::Value',NULL,39),(86,'55330465-5e68-4c8a-b483-acbc4af78ea5','39f83ad6-187e-44a1-be76-5a4bc402fc0b','2026-06-12 08:25:44',NULL,'CREATE','IN_PROGRESS','cell1-InternalApiVirtualIP-hkmkbczqz2xy','39f83ad6-187e-44a1-be76-5a4bc402fc0b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(87,'84e7a238-7ecf-40f3-aa40-0bf87ebc2f31','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:45',NULL,'CREATE','COMPLETE','NetIpVersionMapValue','cell1-NetIpVersionMapValue-nzwsxhiiohrb','state changed','OS::Heat::Value',NULL,39),(88,'54538485-a2f0-44f1-ae8d-7480efa7e8f6','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:45',NULL,'CREATE','IN_PROGRESS','ObjectStorageNetworkConfig','cell1-ObjectStorageNetworkConfig-fbs2bldekyvb','state changed','OS::TripleO::ObjectStorage::Net::SoftwareConfig',NULL,NULL),(89,'d4be4b07-bbae-42b9-8eb8-c55b64b7509c','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:45',NULL,'CREATE','COMPLETE','ObjectStorageNetworkConfig','620da531-8651-4d32-9af9-2963023b0223','state changed','OS::TripleO::ObjectStorage::Net::SoftwareConfig',NULL,NULL),(90,'c59e5bdd-c8d1-431d-a6c3-19b6290706a5','39f83ad6-187e-44a1-be76-5a4bc402fc0b','2026-06-12 08:25:45',NULL,'CREATE','COMPLETE','cell1-InternalApiVirtualIP-hkmkbczqz2xy','39f83ad6-187e-44a1-be76-5a4bc402fc0b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(91,'44534f9a-ab5b-4a18-a9f5-87194d1a734e','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:45',NULL,'CREATE','IN_PROGRESS','BlockStorageNetworkConfig','cell1-BlockStorageNetworkConfig-vxd2ajoostxj','state changed','OS::TripleO::BlockStorage::Net::SoftwareConfig',NULL,NULL),(92,'158d553b-1a7e-456c-8591-32566f16e4f7','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:45',NULL,'CREATE','IN_PROGRESS','CellControllerNetworkConfig','cell1-CellControllerNetworkConfig-4hxs67v6tolz','state changed','OS::TripleO::CellController::Net::SoftwareConfig',NULL,NULL),(93,'607f81ec-7577-4d11-81fb-54c90f81c9c4','c246d8af-c2cf-4b38-bb7e-20b423b8a52f','2026-06-12 08:25:45',NULL,'CREATE','IN_PROGRESS','cell1-PublicVirtualIP-or2mmsnpd7nm','c246d8af-c2cf-4b38-bb7e-20b423b8a52f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(94,'5fa56638-8600-47c8-a7ef-f878052426d4','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:45',NULL,'CREATE','IN_PROGRESS','ControllerRoleUserData','cell1-ControllerRoleUserData-l2dqxkp6vgpv','state changed','OS::TripleO::Controller::NodeUserData',NULL,NULL),(95,'958f70c8-a67e-4d68-a45e-3f41f7a2fe8a','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:45',NULL,'CREATE','COMPLETE','BlockStorageNetworkConfig','d0f23f3e-a326-4a76-b7d8-f2195c5a64eb','state changed','OS::TripleO::BlockStorage::Net::SoftwareConfig',NULL,NULL),(96,'fa3339e3-5172-4f7e-a381-eccec9a366b4','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:45',NULL,'CREATE','COMPLETE','CellControllerNetworkConfig','eb51d9bf-7120-406e-8c6c-5325c3703725','state changed','OS::TripleO::CellController::Net::SoftwareConfig',NULL,NULL),(97,'2d595e7a-e2d1-46f0-a4bd-3beb5833e39f','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:45',NULL,'CREATE','IN_PROGRESS','StorageVirtualIP','cell1-StorageVirtualIP-k3sqzafrqy6b','state changed','OS::TripleO::Network::Ports::StorageVipPort',NULL,41),(98,'cdf4ee24-cebf-48f5-b1cf-399c86675755','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:45',NULL,'CREATE','IN_PROGRESS','NetworkerNetworkConfig','cell1-NetworkerNetworkConfig-ofdz7w2fxzjb','state changed','OS::TripleO::Networker::Net::SoftwareConfig',NULL,NULL),(99,'138333d3-44bb-43c2-8cb2-31cf303d465b','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:45',NULL,'CREATE','IN_PROGRESS','ComputeNetworkConfig','cell1-ComputeNetworkConfig-qb23fupzghds','state changed','OS::TripleO::Compute::Net::SoftwareConfig',NULL,NULL),(100,'9c57567d-2b8e-4cb1-8a1d-978c2979b65e','c246d8af-c2cf-4b38-bb7e-20b423b8a52f','2026-06-12 08:25:45',NULL,'CREATE','COMPLETE','cell1-PublicVirtualIP-or2mmsnpd7nm','c246d8af-c2cf-4b38-bb7e-20b423b8a52f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(101,'c90e3b65-06bd-4be9-b41c-ed7b4942c0d6','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:45',NULL,'CREATE','IN_PROGRESS','ControllerNetworkConfig','cell1-ControllerNetworkConfig-lqm5s2x4g6qr','state changed','OS::TripleO::Controller::Net::SoftwareConfig',NULL,NULL),(102,'e6090462-3ea2-49b2-b1ec-28d985a975d1','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:45',NULL,'CREATE','COMPLETE','NodeAdminUserData','843d34c1-98be-4115-b358-95b2ec5a83fd','state changed','OS::TripleO::NodeAdminUserData',NULL,NULL),(103,'116782c6-30fe-40d9-a490-b85fa73385f5','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:45',NULL,'CREATE','IN_PROGRESS','NetCidrMapValue','cell1-NetCidrMapValue-ct3m55br6yg7','state changed','OS::Heat::Value',NULL,42),(104,'56a8b0f8-7947-4bd7-9f9d-d105c296d510','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:45',NULL,'CREATE','COMPLETE','NetworkerNetworkConfig','26c5a9b0-676e-4faa-80a5-36db4aa8c2f4','state changed','OS::TripleO::Networker::Net::SoftwareConfig',NULL,NULL),(105,'2cb26ad3-e30b-4a99-b3ba-d4bd5160a11c','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:45',NULL,'CREATE','COMPLETE','ComputeNetworkConfig','f66389a6-fae5-4676-97b6-f7809f2b6616','state changed','OS::TripleO::Compute::Net::SoftwareConfig',NULL,NULL),(106,'a05e3e0f-d541-4ce2-9f56-b390c5b0a1c4','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:45',NULL,'CREATE','COMPLETE','PublicVirtualIP','c246d8af-c2cf-4b38-bb7e-20b423b8a52f','state changed','OS::TripleO::Network::Ports::ExternalVipPort',NULL,40),(107,'295e1ffc-fcb1-4419-b93e-5d2c83d91975','7cfeddf9-35ae-475e-9333-0c409e1797c0','2026-06-12 08:25:45',NULL,'CREATE','IN_PROGRESS','cell1-ControllerRoleUserData-l2dqxkp6vgpv','7cfeddf9-35ae-475e-9333-0c409e1797c0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(108,'a21e945a-9179-4367-b8c9-64b60d4d1f7b','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:45',NULL,'CREATE','COMPLETE','NetCidrMapValue','cell1-NetCidrMapValue-ct3m55br6yg7','state changed','OS::Heat::Value',NULL,42),(109,'bcb014a2-8489-4bf8-ae48-fd35c23010eb','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:45',NULL,'CREATE','COMPLETE','ControllerNetworkConfig','5a423e0c-5d78-4074-8a44-4cfd1d162b5b','state changed','OS::TripleO::Controller::Net::SoftwareConfig',NULL,NULL),(110,'02e09096-75b2-4d1f-a79b-9aa0cd1e2f9d','cbcec78d-4798-4473-86f5-eafc687dfc2f','2026-06-12 08:25:45',NULL,'CREATE','IN_PROGRESS','cell1-StorageVirtualIP-k3sqzafrqy6b','cbcec78d-4798-4473-86f5-eafc687dfc2f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(111,'f54100b7-97d2-4fe1-8c8a-acbfaf5e1a8c','cbcec78d-4798-4473-86f5-eafc687dfc2f','2026-06-12 08:25:45',NULL,'CREATE','COMPLETE','cell1-StorageVirtualIP-k3sqzafrqy6b','cbcec78d-4798-4473-86f5-eafc687dfc2f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(112,'14dd63a9-d1d1-4f08-99a6-0c28d12ae542','7cfeddf9-35ae-475e-9333-0c409e1797c0','2026-06-12 08:25:45',NULL,'CREATE','IN_PROGRESS','userdata','cell1-ControllerRoleUserData-l2dqxkp6vgpv-userdata-rebwpccuiyj4','state changed','OS::Heat::MultipartMime',NULL,NULL),(113,'c174255b-a9c9-481b-bb67-295c1d9c27ba','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:45',NULL,'CREATE','IN_PROGRESS','StorageMgmtVirtualIP','cell1-StorageMgmtVirtualIP-b3ulnhqc426q','state changed','OS::TripleO::Network::Ports::StorageMgmtVipPort',NULL,46),(114,'4267304b-1cb0-4ec0-959c-28705789cf31','7cfeddf9-35ae-475e-9333-0c409e1797c0','2026-06-12 08:25:45',NULL,'CREATE','COMPLETE','userdata','9b0e9607-fa6f-42f6-81d0-2fc264dd9342','state changed','OS::Heat::MultipartMime',NULL,NULL),(115,'208ee3b5-c1d8-41a8-9006-bb7323312ee3','7cfeddf9-35ae-475e-9333-0c409e1797c0','2026-06-12 08:25:45',NULL,'CREATE','COMPLETE','cell1-ControllerRoleUserData-l2dqxkp6vgpv','7cfeddf9-35ae-475e-9333-0c409e1797c0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(116,'522ba9ca-eb09-414e-b573-d209e134652e','00c74abd-5661-446a-8bad-82e704b72c1f','2026-06-12 08:25:45',NULL,'CREATE','IN_PROGRESS','cell1-StorageMgmtVirtualIP-b3ulnhqc426q','00c74abd-5661-446a-8bad-82e704b72c1f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(117,'1723876e-f36e-49f4-95d8-0de62eada8f9','00c74abd-5661-446a-8bad-82e704b72c1f','2026-06-12 08:25:45',NULL,'CREATE','COMPLETE','cell1-StorageMgmtVirtualIP-b3ulnhqc426q','00c74abd-5661-446a-8bad-82e704b72c1f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(118,'8c139238-12e2-476f-aad1-2f46b8e69943','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:46',NULL,'CREATE','COMPLETE','InternalApiVirtualIP','39f83ad6-187e-44a1-be76-5a4bc402fc0b','state changed','OS::TripleO::Network::Ports::InternalApiVipPort',NULL,38),(119,'59686235-7084-4333-b16d-13728e5bd054','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:46',NULL,'CREATE','IN_PROGRESS','CephStorageRoleUserData','cell1-CephStorageRoleUserData-frg7ict7rhec','state changed','OS::TripleO::CephStorage::NodeUserData',NULL,NULL),(120,'07258729-7ca3-4c8c-bc43-e35fb155212f','ceeab98a-92b6-42cf-812a-4cf6e496797b','2026-06-12 08:25:46',NULL,'CREATE','IN_PROGRESS','cell1-CephStorageRoleUserData-frg7ict7rhec','ceeab98a-92b6-42cf-812a-4cf6e496797b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(121,'b1562f49-d122-4745-a964-1dce28abaab3','ceeab98a-92b6-42cf-812a-4cf6e496797b','2026-06-12 08:25:46',NULL,'CREATE','IN_PROGRESS','userdata','cell1-CephStorageRoleUserData-frg7ict7rhec-userdata-z74fy3ka4z2t','state changed','OS::Heat::MultipartMime',NULL,NULL),(122,'151696ba-c8f3-4d7a-b85f-92c56f17292a','ceeab98a-92b6-42cf-812a-4cf6e496797b','2026-06-12 08:25:46',NULL,'CREATE','COMPLETE','userdata','ad458520-d703-4682-a3b2-c2a3725b2679','state changed','OS::Heat::MultipartMime',NULL,NULL),(123,'b0f9f888-7ff0-4810-bbeb-67bf3e3a6fc0','ceeab98a-92b6-42cf-812a-4cf6e496797b','2026-06-12 08:25:46',NULL,'CREATE','COMPLETE','cell1-CephStorageRoleUserData-frg7ict7rhec','ceeab98a-92b6-42cf-812a-4cf6e496797b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(124,'5fa702cb-75dd-4703-b3ae-fcc7f11e9fcc','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:46',NULL,'CREATE','COMPLETE','StorageVirtualIP','cbcec78d-4798-4473-86f5-eafc687dfc2f','state changed','OS::TripleO::Network::Ports::StorageVipPort',NULL,41),(125,'2f6e16a6-61aa-4e42-86de-cca99b6fb2de','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:46',NULL,'CREATE','COMPLETE','ControllerRoleUserData','7cfeddf9-35ae-475e-9333-0c409e1797c0','state changed','OS::TripleO::Controller::NodeUserData',NULL,NULL),(126,'872683c6-d886-4038-b31d-ef7600da87f8','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:46',NULL,'CREATE','COMPLETE','StorageMgmtVirtualIP','00c74abd-5661-446a-8bad-82e704b72c1f','state changed','OS::TripleO::Network::Ports::StorageMgmtVipPort',NULL,46),(127,'900108aa-04d1-4fe7-b170-599705d7d7c6','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:46',NULL,'CREATE','IN_PROGRESS','VipMap','cell1-VipMap-xqxwfwsvih65','state changed','OS::TripleO::Network::Ports::NetVipMap',NULL,53),(128,'faaa728d-7150-417d-a22c-7327506fdc2e','a1c2adbf-89dd-4b85-8054-7a05a9663bfa','2026-06-12 08:25:46',NULL,'CREATE','IN_PROGRESS','cell1-VipMap-xqxwfwsvih65','a1c2adbf-89dd-4b85-8054-7a05a9663bfa','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(129,'232c3800-2aa9-4fa3-b83c-6790825e645d','a1c2adbf-89dd-4b85-8054-7a05a9663bfa','2026-06-12 08:25:46',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','cell1-VipMap-xqxwfwsvih65-NetIpMapValue-fejtcti5cfl6','state changed','OS::Heat::Value',NULL,54),(130,'854a7f1f-4364-4680-b8b0-aaad9d83d2c7','a1c2adbf-89dd-4b85-8054-7a05a9663bfa','2026-06-12 08:25:46',NULL,'CREATE','COMPLETE','NetIpMapValue','cell1-VipMap-xqxwfwsvih65-NetIpMapValue-fejtcti5cfl6','state changed','OS::Heat::Value',NULL,54),(131,'4ba91ef2-8c82-4c0f-b238-7080aadfb839','a1c2adbf-89dd-4b85-8054-7a05a9663bfa','2026-06-12 08:25:46',NULL,'CREATE','COMPLETE','cell1-VipMap-xqxwfwsvih65','a1c2adbf-89dd-4b85-8054-7a05a9663bfa','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(132,'37ed67b8-ad55-4684-bad4-14318f5429fe','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:47',NULL,'CREATE','IN_PROGRESS','CloudNames','cell1-CloudNames-etjmsunprpyz','state changed','OS::Heat::Value',NULL,55),(133,'673665fe-4de8-4ac2-90ec-5c3f9937fc85','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:47',NULL,'CREATE','COMPLETE','CloudNames','cell1-CloudNames-etjmsunprpyz','state changed','OS::Heat::Value',NULL,55),(134,'763bf2d8-13de-47c0-857f-c65e630d5237','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:47',NULL,'CREATE','COMPLETE','CephStorageRoleUserData','ceeab98a-92b6-42cf-812a-4cf6e496797b','state changed','OS::TripleO::CephStorage::NodeUserData',NULL,NULL),(135,'7cf664af-a064-423b-9777-8659da980141','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:47',NULL,'CREATE','COMPLETE','VipMap','a1c2adbf-89dd-4b85-8054-7a05a9663bfa','state changed','OS::TripleO::Network::Ports::NetVipMap',NULL,53),(136,'ecc32379-c943-4c8d-b8da-df6cb228b869','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:48',NULL,'CREATE','IN_PROGRESS','EndpointMap','cell1-EndpointMap-5a5vnigf3yf6','state changed','OS::TripleO::EndpointMap',NULL,60),(137,'45247c55-0113-4e52-b838-f2755cc80355','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:48',NULL,'CREATE','IN_PROGRESS','VipHosts','cell1-VipHosts-pq5xpzwvitjb','state changed','OS::Heat::Value',NULL,61),(138,'05cba2b2-7043-4ad4-b0c1-45f7b4495b2e','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:48',NULL,'CREATE','COMPLETE','VipHosts','cell1-VipHosts-pq5xpzwvitjb','state changed','OS::Heat::Value',NULL,61),(139,'2da5bd8f-56b7-462b-9f9a-ea769d5d717c','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:48',NULL,'CREATE','IN_PROGRESS','NodeTimesyncUserData','cell1-NodeTimesyncUserData-n4sx3l3lovc3','state changed','OS::TripleO::NodeTimesyncUserData',NULL,NULL),(140,'14727221-0cb7-4a24-a5ae-07b07fee39ed','814fc223-61c1-48ef-b79e-01e4b51bb3b9','2026-06-12 08:25:48',NULL,'CREATE','IN_PROGRESS','cell1-NodeTimesyncUserData-n4sx3l3lovc3','814fc223-61c1-48ef-b79e-01e4b51bb3b9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(141,'f4ceb287-4982-4ff7-8196-5b8bff5bcc12','cbbba4ee-a688-41dd-aec3-704e5bc2fbf6','2026-06-12 08:25:48',NULL,'CREATE','IN_PROGRESS','cell1-EndpointMap-5a5vnigf3yf6','cbbba4ee-a688-41dd-aec3-704e5bc2fbf6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(142,'a9488f8f-05bb-4d9b-bd4e-759289652a83','cbbba4ee-a688-41dd-aec3-704e5bc2fbf6','2026-06-12 08:25:48',NULL,'CREATE','COMPLETE','cell1-EndpointMap-5a5vnigf3yf6','cbbba4ee-a688-41dd-aec3-704e5bc2fbf6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(143,'f8f55581-99bb-474e-9193-2c36eb18bbb4','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:48',NULL,'CREATE','COMPLETE','EndpointMap','cbbba4ee-a688-41dd-aec3-704e5bc2fbf6','state changed','OS::TripleO::EndpointMap',NULL,60),(144,'1ebf28f7-5925-4503-a351-525be2d96b36','814fc223-61c1-48ef-b79e-01e4b51bb3b9','2026-06-12 08:25:48',NULL,'CREATE','IN_PROGRESS','timesync_sync','cell1-NodeTimesyncUserData-n4sx3l3lovc3-timesync_sync-vj46ik4wjh56','state changed','OS::Heat::SoftwareConfig',NULL,63),(145,'18177bf0-90fa-4101-a29f-fd59a76d2ac2','814fc223-61c1-48ef-b79e-01e4b51bb3b9','2026-06-12 08:25:48',NULL,'CREATE','COMPLETE','timesync_sync','e6d28eb3-7f06-42b4-9a6e-bd245cd08dab','state changed','OS::Heat::SoftwareConfig',NULL,63),(146,'22ca70e1-f04a-4fb1-8e19-8a88b0933c4e','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:48',NULL,'CREATE','IN_PROGRESS','EndpointMapData','cell1-EndpointMapData-d4i5dsh4vel2','state changed','OS::Heat::Value',NULL,65),(147,'16c0ed39-0305-4988-960b-fbb295aec76d','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:48',NULL,'CREATE','COMPLETE','EndpointMapData','cell1-EndpointMapData-d4i5dsh4vel2','state changed','OS::Heat::Value',NULL,65),(148,'da42f407-708b-4c4c-9063-91e6f9970c28','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:48',NULL,'CREATE','IN_PROGRESS','NetworkerServiceChain','cell1-NetworkerServiceChain-w6ts4csx6o2u','state changed','OS::TripleO::NetworkerServices',NULL,66),(149,'72cd80c8-3767-4660-abb7-0f5ff0a62c58','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:48',NULL,'CREATE','IN_PROGRESS','ObjectStorageServiceChain','cell1-ObjectStorageServiceChain-vuwq6dz2onkk','state changed','OS::TripleO::ObjectStorageServices',NULL,67),(150,'7c07286f-5b4a-40c9-ac10-bc289d75b7f6','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:48',NULL,'CREATE','IN_PROGRESS','BlockStorageServiceChain','cell1-BlockStorageServiceChain-xb5mfp73j4eo','state changed','OS::TripleO::BlockStorageServices',NULL,68),(151,'266aeff9-7b7a-4bdb-809a-c310dfe89b46','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:48',NULL,'CREATE','IN_PROGRESS','CephStorageServiceChain','cell1-CephStorageServiceChain-xqicw5xwvg6g','state changed','OS::TripleO::CephStorageServices',NULL,69),(152,'a4c59c00-f77b-434d-b083-a3fc6225031d','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:49',NULL,'CREATE','IN_PROGRESS','ComputeRoleUserData','cell1-ComputeRoleUserData-fmqxlzhbjsap','state changed','OS::TripleO::Compute::NodeUserData',NULL,NULL),(153,'69ca59a8-5078-472d-acff-c22fd7eb5edc','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:49',NULL,'CREATE','IN_PROGRESS','ControllerServiceChain','cell1-ControllerServiceChain-zbda4x4z5on7','state changed','OS::TripleO::ControllerServices',NULL,70),(154,'75c8a897-8bf2-4cb0-851a-920aeb6c91b6','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:49',NULL,'CREATE','IN_PROGRESS','cell1-NetworkerServiceChain-w6ts4csx6o2u','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(155,'1377950d-171e-4e77-beae-bd5597d931d1','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:49',NULL,'CREATE','IN_PROGRESS','cell1-ObjectStorageServiceChain-vuwq6dz2onkk','fe37e76b-9935-4130-aa62-8b87c49e18f6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(156,'8343d07d-999b-46a4-ac51-d5821ac47d0b','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:49',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServiceChain','cell1-CellControllerComputeServiceChain-aseidyipoyc3','state changed','OS::TripleO::CellControllerComputeServices',NULL,71),(157,'24d9bb2a-0d03-4d1c-81d3-d5704d8660a8','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:49',NULL,'CREATE','IN_PROGRESS','ComputeServiceChain','cell1-ComputeServiceChain-egzxltenqxn4','state changed','OS::TripleO::ComputeServices',NULL,72),(158,'dd2f33c5-869a-46f7-b202-b1334316dc2a','5bdeb4aa-f303-4207-9bd1-393ec399a46a','2026-06-12 08:25:49',NULL,'CREATE','IN_PROGRESS','cell1-ComputeRoleUserData-fmqxlzhbjsap','5bdeb4aa-f303-4207-9bd1-393ec399a46a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(159,'2cf32855-87d2-48c0-81af-7455e761e0b4','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:49',NULL,'CREATE','IN_PROGRESS','cell1-CephStorageServiceChain-xqicw5xwvg6g','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(160,'0e9fbf6a-bb30-41a5-b7ac-439f06fa9325','814fc223-61c1-48ef-b79e-01e4b51bb3b9','2026-06-12 08:25:49',NULL,'CREATE','IN_PROGRESS','timesync_chrony','cell1-NodeTimesyncUserData-n4sx3l3lovc3-timesync_chrony-tpnvenym56wv','state changed','OS::Heat::SoftwareConfig',NULL,75),(161,'add66d82-2ca4-49ba-86a4-5cda86a4e11d','5bdeb4aa-f303-4207-9bd1-393ec399a46a','2026-06-12 08:25:49',NULL,'CREATE','IN_PROGRESS','userdata','cell1-ComputeRoleUserData-fmqxlzhbjsap-userdata-5dtacbhyasxy','state changed','OS::Heat::MultipartMime',NULL,NULL),(162,'295f6467-e34c-46fa-890c-f2980f2fb6f9','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:49',NULL,'CREATE','IN_PROGRESS','cell1-ControllerServiceChain-zbda4x4z5on7','f3979da4-1312-4314-a6b6-ac051d536f13','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(163,'c056f4e0-79a8-4c6d-b88e-7697364b06d0','5bdeb4aa-f303-4207-9bd1-393ec399a46a','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','userdata','9a7a5fe2-51a7-4c57-866d-bd7a2d4d3571','state changed','OS::Heat::MultipartMime',NULL,NULL),(164,'b66f9223-0992-41bf-807b-d4c0348c68aa','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:49',NULL,'CREATE','IN_PROGRESS','CellControllerServiceChain','cell1-CellControllerServiceChain-sfzpnsimaenh','state changed','OS::TripleO::CellControllerServices',NULL,74),(165,'f7947fe1-13e0-49ba-b9d1-209ce462bd91','814fc223-61c1-48ef-b79e-01e4b51bb3b9','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','timesync_chrony','fb5ab309-7c16-4ccb-b6fd-062398ea6769','state changed','OS::Heat::SoftwareConfig',NULL,75),(166,'13e0dc0a-5a98-440f-9101-f8de51fd7e6e','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:49',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerComputeServiceChain-aseidyipoyc3','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(167,'00940a39-ecd9-41a7-9c4f-2cb8080d4238','5bdeb4aa-f303-4207-9bd1-393ec399a46a','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','cell1-ComputeRoleUserData-fmqxlzhbjsap','5bdeb4aa-f303-4207-9bd1-393ec399a46a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(168,'f57fe7e7-4aac-41c1-ab80-01495d1d6048','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:49',NULL,'CREATE','IN_PROGRESS','cell1-BlockStorageServiceChain-xb5mfp73j4eo','0292a578-a91f-4468-b72e-e0d581ff796d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(169,'6311557a-25ec-4778-bd7f-219bf090218d','814fc223-61c1-48ef-b79e-01e4b51bb3b9','2026-06-12 08:25:49',NULL,'CREATE','IN_PROGRESS','userdata','cell1-NodeTimesyncUserData-n4sx3l3lovc3-userdata-scnvonlkpwi4','state changed','OS::Heat::MultipartMime',NULL,76),(170,'09153b58-dc5d-42fe-a704-488ca1a28ea0','814fc223-61c1-48ef-b79e-01e4b51bb3b9','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','userdata','265d72a5-61cc-4d33-af71-10d16d2db2f5','state changed','OS::Heat::MultipartMime',NULL,76),(171,'e37a7c33-5417-44f3-91c8-cb67d2e63f19','814fc223-61c1-48ef-b79e-01e4b51bb3b9','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','cell1-NodeTimesyncUserData-n4sx3l3lovc3','814fc223-61c1-48ef-b79e-01e4b51bb3b9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(172,'e23951fa-cf48-4b34-a348-ed992bb66490','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:25:49',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4','145e1916-db5b-4baa-b2e0-d4a4af571da7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(173,'bc09c315-2fe6-4daa-8a3c-1cc2017941e9','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:25:49',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh','30720dfb-21ea-49b3-a244-ecd4aa95b259','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(174,'5b67976c-5823-4b3b-a358-8bd1e76e0dec','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:50',NULL,'CREATE','IN_PROGRESS','ServiceChain','cell1-NetworkerServiceChain-w6ts4csx6o2u-ServiceChain-6xglhovmy6e2','state changed','OS::Heat::ResourceChain',NULL,77),(175,'fe108476-6539-4208-ba02-c12ff2995582','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:50',NULL,'CREATE','IN_PROGRESS','NodeUserData','cell1-NodeUserData-xoh7kt5rl2id','state changed','OS::TripleO::NodeUserData',NULL,NULL),(176,'b823cc7e-5691-433c-8257-65e8de9479be','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:50',NULL,'CREATE','IN_PROGRESS','ServiceChain','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-ServiceChain-yrqnfvoq5arx','state changed','OS::Heat::ResourceChain',NULL,78),(177,'1415cda4-4fa8-461c-836c-3252d1664710','1a8dc641-365a-42c4-9969-7f9b2ccb777b','2026-06-12 08:25:50',NULL,'CREATE','IN_PROGRESS','cell1-NetworkerServiceChain-w6ts4csx6o2u-ServiceChain-6xglhovmy6e2','1a8dc641-365a-42c4-9969-7f9b2ccb777b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(178,'880fb9c6-382c-4998-ad40-c46771e89752','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:50',NULL,'CREATE','IN_PROGRESS','ServiceChain','cell1-ControllerServiceChain-zbda4x4z5on7-ServiceChain-ts3mt2mghstd','state changed','OS::Heat::ResourceChain',NULL,79),(179,'525e032b-2eb6-46d8-b8f2-19ce736ff769','16caa853-8215-4ecc-8d67-4f5607e32e5f','2026-06-12 08:25:50',NULL,'CREATE','IN_PROGRESS','cell1-NodeUserData-xoh7kt5rl2id','16caa853-8215-4ecc-8d67-4f5607e32e5f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(180,'a1b66c0a-0b75-4e28-9b6a-62d603525f02','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:50',NULL,'CREATE','COMPLETE','NodeTimesyncUserData','814fc223-61c1-48ef-b79e-01e4b51bb3b9','state changed','OS::TripleO::NodeTimesyncUserData',NULL,NULL),(181,'2b41ab90-b2b8-464d-bb94-b725935b30eb','347f4bf0-c9ef-44a0-ad6b-b10f6903de90','2026-06-12 08:25:50',NULL,'CREATE','IN_PROGRESS','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-ServiceChain-yrqnfvoq5arx','347f4bf0-c9ef-44a0-ad6b-b10f6903de90','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(182,'b9f32a82-ec41-45d5-a1aa-6f13c4547746','1a8dc641-365a-42c4-9969-7f9b2ccb777b','2026-06-12 08:25:50',NULL,'CREATE','COMPLETE','cell1-NetworkerServiceChain-w6ts4csx6o2u-ServiceChain-6xglhovmy6e2','1a8dc641-365a-42c4-9969-7f9b2ccb777b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(183,'305d732c-0eb4-4f17-a321-03b352993eca','f642a10e-aff6-40ed-b2aa-5e516979a5f5','2026-06-12 08:25:50',NULL,'CREATE','IN_PROGRESS','cell1-ControllerServiceChain-zbda4x4z5on7-ServiceChain-ts3mt2mghstd','f642a10e-aff6-40ed-b2aa-5e516979a5f5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(184,'52599907-c4a2-4d65-b196-129d5083d005','347f4bf0-c9ef-44a0-ad6b-b10f6903de90','2026-06-12 08:25:50',NULL,'CREATE','COMPLETE','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-ServiceChain-yrqnfvoq5arx','347f4bf0-c9ef-44a0-ad6b-b10f6903de90','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(185,'7b1c6bee-91e9-4dfd-a65a-cdd140396efb','f642a10e-aff6-40ed-b2aa-5e516979a5f5','2026-06-12 08:25:50',NULL,'CREATE','COMPLETE','cell1-ControllerServiceChain-zbda4x4z5on7-ServiceChain-ts3mt2mghstd','f642a10e-aff6-40ed-b2aa-5e516979a5f5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(186,'0eed89c4-0bca-4ea8-b5d2-bfb11b1bbad4','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:50',NULL,'CREATE','COMPLETE','ComputeRoleUserData','5bdeb4aa-f303-4207-9bd1-393ec399a46a','state changed','OS::TripleO::Compute::NodeUserData',NULL,NULL),(187,'ff067e36-83f4-4e6a-8b77-58c4d655f7ad','16caa853-8215-4ecc-8d67-4f5607e32e5f','2026-06-12 08:25:50',NULL,'CREATE','IN_PROGRESS','userdata','cell1-NodeUserData-xoh7kt5rl2id-userdata-g2eplmyxndtv','state changed','OS::Heat::MultipartMime',NULL,NULL),(188,'b88db3cb-54e6-4ca1-a4f8-2f5ca8ba9265','16caa853-8215-4ecc-8d67-4f5607e32e5f','2026-06-12 08:25:50',NULL,'CREATE','COMPLETE','userdata','a332562e-25f8-468e-a7ad-9d83337a46fb','state changed','OS::Heat::MultipartMime',NULL,NULL),(189,'514dd8cb-5cd9-4a22-b7c5-52354824f662','16caa853-8215-4ecc-8d67-4f5607e32e5f','2026-06-12 08:25:50',NULL,'CREATE','COMPLETE','cell1-NodeUserData-xoh7kt5rl2id','16caa853-8215-4ecc-8d67-4f5607e32e5f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(190,'d08a32c1-4b51-475d-b8e1-5ef8c31c551e','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:50',NULL,'CREATE','IN_PROGRESS','ServiceChain','cell1-CephStorageServiceChain-xqicw5xwvg6g-ServiceChain-umtorcvknj3r','state changed','OS::Heat::ResourceChain',NULL,82),(191,'e19aa08a-6d7b-497f-9f23-2e79915abb97','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:50',NULL,'CREATE','IN_PROGRESS','ServiceChain','cell1-CellControllerComputeServiceChain-aseidyipoyc3-ServiceChain-3be2rit7x5kg','state changed','OS::Heat::ResourceChain',NULL,83),(192,'b57f7ad2-3547-4e28-a968-4580ea39d817','15d31391-6e75-4ed9-9b47-9d77302c76a8','2026-06-12 08:25:50',NULL,'CREATE','IN_PROGRESS','cell1-CephStorageServiceChain-xqicw5xwvg6g-ServiceChain-umtorcvknj3r','15d31391-6e75-4ed9-9b47-9d77302c76a8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(193,'df58d213-08c1-4b13-8aa9-6d5b3b5fd14c','15d31391-6e75-4ed9-9b47-9d77302c76a8','2026-06-12 08:25:50',NULL,'CREATE','COMPLETE','cell1-CephStorageServiceChain-xqicw5xwvg6g-ServiceChain-umtorcvknj3r','15d31391-6e75-4ed9-9b47-9d77302c76a8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(194,'92a5cd20-89ac-4bbe-ad06-7b3ed55e80f7','9e55200a-9a50-4ae6-95bf-9517d3d7963d','2026-06-12 08:25:50',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerComputeServiceChain-aseidyipoyc3-ServiceChain-3be2rit7x5kg','9e55200a-9a50-4ae6-95bf-9517d3d7963d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(195,'2f64995d-bd45-4838-8a4a-5f444bee387e','9e55200a-9a50-4ae6-95bf-9517d3d7963d','2026-06-12 08:25:50',NULL,'CREATE','COMPLETE','cell1-CellControllerComputeServiceChain-aseidyipoyc3-ServiceChain-3be2rit7x5kg','9e55200a-9a50-4ae6-95bf-9517d3d7963d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(196,'23536a48-a40b-45dd-a1a5-8596f1a1ab98','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:51',NULL,'CREATE','IN_PROGRESS','ServiceChain','cell1-BlockStorageServiceChain-xb5mfp73j4eo-ServiceChain-rda6m5cgkdzf','state changed','OS::Heat::ResourceChain',NULL,84),(197,'0cb5b3cf-757a-4b63-8db8-92a769b9d11b','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:25:51',NULL,'CREATE','IN_PROGRESS','ServiceChain','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo','state changed','OS::Heat::ResourceChain',NULL,85),(198,'4c151c0e-8067-4e8c-89ca-389ab0977b03','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:51',NULL,'CREATE','COMPLETE','ServiceChain','1a8dc641-365a-42c4-9969-7f9b2ccb777b','state changed','OS::Heat::ResourceChain',NULL,77),(199,'e0919c22-a34d-4f82-b83f-2639f289bac3','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:51',NULL,'CREATE','COMPLETE','ServiceChain','347f4bf0-c9ef-44a0-ad6b-b10f6903de90','state changed','OS::Heat::ResourceChain',NULL,78),(200,'bcc11cd9-f5ff-4192-9432-612276fdd9b2','d3ee7ac5-da0c-4984-87b0-48b57f75707f','2026-06-12 08:25:51',NULL,'CREATE','IN_PROGRESS','cell1-BlockStorageServiceChain-xb5mfp73j4eo-ServiceChain-rda6m5cgkdzf','d3ee7ac5-da0c-4984-87b0-48b57f75707f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(201,'bc0878cf-c28f-4dc5-b7bb-394b5dbd8f68','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:51',NULL,'CREATE','COMPLETE','ServiceChain','f642a10e-aff6-40ed-b2aa-5e516979a5f5','state changed','OS::Heat::ResourceChain',NULL,79),(202,'d11ec221-8567-489e-8d26-4e5cc0f85a44','d3ee7ac5-da0c-4984-87b0-48b57f75707f','2026-06-12 08:25:51',NULL,'CREATE','COMPLETE','cell1-BlockStorageServiceChain-xb5mfp73j4eo-ServiceChain-rda6m5cgkdzf','d3ee7ac5-da0c-4984-87b0-48b57f75707f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(203,'3e227382-22e8-402e-a9d2-60a1e1b254dc','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:51',NULL,'CREATE','COMPLETE','ServiceChain','d3ee7ac5-da0c-4984-87b0-48b57f75707f','state changed','OS::Heat::ResourceChain',NULL,84),(204,'ad575b9b-dc99-4a9c-b449-a7e71f136160','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:51',NULL,'CREATE','COMPLETE','NodeUserData','16caa853-8215-4ecc-8d67-4f5607e32e5f','state changed','OS::TripleO::NodeUserData',NULL,NULL),(205,'8b0732e0-31fb-4785-a81c-a0452374a6a1','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:25:51',NULL,'CREATE','IN_PROGRESS','ServiceChain','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt','state changed','OS::Heat::ResourceChain',NULL,86),(206,'6ed626e0-fe9b-401b-834b-c93919517d67','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:51',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','cell1-ControllerServiceChain-zbda4x4z5on7-ContainerPuppetTasks-wup2yfw7iztv','state changed','OS::Heat::Value',NULL,88),(207,'cc412c5a-d5c8-4549-89a8-cd13bb88fd92','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:51',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','cell1-ControllerServiceChain-zbda4x4z5on7-ContainerPuppetTasks-wup2yfw7iztv','state changed','OS::Heat::Value',NULL,88),(208,'a9dbc638-d008-4ac0-a3aa-0136e6e587b6','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:51',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','cell1-NetworkerServiceChain-w6ts4csx6o2u-PreDeployStepTasks-ej7ywhj72r5s','state changed','OS::Heat::Value',NULL,89),(209,'3369a5d7-936e-4530-844b-6d9866792c6e','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:51',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','cell1-NetworkerServiceChain-w6ts4csx6o2u-ServiceConfigSettings-4ayvxf7f5fyd','state changed','OS::Heat::Value',NULL,90),(210,'e3fab10c-4db2-4162-a4fd-cbbb76ea205e','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:51',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','cell1-ControllerServiceChain-zbda4x4z5on7-ServiceServerMetadataHook-ciyttq3szkgj','state changed','OS::TripleO::ControllerServiceServerMetadataHook',NULL,NULL),(211,'e9502e06-6cd8-4a10-910c-1399796349aa','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:51',NULL,'CREATE','IN_PROGRESS','ServiceNames','cell1-ControllerServiceChain-zbda4x4z5on7-ServiceNames-rxsnnlaixk5i','state changed','OS::Heat::Value',NULL,87),(212,'3d3f3762-4c19-4310-9240-b11e44ed08f9','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:51',NULL,'CREATE','IN_PROGRESS','ComputeUserData','cell1-ComputeUserData-wkw72ydsw35h','state changed','OS::Heat::MultipartMime',NULL,91),(213,'ffde1ba4-a8fd-4955-b69e-1b27bfd32b0b','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:51',NULL,'CREATE','IN_PROGRESS','ObjectStorageUserData','cell1-ObjectStorageUserData-6o2ldz7dlijz','state changed','OS::Heat::MultipartMime',NULL,92),(214,'ff6fc5bf-58b1-49b2-8623-d0d5dff7fd8c','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:51',NULL,'CREATE','COMPLETE','PreDeployStepTasks','cell1-NetworkerServiceChain-w6ts4csx6o2u-PreDeployStepTasks-ej7ywhj72r5s','state changed','OS::Heat::Value',NULL,89),(215,'08ca84dc-0b02-4073-bdfd-493c342625dc','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:51',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','cell1-NetworkerServiceChain-w6ts4csx6o2u-DockerPuppetTasks-sou7urondmb5','state changed','OS::Heat::Value',NULL,93),(216,'c93c894c-98ea-4afa-9f84-7d608cdebaf4','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:51',NULL,'CREATE','IN_PROGRESS','UpdateTasks','cell1-ControllerServiceChain-zbda4x4z5on7-UpdateTasks-b7q3nkhv6r3t','state changed','OS::Heat::Value',NULL,96),(217,'b61bd87c-d3b0-4b79-8f01-248260128ad4','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:51',NULL,'CREATE','COMPLETE','DockerPuppetTasks','cell1-NetworkerServiceChain-w6ts4csx6o2u-DockerPuppetTasks-sou7urondmb5','state changed','OS::Heat::Value',NULL,93),(218,'ed285fd3-9576-4f87-baad-998ccbf731ba','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:51',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','cell1-ControllerServiceChain-zbda4x4z5on7-MonitoringSubscriptionsConfig-ozyqbbs4blub','state changed','OS::Heat::Value',NULL,95),(219,'20c4d34b-a9ff-47cb-be89-40ad090f608e','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:51',NULL,'CREATE','IN_PROGRESS','PuppetConfig','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-PuppetConfig-xc4doxex75k2','state changed','OS::Heat::Value',NULL,98),(220,'649de3f4-6085-413b-9cc4-720df6dfa00f','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:51',NULL,'CREATE','COMPLETE','ServiceChain','15d31391-6e75-4ed9-9b47-9d77302c76a8','state changed','OS::Heat::ResourceChain',NULL,82),(221,'1e8b49de-4a7f-4053-8666-b61d09892499','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:51',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','cell1-BlockStorageServiceChain-xb5mfp73j4eo-ExternalPostDeployTasks-t4s5ev7juvnc','state changed','OS::Heat::Value',NULL,94),(222,'21000cb3-b567-47cb-ae67-86397a5b7b27','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:51',NULL,'CREATE','COMPLETE','ServiceNames','cell1-ControllerServiceChain-zbda4x4z5on7-ServiceNames-rxsnnlaixk5i','state changed','OS::Heat::Value',NULL,87),(223,'b0192224-bdf8-466a-899e-6dc567e519ac','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:51',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-AnsibleGroupVars-bq2qtg6mqutk','state changed','OS::Heat::Value',NULL,97),(224,'64c9b786-41ce-4193-827b-5979eec2b0e0','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:51',NULL,'CREATE','COMPLETE','UpdateTasks','cell1-ControllerServiceChain-zbda4x4z5on7-UpdateTasks-b7q3nkhv6r3t','state changed','OS::Heat::Value',NULL,96),(225,'79df936a-44a9-4cf0-8ec4-23c0f6685de1','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:51',NULL,'CREATE','IN_PROGRESS','CellControllerComputeUserData','cell1-CellControllerComputeUserData-e2jb6b5kcmu3','state changed','OS::Heat::MultipartMime',NULL,100),(226,'8c662c62-ebf4-4803-9b1a-6b7c2af2189e','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:51',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','cell1-ControllerServiceChain-zbda4x4z5on7-PuppetStepConfig-r3f6blkyokb4','state changed','OS::Heat::Value',NULL,103),(227,'cdfd1b91-ffa9-4b16-b396-32dcb72838dc','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:51',NULL,'CREATE','COMPLETE','ServiceConfigSettings','cell1-NetworkerServiceChain-w6ts4csx6o2u-ServiceConfigSettings-4ayvxf7f5fyd','state changed','OS::Heat::Value',NULL,90),(228,'763f6b6d-2be6-49f3-bfd0-3fd49c77d89f','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','PuppetStepConfig','cell1-ControllerServiceChain-zbda4x4z5on7-PuppetStepConfig-r3f6blkyokb4','state changed','OS::Heat::Value',NULL,103),(229,'1b7dfcba-1733-480b-a24f-7e7b32a9bc77','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','cell1-NetworkerServiceChain-w6ts4csx6o2u-PostUpgradeTasks-vd3sc5eaz3ch','state changed','OS::Heat::Value',NULL,106),(230,'3cddec0c-0430-4302-a86c-ab59d925f170','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','cell1-BlockStorageServiceChain-xb5mfp73j4eo-HostFirewallTasks-z4kyaryu5txs','state changed','OS::Heat::Value',NULL,104),(231,'f23755f1-898b-4cca-9db3-1befcf9b220d','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','PuppetConfig','cell1-BlockStorageServiceChain-xb5mfp73j4eo-PuppetConfig-pdel7bghwpij','state changed','OS::Heat::Value',NULL,101),(232,'ac454dee-a3ba-400a-84b4-ec7925b1d7bd','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','cell1-NetworkerServiceChain-w6ts4csx6o2u-KeystoneResourcesConfigs-gbtlo5vxhhgk','state changed','OS::Heat::Value',NULL,108),(233,'0bb0024f-8ace-452b-b1bd-dc4f21332e4f','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','c1f1b2f6-ae73-45b2-9e56-eaf93f3898d3','state changed','OS::TripleO::ControllerServiceServerMetadataHook',NULL,NULL),(234,'d8a5fc84-6dc4-45f6-8f8a-2adf7cc0e338','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','cell1-NetworkerServiceChain-w6ts4csx6o2u-DeployStepsTasks-7wdjvnizmv3f','state changed','OS::Heat::Value',NULL,107),(235,'1c18a79d-7d82-4eb9-b748-6e41a87cd5d6','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','cell1-NetworkerServiceChain-w6ts4csx6o2u-KeystoneResourcesConfigs-gbtlo5vxhhgk','state changed','OS::Heat::Value',NULL,108),(236,'20481bc2-63e9-4277-afd6-230ba90fbd0f','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','ControllerUserData','cell1-ControllerUserData-gsjwsk67rztj','state changed','OS::Heat::MultipartMime',NULL,102),(237,'3d287381-8a8d-4e4a-98c9-573b35aa6ad5','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','CellControllerUserData','cell1-CellControllerUserData-zks247xnqg2b','state changed','OS::Heat::MultipartMime',NULL,99),(238,'bea785b9-645f-4aa9-8d23-bcefc0a6e8d7','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','CephStorageUserData','cell1-CephStorageUserData-wijaolacn5gb','state changed','OS::Heat::MultipartMime',NULL,109),(239,'7ed74396-c00b-480e-9276-ff18c42ea96d','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','cell1-ControllerServiceChain-zbda4x4z5on7-MonitoringSubscriptionsConfig-ozyqbbs4blub','state changed','OS::Heat::Value',NULL,95),(240,'8f74e998-c7da-4bf0-8357-ddbbfed5813a','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','HostFirewallTasks','cell1-BlockStorageServiceChain-xb5mfp73j4eo-HostFirewallTasks-z4kyaryu5txs','state changed','OS::Heat::Value',NULL,104),(241,'172d70d9-dac9-45a7-9300-6a7dab9e5959','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','PostUpgradeTasks','cell1-NetworkerServiceChain-w6ts4csx6o2u-PostUpgradeTasks-vd3sc5eaz3ch','state changed','OS::Heat::Value',NULL,106),(242,'24ff5ff9-bd1e-443e-a8b3-efebff15fa24','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt','a465b367-1cd1-49f7-9936-052ba909fd04','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(243,'b9a9964b-47ee-46f5-9ff7-9dfa3d931006','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','PuppetConfig','cell1-BlockStorageServiceChain-xb5mfp73j4eo-PuppetConfig-pdel7bghwpij','state changed','OS::Heat::Value',NULL,101),(244,'743c7d9b-283a-4059-b4a1-b12ab0d4b198','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','DockerConfig','cell1-ControllerServiceChain-zbda4x4z5on7-DockerConfig-peu2ow5rv2tm','state changed','OS::Heat::Value',NULL,111),(245,'952b4323-4367-4352-a4f2-85688ce86065','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','DeployStepsTasks','cell1-NetworkerServiceChain-w6ts4csx6o2u-DeployStepsTasks-7wdjvnizmv3f','state changed','OS::Heat::Value',NULL,107),(246,'68f911d1-04db-4e7e-9941-2249d090e817','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','UpdateTasks','cell1-NetworkerServiceChain-w6ts4csx6o2u-UpdateTasks-4fr3fau337as','state changed','OS::Heat::Value',NULL,112),(247,'2b9a1616-9f08-4552-9d20-42c2b84e805c','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','ServiceChain','9e55200a-9a50-4ae6-95bf-9517d3d7963d','state changed','OS::Heat::ResourceChain',NULL,83),(248,'ac420bee-4221-4cf3-a300-a13522369168','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','BlockStorageUserData','cell1-BlockStorageUserData-rcm7u5fa73ha','state changed','OS::Heat::MultipartMime',NULL,110),(249,'d75fb25e-9d0c-462e-a16d-bb92dfe5e249','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','CellControllerComputeUserData','9fb16131-79c8-4342-b300-7905233f7a70','state changed','OS::Heat::MultipartMime',NULL,100),(250,'3386f34b-5359-4546-88c1-55de49f863ec','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','UpdateTasks','cell1-NetworkerServiceChain-w6ts4csx6o2u-UpdateTasks-4fr3fau337as','state changed','OS::Heat::Value',NULL,112),(251,'5fcffadb-8c2b-4647-ac90-78bd09ab6f63','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','PuppetConfig','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-PuppetConfig-xc4doxex75k2','state changed','OS::Heat::Value',NULL,98),(252,'bf9a87c9-06b9-4da0-bd87-5b4622dc55ce','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','cell1-BlockStorageServiceChain-xb5mfp73j4eo-ExternalPostDeployTasks-t4s5ev7juvnc','state changed','OS::Heat::Value',NULL,94),(253,'04fc5e60-b517-447b-8b9a-eab17bcf8632','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','AnsibleGroupVars','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-AnsibleGroupVars-bq2qtg6mqutk','state changed','OS::Heat::Value',NULL,97),(254,'27adc288-fcd8-4d23-9b0c-a569af54afbb','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-ServiceConfigSettings-wvisjdya5muy','state changed','OS::Heat::Value',NULL,113),(255,'8627ff64-9c1c-454b-88da-e573bd814d59','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','cell1-NetworkerServiceChain-w6ts4csx6o2u-UpgradeTasks-lpeu6mf67mby','state changed','OS::Heat::Value',NULL,118),(256,'fc6ae4df-e66b-4e0e-b31b-df1f1a78c7f3','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','KollaConfig','cell1-BlockStorageServiceChain-xb5mfp73j4eo-KollaConfig-rmhvulydzvph','state changed','OS::Heat::Value',NULL,114),(257,'e26508b5-82e4-44df-b93e-cab5cb1772b6','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','UpgradeTasks','cell1-NetworkerServiceChain-w6ts4csx6o2u-UpgradeTasks-lpeu6mf67mby','state changed','OS::Heat::Value',NULL,118),(258,'ac6add28-edae-402b-8601-99cff2c4820e','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','FirewallRules','cell1-NetworkerServiceChain-w6ts4csx6o2u-FirewallRules-yjh6kvjdcapz','state changed','OS::Heat::Value',NULL,115),(259,'aafa8830-776a-4fb4-9900-464046094ceb','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','ServiceNames','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-ServiceNames-4qtd57julec5','state changed','OS::Heat::Value',NULL,120),(260,'55cbda5c-8b94-49bd-b0ec-fd4226db4185','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','cell1-NetworkerServiceChain-w6ts4csx6o2u-FirewallFrontendRules-sz5dmelkzrar','state changed','OS::Heat::Value',NULL,116),(261,'56313865-76ee-4a6e-81ae-ba15b5476009','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-ServiceServerMetadataHook-xmwwsavgc2vz','state changed','OS::TripleO::ObjectStorageServiceServerMetadataHook',NULL,NULL),(262,'a2eaac0b-2d2e-4a89-9a0f-ef1cbfe6818a','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo','2a198607-a616-42e1-bc58-6127fed18088','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(263,'1dd871b0-1c1c-4a27-bda5-c75bdd2c27fd','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','cell1-CephStorageServiceChain-xqicw5xwvg6g-ExternalUpdateTasks-saq3biugmsv4','state changed','OS::Heat::Value',NULL,119),(264,'ad49aaa5-8ff1-4b90-b8e6-fe5ee1650950','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','ComputeUserData','e6c7f922-11d5-4ad5-b28d-5383f2775679','state changed','OS::Heat::MultipartMime',NULL,91),(265,'fd436e0c-28ef-44b1-b918-32c6b5162900','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','ServiceNames','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-ServiceNames-4qtd57julec5','state changed','OS::Heat::Value',NULL,120),(266,'d70953f0-1ef7-439e-803e-73e771f652ea','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','NetworkerUserData','cell1-NetworkerUserData-a6j32vawke4g','state changed','OS::Heat::MultipartMime',NULL,117),(267,'d29b438f-0872-44c0-bb33-86602fda070c','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','DockerConfig','cell1-ControllerServiceChain-zbda4x4z5on7-DockerConfig-peu2ow5rv2tm','state changed','OS::Heat::Value',NULL,111),(268,'ce63f282-7b83-42ac-90fe-712322c3a730','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','ScaleTasks','cell1-ControllerServiceChain-zbda4x4z5on7-ScaleTasks-7izouwq2wfz3','state changed','OS::Heat::Value',NULL,121),(269,'0cd7c4a5-a957-4bb3-8e5d-5f43f6a572fa','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','ServiceConfigSettings','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-ServiceConfigSettings-wvisjdya5muy','state changed','OS::Heat::Value',NULL,113),(270,'bf4b01a5-3d40-4849-adf3-f191df869b84','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','ObjectStorageUserData','31f8fa8d-bf43-41a5-a22a-61fc16c8f882','state changed','OS::Heat::MultipartMime',NULL,92),(271,'24c68ed4-4c94-4156-b46e-7d70e91af718','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','cell1-CephStorageServiceChain-xqicw5xwvg6g-IpaRegistrationTasks-pdfih5qneafw','state changed','OS::Heat::Value',NULL,123),(272,'ba33c824-bf4a-47d2-890f-94a4c5eb27f2','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','cell1-CellControllerComputeServiceChain-aseidyipoyc3-ExternalPostDeployTasks-tz6uto6ti5zm','state changed','OS::Heat::Value',NULL,125),(273,'5fcb6b7c-7afc-4448-a694-e3575ad78e14','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','cell1-CellControllerComputeServiceChain-aseidyipoyc3-ExternalPostDeployTasks-tz6uto6ti5zm','state changed','OS::Heat::Value',NULL,125),(274,'a5102919-8382-415e-9e7f-7fe48f30ba18','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','KollaConfig','cell1-BlockStorageServiceChain-xb5mfp73j4eo-KollaConfig-rmhvulydzvph','state changed','OS::Heat::Value',NULL,114),(275,'7bc676c1-46dc-465c-87ad-34680835dc55','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-PreDeployStepTasks-ntppmleqcoed','state changed','OS::Heat::Value',NULL,122),(276,'d86c0e06-78dd-442d-a8aa-3b9ad6ee1149','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','cell1-CephStorageServiceChain-xqicw5xwvg6g-FirewallFrontendRules-gu5qzijwurtd','state changed','OS::Heat::Value',NULL,128),(277,'c6d67388-0e72-4f92-ac47-16f010b5c501','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','FirewallRules','cell1-NetworkerServiceChain-w6ts4csx6o2u-FirewallRules-yjh6kvjdcapz','state changed','OS::Heat::Value',NULL,115),(278,'1e1c8ba5-faee-40a3-826e-3a87cb3590fc','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','cell1-NetworkerServiceChain-w6ts4csx6o2u-ExternalPostDeployTasks-hepwvq6qm5qw','state changed','OS::Heat::Value',NULL,126),(279,'5e0ef347-8131-470b-b62e-de6046a5b890','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','FirewallFrontendRules','cell1-NetworkerServiceChain-w6ts4csx6o2u-FirewallFrontendRules-sz5dmelkzrar','state changed','OS::Heat::Value',NULL,116),(280,'6666d794-2c3f-44b7-898d-11157bdc4ad4','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','FirewallRules','cell1-BlockStorageServiceChain-xb5mfp73j4eo-FirewallRules-63g6p3lsjq66','state changed','OS::Heat::Value',NULL,124),(281,'ae47663f-1e07-42b4-b633-615c59e901aa','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','cell1-CephStorageServiceChain-xqicw5xwvg6g-ExternalUpdateTasks-saq3biugmsv4','state changed','OS::Heat::Value',NULL,119),(282,'ead8427a-f8e3-42b2-b419-62dd3adb3365','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','FirewallFrontendRules','cell1-CephStorageServiceChain-xqicw5xwvg6g-FirewallFrontendRules-gu5qzijwurtd','state changed','OS::Heat::Value',NULL,128),(283,'ec2665ba-bf9c-4b7d-97d0-d4ddbe9d83b9','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-HostFirewallTasks-a6suutxd7v4n','state changed','OS::Heat::Value',NULL,127),(284,'c7f914e9-3db1-4f2d-b30d-cabeaa03b6e2','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','cell1-CephStorageServiceChain-xqicw5xwvg6g-IpaRegistrationTasks-pdfih5qneafw','state changed','OS::Heat::Value',NULL,123),(285,'78e06128-1ae8-42a2-8f9a-3634e0685c96','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','cell1-BlockStorageServiceChain-xb5mfp73j4eo-ExternalUpdateTasks-33h6nlxxzznp','state changed','OS::Heat::Value',NULL,129),(286,'55972c3b-3000-41c0-b683-506513403deb','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','PuppetConfig','cell1-CephStorageServiceChain-xqicw5xwvg6g-PuppetConfig-rz7eqtqov3ie','state changed','OS::Heat::Value',NULL,132),(287,'56cb2d63-5395-4d72-bab2-54466e282b14','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','CephStorageUserData','cc0153a5-92ca-483a-9913-47644b63fa8c','state changed','OS::Heat::MultipartMime',NULL,109),(288,'425738c6-4173-4414-a859-d257ca8f672a','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','ScaleTasks','cell1-ControllerServiceChain-zbda4x4z5on7-ScaleTasks-7izouwq2wfz3','state changed','OS::Heat::Value',NULL,121),(289,'8f3487bc-c135-4fa5-b6c6-e042be5aa4c8','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','cell1-NetworkerServiceChain-w6ts4csx6o2u-ExternalPostDeployTasks-hepwvq6qm5qw','state changed','OS::Heat::Value',NULL,126),(290,'dc1ce27a-5be8-4d95-9d13-b3cd2f76dcba','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','cell1-CellControllerComputeServiceChain-aseidyipoyc3-UpgradeBatchTasks-26yyfljwrdka','state changed','OS::Heat::Value',NULL,133),(291,'cb31d365-9221-4212-8ad9-a25efcd47fe3','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','PuppetConfig','cell1-NetworkerServiceChain-w6ts4csx6o2u-PuppetConfig-r36b7mbecm6z','state changed','OS::Heat::Value',NULL,131),(292,'9e844a19-1e19-490e-8a37-04bed71a38ff','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','cell1-NetworkerServiceChain-w6ts4csx6o2u-DockerConfigScripts-nbvelo7vf7ba','state changed','OS::Heat::Value',NULL,135),(293,'fcd17837-c994-41a9-b3fe-408d4ac0fc89','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','PuppetConfig','cell1-CephStorageServiceChain-xqicw5xwvg6g-PuppetConfig-rz7eqtqov3ie','state changed','OS::Heat::Value',NULL,132),(294,'fc6587dc-054d-49f6-879c-ea55f0455937','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','cell1-CephStorageServiceChain-xqicw5xwvg6g-ExternalUpgradeTasks-wg7vsqwf7hqr','state changed','OS::Heat::Value',NULL,130),(295,'d8a43601-de06-48b0-ab2c-9cf521871d59','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','CellControllerUserData','143aaca9-8b31-4027-a27f-38df24607525','state changed','OS::Heat::MultipartMime',NULL,99),(296,'d7b486a3-4f90-4bc4-9521-2984b2bc6ea1','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','DockerConfigScripts','cell1-NetworkerServiceChain-w6ts4csx6o2u-DockerConfigScripts-nbvelo7vf7ba','state changed','OS::Heat::Value',NULL,135),(297,'c9f1fce3-d7c8-43b5-895a-23674a319ac0','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','cell1-CephStorageServiceChain-xqicw5xwvg6g-UpgradeBatchTasks-m3wexq33q5xj','state changed','OS::Heat::Value',NULL,139),(298,'cb26bf7c-a0a7-4dce-be61-91dfa1104393','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','5215d090-78b0-4aca-8182-91d2c3c97a6b','state changed','OS::TripleO::ObjectStorageServiceServerMetadataHook',NULL,NULL),(299,'607ab04b-395d-42a8-bc99-afa125215a63','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','cell1-BlockStorageServiceChain-xb5mfp73j4eo-PreUpgradeRollingTasks-trwtajcpdyf3','state changed','OS::Heat::Value',NULL,137),(300,'77350f0b-c46f-4617-9999-54d6bfc8aa98','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','cell1-CephStorageServiceChain-xqicw5xwvg6g-UpgradeBatchTasks-m3wexq33q5xj','state changed','OS::Heat::Value',NULL,139),(301,'ac7f7b91-8d91-4ce1-8c1a-90ab0aff9403','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','cell1-CephStorageServiceChain-xqicw5xwvg6g-DockerPuppetTasks-aaex2cpki5sd','state changed','OS::Heat::Value',NULL,140),(302,'c9d8160f-78f1-427b-9976-db584b6193c1','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','cell1-BlockStorageServiceChain-xb5mfp73j4eo-ExternalUpdateTasks-33h6nlxxzznp','state changed','OS::Heat::Value',NULL,129),(303,'456cd81b-18ae-4dca-aff3-6d2de901acfe','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','KollaConfig','cell1-ControllerServiceChain-zbda4x4z5on7-KollaConfig-t4xyn6i6gq3k','state changed','OS::Heat::Value',NULL,134),(304,'f4d01c30-8070-4315-b1d5-e6d0ed15e908','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','cell1-CellControllerComputeServiceChain-aseidyipoyc3-UpgradeBatchTasks-26yyfljwrdka','state changed','OS::Heat::Value',NULL,133),(305,'9573af6a-66cd-4ad8-8ce3-ffb7b18e7e15','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','PreDeployStepTasks','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-PreDeployStepTasks-ntppmleqcoed','state changed','OS::Heat::Value',NULL,122),(306,'4f1bf354-788c-44a4-9ba3-5b598dd308d7','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','cell1-CephStorageServiceChain-xqicw5xwvg6g-GlobalConfigSettings-jnohbbiqq6tf','state changed','OS::Heat::Value',NULL,144),(307,'468e0057-059b-4511-a3be-d577ba11ea01','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','KollaConfig','cell1-NetworkerServiceChain-w6ts4csx6o2u-KollaConfig-kohnhsr7hwpf','state changed','OS::Heat::Value',NULL,138),(308,'f1a7cf26-5b40-48a1-8d0d-f616191fa195','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','cell1-CellControllerComputeServiceChain-aseidyipoyc3-ExternalUpdateTasks-cuzqtb4ooup5','state changed','OS::Heat::Value',NULL,141),(309,'a3591ffa-bafa-4fa0-9018-91a68a2799b3','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','FirewallRules','cell1-BlockStorageServiceChain-xb5mfp73j4eo-FirewallRules-63g6p3lsjq66','state changed','OS::Heat::Value',NULL,124),(310,'d76185cf-726a-4c4a-82ed-d73b4a80cad8','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-PostUpgradeTasks-jiex2o7xl3x3','state changed','OS::Heat::Value',NULL,136),(311,'0dc402a6-c816-4dc5-9988-cff7deba5ae0','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','BlockStorageUserData','b3ca0023-b8d9-4644-ace7-7e45825a3fd8','state changed','OS::Heat::MultipartMime',NULL,110),(312,'9009c949-f778-4c00-9b30-34aec22b0850','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','GlobalConfigSettings','cell1-CephStorageServiceChain-xqicw5xwvg6g-GlobalConfigSettings-jnohbbiqq6tf','state changed','OS::Heat::Value',NULL,144),(313,'558ac870-0eaf-4d1e-b824-fe41cc53dc65','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','cell1-CephStorageServiceChain-xqicw5xwvg6g-DockerConfigScripts-3rqui6bjqenw','state changed','OS::Heat::Value',NULL,146),(314,'755d644e-eb6a-47a1-81cc-136a433c179a','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','cell1-CellControllerComputeServiceChain-aseidyipoyc3-ExternalUpgradeTasks-7ow7mh2cfhqe','state changed','OS::Heat::Value',NULL,143),(315,'8e99cb29-c2df-413c-8fa7-15179540651f','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','DockerConfigScripts','cell1-CephStorageServiceChain-xqicw5xwvg6g-DockerConfigScripts-3rqui6bjqenw','state changed','OS::Heat::Value',NULL,146),(316,'204e3e83-9708-4420-a7cd-4faddbdeb102','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','HostFirewallTasks','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-HostFirewallTasks-a6suutxd7v4n','state changed','OS::Heat::Value',NULL,127),(317,'e5309bd3-4096-4e00-9527-4d5d52c6112a','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','cell1-BlockStorageServiceChain-xb5mfp73j4eo-PreUpgradeRollingTasks-trwtajcpdyf3','state changed','OS::Heat::Value',NULL,137),(318,'878a5b3b-4e1c-459d-93a3-282992430651','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','DockerPuppetTasks','cell1-CephStorageServiceChain-xqicw5xwvg6g-DockerPuppetTasks-aaex2cpki5sd','state changed','OS::Heat::Value',NULL,140),(319,'5f54bb3f-b838-4a08-8068-44234ab7eb29','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','cell1-CephStorageServiceChain-xqicw5xwvg6g-ExternalUpgradeTasks-wg7vsqwf7hqr','state changed','OS::Heat::Value',NULL,130),(320,'3420fd00-5a7c-4e22-8ab0-85563ac066f5','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','cell1-BlockStorageServiceChain-xb5mfp73j4eo-KeystoneResourcesConfigs-djo2u4pczsch','state changed','OS::Heat::Value',NULL,148),(321,'ae3aeab9-62fb-4410-beec-368619ebdd9a','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','cell1-NetworkerServiceChain-w6ts4csx6o2u-ContainerPuppetTasks-ckpueveul4fb','state changed','OS::Heat::Value',NULL,151),(322,'994aaf4d-92da-47b5-950e-ee74d1781681','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','cell1-NetworkerServiceChain-w6ts4csx6o2u-PuppetStepConfig-r2vzisu2blgl','state changed','OS::Heat::Value',NULL,147),(323,'a80fbfa0-6e78-479f-afb9-b1fe3c7555be','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','cell1-NetworkerServiceChain-w6ts4csx6o2u-PostUpdateTasks-dtaqsq3smfqn','state changed','OS::Heat::Value',NULL,149),(324,'6d62fb40-e494-4537-8c9a-1d6bb7d1cb50','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','cell1-NetworkerServiceChain-w6ts4csx6o2u-ContainerPuppetTasks-ckpueveul4fb','state changed','OS::Heat::Value',NULL,151),(325,'3cfada85-783c-4b9c-a72d-a3a0742d1c61','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','KollaConfig','cell1-ControllerServiceChain-zbda4x4z5on7-KollaConfig-t4xyn6i6gq3k','state changed','OS::Heat::Value',NULL,134),(326,'28da6be7-f611-4ca4-be87-02b0161c66ab','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','KollaConfig','cell1-NetworkerServiceChain-w6ts4csx6o2u-KollaConfig-kohnhsr7hwpf','state changed','OS::Heat::Value',NULL,138),(327,'1b867359-d0e0-4cbd-aa22-d55e4f6bd174','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','cell1-ControllerServiceChain-zbda4x4z5on7-ServiceConfigSettings-qw2ndyvpqc3p','state changed','OS::Heat::Value',NULL,150),(328,'0a8f5013-e22f-469f-b653-013f14252b53','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','cell1-CellControllerComputeServiceChain-aseidyipoyc3-ExternalUpdateTasks-cuzqtb4ooup5','state changed','OS::Heat::Value',NULL,141),(329,'c6e16f5d-ed16-48c1-a45c-01b9e21d6af4','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-UpgradeBatchTasks-q2tiyko6lyw5','state changed','OS::Heat::Value',NULL,142),(330,'61d8f40f-a687-445c-99cf-35a22ba6a2e0','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','cell1-ControllerServiceChain-zbda4x4z5on7-AnsibleGroupVars-q4mijmecypf7','state changed','OS::Heat::Value',NULL,145),(331,'0167ffce-3dd7-4c0c-8dab-c8d84d7fd935','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:52',NULL,'CREATE','COMPLETE','NetworkerUserData','552179ed-299f-444c-9a74-d5624bafad92','state changed','OS::Heat::MultipartMime',NULL,117),(332,'312391f9-8292-415d-8646-088e9ea46525','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','cell1-NetworkerServiceChain-w6ts4csx6o2u-GlobalConfigSettings-pmd2kgzcfpi7','state changed','OS::Heat::Value',NULL,153),(333,'5e27879e-bab6-4b3c-b397-185a21375a09','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:52',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','cell1-NetworkerServiceChain-w6ts4csx6o2u-MonitoringSubscriptionsConfig-fm7pcnxkmujs','state changed','OS::Heat::Value',NULL,156),(334,'9a60e883-129a-4ca8-9e9b-aec2760ad90a','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','cell1-NetworkerServiceChain-w6ts4csx6o2u-MonitoringSubscriptionsConfig-fm7pcnxkmujs','state changed','OS::Heat::Value',NULL,156),(335,'524ab4a4-24bd-4f45-b44f-b55ec4c926db','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','cell1-BlockStorageServiceChain-xb5mfp73j4eo-KeystoneResourcesConfigs-djo2u4pczsch','state changed','OS::Heat::Value',NULL,148),(336,'ad2d3a9b-85a0-4ca3-a03e-03555c3ba9ad','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','DockerConfig','cell1-NetworkerServiceChain-w6ts4csx6o2u-DockerConfig-fozv5qwgtkkf','state changed','OS::Heat::Value',NULL,157),(337,'03e7c925-b074-425e-9d23-27cc74bf622c','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','cell1-ControllerServiceChain-zbda4x4z5on7-KeystoneResourcesConfigs-pw7bnpo2alvz','state changed','OS::Heat::Value',NULL,152),(338,'f5c3ff32-b82f-42d0-a790-9082fc59b4d2','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','DockerConfig','cell1-NetworkerServiceChain-w6ts4csx6o2u-DockerConfig-fozv5qwgtkkf','state changed','OS::Heat::Value',NULL,157),(339,'b90a697b-f0fd-43c5-9d42-3de6aceb49a9','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','cell1-CellControllerComputeServiceChain-aseidyipoyc3-ExternalUpgradeTasks-7ow7mh2cfhqe','state changed','OS::Heat::Value',NULL,143),(340,'a90fd8ff-57ff-434d-9432-d78682fcfc72','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','PuppetConfig','cell1-NetworkerServiceChain-w6ts4csx6o2u-PuppetConfig-r36b7mbecm6z','state changed','OS::Heat::Value',NULL,131),(341,'268e620f-9b81-42d5-a2b7-8c81d5eec83b','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-ExternalUpdateTasks-knnwomjmf5vm','state changed','OS::Heat::Value',NULL,155),(342,'b11e73a7-7abe-40f2-afb3-5de260acc3f4','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','cell1-BlockStorageServiceChain-xb5mfp73j4eo-IpaRegistrationTasks-5drq5hmdpdbm','state changed','OS::Heat::Value',NULL,154),(343,'12c4708b-7766-4422-8f18-f0aa04d80aac','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','ServiceConfigSettings','cell1-ControllerServiceChain-zbda4x4z5on7-ServiceConfigSettings-qw2ndyvpqc3p','state changed','OS::Heat::Value',NULL,150),(344,'0a6023ba-9b2c-4dc3-9964-1b48f7979baf','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','cell1-CephStorageServiceChain-xqicw5xwvg6g-ExternalPostDeployTasks-y7e3n4vxswgm','state changed','OS::Heat::Value',NULL,158),(345,'00ab1373-96ec-4975-8e55-4620bea24a1c','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','UpdateTasks','cell1-CephStorageServiceChain-xqicw5xwvg6g-UpdateTasks-2galvfzw2qz7','state changed','OS::Heat::Value',NULL,159),(346,'d96e3f76-4a9e-4b6f-9370-0df656e817a5','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','ServiceNames','cell1-NetworkerServiceChain-w6ts4csx6o2u-ServiceNames-ijbspbtasodp','state changed','OS::Heat::Value',NULL,165),(347,'b75e60ae-32a7-4839-87e4-242609ee6678','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','PostUpgradeTasks','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-PostUpgradeTasks-jiex2o7xl3x3','state changed','OS::Heat::Value',NULL,136),(348,'0ee8f070-557e-43c1-8dd6-093616b012ab','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','cell1-CellControllerComputeServiceChain-aseidyipoyc3-DockerConfigScripts-mjqqpgqste6n','state changed','OS::Heat::Value',NULL,162),(349,'cb07d950-99d6-4acd-9e40-3135802c6bb5','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','cell1-BlockStorageServiceChain-xb5mfp73j4eo-PreDeployStepTasks-tge6rh7srgqq','state changed','OS::Heat::Value',NULL,161),(350,'3b3f5051-e398-488f-9cfe-fe89ca4aa047','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','PuppetStepConfig','cell1-NetworkerServiceChain-w6ts4csx6o2u-PuppetStepConfig-r2vzisu2blgl','state changed','OS::Heat::Value',NULL,147),(351,'c97be72c-2d3c-4b05-8947-ab27504a5057','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','PostUpdateTasks','cell1-NetworkerServiceChain-w6ts4csx6o2u-PostUpdateTasks-dtaqsq3smfqn','state changed','OS::Heat::Value',NULL,149),(352,'4db84721-1337-4175-b474-99ce807ac57f','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','ControllerUserData','e8aa603a-c31c-4f4e-b47f-3a39060b577d','state changed','OS::Heat::MultipartMime',NULL,102),(353,'7f92e68d-3d6a-495c-b67d-ac07740415c0','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','ServiceNames','cell1-NetworkerServiceChain-w6ts4csx6o2u-ServiceNames-ijbspbtasodp','state changed','OS::Heat::Value',NULL,165),(354,'cc2eacac-d6b5-46d3-bdd7-de7bb6140f1b','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','cell1-NetworkerServiceChain-w6ts4csx6o2u-HostPrepTasks-de6bwy7ory6u','state changed','OS::Heat::Value',NULL,167),(355,'addddd9b-cdb2-4401-8f64-91e212c9047f','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','HostPrepTasks','cell1-NetworkerServiceChain-w6ts4csx6o2u-HostPrepTasks-de6bwy7ory6u','state changed','OS::Heat::Value',NULL,167),(356,'ee7c478c-8e74-4775-b63b-680eaf75ed50','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','cell1-CephStorageServiceChain-xqicw5xwvg6g-ExternalPostDeployTasks-y7e3n4vxswgm','state changed','OS::Heat::Value',NULL,158),(357,'a11bda5f-843b-4505-93a1-fb8a5051150a','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','cell1-CephStorageServiceChain-xqicw5xwvg6g-PostUpdateTasks-hhmurpey27gj','state changed','OS::Heat::Value',NULL,168),(358,'bec9662d-fa1a-4bff-bdea-8a3b67eb2774','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','UpdateTasks','cell1-CephStorageServiceChain-xqicw5xwvg6g-UpdateTasks-2galvfzw2qz7','state changed','OS::Heat::Value',NULL,159),(359,'3ed6e0eb-3232-4565-a56f-453578b47a9a','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','FirewallRules','cell1-ControllerServiceChain-zbda4x4z5on7-FirewallRules-q4fz3yaaqsus','state changed','OS::Heat::Value',NULL,160),(360,'e6448814-83d2-48e3-b8df-59589d6feb95','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','cell1-CellControllerComputeServiceChain-aseidyipoyc3-HostFirewallTasks-cchsccugoz3o','state changed','OS::Heat::Value',NULL,163),(361,'c480dd12-b641-452a-a705-38e493321dd8','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','cell1-NetworkerServiceChain-w6ts4csx6o2u-ExternalDeployTasks-ktu2vwp2t4dn','state changed','OS::Heat::Value',NULL,171),(362,'1e2ba131-1fbf-4df5-9bd1-c7f46d8d26b4','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-UpgradeBatchTasks-q2tiyko6lyw5','state changed','OS::Heat::Value',NULL,142),(363,'9d30793f-f030-4c69-9720-30909e1da5a9','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-FirewallFrontendRules-sr3s5v4nklqw','state changed','OS::Heat::Value',NULL,164),(364,'997f5e30-ff71-4dab-aa02-357806ad9f6a','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','cell1-CephStorageServiceChain-xqicw5xwvg6g-ServiceServerMetadataHook-u25zk2gq2bas','state changed','OS::TripleO::CephStorageServiceServerMetadataHook',NULL,NULL),(365,'cbe1ddab-4e5f-45a8-8a60-37eb0e1a4f7c','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','ExternalDeployTasks','cell1-NetworkerServiceChain-w6ts4csx6o2u-ExternalDeployTasks-ktu2vwp2t4dn','state changed','OS::Heat::Value',NULL,171),(366,'971c3834-4938-4f66-92d7-19af42a8ea8d','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','DockerConfigScripts','cell1-CellControllerComputeServiceChain-aseidyipoyc3-DockerConfigScripts-mjqqpgqste6n','state changed','OS::Heat::Value',NULL,162),(367,'b4707795-9a68-48c3-9284-ab7c6be05b56','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','AnsibleGroupVars','cell1-ControllerServiceChain-zbda4x4z5on7-AnsibleGroupVars-q4mijmecypf7','state changed','OS::Heat::Value',NULL,145),(368,'bbaba49b-af10-4c5b-88f9-6e093d142635','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','GlobalConfigSettings','cell1-NetworkerServiceChain-w6ts4csx6o2u-GlobalConfigSettings-pmd2kgzcfpi7','state changed','OS::Heat::Value',NULL,153),(369,'058853c4-ee32-4415-a58b-85ad1017fd07','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','cell1-ControllerServiceChain-zbda4x4z5on7-GlobalConfigSettings-wpch35bd4s4j','state changed','OS::Heat::Value',NULL,166),(370,'b8f07a41-f28f-4c08-8e85-478f35d41745','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','cell1-BlockStorageServiceChain-xb5mfp73j4eo-FirewallFrontendRules-yxd24mil7vru','state changed','OS::Heat::Value',NULL,169),(371,'cafc7089-06fe-4891-bb46-dd4c33bd6d99','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','PostUpdateTasks','cell1-CephStorageServiceChain-xqicw5xwvg6g-PostUpdateTasks-hhmurpey27gj','state changed','OS::Heat::Value',NULL,168),(372,'12eb97cb-e450-4354-981d-dbc49dce7a96','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','cell1-BlockStorageServiceChain-xb5mfp73j4eo-IpaRegistrationTasks-5drq5hmdpdbm','state changed','OS::Heat::Value',NULL,154),(373,'e7d9d5d9-3f30-4e5d-8f4c-634947bfb4bd','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-ExternalPostDeployTasks-6f4j2rcbs4qx','state changed','OS::Heat::Value',NULL,172),(374,'6910f2e6-c657-4df6-a6f7-fe370125c289','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','ServiceNames','cell1-CephStorageServiceChain-xqicw5xwvg6g-ServiceNames-apd2kufrepct','state changed','OS::Heat::Value',NULL,174),(375,'b7a030cb-02d2-49be-bb7f-ae868fbbe0a6','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','cell1-CephStorageServiceChain-xqicw5xwvg6g-PuppetStepConfig-5hv62hs4obd4','state changed','OS::Heat::Value',NULL,175),(376,'95e88a21-c252-45c9-98f6-71f76fe8e4e2','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','cell1-CephStorageServiceChain-xqicw5xwvg6g-ContainerPuppetTasks-2cv4x7nprytd','state changed','OS::Heat::Value',NULL,178),(377,'2ac07e70-f73c-4b6c-be49-3a88085a9d7c','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','cell1-NetworkerServiceChain-w6ts4csx6o2u-AnsibleGroupVars-7hchvnejho7s','state changed','OS::Heat::Value',NULL,177),(378,'0364e358-9797-42de-86c9-ccaf4a6d569a','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','cell1-CephStorageServiceChain-xqicw5xwvg6g-ContainerPuppetTasks-2cv4x7nprytd','state changed','OS::Heat::Value',NULL,178),(379,'c75a9a5e-4a37-4516-9f09-bb1f4a092c91','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','6aa0a00f-a362-4ff1-bb1d-001b235e6ad3','state changed','OS::TripleO::CephStorageServiceServerMetadataHook',NULL,NULL),(380,'6f904310-2bc1-4846-b42c-81c42fe9370c','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','PuppetStepConfig','cell1-CephStorageServiceChain-xqicw5xwvg6g-PuppetStepConfig-5hv62hs4obd4','state changed','OS::Heat::Value',NULL,175),(381,'cd1b6316-b98e-4062-a302-af8ce5e218f5','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','cell1-BlockStorageServiceChain-xb5mfp73j4eo-DockerPuppetTasks-h2ybj3h56llm','state changed','OS::Heat::Value',NULL,176),(382,'2141cedd-5d4d-4622-8b1a-2230b19a2c62','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','cell1-CephStorageServiceChain-xqicw5xwvg6g-HostPrepTasks-a4qn6aa5e5ym','state changed','OS::Heat::Value',NULL,170),(383,'cecd7e19-10fd-41c0-a664-4d5c3777bb27','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','PreDeployStepTasks','cell1-BlockStorageServiceChain-xb5mfp73j4eo-PreDeployStepTasks-tge6rh7srgqq','state changed','OS::Heat::Value',NULL,161),(384,'954dcebd-aa7d-431c-bc56-05c874d9c7a8','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','ServiceNames','cell1-CephStorageServiceChain-xqicw5xwvg6g-ServiceNames-apd2kufrepct','state changed','OS::Heat::Value',NULL,174),(385,'39ee24b2-5078-4584-85f2-cacb60b2e012','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','cell1-ControllerServiceChain-zbda4x4z5on7-KeystoneResourcesConfigs-pw7bnpo2alvz','state changed','OS::Heat::Value',NULL,152),(386,'2a80abd8-c6ab-41ee-a0ca-fcf8097620e9','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-ExternalUpdateTasks-knnwomjmf5vm','state changed','OS::Heat::Value',NULL,155),(387,'93747d47-6ef2-4b8f-bb6b-0d9fee8f5002','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','cell1-CellControllerComputeServiceChain-aseidyipoyc3-PuppetStepConfig-5cxn6wmw3ykb','state changed','OS::Heat::Value',NULL,183),(388,'6f29c951-cbfd-4ebe-a6ff-cdd925acfb9c','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-ExternalUpgradeTasks-mxut7oicrufh','state changed','OS::Heat::Value',NULL,179),(389,'47203c23-ee29-4049-8fc8-3317b7a178f7','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','cell1-NetworkerServiceChain-w6ts4csx6o2u-IpaRegistrationTasks-draqberlxdj4','state changed','OS::Heat::Value',NULL,182),(390,'04d98816-97fd-4ccf-9c4b-7d1385a4897f','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','AnsibleGroupVars','cell1-NetworkerServiceChain-w6ts4csx6o2u-AnsibleGroupVars-7hchvnejho7s','state changed','OS::Heat::Value',NULL,177),(391,'febca258-591d-41f4-9541-3e6b586eae7f','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','GlobalConfigSettings','cell1-ControllerServiceChain-zbda4x4z5on7-GlobalConfigSettings-wpch35bd4s4j','state changed','OS::Heat::Value',NULL,166),(392,'eece395e-eba5-4a31-a05b-a6b200ed6106','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','FirewallFrontendRules','cell1-BlockStorageServiceChain-xb5mfp73j4eo-FirewallFrontendRules-yxd24mil7vru','state changed','OS::Heat::Value',NULL,169),(393,'aa22ed3b-a6c2-47fd-9bdb-94dd1b28862c','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','cell1-BlockStorageServiceChain-xb5mfp73j4eo-PostUpgradeTasks-s6pqzjzhospl','state changed','OS::Heat::Value',NULL,184),(394,'5887e746-373b-4aa1-8274-3f4bf5f72f34','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','cell1-NetworkerServiceChain-w6ts4csx6o2u-HostFirewallTasks-ltkcqgy6jbrt','state changed','OS::Heat::Value',NULL,181),(395,'be2bdb65-5324-4170-916b-282414ed0984','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','PuppetStepConfig','cell1-CellControllerComputeServiceChain-aseidyipoyc3-PuppetStepConfig-5cxn6wmw3ykb','state changed','OS::Heat::Value',NULL,183),(396,'43b628c8-6421-4bb0-8121-1b052ac2da04','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','cell1-CephStorageServiceChain-xqicw5xwvg6g-AnsibleGroupVars-qcsu6igfsjl2','state changed','OS::Heat::Value',NULL,187),(397,'83111574-9c9b-4da5-9d70-d51d85f68eb9','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','cell1-ControllerServiceChain-zbda4x4z5on7-PreUpgradeRollingTasks-ylry4y2lxmf6','state changed','OS::Heat::Value',NULL,173),(398,'339d6351-b548-4df9-99d8-7d1834230be7','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','cell1-NetworkerServiceChain-w6ts4csx6o2u-ServiceServerMetadataHook-zkbtiaiy4h3v','state changed','OS::TripleO::NetworkerServiceServerMetadataHook',NULL,NULL),(399,'a35ed9ab-661c-40fd-ad33-18bde1fba1ef','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-ExternalPostDeployTasks-6f4j2rcbs4qx','state changed','OS::Heat::Value',NULL,172),(400,'f8320bed-14a3-4ab9-aaa6-c854e013477d','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','ScaleTasks','cell1-CellControllerComputeServiceChain-aseidyipoyc3-ScaleTasks-2x5rmarktjlc','state changed','OS::Heat::Value',NULL,180),(401,'41a01f97-5d02-481f-80fc-03982cd500dd','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','cell1-ControllerServiceChain-zbda4x4z5on7-ExternalDeployTasks-m7tzva4xsrvv','state changed','OS::Heat::Value',NULL,185),(402,'87a500be-dcb5-4f29-8df1-6f01568804dc','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','DockerPuppetTasks','cell1-BlockStorageServiceChain-xb5mfp73j4eo-DockerPuppetTasks-h2ybj3h56llm','state changed','OS::Heat::Value',NULL,176),(403,'7f12442d-dff7-4482-b6ec-77fcb7e5d2a6','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','cell1-ControllerServiceChain-zbda4x4z5on7-UpgradeBatchTasks-clgucth3p7ho','state changed','OS::Heat::Value',NULL,188),(404,'a0b0aaab-1093-4900-a8fc-aa4e2b1672d1','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','AnsibleGroupVars','cell1-CephStorageServiceChain-xqicw5xwvg6g-AnsibleGroupVars-qcsu6igfsjl2','state changed','OS::Heat::Value',NULL,187),(405,'00a1ab34-2d26-4acf-8836-b85caa8e664c','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-ExternalDeployTasks-kbbpx6x4gtqy','state changed','OS::Heat::Value',NULL,189),(406,'89377a89-69c0-4bca-9e31-82c0a3f043aa','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','cell1-NetworkerServiceChain-w6ts4csx6o2u-IpaRegistrationTasks-draqberlxdj4','state changed','OS::Heat::Value',NULL,182),(407,'28d0aad4-7ad4-4a64-875f-df9b4c8b86a7','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','cell1-ControllerServiceChain-zbda4x4z5on7-UpgradeTasks-x557f7sbvh7x','state changed','OS::Heat::Value',NULL,192),(408,'e4898b79-98da-40aa-83d0-b478f0cd3505','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','ExternalDeployTasks','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-ExternalDeployTasks-kbbpx6x4gtqy','state changed','OS::Heat::Value',NULL,189),(409,'3ac92ae9-23fa-4ccc-896b-54adf1eb1289','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','UpgradeTasks','cell1-ControllerServiceChain-zbda4x4z5on7-UpgradeTasks-x557f7sbvh7x','state changed','OS::Heat::Value',NULL,192),(410,'4a866108-0f6d-4d27-ada4-bda1e4d2e81e','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','PostUpgradeTasks','cell1-BlockStorageServiceChain-xb5mfp73j4eo-PostUpgradeTasks-s6pqzjzhospl','state changed','OS::Heat::Value',NULL,184),(411,'79ff82ea-740a-4950-9581-15078eb22f31','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-ExternalUpgradeTasks-mxut7oicrufh','state changed','OS::Heat::Value',NULL,179),(412,'49b80d6a-3b5e-4ed3-8b41-65d97297952e','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','DockerConfig','cell1-CephStorageServiceChain-xqicw5xwvg6g-DockerConfig-qeyhikfzfn36','state changed','OS::Heat::Value',NULL,193),(413,'86914ba5-2d0c-4207-af9d-1955e2cc1370','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','cell1-BlockStorageServiceChain-xb5mfp73j4eo-DockerConfigScripts-kl465ts674th','state changed','OS::Heat::Value',NULL,191),(414,'bfc19b57-bac9-4949-bd30-e816499f3c9c','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','HostFirewallTasks','cell1-NetworkerServiceChain-w6ts4csx6o2u-HostFirewallTasks-ltkcqgy6jbrt','state changed','OS::Heat::Value',NULL,181),(415,'d4334837-d648-4df6-a3b2-8beafdb251d0','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','FirewallRules','cell1-ControllerServiceChain-zbda4x4z5on7-FirewallRules-q4fz3yaaqsus','state changed','OS::Heat::Value',NULL,160),(416,'1ceeadf4-6b0a-42a4-ae2b-8d999e352d48','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','PuppetConfig','cell1-ControllerServiceChain-zbda4x4z5on7-PuppetConfig-zt56vdo56gif','state changed','OS::Heat::Value',NULL,197),(417,'fc44c661-f66e-421b-b965-959c37a70fd1','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','DockerConfig','cell1-BlockStorageServiceChain-xb5mfp73j4eo-DockerConfig-4iehr34r5gme','state changed','OS::Heat::Value',NULL,195),(418,'d9b7c017-718e-4bd8-b8b5-7944ae8d36b2','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','HostFirewallTasks','cell1-CellControllerComputeServiceChain-aseidyipoyc3-HostFirewallTasks-cchsccugoz3o','state changed','OS::Heat::Value',NULL,163),(419,'13c4dd47-86c5-468d-87d0-df349934ae68','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','FirewallFrontendRules','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-FirewallFrontendRules-sr3s5v4nklqw','state changed','OS::Heat::Value',NULL,164),(420,'9fafbd9e-40df-4a5a-8045-f943c486f449','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','cell1-ControllerServiceChain-zbda4x4z5on7-UpgradeBatchTasks-clgucth3p7ho','state changed','OS::Heat::Value',NULL,188),(421,'6d65662c-95f8-41f1-9ab8-9d39afd57584','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','ExternalDeployTasks','cell1-ControllerServiceChain-zbda4x4z5on7-ExternalDeployTasks-m7tzva4xsrvv','state changed','OS::Heat::Value',NULL,185),(422,'7ff0a76f-99d8-4b90-9df8-c5ead5ff2d84','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','PuppetConfig','cell1-ControllerServiceChain-zbda4x4z5on7-PuppetConfig-zt56vdo56gif','state changed','OS::Heat::Value',NULL,197),(423,'b3aa8166-712e-430f-a48a-06b41d34e9b5','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','cell1-ControllerServiceChain-zbda4x4z5on7-DockerConfigScripts-bzd6jkvzqnkd','state changed','OS::Heat::Value',NULL,186),(424,'8f4d0e9b-a281-422b-9568-4bf112c8b46d','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','cell1-CellControllerComputeServiceChain-aseidyipoyc3-GlobalConfigSettings-drj2gtpkluj4','state changed','OS::Heat::Value',NULL,194),(425,'2839a06f-4284-4006-9ef5-38b87bcd26e5','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','cell1-NetworkerServiceChain-w6ts4csx6o2u-ExternalUpgradeTasks-h2ncrwwt23cu','state changed','OS::Heat::Value',NULL,196),(426,'a9d52966-1c8d-467a-a389-a43b8c7ddd35','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','03c9fa6d-46b4-4d9a-aea2-ba0217793f32','state changed','OS::TripleO::NetworkerServiceServerMetadataHook',NULL,NULL),(427,'f9203d1d-370b-485b-b01e-f27bcd505fd7','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','cell1-CephStorageServiceChain-xqicw5xwvg6g-HostFirewallTasks-ckhcriyqmlnz','state changed','OS::Heat::Value',NULL,204),(428,'4dc65625-44ea-4644-a69c-9fb87b6d92f6','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','DockerConfig','cell1-CephStorageServiceChain-xqicw5xwvg6g-DockerConfig-qeyhikfzfn36','state changed','OS::Heat::Value',NULL,193),(429,'fa86ae93-7a55-4231-ab1c-4fea92ea2e53','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','cell1-ControllerServiceChain-zbda4x4z5on7-ExternalUpgradeTasks-hoc2xnlsptcv','state changed','OS::Heat::Value',NULL,206),(430,'86c3a8dd-1cd4-4cac-b381-21b44e766f8f','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','cell1-CephStorageServiceChain-xqicw5xwvg6g-MonitoringSubscriptionsConfig-fahbfpysnyck','state changed','OS::Heat::Value',NULL,202),(431,'8d2c7db5-96d0-4348-bab1-1135d8f2133a','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','ScaleTasks','cell1-BlockStorageServiceChain-xb5mfp73j4eo-ScaleTasks-4r3fd6y7zyer','state changed','OS::Heat::Value',NULL,203),(432,'2693b2f9-c993-4564-bbbb-813cebc4aa1c','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','HostFirewallTasks','cell1-CephStorageServiceChain-xqicw5xwvg6g-HostFirewallTasks-ckhcriyqmlnz','state changed','OS::Heat::Value',NULL,204),(433,'650808e3-5c93-47f6-9a54-5418cd0b0f9e','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','DockerConfig','cell1-BlockStorageServiceChain-xb5mfp73j4eo-DockerConfig-4iehr34r5gme','state changed','OS::Heat::Value',NULL,195),(434,'f007b80e-eb92-4668-aa33-c19258cc7597','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','DockerConfigScripts','cell1-BlockStorageServiceChain-xb5mfp73j4eo-DockerConfigScripts-kl465ts674th','state changed','OS::Heat::Value',NULL,191),(435,'436f93aa-9e53-411e-9763-b344755f75c9','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','cell1-ControllerServiceChain-zbda4x4z5on7-ExternalUpgradeTasks-hoc2xnlsptcv','state changed','OS::Heat::Value',NULL,206),(436,'959f48e5-7bed-4911-b6b5-03b62cca65d1','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','cell1-NetworkerServiceChain-w6ts4csx6o2u-PreUpgradeRollingTasks-ysdl7b5li57q','state changed','OS::Heat::Value',NULL,207),(437,'2dd0ae73-0fc8-48fa-b4b8-a57eecf09f6a','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','GlobalConfigSettings','cell1-CellControllerComputeServiceChain-aseidyipoyc3-GlobalConfigSettings-drj2gtpkluj4','state changed','OS::Heat::Value',NULL,194),(438,'d2c92e14-9231-4239-bf85-457df857a1b1','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','FirewallRules','cell1-CephStorageServiceChain-xqicw5xwvg6g-FirewallRules-tax5d2q36nwf','state changed','OS::Heat::Value',NULL,190),(439,'9ef277f7-fa4a-407b-baad-14540f1202c6','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','UpdateTasks','cell1-BlockStorageServiceChain-xb5mfp73j4eo-UpdateTasks-2c2f662pwjho','state changed','OS::Heat::Value',NULL,208),(440,'04d5d25a-8bb0-47ad-924c-22eeda81270c','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','cell1-CellControllerComputeServiceChain-aseidyipoyc3-ServiceConfigSettings-l2zsefsrib4m','state changed','OS::Heat::Value',NULL,211),(441,'73d394ca-818c-4207-bf5c-197c34262096','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','cell1-NetworkerServiceChain-w6ts4csx6o2u-ExternalUpgradeTasks-h2ncrwwt23cu','state changed','OS::Heat::Value',NULL,196),(442,'8374764a-5d06-47ca-bbab-47d16e99d692','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','ServiceConfigSettings','cell1-CellControllerComputeServiceChain-aseidyipoyc3-ServiceConfigSettings-l2zsefsrib4m','state changed','OS::Heat::Value',NULL,211),(443,'ac24c4e0-a3f6-498b-bb46-fb8af9011717','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','cell1-CephStorageServiceChain-xqicw5xwvg6g-ExternalDeployTasks-5k4xprquq2dj','state changed','OS::Heat::Value',NULL,210),(444,'a3695962-b8b5-41ba-916a-fd8b5a5828e1','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','cell1-NetworkerServiceChain-w6ts4csx6o2u-UpgradeBatchTasks-vcz2hcsbjctq','state changed','OS::Heat::Value',NULL,199),(445,'748d1ad8-2f15-4ee4-976c-381f4d23e67c','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','ScaleTasks','cell1-BlockStorageServiceChain-xb5mfp73j4eo-ScaleTasks-4r3fd6y7zyer','state changed','OS::Heat::Value',NULL,203),(446,'df47b4c7-8508-4124-83c8-b84edf57ef3c','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','ServiceNames','cell1-BlockStorageServiceChain-xb5mfp73j4eo-ServiceNames-jhbwarakegvu','state changed','OS::Heat::Value',NULL,198),(447,'b8f5415c-29c9-4a03-bfb9-701a7a89c1f9','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','cell1-CephStorageServiceChain-xqicw5xwvg6g-MonitoringSubscriptionsConfig-fahbfpysnyck','state changed','OS::Heat::Value',NULL,202),(448,'bea66e0d-8622-46a0-b408-a9ec78f5584b','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','cell1-NetworkerServiceChain-w6ts4csx6o2u-PreUpgradeRollingTasks-ysdl7b5li57q','state changed','OS::Heat::Value',NULL,207),(449,'5a47331c-9b32-404c-9435-8e437c5888a8','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','KollaConfig','cell1-CephStorageServiceChain-xqicw5xwvg6g-KollaConfig-dqtzsstmyum4','state changed','OS::Heat::Value',NULL,213),(450,'fae05557-d707-412e-b594-49c4a302cae5','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','cell1-BlockStorageServiceChain-xb5mfp73j4eo-PuppetStepConfig-ulqili2smnzo','state changed','OS::Heat::Value',NULL,212),(451,'fb22b430-a5a2-436a-b326-aac27c50ad27','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','cell1-CephStorageServiceChain-xqicw5xwvg6g-DeployStepsTasks-spwhj6kyttp2','state changed','OS::Heat::Value',NULL,215),(452,'5551fedb-a937-41ad-a825-a22cbaeab1d4','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','cell1-CephStorageServiceChain-xqicw5xwvg6g-KeystoneResourcesConfigs-cf6zubrgvrs6','state changed','OS::Heat::Value',NULL,200),(453,'20e0c918-62a0-4c3e-b9f4-85c835ef6885','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','DeployStepsTasks','cell1-CephStorageServiceChain-xqicw5xwvg6g-DeployStepsTasks-spwhj6kyttp2','state changed','OS::Heat::Value',NULL,215),(454,'7bcec251-02ac-4100-846a-055fa0986c32','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','cell1-ControllerServiceChain-zbda4x4z5on7-PreUpgradeRollingTasks-ylry4y2lxmf6','state changed','OS::Heat::Value',NULL,173),(455,'830ea45e-2269-4b51-896c-e11ec00e7045','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','cell1-NetworkerServiceChain-w6ts4csx6o2u-ExternalUpdateTasks-h4nm5v4dpiha','state changed','OS::Heat::Value',NULL,205),(456,'64d9353f-f746-4329-8f04-532d3f62ab00','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','UpdateTasks','cell1-BlockStorageServiceChain-xb5mfp73j4eo-UpdateTasks-2c2f662pwjho','state changed','OS::Heat::Value',NULL,208),(457,'8963689e-f2c6-4950-8fc0-dbb8a95b4d52','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','cell1-CephStorageServiceChain-xqicw5xwvg6g-PreDeployStepTasks-z4zr6u3vplqr','state changed','OS::Heat::Value',NULL,209),(458,'c60df3be-c294-4a5d-801e-7127736bf794','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','ExternalDeployTasks','cell1-CephStorageServiceChain-xqicw5xwvg6g-ExternalDeployTasks-5k4xprquq2dj','state changed','OS::Heat::Value',NULL,210),(459,'e3c4756b-a9df-4f2f-b1aa-a0120a3bad3f','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','HostPrepTasks','cell1-CephStorageServiceChain-xqicw5xwvg6g-HostPrepTasks-a4qn6aa5e5ym','state changed','OS::Heat::Value',NULL,170),(460,'5f253b1c-0f09-4b3c-bedf-336de6298177','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','cell1-BlockStorageServiceChain-xb5mfp73j4eo-DeployStepsTasks-x6mgrvqxd4qr','state changed','OS::Heat::Value',NULL,216),(461,'0c2641e7-9444-40b4-9a8f-61ff9fb266d9','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-PostUpdateTasks-2343itl265wp','state changed','OS::Heat::Value',NULL,219),(462,'2778ff8f-c3ee-4cd6-8fee-7da3d19523ba','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','cell1-ControllerServiceChain-zbda4x4z5on7-PreDeployStepTasks-ki3albydkxhd','state changed','OS::Heat::Value',NULL,218),(463,'f1bf511a-5424-4e47-b611-df369e5e039a','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','PuppetStepConfig','cell1-BlockStorageServiceChain-xb5mfp73j4eo-PuppetStepConfig-ulqili2smnzo','state changed','OS::Heat::Value',NULL,212),(464,'c4a963ac-d4ab-452f-9b9e-402152ce6713','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','cell1-BlockStorageServiceChain-xb5mfp73j4eo-UpgradeBatchTasks-rpeqxzfzndif','state changed','OS::Heat::Value',NULL,220),(465,'6f829cb3-04e2-4dc4-b521-3db6c1970f76','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','ScaleTasks','cell1-CellControllerComputeServiceChain-aseidyipoyc3-ScaleTasks-2x5rmarktjlc','state changed','OS::Heat::Value',NULL,180),(466,'13273146-e74f-4c9c-a056-a7986c615fc4','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','PostUpdateTasks','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-PostUpdateTasks-2343itl265wp','state changed','OS::Heat::Value',NULL,219),(467,'338e681a-6164-4e1a-b934-7aeeff12110a','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','cell1-CellControllerComputeServiceChain-aseidyipoyc3-DeployStepsTasks-hua2kb6fj75k','state changed','OS::Heat::Value',NULL,222),(468,'1d6cc9d2-c8cf-49cd-9888-4ef4278c8e96','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','KollaConfig','cell1-CephStorageServiceChain-xqicw5xwvg6g-KollaConfig-dqtzsstmyum4','state changed','OS::Heat::Value',NULL,213),(469,'1e3b1cea-89be-40dc-a4c6-8a071ea77bd8','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','cell1-BlockStorageServiceChain-xb5mfp73j4eo-ServiceServerMetadataHook-2n3agvele4tq','state changed','OS::TripleO::BlockStorageServiceServerMetadataHook',NULL,NULL),(470,'bcba052f-5f36-49dc-a198-2d661ec15498','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','DeployStepsTasks','cell1-CellControllerComputeServiceChain-aseidyipoyc3-DeployStepsTasks-hua2kb6fj75k','state changed','OS::Heat::Value',NULL,222),(471,'966b31a6-39d9-45b9-a97b-a6f1f6b1674e','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:53',NULL,'CREATE','COMPLETE','DeployStepsTasks','cell1-BlockStorageServiceChain-xb5mfp73j4eo-DeployStepsTasks-x6mgrvqxd4qr','state changed','OS::Heat::Value',NULL,216),(472,'b7a4d586-ae48-451c-bcea-c1459d14a663','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','ScaleTasks','cell1-NetworkerServiceChain-w6ts4csx6o2u-ScaleTasks-osyuoem7qaif','state changed','OS::Heat::Value',NULL,214),(473,'2e321b75-c726-4d2c-a032-3590f12c5245','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:53',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','cell1-ControllerServiceChain-zbda4x4z5on7-HostFirewallTasks-4ihh5svrzv3z','state changed','OS::Heat::Value',NULL,223),(474,'ccc0810e-fd37-4111-90c8-7edc8dea789f','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-PuppetStepConfig-5z7jmousxjet','state changed','OS::Heat::Value',NULL,217),(475,'38d15d0c-48dd-430d-acee-3e2bf443a273','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','cell1-ControllerServiceChain-zbda4x4z5on7-ExternalUpdateTasks-dqbc2dija6yi','state changed','OS::Heat::Value',NULL,224),(476,'464ae284-c7b3-4f83-9954-e05946f11ddf','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','cell1-BlockStorageServiceChain-xb5mfp73j4eo-UpgradeBatchTasks-rpeqxzfzndif','state changed','OS::Heat::Value',NULL,220),(477,'dcc2b82e-32eb-47ef-9eb4-9de9e47f6c62','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','PreDeployStepTasks','cell1-ControllerServiceChain-zbda4x4z5on7-PreDeployStepTasks-ki3albydkxhd','state changed','OS::Heat::Value',NULL,218),(478,'8f768040-eb79-4efb-9209-5b7d76e9f11f','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','cell1-ControllerServiceChain-zbda4x4z5on7-DeployStepsTasks-ywmphu6wsnj4','state changed','OS::Heat::Value',NULL,225),(479,'25edc440-87e4-4552-97fe-69bbac2427c5','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','DockerConfigScripts','cell1-ControllerServiceChain-zbda4x4z5on7-DockerConfigScripts-bzd6jkvzqnkd','state changed','OS::Heat::Value',NULL,186),(480,'23e18b66-aa76-42d9-a44e-05fc8be498dc','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','cell1-CephStorageServiceChain-xqicw5xwvg6g-ServiceConfigSettings-g62e6ujzm6aj','state changed','OS::Heat::Value',NULL,226),(481,'898b1408-dc82-43a4-b19a-6bcd4a5bbbb6','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','cell1-ControllerServiceChain-zbda4x4z5on7-ExternalUpdateTasks-dqbc2dija6yi','state changed','OS::Heat::Value',NULL,224),(482,'ca7ce340-d6d5-449b-9281-3b1c588e5ffd','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','cell1-BlockStorageServiceChain-xb5mfp73j4eo-HostPrepTasks-6yeko6vucjaf','state changed','OS::Heat::Value',NULL,230),(483,'84e7d0b2-7ff9-4b0b-a96c-a6c796f7cbe0','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','cell1-BlockStorageServiceChain-xb5mfp73j4eo-ServiceConfigSettings-q2nfish7bgpq','state changed','OS::Heat::Value',NULL,228),(484,'864c9529-dbb3-4024-9cc6-d3cd259b65d9','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','HostFirewallTasks','cell1-ControllerServiceChain-zbda4x4z5on7-HostFirewallTasks-4ihh5svrzv3z','state changed','OS::Heat::Value',NULL,223),(485,'c362fa77-dad7-4b7c-8283-ff5459d77d12','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','UpdateTasks','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-UpdateTasks-j3grwlwdhpn2','state changed','OS::Heat::Value',NULL,233),(486,'cbb8d613-64f4-44e0-a35d-d32ab29fc97d','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','cell1-ControllerServiceChain-zbda4x4z5on7-IpaRegistrationTasks-m5zoddjt3mgc','state changed','OS::Heat::Value',NULL,231),(487,'512890e5-8a7a-4d48-bcbc-2e4d278ddf1c','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','7c296f2e-e07b-47ed-80d3-2f6b3f37b62c','state changed','OS::TripleO::BlockStorageServiceServerMetadataHook',NULL,NULL),(488,'a0be630d-eef9-44dd-82f8-2ff5e40fcd2e','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','DeployStepsTasks','cell1-ControllerServiceChain-zbda4x4z5on7-DeployStepsTasks-ywmphu6wsnj4','state changed','OS::Heat::Value',NULL,225),(489,'3830534d-952f-4efe-862d-cea3e566aec9','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','ServiceConfigSettings','cell1-BlockStorageServiceChain-xb5mfp73j4eo-ServiceConfigSettings-q2nfish7bgpq','state changed','OS::Heat::Value',NULL,228),(490,'6a8e7a78-f2fb-41d0-b61f-b691fa723ec0','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','cell1-BlockStorageServiceChain-xb5mfp73j4eo-AnsibleGroupVars-2mmbgzk6cbj5','state changed','OS::Heat::Value',NULL,234),(491,'e3229c8d-7ced-4050-a7c3-c70aab26fb84','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','HostPrepTasks','cell1-BlockStorageServiceChain-xb5mfp73j4eo-HostPrepTasks-6yeko6vucjaf','state changed','OS::Heat::Value',NULL,230),(492,'75ac62b4-d318-4715-808a-b1b8721e0af0','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','UpdateTasks','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-UpdateTasks-j3grwlwdhpn2','state changed','OS::Heat::Value',NULL,233),(493,'c5c89b5e-1ff9-40db-bd18-a57c3062cf03','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','cell1-ControllerServiceChain-zbda4x4z5on7-ExternalPostDeployTasks-zp3m2mwnmy5m','state changed','OS::Heat::Value',NULL,221),(494,'bb448ac5-9656-4f83-9a56-90c369f91e7b','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','AnsibleGroupVars','cell1-BlockStorageServiceChain-xb5mfp73j4eo-AnsibleGroupVars-2mmbgzk6cbj5','state changed','OS::Heat::Value',NULL,234),(495,'2cc5440f-4441-4dc5-a0ac-265f11d0ece9','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','ServiceConfigSettings','cell1-CephStorageServiceChain-xqicw5xwvg6g-ServiceConfigSettings-g62e6ujzm6aj','state changed','OS::Heat::Value',NULL,226),(496,'463fb2fc-f361-4870-95d4-c106056e59ef','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','cell1-ControllerServiceChain-zbda4x4z5on7-DockerPuppetTasks-aebcu3gd6vxv','state changed','OS::Heat::Value',NULL,235),(497,'be06ef75-e119-4159-9c41-a04acdf3690d','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','cell1-ControllerServiceChain-zbda4x4z5on7-HostPrepTasks-p3qhdqzazv37','state changed','OS::Heat::Value',NULL,237),(498,'b4397162-771f-4fdf-82b3-12efca2d537d','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','cell1-ControllerServiceChain-zbda4x4z5on7-IpaRegistrationTasks-m5zoddjt3mgc','state changed','OS::Heat::Value',NULL,231),(499,'f6a19988-3f1d-4132-a54e-0c49b008f323','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','ServiceNames','cell1-BlockStorageServiceChain-xb5mfp73j4eo-ServiceNames-jhbwarakegvu','state changed','OS::Heat::Value',NULL,198),(500,'6bce2fc7-1490-4bbc-8b63-871e100156ff','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','cell1-CephStorageServiceChain-xqicw5xwvg6g-KeystoneResourcesConfigs-cf6zubrgvrs6','state changed','OS::Heat::Value',NULL,200),(501,'90669012-a214-4e7d-b1e6-31f9ca306fef','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','cell1-BlockStorageServiceChain-xb5mfp73j4eo-PostUpdateTasks-infgpcfkzend','state changed','OS::Heat::Value',NULL,240),(502,'942b30a5-c4b6-4e26-b68b-cfe5774d2e38','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','cell1-NetworkerServiceChain-w6ts4csx6o2u-UpgradeBatchTasks-vcz2hcsbjctq','state changed','OS::Heat::Value',NULL,199),(503,'6034826d-6ed6-42ea-9a17-36e4fc93b889','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','cell1-CellControllerComputeServiceChain-aseidyipoyc3-AnsibleGroupVars-hjen4d2fw7dj','state changed','OS::Heat::Value',NULL,241),(504,'e5aec347-9f0c-461f-b6e1-9aeb72e3461b','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','HostPrepTasks','cell1-ControllerServiceChain-zbda4x4z5on7-HostPrepTasks-p3qhdqzazv37','state changed','OS::Heat::Value',NULL,237),(505,'7fa9e8b4-e156-467b-8f7e-1b3765a57ff0','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','PostUpdateTasks','cell1-BlockStorageServiceChain-xb5mfp73j4eo-PostUpdateTasks-infgpcfkzend','state changed','OS::Heat::Value',NULL,240),(506,'2a17d179-a29a-4d4a-aa52-ecf48e925d07','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','AnsibleGroupVars','cell1-CellControllerComputeServiceChain-aseidyipoyc3-AnsibleGroupVars-hjen4d2fw7dj','state changed','OS::Heat::Value',NULL,241),(507,'64e70004-2918-486b-b88e-f8349d7c7de4','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','FirewallRules','cell1-CephStorageServiceChain-xqicw5xwvg6g-FirewallRules-tax5d2q36nwf','state changed','OS::Heat::Value',NULL,190),(508,'c6885f8d-fa23-4ee2-9b44-b45dcbde37a3','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','ScaleTasks','cell1-CephStorageServiceChain-xqicw5xwvg6g-ScaleTasks-wssznyblakm5','state changed','OS::Heat::Value',NULL,229),(509,'4486b650-e8a5-4866-a139-58acb3e89193','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','cell1-NetworkerServiceChain-w6ts4csx6o2u-ExternalUpdateTasks-h4nm5v4dpiha','state changed','OS::Heat::Value',NULL,205),(510,'e6a45e91-c597-43ce-b601-8f8072a010c7','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','cell1-ControllerServiceChain-zbda4x4z5on7-PostUpdateTasks-ybw64zde2lzp','state changed','OS::Heat::Value',NULL,227),(511,'79bf7c6a-79e4-4d38-8d77-da8b326592fe','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','DockerPuppetTasks','cell1-ControllerServiceChain-zbda4x4z5on7-DockerPuppetTasks-aebcu3gd6vxv','state changed','OS::Heat::Value',NULL,235),(512,'f6376e13-d2b7-4d01-bc7b-978730a9370d','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-ContainerPuppetTasks-uoeblcbxgy7f','state changed','OS::Heat::Value',NULL,244),(513,'31e33598-1d74-4155-abc0-e0c037b08b1f','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','cell1-ControllerServiceChain-zbda4x4z5on7-PostUpgradeTasks-soxgdwoprzor','state changed','OS::Heat::Value',NULL,242),(514,'25bcc77b-b14c-4440-8828-2f1f66425ff6','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','PreDeployStepTasks','cell1-CephStorageServiceChain-xqicw5xwvg6g-PreDeployStepTasks-z4zr6u3vplqr','state changed','OS::Heat::Value',NULL,209),(515,'54db37df-7fe2-4016-a5b8-acc30a79b351','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-ContainerPuppetTasks-uoeblcbxgy7f','state changed','OS::Heat::Value',NULL,244),(516,'54345f0b-4831-4b71-b368-319b02912208','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','cell1-BlockStorageServiceChain-xb5mfp73j4eo-GlobalConfigSettings-5x4qyubru5r6','state changed','OS::Heat::Value',NULL,247),(517,'9448e506-bcc7-41b0-8e8a-6842bccc3a70','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','cell1-BlockStorageServiceChain-xb5mfp73j4eo-UpgradeTasks-7ajvenyr5wdf','state changed','OS::Heat::Value',NULL,246),(518,'f4760dfb-e183-4e1d-b64b-0b5c2cff4fe3','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','cell1-CephStorageServiceChain-xqicw5xwvg6g-UpgradeTasks-a6noh6blij3u','state changed','OS::Heat::Value',NULL,236),(519,'4b5959f9-0026-4f74-96ae-4ed96dcea5a8','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','GlobalConfigSettings','cell1-BlockStorageServiceChain-xb5mfp73j4eo-GlobalConfigSettings-5x4qyubru5r6','state changed','OS::Heat::Value',NULL,247),(520,'47a352b1-6598-4296-866f-ac7d80bfd91c','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','PostUpgradeTasks','cell1-ControllerServiceChain-zbda4x4z5on7-PostUpgradeTasks-soxgdwoprzor','state changed','OS::Heat::Value',NULL,242),(521,'f8c33b1b-2817-414b-acc7-f410b7354a67','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','cell1-BlockStorageServiceChain-xb5mfp73j4eo-MonitoringSubscriptionsConfig-u4spuncctfxa','state changed','OS::Heat::Value',NULL,238),(522,'e9fef177-e0a4-4065-b0dc-3acea621c244','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','UpgradeTasks','cell1-BlockStorageServiceChain-xb5mfp73j4eo-UpgradeTasks-7ajvenyr5wdf','state changed','OS::Heat::Value',NULL,246),(523,'d980a7d3-6432-4f83-b858-cc1d5441d250','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','ServiceNames','cell1-CellControllerComputeServiceChain-aseidyipoyc3-ServiceNames-dd4frm4k4b73','state changed','OS::Heat::Value',NULL,250),(524,'2ef449f6-2778-4731-8735-8bcae113945b','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','cell1-BlockStorageServiceChain-xb5mfp73j4eo-ExternalDeployTasks-xiwjpewykmbl','state changed','OS::Heat::Value',NULL,249),(525,'5ce686be-30ea-472b-853f-33d88f96cac5','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','ServiceNames','cell1-CellControllerComputeServiceChain-aseidyipoyc3-ServiceNames-dd4frm4k4b73','state changed','OS::Heat::Value',NULL,250),(526,'f1dffda5-0a12-49d8-a012-2162299f2f45','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','ExternalDeployTasks','cell1-BlockStorageServiceChain-xb5mfp73j4eo-ExternalDeployTasks-xiwjpewykmbl','state changed','OS::Heat::Value',NULL,249),(527,'edbe7d56-2f6c-4638-90fb-d3d7bf006580','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','PuppetStepConfig','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-PuppetStepConfig-5z7jmousxjet','state changed','OS::Heat::Value',NULL,217),(528,'dc6a042c-30b2-405a-937b-02504bf6a0f4','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','ScaleTasks','cell1-NetworkerServiceChain-w6ts4csx6o2u-ScaleTasks-osyuoem7qaif','state changed','OS::Heat::Value',NULL,214),(529,'e6f7866c-180a-46a4-bb6d-0e9b4a57e8ba','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','cell1-CephStorageServiceChain-xqicw5xwvg6g-PostUpgradeTasks-wlvw4qvqmifg','state changed','OS::Heat::Value',NULL,243),(530,'a3d47820-a946-4c66-880b-e4e8e6098f9e','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','cell1-BlockStorageServiceChain-xb5mfp73j4eo-ContainerPuppetTasks-bzbjsshvdkuc','state changed','OS::Heat::Value',NULL,245),(531,'e1cc0d05-af2b-4112-bb0e-b772fab631d5','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','cell1-ControllerServiceChain-zbda4x4z5on7-ExternalPostDeployTasks-zp3m2mwnmy5m','state changed','OS::Heat::Value',NULL,221),(532,'f289f174-29a9-4115-a59e-f0395ac58a45','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','2','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-2-wz6klstizmzw','state changed','OS::TripleO::Services::Clustercheck',NULL,253),(533,'674dd578-f06f-4e21-b407-44a3d60bf548','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','cell1-CephStorageServiceChain-xqicw5xwvg6g-PreUpgradeRollingTasks-7e5h4nlgskec','state changed','OS::Heat::Value',NULL,251),(534,'7c5096e8-8320-445a-b0a4-9caa02162d3e','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','cell1-ControllerServiceChain-zbda4x4z5on7-FirewallFrontendRules-dmqtqphdnafa','state changed','OS::Heat::Value',NULL,252),(535,'fb583eed-2db7-4e77-aa8d-fcb85dc90376','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','ScaleTasks','cell1-CephStorageServiceChain-xqicw5xwvg6g-ScaleTasks-wssznyblakm5','state changed','OS::Heat::Value',NULL,229),(536,'ae440cb9-764d-45b7-b38f-512f3d6d388b','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','PostUpdateTasks','cell1-ControllerServiceChain-zbda4x4z5on7-PostUpdateTasks-ybw64zde2lzp','state changed','OS::Heat::Value',NULL,227),(537,'3a30b2cc-a03a-4710-8a6e-f68f8550adb0','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','cell1-CellControllerComputeServiceChain-aseidyipoyc3-PreUpgradeRollingTasks-engwoq2evv72','state changed','OS::Heat::Value',NULL,256),(538,'f38cbd0a-46c2-43e8-8d3e-7fb6b9932fa8','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','cell1-CellControllerComputeServiceChain-aseidyipoyc3-PreUpgradeRollingTasks-engwoq2evv72','state changed','OS::Heat::Value',NULL,256),(539,'99f18f61-85e4-48af-aacb-20bc7dcb231f','f150be6c-b1ea-4b80-ae04-d2a879a02cf6','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-2-wz6klstizmzw','f150be6c-b1ea-4b80-ae04-d2a879a02cf6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(540,'bc663b4d-6aad-4b29-9e2d-e44950f4d124','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','ScaleTasks','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-ScaleTasks-vfsn2zmy3k45','state changed','OS::Heat::Value',NULL,257),(541,'d4c60c4f-c105-452b-adda-9901e3f8f59b','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','ScaleTasks','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-ScaleTasks-vfsn2zmy3k45','state changed','OS::Heat::Value',NULL,257),(542,'6fcb8c02-9b41-44e1-a013-11b05b84bd43','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','UpgradeTasks','cell1-CephStorageServiceChain-xqicw5xwvg6g-UpgradeTasks-a6noh6blij3u','state changed','OS::Heat::Value',NULL,236),(543,'9b54c888-0b2e-4565-8759-be6f68b5d85e','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','cell1-BlockStorageServiceChain-xb5mfp73j4eo-MonitoringSubscriptionsConfig-u4spuncctfxa','state changed','OS::Heat::Value',NULL,238),(544,'8509162c-e829-43c6-b946-c6010f150e0d','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','cell1-BlockStorageServiceChain-xb5mfp73j4eo-ExternalUpgradeTasks-mcjxkmmgdvio','state changed','OS::Heat::Value',NULL,254),(545,'ff3d7635-7013-483e-a232-62e4eae471b4','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','PostUpgradeTasks','cell1-CephStorageServiceChain-xqicw5xwvg6g-PostUpgradeTasks-wlvw4qvqmifg','state changed','OS::Heat::Value',NULL,243),(546,'c13b4a5c-f226-420f-8063-f5f0278cfbd8','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','FirewallRules','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-FirewallRules-4s4gsbwioitk','state changed','OS::Heat::Value',NULL,255),(547,'ede0e931-3dc1-4089-a90f-8037aedba655','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','UpdateTasks','cell1-CellControllerComputeServiceChain-aseidyipoyc3-UpdateTasks-kzpgphumqqgd','state changed','OS::Heat::Value',NULL,258),(548,'9692085d-5a4c-4bed-9ffb-f67bd58b3123','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','cell1-BlockStorageServiceChain-xb5mfp73j4eo-ContainerPuppetTasks-bzbjsshvdkuc','state changed','OS::Heat::Value',NULL,245),(549,'65cb782c-d4f2-4d7e-bc86-df37ec86c129','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','UpdateTasks','cell1-CellControllerComputeServiceChain-aseidyipoyc3-UpdateTasks-kzpgphumqqgd','state changed','OS::Heat::Value',NULL,258),(550,'ab21e5e8-e5ae-40e2-995e-123b86ddfa05','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','FirewallFrontendRules','cell1-ControllerServiceChain-zbda4x4z5on7-FirewallFrontendRules-dmqtqphdnafa','state changed','OS::Heat::Value',NULL,252),(551,'d103af1f-f771-4fad-8ca4-be30c3baaca1','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','cell1-CephStorageServiceChain-xqicw5xwvg6g-PreUpgradeRollingTasks-7e5h4nlgskec','state changed','OS::Heat::Value',NULL,251),(552,'719d2f11-f5b2-4f7c-9d4d-f000d932c321','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','cell1-CellControllerComputeServiceChain-aseidyipoyc3-ContainerPuppetTasks-ljufmksjwevd','state changed','OS::Heat::Value',NULL,259),(553,'1c303b60-1d1e-4768-aee5-dc53ccc9f36c','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','cell1-NetworkerServiceChain-w6ts4csx6o2u','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(554,'321ad086-5ac4-410d-b861-fcc822d4d35b','f150be6c-b1ea-4b80-ae04-d2a879a02cf6','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','MysqlPuppetBase','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-2-wz6klstizmzw-MysqlPuppetBase-vhvodulspwnz','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml',NULL,261),(555,'5468f0d8-00eb-4ba3-9081-f23b9c70a66a','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','cell1-CellControllerComputeServiceChain-aseidyipoyc3-ContainerPuppetTasks-ljufmksjwevd','state changed','OS::Heat::Value',NULL,259),(556,'bee6ff88-ab61-4392-b93c-4dc83b9996dc','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-IpaRegistrationTasks-sg76qptgwpjn','state changed','OS::Heat::Value',NULL,262),(557,'8e85676b-2bc3-4700-90c0-dce59e34f0ea','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','cell1-BlockStorageServiceChain-xb5mfp73j4eo-ExternalUpgradeTasks-mcjxkmmgdvio','state changed','OS::Heat::Value',NULL,254),(558,'a0121bb3-5172-4efc-a09c-cad280d2780d','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-DeployStepsTasks-xpcnbufs3xm4','state changed','OS::Heat::Value',NULL,260),(559,'7fdd37c1-298b-4ecf-b980-01eb63a27fca','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','FirewallRules','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-FirewallRules-4s4gsbwioitk','state changed','OS::Heat::Value',NULL,255),(560,'6f1ae726-327e-4be0-88fd-ff06291b1997','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-IpaRegistrationTasks-sg76qptgwpjn','state changed','OS::Heat::Value',NULL,262),(561,'f1b88f6f-77e3-4ba2-a5e2-3ed26df6b947','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-DockerConfigScripts-xdr32yte2xun','state changed','OS::Heat::Value',NULL,263),(562,'19ad9f47-e8b4-4ae6-86b0-7441fb6a5ae1','96410e6c-c152-402d-9a63-b396d4be3ed2','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-2-wz6klstizmzw-MysqlPuppetBase-vhvodulspwnz','96410e6c-c152-402d-9a63-b396d4be3ed2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(563,'5f3f55a2-1d91-4d69-87b5-be0c8bca5d53','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','DockerConfigScripts','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-DockerConfigScripts-xdr32yte2xun','state changed','OS::Heat::Value',NULL,263),(564,'ffbbde64-12c1-4309-8e0f-ad28a6e79ae8','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','cell1-CellControllerComputeServiceChain-aseidyipoyc3-DockerPuppetTasks-2qd5ptdhzl26','state changed','OS::Heat::Value',NULL,264),(565,'151add72-9ac4-4447-ba73-bd6fcef3b131','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','cell1-CephStorageServiceChain-xqicw5xwvg6g','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(566,'07733bab-8996-4fce-a5e4-87d9b91a8674','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-KeystoneResourcesConfigs-ieeq2syzp4wu','state changed','OS::Heat::Value',NULL,265),(567,'ec7ad566-9417-4e2c-b64f-9a7714a6b0d2','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','DeployStepsTasks','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-DeployStepsTasks-xpcnbufs3xm4','state changed','OS::Heat::Value',NULL,260),(568,'576f00c0-b53b-4876-ad76-2f27b70b3db8','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','PuppetConfig','cell1-CellControllerComputeServiceChain-aseidyipoyc3-PuppetConfig-52h5lgr6sz5x','state changed','OS::Heat::Value',NULL,266),(569,'36331818-3fe7-4021-9320-dbb73a93fcc1','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-KeystoneResourcesConfigs-ieeq2syzp4wu','state changed','OS::Heat::Value',NULL,265),(570,'5a7ab909-7ac7-48fb-8928-4894ee93c228','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','PuppetConfig','cell1-CellControllerComputeServiceChain-aseidyipoyc3-PuppetConfig-52h5lgr6sz5x','state changed','OS::Heat::Value',NULL,266),(571,'50fa43b2-a783-4f46-b2d8-c49df8f9e563','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:54',NULL,'CREATE','IN_PROGRESS','DockerConfig','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-DockerConfig-amtl2v2akr5a','state changed','OS::Heat::Value',NULL,267),(572,'95752526-bb64-48d3-8b84-510c910ff614','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:54',NULL,'CREATE','COMPLETE','DockerConfig','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-DockerConfig-amtl2v2akr5a','state changed','OS::Heat::Value',NULL,267),(573,'1612e57c-4071-4033-b136-eb057201dbd1','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:55',NULL,'CREATE','COMPLETE','DockerPuppetTasks','cell1-CellControllerComputeServiceChain-aseidyipoyc3-DockerPuppetTasks-2qd5ptdhzl26','state changed','OS::Heat::Value',NULL,264),(574,'5f442f74-c854-45d0-9e75-e9a1bd782217','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:55',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-GlobalConfigSettings-2pz3uahtadnm','state changed','OS::Heat::Value',NULL,269),(575,'e3967520-2262-494d-b7c3-a50b0e8c4002','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:55',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','cell1-CellControllerComputeServiceChain-aseidyipoyc3-IpaRegistrationTasks-k76tyt6pdafd','state changed','OS::Heat::Value',NULL,268),(576,'e499edc9-aba7-4cc4-b3c5-aa3ab7ab6b5d','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:55',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','cell1-CellControllerComputeServiceChain-aseidyipoyc3-HostPrepTasks-lykbjse6itgs','state changed','OS::Heat::Value',NULL,270),(577,'3718d836-f4b1-4eea-bcb2-fc83552d45ec','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:55',NULL,'CREATE','COMPLETE','GlobalConfigSettings','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-GlobalConfigSettings-2pz3uahtadnm','state changed','OS::Heat::Value',NULL,269),(578,'11674122-62d9-4e21-b522-b8b840728104','0292a578-a91f-4468-b72e-e0d581ff796d','2026-06-12 08:25:55',NULL,'CREATE','COMPLETE','cell1-BlockStorageServiceChain-xb5mfp73j4eo','0292a578-a91f-4468-b72e-e0d581ff796d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(579,'fe095279-7e5e-441f-b1f7-d483e0852d3f','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:55',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','cell1-CellControllerComputeServiceChain-aseidyipoyc3-KeystoneResourcesConfigs-dhmi7lgc2fxj','state changed','OS::Heat::Value',NULL,272),(580,'6d82d6a5-55d3-4bca-b8a1-a4a03a34a6c8','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:55',NULL,'CREATE','COMPLETE','HostPrepTasks','cell1-CellControllerComputeServiceChain-aseidyipoyc3-HostPrepTasks-lykbjse6itgs','state changed','OS::Heat::Value',NULL,270),(581,'4a1eb99e-e4b7-4240-817b-8605e5c30a42','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:55',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-DockerPuppetTasks-qdoe5uwwkwnk','state changed','OS::Heat::Value',NULL,273),(582,'24aa54b9-420d-4ada-a4d5-17a6f5d9ccad','f3979da4-1312-4314-a6b6-ac051d536f13','2026-06-12 08:25:55',NULL,'CREATE','COMPLETE','cell1-ControllerServiceChain-zbda4x4z5on7','f3979da4-1312-4314-a6b6-ac051d536f13','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(583,'cf9ca39d-939d-49a0-a04a-d8cf79d53690','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:55',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','cell1-CellControllerComputeServiceChain-aseidyipoyc3-KeystoneResourcesConfigs-dhmi7lgc2fxj','state changed','OS::Heat::Value',NULL,272),(584,'b826ca60-d6cc-429d-bab8-a3088c24cc5e','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:55',NULL,'CREATE','COMPLETE','DockerPuppetTasks','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-DockerPuppetTasks-qdoe5uwwkwnk','state changed','OS::Heat::Value',NULL,273),(585,'c9c0ba5e-9199-4f09-b030-30231f6d6a02','96410e6c-c152-402d-9a63-b396d4be3ed2','2026-06-12 08:25:55',NULL,'CREATE','IN_PROGRESS','MysqlBase','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-2-wz6klstizmzw-MysqlPuppetBase-vhvodulspwnz-MysqlBase-utemobmazjtf','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-base.yaml',NULL,271),(586,'60f95df3-e52f-4393-ac4e-86392c7fcbe1','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:55',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','cell1-CellControllerComputeServiceChain-aseidyipoyc3-FirewallFrontendRules-2ayo6olmp2mo','state changed','OS::Heat::Value',NULL,274),(587,'18cddedf-b32a-440a-89dc-4deaf711d467','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:55',NULL,'CREATE','COMPLETE','FirewallFrontendRules','cell1-CellControllerComputeServiceChain-aseidyipoyc3-FirewallFrontendRules-2ayo6olmp2mo','state changed','OS::Heat::Value',NULL,274),(588,'974aab9f-7069-4bde-be9d-32b3224edea6','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:55',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','cell1-CellControllerComputeServiceChain-aseidyipoyc3-IpaRegistrationTasks-k76tyt6pdafd','state changed','OS::Heat::Value',NULL,268),(589,'ec6701f4-1b1c-4238-bfee-b9197f169e14','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:55',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','cell1-CellControllerComputeServiceChain-aseidyipoyc3-UpgradeTasks-vgq7vvb2nlm6','state changed','OS::Heat::Value',NULL,275),(590,'2b89432c-966f-408f-952d-805b3d4cd9a2','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:55',NULL,'CREATE','COMPLETE','UpgradeTasks','cell1-CellControllerComputeServiceChain-aseidyipoyc3-UpgradeTasks-vgq7vvb2nlm6','state changed','OS::Heat::Value',NULL,275),(591,'09d80755-0aa8-41c9-9e43-37f4f4cb928b','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:55',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-PreUpgradeRollingTasks-46ucy5qywsfp','state changed','OS::Heat::Value',NULL,277),(592,'c2b3d582-caf7-47d7-8c92-de0ac34ad621','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:55',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','cell1-CellControllerComputeServiceChain-aseidyipoyc3-ExternalDeployTasks-ep5pwakp36ys','state changed','OS::Heat::Value',NULL,278),(593,'2c5ba4f9-cf5d-4367-adc6-5957d593daad','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:55',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-MonitoringSubscriptionsConfig-wwwwj534vyyl','state changed','OS::Heat::Value',NULL,276),(594,'692fe97d-0fd9-4dfb-a01a-bdc97f641ad7','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:55',NULL,'CREATE','COMPLETE','ExternalDeployTasks','cell1-CellControllerComputeServiceChain-aseidyipoyc3-ExternalDeployTasks-ep5pwakp36ys','state changed','OS::Heat::Value',NULL,278),(595,'fbe60a59-f146-4010-959e-88b21136e277','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:55',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-PreUpgradeRollingTasks-46ucy5qywsfp','state changed','OS::Heat::Value',NULL,277),(596,'ae0b16b7-fde9-45c8-af23-d751ede0fe91','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:55',NULL,'CREATE','IN_PROGRESS','DockerConfig','cell1-CellControllerComputeServiceChain-aseidyipoyc3-DockerConfig-phigtjugmwqd','state changed','OS::Heat::Value',NULL,279),(597,'ecae5ad9-b4bd-40a8-819e-8524e8e3d0dd','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:55',NULL,'CREATE','COMPLETE','DockerConfig','cell1-CellControllerComputeServiceChain-aseidyipoyc3-DockerConfig-phigtjugmwqd','state changed','OS::Heat::Value',NULL,279),(598,'58bb4626-0da2-4988-83d6-e8ed74e1bdae','78507f36-81c1-4764-98ef-d65823dd1dc6','2026-06-12 08:25:55',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-2-wz6klstizmzw-MysqlPuppetBase-vhvodulspwnz-MysqlBase-utemobmazjtf','78507f36-81c1-4764-98ef-d65823dd1dc6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(599,'e88471d9-e635-4e2a-8810-7e043f7368cf','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:55',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-MonitoringSubscriptionsConfig-wwwwj534vyyl','state changed','OS::Heat::Value',NULL,276),(600,'05654747-a836-43ad-a590-0a1999caaec6','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:55',NULL,'CREATE','IN_PROGRESS','KollaConfig','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-KollaConfig-dmpwd3wbciw2','state changed','OS::Heat::Value',NULL,281),(601,'c172fd5e-fb35-407e-ab02-c1f2288e53eb','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:55',NULL,'CREATE','IN_PROGRESS','FirewallRules','cell1-CellControllerComputeServiceChain-aseidyipoyc3-FirewallRules-vhzw5dfmnaoa','state changed','OS::Heat::Value',NULL,282),(602,'9b6b0292-336a-4fc3-afcc-0e92823741c0','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:55',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-HostPrepTasks-ekrthjp7qiqa','state changed','OS::Heat::Value',NULL,280),(603,'474fe909-4b18-4136-bf36-c4531fd87063','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:55',NULL,'CREATE','COMPLETE','KollaConfig','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-KollaConfig-dmpwd3wbciw2','state changed','OS::Heat::Value',NULL,281),(604,'61dad7fa-be68-499b-96cf-0df9f9cf5dcb','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:55',NULL,'CREATE','COMPLETE','FirewallRules','cell1-CellControllerComputeServiceChain-aseidyipoyc3-FirewallRules-vhzw5dfmnaoa','state changed','OS::Heat::Value',NULL,282),(605,'590bc8c7-52f9-4b4d-86c7-7f4dbc8278de','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:55',NULL,'CREATE','IN_PROGRESS','KollaConfig','cell1-CellControllerComputeServiceChain-aseidyipoyc3-KollaConfig-rngfmkk5gjm3','state changed','OS::Heat::Value',NULL,284),(606,'31094d3a-8416-4525-b5dd-60e09b92894a','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:55',NULL,'CREATE','COMPLETE','KollaConfig','cell1-CellControllerComputeServiceChain-aseidyipoyc3-KollaConfig-rngfmkk5gjm3','state changed','OS::Heat::Value',NULL,284),(607,'c00adb2f-ee92-4502-9267-bcc062985afc','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:55',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','cell1-CellControllerComputeServiceChain-aseidyipoyc3-MonitoringSubscriptionsConfig-tr3aynhjmqj4','state changed','OS::Heat::Value',NULL,286),(608,'e050127b-c1b3-4a5f-b096-dbaff8e6305e','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:55',NULL,'CREATE','COMPLETE','BlockStorageServiceChain','0292a578-a91f-4468-b72e-e0d581ff796d','state changed','OS::TripleO::BlockStorageServices',NULL,68),(609,'5713143a-e133-43c3-bd60-079ee66aaa45','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:55',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','cell1-CellControllerComputeServiceChain-aseidyipoyc3-MonitoringSubscriptionsConfig-tr3aynhjmqj4','state changed','OS::Heat::Value',NULL,286),(610,'d5c0c0be-1f90-4f45-827d-44176fb6114c','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:55',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-UpgradeTasks-4bpep2yz2oe2','state changed','OS::Heat::Value',NULL,285),(611,'32de384f-a1fa-4f87-b688-8fcb0ba5d0bf','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:55',NULL,'CREATE','COMPLETE','HostPrepTasks','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-HostPrepTasks-ekrthjp7qiqa','state changed','OS::Heat::Value',NULL,280),(612,'ebdacae7-b1fb-4964-9c7e-305ab85dc8a4','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:55',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','cell1-CellControllerComputeServiceChain-aseidyipoyc3-PostUpgradeTasks-j553hnh4sang','state changed','OS::Heat::Value',NULL,287),(613,'4d67613c-f5ee-4920-a993-fdf040071c51','78507f36-81c1-4764-98ef-d65823dd1dc6','2026-06-12 08:25:55',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-2-wz6klstizmzw-MysqlPuppetBase-vhvodulspwnz-MysqlBase-utemobmazjtf','78507f36-81c1-4764-98ef-d65823dd1dc6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(614,'7b1489c2-3f52-4ee3-a72d-8741b6930468','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:55',NULL,'CREATE','COMPLETE','PostUpgradeTasks','cell1-CellControllerComputeServiceChain-aseidyipoyc3-PostUpgradeTasks-j553hnh4sang','state changed','OS::Heat::Value',NULL,287),(615,'01b88011-5881-447f-88e7-8c227892da80','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:55',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','cell1-CellControllerComputeServiceChain-aseidyipoyc3-PostUpdateTasks-wl3iltl5bujp','state changed','OS::Heat::Value',NULL,289),(616,'c2ef1d27-e345-4f70-b61f-49f267471675','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:55',NULL,'CREATE','COMPLETE','PostUpdateTasks','cell1-CellControllerComputeServiceChain-aseidyipoyc3-PostUpdateTasks-wl3iltl5bujp','state changed','OS::Heat::Value',NULL,289),(617,'9671e8a6-fbbd-498d-bebe-f72e0f459cba','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:55',NULL,'CREATE','COMPLETE','NetworkerServiceChain','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','state changed','OS::TripleO::NetworkerServices',NULL,66),(618,'383e671d-2605-45a9-a8f4-aaef13453e39','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:55',NULL,'CREATE','COMPLETE','UpgradeTasks','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-UpgradeTasks-4bpep2yz2oe2','state changed','OS::Heat::Value',NULL,285),(619,'83928f0c-f2d7-4e89-8225-3c01abb58c72','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:25:55',NULL,'CREATE','IN_PROGRESS','0','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-0-xdmo5kut7bal','state changed','OS::TripleO::Services::BootParams',NULL,294),(620,'77b9c891-4567-4bd7-ad4e-5da6e0cc48df','fe37e76b-9935-4130-aa62-8b87c49e18f6','2026-06-12 08:25:55',NULL,'CREATE','COMPLETE','cell1-ObjectStorageServiceChain-vuwq6dz2onkk','fe37e76b-9935-4130-aa62-8b87c49e18f6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(621,'241a166a-187d-457c-95bb-86628c809bee','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:55',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','cell1-CellControllerComputeServiceChain-aseidyipoyc3-ServiceServerMetadataHook-3bhd7eijo3u3','state changed','OS::TripleO::CellControllerComputeServiceServerMetadataHook',NULL,NULL),(622,'e9d74be2-3949-4569-bfe5-86ca7b101edb','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:55',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','cell1-CellControllerComputeServiceChain-aseidyipoyc3-PreDeployStepTasks-auy2mbkswh2s','state changed','OS::Heat::Value',NULL,307),(623,'b9473a2f-bb68-4d7c-970d-f423046452ec','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:55',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','107e8afb-6fdc-4667-8014-261b55728735','state changed','OS::TripleO::CellControllerComputeServiceServerMetadataHook',NULL,NULL),(624,'fbe6be13-69a7-4642-97e4-4ca384a5bb92','3ea2b1fd-84b5-42c1-aba0-323530b8a754','2026-06-12 08:25:55',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-0-xdmo5kut7bal','3ea2b1fd-84b5-42c1-aba0-323530b8a754','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(625,'bdd9247b-48a4-46a7-86f3-cb2e89d515a3','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:55',NULL,'CREATE','COMPLETE','PreDeployStepTasks','cell1-CellControllerComputeServiceChain-aseidyipoyc3-PreDeployStepTasks-auy2mbkswh2s','state changed','OS::Heat::Value',NULL,307),(626,'9e3d7851-0d53-483d-853b-0fc4a2778988','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','2026-06-12 08:25:55',NULL,'CREATE','COMPLETE','cell1-CellControllerComputeServiceChain-aseidyipoyc3','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(627,'a020072f-0279-4c57-81b5-086e9df58ff7','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:55',NULL,'CREATE','COMPLETE','ControllerServiceChain','f3979da4-1312-4314-a6b6-ac051d536f13','state changed','OS::TripleO::ControllerServices',NULL,70),(628,'9e304f84-4de3-4c5e-9219-7abeaf30ac33','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:55',NULL,'CREATE','COMPLETE','CephStorageServiceChain','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','state changed','OS::TripleO::CephStorageServices',NULL,69),(629,'d780ac7f-4f7f-404e-8be7-34652eb87c1c','3ea2b1fd-84b5-42c1-aba0-323530b8a754','2026-06-12 08:25:55',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-0-xdmo5kut7bal-RoleParametersValue-npdixfo2hiif','state changed','OS::Heat::Value',NULL,335),(630,'ae4a3141-c01b-43a3-b362-ff4e19c5f082','3ea2b1fd-84b5-42c1-aba0-323530b8a754','2026-06-12 08:25:55',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-0-xdmo5kut7bal-RoleParametersValue-npdixfo2hiif','state changed','OS::Heat::Value',NULL,335),(631,'0eaa2830-bc6d-482c-b5f7-1141aaab7d01','f150be6c-b1ea-4b80-ae04-d2a879a02cf6','2026-06-12 08:25:55',NULL,'CREATE','IN_PROGRESS','ContainersCommon','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-2-wz6klstizmzw-ContainersCommon-eanqswtfaqkq','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(632,'7aa5b230-6784-4b04-a0c0-5223cc8e6279','3ea2b1fd-84b5-42c1-aba0-323530b8a754','2026-06-12 08:25:55',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-0-xdmo5kut7bal','3ea2b1fd-84b5-42c1-aba0-323530b8a754','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(633,'df748890-056b-48cb-bff7-aaff0c789ace','2c249235-3b59-4adc-9ee6-d94d75b45b3b','2026-06-12 08:25:55',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-2-wz6klstizmzw-ContainersCommon-eanqswtfaqkq','2c249235-3b59-4adc-9ee6-d94d75b45b3b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(634,'db025d73-34ee-412e-bb23-2251357633d0','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:55',NULL,'CREATE','COMPLETE','CellControllerComputeServiceChain','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','state changed','OS::TripleO::CellControllerComputeServices',NULL,71),(635,'bd18e3bc-cfb0-4641-badb-81590be110b6','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:56',NULL,'CREATE','IN_PROGRESS','BlockStorageServiceChainRoleData','cell1-BlockStorageServiceChainRoleData-fjubjw6btssv','state changed','OS::Heat::Value',NULL,379),(636,'524e0a0a-511e-4c8c-912c-9a6afa1c3376','2c249235-3b59-4adc-9ee6-d94d75b45b3b','2026-06-12 08:25:56',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-2-wz6klstizmzw-ContainersCommon-eanqswtfaqkq','2c249235-3b59-4adc-9ee6-d94d75b45b3b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(637,'9de4d4f5-8d6d-4f18-93de-4452ab4da7bf','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:56',NULL,'CREATE','COMPLETE','BlockStorageServiceChainRoleData','cell1-BlockStorageServiceChainRoleData-fjubjw6btssv','state changed','OS::Heat::Value',NULL,379),(638,'6b9be2e1-24a0-47fd-93ae-27cc1e7fb100','96410e6c-c152-402d-9a63-b396d4be3ed2','2026-06-12 08:25:56',NULL,'CREATE','IN_PROGRESS','ContainersCommon','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-2-wz6klstizmzw-MysqlPuppetBase-vhvodulspwnz-ContainersCommon-pbnfk5oz7uav','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(639,'d4426120-57bc-47ae-aa02-03c2e55726de','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:25:56',NULL,'CREATE','IN_PROGRESS','2','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-2-mjecmijlgaua','state changed','OS::TripleO::Services::Collectd',NULL,409),(640,'7364b4c4-a01a-4d78-939d-563ed471747b','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:56',NULL,'CREATE','IN_PROGRESS','NetworkerServiceChainRoleData','cell1-NetworkerServiceChainRoleData-nom5c6vibfae','state changed','OS::Heat::Value',NULL,419),(641,'4b9cf62e-da53-4a05-8bdd-30fe92056c8f','cfb345cc-dc34-424b-9b2b-6cc07b5c2029','2026-06-12 08:25:56',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-2-wz6klstizmzw-MysqlPuppetBase-vhvodulspwnz-ContainersCommon-pbnfk5oz7uav','cfb345cc-dc34-424b-9b2b-6cc07b5c2029','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(642,'12ffad92-124a-4041-99a2-4a54b86312ae','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:56',NULL,'CREATE','IN_PROGRESS','BlockStorageServiceNames','cell1-BlockStorageServiceNames-kzxhv22r7mlv','state changed','OS::Heat::Value',NULL,425),(643,'3208c7a2-befb-4b61-8d2d-81dd57bdf7f4','cfb345cc-dc34-424b-9b2b-6cc07b5c2029','2026-06-12 08:25:56',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-2-wz6klstizmzw-MysqlPuppetBase-vhvodulspwnz-ContainersCommon-pbnfk5oz7uav','cfb345cc-dc34-424b-9b2b-6cc07b5c2029','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(644,'92ce9d76-1cd1-4c74-9f01-c3e8410de1b9','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:56',NULL,'CREATE','COMPLETE','NetworkerServiceChainRoleData','cell1-NetworkerServiceChainRoleData-nom5c6vibfae','state changed','OS::Heat::Value',NULL,419),(645,'d9d2be8c-d27b-4898-bab4-7f4ae36fd33c','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:56',NULL,'CREATE','COMPLETE','BlockStorageServiceNames','cell1-BlockStorageServiceNames-kzxhv22r7mlv','state changed','OS::Heat::Value',NULL,425),(646,'d172afaa-1975-4e86-a715-1a9bf07ab04b','7e42f6df-4d85-4524-842c-c3711bfd9c2a','2026-06-12 08:25:56',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-2-mjecmijlgaua','7e42f6df-4d85-4524-842c-c3711bfd9c2a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(647,'4baa5ae4-ebeb-4790-99a5-59ac3089313c','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:56',NULL,'CREATE','IN_PROGRESS','NetworkerServiceNames','cell1-NetworkerServiceNames-gxfopog6eipc','state changed','OS::Heat::Value',NULL,460),(648,'c74b3a0c-52c9-478b-a452-51be05fdd4f8','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:56',NULL,'CREATE','COMPLETE','NetworkerServiceNames','cell1-NetworkerServiceNames-gxfopog6eipc','state changed','OS::Heat::Value',NULL,460),(649,'0773d3c4-1aba-4124-b76a-8ad84dad43e6','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:56',NULL,'CREATE','IN_PROGRESS','ControllerServiceChainRoleData','cell1-ControllerServiceChainRoleData-txz7tvz2oexn','state changed','OS::Heat::Value',NULL,461),(650,'42fa89c7-855e-437c-94b5-c5fa2fe91e63','96410e6c-c152-402d-9a63-b396d4be3ed2','2026-06-12 08:25:56',NULL,'CREATE','COMPLETE','MysqlBase','78507f36-81c1-4764-98ef-d65823dd1dc6','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-base.yaml',NULL,271),(651,'3161f598-2e15-4ca2-91b1-354d37ffaa52','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:56',NULL,'CREATE','COMPLETE','ControllerServiceChainRoleData','cell1-ControllerServiceChainRoleData-txz7tvz2oexn','state changed','OS::Heat::Value',NULL,461),(652,'a5e9cbef-6139-4db4-82b8-f23e909c7d95','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:56',NULL,'CREATE','IN_PROGRESS','CephStorageServiceChainRoleData','cell1-CephStorageServiceChainRoleData-3aqqnlfmxvbh','state changed','OS::Heat::Value',NULL,464),(653,'c56cd8f1-d3d8-4412-b11b-55fbde0c218e','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:56',NULL,'CREATE','COMPLETE','CephStorageServiceChainRoleData','cell1-CephStorageServiceChainRoleData-3aqqnlfmxvbh','state changed','OS::Heat::Value',NULL,464),(654,'7fb3d9f6-42c0-4321-9534-db4e3b34ce28','7e42f6df-4d85-4524-842c-c3711bfd9c2a','2026-06-12 08:25:56',NULL,'CREATE','IN_PROGRESS','ContainersCommon','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-2-mjecmijlgaua-ContainersCommon-rffprbegbs6a','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(655,'759193bd-9fa0-4c65-b4a1-8ebc48c21c2e','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:56',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServiceChainRoleData','cell1-CellControllerComputeServiceChainRoleData-tiyrjjkdbwcv','state changed','OS::Heat::Value',NULL,465),(656,'f4dc5b0a-6f29-4dc7-9fe3-57792292468e','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:25:56',NULL,'CREATE','IN_PROGRESS','1','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-1-og6hwpijbuiu','state changed','OS::TripleO::Services::CACerts',NULL,466),(657,'b5c392ff-8ed8-4310-8441-7a70dea4d8ed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:56',NULL,'CREATE','COMPLETE','ObjectStorageServiceChain','fe37e76b-9935-4130-aa62-8b87c49e18f6','state changed','OS::TripleO::ObjectStorageServices',NULL,67),(658,'6b6bfdd3-7219-4144-badb-7b953bfc96c1','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:56',NULL,'CREATE','COMPLETE','CellControllerComputeServiceChainRoleData','cell1-CellControllerComputeServiceChainRoleData-tiyrjjkdbwcv','state changed','OS::Heat::Value',NULL,465),(659,'67e47376-881f-455d-bc2e-ce855a0b7266','6f38bf62-8a05-4e70-ad10-20bc69fe9a83','2026-06-12 08:25:56',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-1-og6hwpijbuiu','6f38bf62-8a05-4e70-ad10-20bc69fe9a83','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(660,'87582b29-9330-42b2-8ffe-05bf44c9ca41','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:25:56',NULL,'CREATE','COMPLETE','0','3ea2b1fd-84b5-42c1-aba0-323530b8a754','state changed','OS::TripleO::Services::BootParams',NULL,294),(661,'056b8190-c9c4-46a2-bb7a-6464d95076a2','6f38bf62-8a05-4e70-ad10-20bc69fe9a83','2026-06-12 08:25:56',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-1-og6hwpijbuiu','6f38bf62-8a05-4e70-ad10-20bc69fe9a83','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(662,'2c7f347d-34f4-463c-afd1-8a20315bec03','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:56',NULL,'CREATE','IN_PROGRESS','CephStorageServiceNames','cell1-CephStorageServiceNames-zbcfcpfakmvr','state changed','OS::Heat::Value',NULL,469),(663,'677a4d34-4688-478b-8910-78d8da164f46','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:56',NULL,'CREATE','IN_PROGRESS','BlockStorage','cell1-BlockStorage-jyr5bxugzeda','state changed','OS::Heat::ResourceGroup',NULL,470),(664,'6cc781e1-6f6b-4f6a-9ba2-7766e8112178','f150be6c-b1ea-4b80-ae04-d2a879a02cf6','2026-06-12 08:25:56',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-2-wz6klstizmzw-RoleParametersValue-sfazuam5r5np','state changed','OS::Heat::Value',NULL,475),(665,'1ef7492b-84c9-43cc-98f0-b761dcf81ffc','f150be6c-b1ea-4b80-ae04-d2a879a02cf6','2026-06-12 08:25:56',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-2-wz6klstizmzw-RoleParametersValue-sfazuam5r5np','state changed','OS::Heat::Value',NULL,475),(666,'900df217-b039-4453-a3f2-95fa4b0622eb','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:56',NULL,'CREATE','COMPLETE','CephStorageServiceNames','cell1-CephStorageServiceNames-zbcfcpfakmvr','state changed','OS::Heat::Value',NULL,469),(667,'3f43f6aa-944e-427c-99d7-b90e13462bdc','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:25:56',NULL,'CREATE','COMPLETE','1','6f38bf62-8a05-4e70-ad10-20bc69fe9a83','state changed','OS::TripleO::Services::CACerts',NULL,466),(668,'de21aba5-1efc-4a34-a8c4-a3e0804497a3','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:56',NULL,'CREATE','IN_PROGRESS','ControllerServiceNames','cell1-ControllerServiceNames-yi7ah66um725','state changed','OS::Heat::Value',NULL,474),(669,'48ee1ac6-9429-470d-af3c-7e635ed673d0','7144d587-abdb-41cb-bee3-759af144db2b','2026-06-12 08:25:56',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-2-mjecmijlgaua-ContainersCommon-rffprbegbs6a','7144d587-abdb-41cb-bee3-759af144db2b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(670,'22f24d59-88ed-4271-8180-f8a456eddfbf','1ff3e92f-9b0f-4f8d-84ca-b1b090a3706e','2026-06-12 08:25:56',NULL,'CREATE','IN_PROGRESS','cell1-BlockStorage-jyr5bxugzeda','1ff3e92f-9b0f-4f8d-84ca-b1b090a3706e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(671,'188a38db-cb74-4c2d-8432-1ec514d39a0c','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:56',NULL,'CREATE','COMPLETE','ControllerServiceNames','cell1-ControllerServiceNames-yi7ah66um725','state changed','OS::Heat::Value',NULL,474),(672,'87f5aab1-0957-424f-a9ac-a34d8e08dc3b','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:25:56',NULL,'CREATE','IN_PROGRESS','4','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-4-ks2oime3yi7k','state changed','OS::TripleO::Services::ContainerImagePrepare',NULL,482),(673,'d0c98cbf-ac91-483e-b863-4feda28295b3','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:57',NULL,'CREATE','IN_PROGRESS','Networker','cell1-Networker-l5by4tsig5wz','state changed','OS::Heat::ResourceGroup',NULL,485),(674,'aa688140-8b6b-4e0a-af82-9d6b1b68cd00','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:57',NULL,'CREATE','IN_PROGRESS','CephStorage','cell1-CephStorage-phmps4ll5uyq','state changed','OS::Heat::ResourceGroup',NULL,484),(675,'ddf0e4fd-9c2f-499d-8bca-2a08621e5110','7144d587-abdb-41cb-bee3-759af144db2b','2026-06-12 08:25:57',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-2-mjecmijlgaua-ContainersCommon-rffprbegbs6a','7144d587-abdb-41cb-bee3-759af144db2b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(676,'d24f5668-28f5-4e09-aba7-9617753c55ec','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:57',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServiceNames','cell1-CellControllerComputeServiceNames-h4ktymzpd6wd','state changed','OS::Heat::Value',NULL,486),(677,'e3a08e99-658f-4c80-8ce9-8dfb60692f2c','1ff3e92f-9b0f-4f8d-84ca-b1b090a3706e','2026-06-12 08:25:57',NULL,'CREATE','COMPLETE','cell1-BlockStorage-jyr5bxugzeda','1ff3e92f-9b0f-4f8d-84ca-b1b090a3706e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(678,'2c959beb-6788-4127-9bf6-25e3fa33b8b7','96410e6c-c152-402d-9a63-b396d4be3ed2','2026-06-12 08:25:57',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-2-wz6klstizmzw-MysqlPuppetBase-vhvodulspwnz-RoleParametersValue-fvvusxuzmxtg','state changed','OS::Heat::Value',NULL,488),(679,'b83252a4-0e25-4f68-bd6d-26db879a977b','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:57',NULL,'CREATE','COMPLETE','CellControllerComputeServiceNames','cell1-CellControllerComputeServiceNames-h4ktymzpd6wd','state changed','OS::Heat::Value',NULL,486),(680,'b5ded171-7ee0-41bf-a4e5-1a5c0be0244c','96410e6c-c152-402d-9a63-b396d4be3ed2','2026-06-12 08:25:57',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-2-wz6klstizmzw-MysqlPuppetBase-vhvodulspwnz-RoleParametersValue-fvvusxuzmxtg','state changed','OS::Heat::Value',NULL,488),(681,'048b444e-ad0c-4e10-8422-04412eb6ff8d','dd6d9b23-be82-4983-93db-b99c31d045fc','2026-06-12 08:25:57',NULL,'CREATE','IN_PROGRESS','cell1-Networker-l5by4tsig5wz','dd6d9b23-be82-4983-93db-b99c31d045fc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(682,'f0ba3848-0711-433a-bada-76c666f43dec','dd6d9b23-be82-4983-93db-b99c31d045fc','2026-06-12 08:25:57',NULL,'CREATE','COMPLETE','cell1-Networker-l5by4tsig5wz','dd6d9b23-be82-4983-93db-b99c31d045fc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(683,'1a7f592a-422e-4f61-bd2d-d8776e09849e','f150be6c-b1ea-4b80-ae04-d2a879a02cf6','2026-06-12 08:25:57',NULL,'CREATE','COMPLETE','ContainersCommon','2c249235-3b59-4adc-9ee6-d94d75b45b3b','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(684,'b82426b2-4fef-4974-8e2e-98530b500616','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:25:57',NULL,'CREATE','IN_PROGRESS','0','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-0-vam7tpbenaum','state changed','OS::TripleO::Services::BootParams',NULL,490),(685,'50205ab8-fb06-4033-92a6-11445717bcaf','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:25:57',NULL,'CREATE','IN_PROGRESS','5','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-5-lpcvlr4p5gdm','state changed','OS::TripleO::Services::ContainersLogrotateCrond',NULL,489),(686,'4e53be22-cd84-41be-95a1-a975e5a9c6c1','321eb990-9594-4c85-81e4-e46ac106bd7c','2026-06-12 08:25:57',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-4-ks2oime3yi7k','321eb990-9594-4c85-81e4-e46ac106bd7c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(687,'e823fa41-a8f7-4128-9eb4-b98c066de097','96410e6c-c152-402d-9a63-b396d4be3ed2','2026-06-12 08:25:57',NULL,'CREATE','COMPLETE','ContainersCommon','cfb345cc-dc34-424b-9b2b-6cc07b5c2029','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(688,'dc40a59a-6cb6-4409-bedc-5b37bb650472','5befeaa1-dc7f-4614-b1b8-c00bb4b633af','2026-06-12 08:25:57',NULL,'CREATE','IN_PROGRESS','cell1-CephStorage-phmps4ll5uyq','5befeaa1-dc7f-4614-b1b8-c00bb4b633af','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(689,'cd31f51f-86ef-406c-ba87-85a471bdf360','321eb990-9594-4c85-81e4-e46ac106bd7c','2026-06-12 08:25:57',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-4-ks2oime3yi7k','321eb990-9594-4c85-81e4-e46ac106bd7c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(690,'7ef10d76-a5d8-4c63-a998-a68f4d522c70','ad319e04-5e52-4122-828d-2067f37851e7','2026-06-12 08:25:57',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-0-vam7tpbenaum','ad319e04-5e52-4122-828d-2067f37851e7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(691,'71f8a4f9-5c19-4be1-add0-26b9cbe72c80','359dc1b1-b997-4184-828b-7e29eb2f5921','2026-06-12 08:25:57',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-5-lpcvlr4p5gdm','359dc1b1-b997-4184-828b-7e29eb2f5921','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(692,'a8a6ce82-3af5-4b61-af89-cb005b60058b','96410e6c-c152-402d-9a63-b396d4be3ed2','2026-06-12 08:25:57',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-2-wz6klstizmzw-MysqlPuppetBase-vhvodulspwnz','96410e6c-c152-402d-9a63-b396d4be3ed2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(693,'8d1bf2bb-cb25-4d7c-8664-04028bd4e4a4','5befeaa1-dc7f-4614-b1b8-c00bb4b633af','2026-06-12 08:25:57',NULL,'CREATE','COMPLETE','cell1-CephStorage-phmps4ll5uyq','5befeaa1-dc7f-4614-b1b8-c00bb4b633af','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(694,'1c31ddfb-9acb-47c7-8bab-9c95289854ec','359dc1b1-b997-4184-828b-7e29eb2f5921','2026-06-12 08:25:57',NULL,'CREATE','IN_PROGRESS','ContainersCommon','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-5-lpcvlr4p5gdm-ContainersCommon-c4c53tw3zrzq','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(695,'e1aad555-6931-4c9b-8846-ecc23eb77e10','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:57',NULL,'CREATE','IN_PROGRESS','Controller','cell1-Controller-nil5a3jziwpw','state changed','OS::Heat::ResourceGroup',NULL,517),(696,'3014f712-a705-46df-9ce1-7d77ded9e99b','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:25:57',NULL,'CREATE','IN_PROGRESS','3','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-3-fo5jiixb4ojl','state changed','OS::TripleO::Services::Collectd',NULL,523),(697,'e909f6ca-643d-4ab1-875d-8839723e347a','7e42f6df-4d85-4524-842c-c3711bfd9c2a','2026-06-12 08:25:57',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-2-mjecmijlgaua-RoleParametersValue-txyj32yoqsm6','state changed','OS::Heat::Value',NULL,524),(698,'9553f1cc-e73a-468d-8b67-b79584866c89','f017d30e-3fb3-4803-a180-4886096685a5','2026-06-12 08:25:57',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-5-lpcvlr4p5gdm-ContainersCommon-c4c53tw3zrzq','f017d30e-3fb3-4803-a180-4886096685a5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(699,'741198ea-5c52-411e-8af2-68e516083ad0','f017d30e-3fb3-4803-a180-4886096685a5','2026-06-12 08:25:57',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-5-lpcvlr4p5gdm-ContainersCommon-c4c53tw3zrzq','f017d30e-3fb3-4803-a180-4886096685a5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(700,'31c3818c-d680-46d3-9fa7-eb7e8b07f3c7','ad319e04-5e52-4122-828d-2067f37851e7','2026-06-12 08:25:57',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-0-vam7tpbenaum-RoleParametersValue-6z6iylhkback','state changed','OS::Heat::Value',NULL,525),(701,'b22112dd-ebc6-40a4-8d4b-aabb8f67b7bb','7e42f6df-4d85-4524-842c-c3711bfd9c2a','2026-06-12 08:25:57',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-2-mjecmijlgaua-RoleParametersValue-txyj32yoqsm6','state changed','OS::Heat::Value',NULL,524),(702,'0b8665c2-2b18-417f-a59e-e4875f7daaa4','ad319e04-5e52-4122-828d-2067f37851e7','2026-06-12 08:25:57',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-0-vam7tpbenaum-RoleParametersValue-6z6iylhkback','state changed','OS::Heat::Value',NULL,525),(703,'e6748922-96f0-4404-bdd4-5f4494bf2776','775f7e6e-e594-45d1-bb15-35c6cf3a06fd','2026-06-12 08:25:57',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-3-fo5jiixb4ojl','775f7e6e-e594-45d1-bb15-35c6cf3a06fd','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(704,'a2556d0b-5d7a-40a9-ace2-fec4e02102c5','ad319e04-5e52-4122-828d-2067f37851e7','2026-06-12 08:25:57',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-0-vam7tpbenaum','ad319e04-5e52-4122-828d-2067f37851e7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(705,'8eb2cf40-b40c-4b64-8630-e820f7ee3e8c','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:57',NULL,'CREATE','IN_PROGRESS','CellControllerCompute','cell1-CellControllerCompute-abahhgt3ie7w','state changed','OS::Heat::ResourceGroup',NULL,526),(706,'b51f3dfb-ee2a-4812-b691-ba7e89871f9d','775f7e6e-e594-45d1-bb15-35c6cf3a06fd','2026-06-12 08:25:57',NULL,'CREATE','IN_PROGRESS','ContainersCommon','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-3-fo5jiixb4ojl-ContainersCommon-oduy7ix2bml7','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(707,'a9c40e16-5d70-4299-adf7-a3f19f1d3b54','20e5f319-308e-4d54-8aa6-2e65c7e250a0','2026-06-12 08:25:57',NULL,'CREATE','IN_PROGRESS','cell1-Controller-nil5a3jziwpw','20e5f319-308e-4d54-8aa6-2e65c7e250a0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(708,'fac88d91-ef87-4f3a-a9d3-5109850b3d6d','ac9109b8-accc-4549-bf53-f6d0802e55c3','2026-06-12 08:25:57',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerCompute-abahhgt3ie7w','ac9109b8-accc-4549-bf53-f6d0802e55c3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(709,'1cd1194b-9668-4fcd-99fc-96434304a454','20e5f319-308e-4d54-8aa6-2e65c7e250a0','2026-06-12 08:25:57',NULL,'CREATE','COMPLETE','cell1-Controller-nil5a3jziwpw','20e5f319-308e-4d54-8aa6-2e65c7e250a0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(710,'03a2a9eb-4019-43ad-912c-2fe32ffee421','ac9109b8-accc-4549-bf53-f6d0802e55c3','2026-06-12 08:25:57',NULL,'CREATE','COMPLETE','cell1-CellControllerCompute-abahhgt3ie7w','ac9109b8-accc-4549-bf53-f6d0802e55c3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(711,'0da57050-4a83-4422-8e2c-df421c58d97e','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:57',NULL,'CREATE','IN_PROGRESS','ObjectStorageServiceChainRoleData','cell1-ObjectStorageServiceChainRoleData-uzpvdjae4wmm','state changed','OS::Heat::Value',NULL,529),(712,'9eca286e-337a-485b-ad5c-ae679f8870c6','ea5a38cf-628b-4978-a33c-61d6bdb40ce9','2026-06-12 08:25:57',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-3-fo5jiixb4ojl-ContainersCommon-oduy7ix2bml7','ea5a38cf-628b-4978-a33c-61d6bdb40ce9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(713,'1080c5e3-f444-4e48-9be2-d2c4056a02c8','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:57',NULL,'CREATE','COMPLETE','ObjectStorageServiceChainRoleData','cell1-ObjectStorageServiceChainRoleData-uzpvdjae4wmm','state changed','OS::Heat::Value',NULL,529),(714,'3e3d8713-e87f-4ac2-9e64-cc2137806307','ea5a38cf-628b-4978-a33c-61d6bdb40ce9','2026-06-12 08:25:57',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-3-fo5jiixb4ojl-ContainersCommon-oduy7ix2bml7','ea5a38cf-628b-4978-a33c-61d6bdb40ce9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(715,'17530f05-931b-44f3-81bb-5ca68d2c8e35','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:58',NULL,'CREATE','COMPLETE','BlockStorage','1ff3e92f-9b0f-4f8d-84ca-b1b090a3706e','state changed','OS::Heat::ResourceGroup',NULL,470),(716,'29cbfecc-eb1b-4a86-aef7-bb99ff130505','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:58',NULL,'CREATE','IN_PROGRESS','ObjectStorageServiceNames','cell1-ObjectStorageServiceNames-h56j5qdvwwyu','state changed','OS::Heat::Value',NULL,530),(717,'73d999fb-4aad-4d6d-8fac-564a29829a03','f150be6c-b1ea-4b80-ae04-d2a879a02cf6','2026-06-12 08:25:58',NULL,'CREATE','COMPLETE','MysqlPuppetBase','96410e6c-c152-402d-9a63-b396d4be3ed2','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml',NULL,261),(718,'da5f096a-fd8e-4398-ae72-eedfd84b0b5c','7e42f6df-4d85-4524-842c-c3711bfd9c2a','2026-06-12 08:25:58',NULL,'CREATE','COMPLETE','ContainersCommon','7144d587-abdb-41cb-bee3-759af144db2b','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(719,'6f64dbc4-241c-4af6-b056-ff23e35f5b6f','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:58',NULL,'CREATE','COMPLETE','ObjectStorageServiceNames','cell1-ObjectStorageServiceNames-h56j5qdvwwyu','state changed','OS::Heat::Value',NULL,530),(720,'4da15988-b234-42b0-bcfe-1966f80ed3d8','f150be6c-b1ea-4b80-ae04-d2a879a02cf6','2026-06-12 08:25:58',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-2-wz6klstizmzw','f150be6c-b1ea-4b80-ae04-d2a879a02cf6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(721,'19095628-0dfc-4dd0-8c09-46575c8a075a','7e42f6df-4d85-4524-842c-c3711bfd9c2a','2026-06-12 08:25:58',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-2-mjecmijlgaua','7e42f6df-4d85-4524-842c-c3711bfd9c2a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(722,'bf7b0b80-9545-4a28-aeb0-e6a914140c7f','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:58',NULL,'CREATE','COMPLETE','Networker','dd6d9b23-be82-4983-93db-b99c31d045fc','state changed','OS::Heat::ResourceGroup',NULL,485),(723,'66d34059-b672-4a0e-abfb-b9fe76994b09','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:25:58',NULL,'CREATE','IN_PROGRESS','1','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-1-3v3minbktodp','state changed','OS::TripleO::Services::CACerts',NULL,532),(724,'59222fb2-5bd6-440e-b6fc-ec6ff39b4584','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:58',NULL,'CREATE','IN_PROGRESS','BlockStorageNetworkHostnameMap','cell1-BlockStorageNetworkHostnameMap-ik34ziagrsxf','state changed','OS::Heat::Value',NULL,533),(725,'6317abe3-80ec-412f-9cd2-bdc00fd9d546','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:58',NULL,'CREATE','COMPLETE','BlockStorageNetworkHostnameMap','cell1-BlockStorageNetworkHostnameMap-ik34ziagrsxf','state changed','OS::Heat::Value',NULL,533),(726,'92146d83-d680-43b2-a6db-14916df51b45','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:25:58',NULL,'CREATE','COMPLETE','4','321eb990-9594-4c85-81e4-e46ac106bd7c','state changed','OS::TripleO::Services::ContainerImagePrepare',NULL,482),(727,'fcc09c9d-7564-4657-aff2-95d6b06ce039','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:25:58',NULL,'CREATE','COMPLETE','2','7e42f6df-4d85-4524-842c-c3711bfd9c2a','state changed','OS::TripleO::Services::Collectd',NULL,409),(728,'0c696ad7-8c58-4eb9-8947-5f4b32e4a6c0','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:58',NULL,'CREATE','IN_PROGRESS','NetworkerServers','cell1-NetworkerServers-tx72mmdxupxs','state changed','OS::Heat::Value',NULL,536),(729,'b0ba630a-2568-44db-81ee-c7908190f6a0','37578041-f4dd-48f1-b1ae-95e1200aa4a4','2026-06-12 08:25:58',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-1-3v3minbktodp','37578041-f4dd-48f1-b1ae-95e1200aa4a4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(730,'0508243c-8aa5-41c0-8d31-d4147268e5ae','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:58',NULL,'CREATE','IN_PROGRESS','NetworkerNetworkHostnameMap','cell1-NetworkerNetworkHostnameMap-4pwxxetbqhxk','state changed','OS::Heat::Value',NULL,537),(731,'607cb0ea-73e6-4842-b934-faf14201ebbe','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:58',NULL,'CREATE','COMPLETE','CephStorage','5befeaa1-dc7f-4614-b1b8-c00bb4b633af','state changed','OS::Heat::ResourceGroup',NULL,484),(732,'1f948c75-51f8-443d-995d-cc4f43e984a2','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:58',NULL,'CREATE','COMPLETE','NetworkerNetworkHostnameMap','cell1-NetworkerNetworkHostnameMap-4pwxxetbqhxk','state changed','OS::Heat::Value',NULL,537),(733,'0e5b1aa0-ac8f-4d93-9418-b9ba9fb543f2','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:25:58',NULL,'CREATE','COMPLETE','0','ad319e04-5e52-4122-828d-2067f37851e7','state changed','OS::TripleO::Services::BootParams',NULL,490),(734,'ad19c330-7f04-411e-81a4-9b797f049517','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:58',NULL,'CREATE','IN_PROGRESS','BlockStorageIpListMap','cell1-BlockStorageIpListMap-kse3ivk3mc4x','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,540),(735,'51a9f691-e71f-4488-885e-f899156beaaf','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:58',NULL,'CREATE','IN_PROGRESS','BlockStorageServers','cell1-BlockStorageServers-btsduvbdvmep','state changed','OS::Heat::Value',NULL,539),(736,'ab06a08a-7ef9-4e85-9ab0-3973dbc5d6e2','37578041-f4dd-48f1-b1ae-95e1200aa4a4','2026-06-12 08:25:58',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-1-3v3minbktodp','37578041-f4dd-48f1-b1ae-95e1200aa4a4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(737,'6aa0f525-dada-4d97-9f78-1513c5ef6a1a','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:58',NULL,'CREATE','COMPLETE','NetworkerServers','cell1-NetworkerServers-tx72mmdxupxs','state changed','OS::Heat::Value',NULL,536),(738,'bfafbe3a-a775-44b2-bba8-40aa909ecc67','80f2ace2-f881-4110-bcea-a8e8c1c6ca4d','2026-06-12 08:25:58',NULL,'CREATE','IN_PROGRESS','cell1-BlockStorageIpListMap-kse3ivk3mc4x','80f2ace2-f881-4110-bcea-a8e8c1c6ca4d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(739,'fe59faef-a771-449b-9b07-ba0891f7e5d3','359dc1b1-b997-4184-828b-7e29eb2f5921','2026-06-12 08:25:58',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-5-lpcvlr4p5gdm-RoleParametersValue-6gbbot4pdlix','state changed','OS::Heat::Value',NULL,543),(740,'908d7956-21b2-4c82-822a-8d522b075209','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:58',NULL,'CREATE','COMPLETE','BlockStorageServers','cell1-BlockStorageServers-btsduvbdvmep','state changed','OS::Heat::Value',NULL,539),(741,'64524266-2520-47e7-acdd-a5c8090d2b66','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:58',NULL,'CREATE','IN_PROGRESS','CephStorageServers','cell1-CephStorageServers-gkq5gkyp3ds5','state changed','OS::Heat::Value',NULL,545),(742,'53f5d36a-79a3-4dcb-ac0b-38d245a24ee5','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:25:58',NULL,'CREATE','IN_PROGRESS','8','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-8-m6gwavvys337','state changed','OS::TripleO::Services::Kernel',NULL,548),(743,'6063f698-9bd6-4fc8-9527-9a54b2b2938a','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:58',NULL,'CREATE','COMPLETE','CephStorageServers','cell1-CephStorageServers-gkq5gkyp3ds5','state changed','OS::Heat::Value',NULL,545),(744,'d2d2ba9b-e347-4ed7-a78b-4a9fa492f3f5','359dc1b1-b997-4184-828b-7e29eb2f5921','2026-06-12 08:25:58',NULL,'CREATE','COMPLETE','ContainersCommon','f017d30e-3fb3-4803-a180-4886096685a5','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(745,'e8e3cc10-32e5-45ed-9097-bd03ca332c24','359dc1b1-b997-4184-828b-7e29eb2f5921','2026-06-12 08:25:58',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-5-lpcvlr4p5gdm-RoleParametersValue-6gbbot4pdlix','state changed','OS::Heat::Value',NULL,543),(746,'7565c2b6-89d2-416b-afb4-592f73c89ddb','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:58',NULL,'CREATE','IN_PROGRESS','NetworkerIpListMap','cell1-NetworkerIpListMap-e5z2h5cn4r4m','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,550),(747,'439869ca-a09d-4127-9128-609409dfa83c','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:25:58',NULL,'CREATE','COMPLETE','2','f150be6c-b1ea-4b80-ae04-d2a879a02cf6','state changed','OS::TripleO::Services::Clustercheck',NULL,253),(748,'630a31ae-a045-48f9-9592-2f6d5ce8e2d0','80f2ace2-f881-4110-bcea-a8e8c1c6ca4d','2026-06-12 08:25:58',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','cell1-BlockStorageIpListMap-kse3ivk3mc4x-EnabledServicesValue-u3ex634awvx3','state changed','OS::Heat::Value',NULL,553),(749,'701fa0b6-3d27-410f-b1b4-636f9036333b','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:58',NULL,'CREATE','IN_PROGRESS','ObjectStorage','cell1-ObjectStorage-wrx6rjipqxsc','state changed','OS::Heat::ResourceGroup',NULL,547),(750,'1ee7e12a-c2af-400b-bcfc-c75de864fccf','359dc1b1-b997-4184-828b-7e29eb2f5921','2026-06-12 08:25:58',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-5-lpcvlr4p5gdm','359dc1b1-b997-4184-828b-7e29eb2f5921','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(751,'3b6469db-3682-430c-8cea-5ea187fd3ca4','80f2ace2-f881-4110-bcea-a8e8c1c6ca4d','2026-06-12 08:25:58',NULL,'CREATE','COMPLETE','EnabledServicesValue','cell1-BlockStorageIpListMap-kse3ivk3mc4x-EnabledServicesValue-u3ex634awvx3','state changed','OS::Heat::Value',NULL,553),(752,'7aec9b2c-22e2-4155-835d-4dda0206eec0','775f7e6e-e594-45d1-bb15-35c6cf3a06fd','2026-06-12 08:25:58',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-3-fo5jiixb4ojl-RoleParametersValue-ovuzwfkc6wb7','state changed','OS::Heat::Value',NULL,556),(753,'49913b51-82d9-4733-98c1-05582f507fe2','df5a343b-39ae-4424-a5b0-1cd4bf3907dc','2026-06-12 08:25:58',NULL,'CREATE','IN_PROGRESS','cell1-NetworkerIpListMap-e5z2h5cn4r4m','df5a343b-39ae-4424-a5b0-1cd4bf3907dc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(754,'bbbacf15-2d60-4f56-a749-62cd24c56463','775f7e6e-e594-45d1-bb15-35c6cf3a06fd','2026-06-12 08:25:58',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-3-fo5jiixb4ojl-RoleParametersValue-ovuzwfkc6wb7','state changed','OS::Heat::Value',NULL,556),(755,'3c223f2c-8741-4bf1-89ac-1f2437fb32f3','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:58',NULL,'CREATE','COMPLETE','CellControllerCompute','ac9109b8-accc-4549-bf53-f6d0802e55c3','state changed','OS::Heat::ResourceGroup',NULL,526),(756,'1059e14a-55ef-4d80-a9e7-28c234fd81ca','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:25:58',NULL,'CREATE','IN_PROGRESS','4','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-4-4pmbtyk4cwdx','state changed','OS::TripleO::Services::CeilometerAgentIpmi',NULL,555),(757,'a9b414e2-2fdf-499c-8fac-a4e3260e436e','775f7e6e-e594-45d1-bb15-35c6cf3a06fd','2026-06-12 08:25:58',NULL,'CREATE','COMPLETE','ContainersCommon','ea5a38cf-628b-4978-a33c-61d6bdb40ce9','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(758,'b4db3edc-dcaf-44a8-a767-3279bf8b7c77','775f7e6e-e594-45d1-bb15-35c6cf3a06fd','2026-06-12 08:25:58',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-3-fo5jiixb4ojl','775f7e6e-e594-45d1-bb15-35c6cf3a06fd','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(759,'6d1d23c2-f31f-4f5f-9d24-ed86b0aa4ad5','61fccc8d-01b4-4716-bdfa-37b1b4f1f8f1','2026-06-12 08:25:58',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-4-4pmbtyk4cwdx','61fccc8d-01b4-4716-bdfa-37b1b4f1f8f1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(760,'efb9a23b-1c06-4b5f-94b9-2a1277307d12','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:58',NULL,'CREATE','IN_PROGRESS','CephStorageNetworkHostnameMap','cell1-CephStorageNetworkHostnameMap-inkylvdjo5g4','state changed','OS::Heat::Value',NULL,561),(761,'874447e1-a78d-4d9d-af3f-721d0e5a8ee1','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:58',NULL,'CREATE','COMPLETE','Controller','20e5f319-308e-4d54-8aa6-2e65c7e250a0','state changed','OS::Heat::ResourceGroup',NULL,517),(762,'375c84e8-6561-4bba-ade7-f85da27df705','29ffb44b-a679-486f-aefb-2d26246a23fa','2026-06-12 08:25:58',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-8-m6gwavvys337','29ffb44b-a679-486f-aefb-2d26246a23fa','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(763,'3eba4372-1be6-418c-ba5e-bdf62d35de0a','df5a343b-39ae-4424-a5b0-1cd4bf3907dc','2026-06-12 08:25:59',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','cell1-NetworkerIpListMap-e5z2h5cn4r4m-NetIpMapValue-k7neawg5q4qf','state changed','OS::Heat::Value',NULL,565),(764,'f52a167c-1da3-48a2-ac33-e56accac56be','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:59',NULL,'CREATE','COMPLETE','CephStorageNetworkHostnameMap','cell1-CephStorageNetworkHostnameMap-inkylvdjo5g4','state changed','OS::Heat::Value',NULL,561),(765,'146245ca-1b53-4a37-917a-21f513233298','7585cd69-d480-470b-983f-9e7db34c857f','2026-06-12 08:25:59',NULL,'CREATE','IN_PROGRESS','cell1-ObjectStorage-wrx6rjipqxsc','7585cd69-d480-470b-983f-9e7db34c857f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(766,'bde63965-c9c1-4d9d-aa1d-3c6bf248f114','df5a343b-39ae-4424-a5b0-1cd4bf3907dc','2026-06-12 08:25:59',NULL,'CREATE','COMPLETE','NetIpMapValue','cell1-NetworkerIpListMap-e5z2h5cn4r4m-NetIpMapValue-k7neawg5q4qf','state changed','OS::Heat::Value',NULL,565),(767,'fa87b99a-d949-4863-93e2-3c82b036809d','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:59',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServers','cell1-CellControllerComputeServers-7qlmumqqcv4p','state changed','OS::Heat::Value',NULL,569),(768,'01d145ad-3c3f-44f9-9a5c-14bdc6598069','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:25:59',NULL,'CREATE','IN_PROGRESS','6','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-6-tfclxwc3mtfr','state changed','OS::TripleO::Services::Kernel',NULL,570),(769,'22934a51-7a35-48ca-84fe-cd393a346418','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:59',NULL,'CREATE','IN_PROGRESS','CellControllerComputeNetworkHostnameMap','cell1-CellControllerComputeNetworkHostnameMap-ojsehhrzppn2','state changed','OS::Heat::Value',NULL,572),(770,'c9bf6615-6ac9-4f6c-82e2-cceba519111e','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:59',NULL,'CREATE','COMPLETE','CellControllerComputeServers','cell1-CellControllerComputeServers-7qlmumqqcv4p','state changed','OS::Heat::Value',NULL,569),(771,'d462e6a8-c379-4e75-abd8-9645bee39a88','c078fb68-eea1-4fe9-8563-30285f2f8085','2026-06-12 08:25:59',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-6-tfclxwc3mtfr','c078fb68-eea1-4fe9-8563-30285f2f8085','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(772,'4b5f8147-14e2-4cd7-9031-8c7f25748437','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:59',NULL,'CREATE','COMPLETE','CellControllerComputeNetworkHostnameMap','cell1-CellControllerComputeNetworkHostnameMap-ojsehhrzppn2','state changed','OS::Heat::Value',NULL,572),(773,'97c55618-c527-483c-933c-5b2edbe6919b','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:59',NULL,'CREATE','IN_PROGRESS','CephStorageIpListMap','cell1-CephStorageIpListMap-vemgjlwrjbht','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,575),(774,'e7721b15-e71b-452b-b7b3-6150b1aec70b','7585cd69-d480-470b-983f-9e7db34c857f','2026-06-12 08:25:59',NULL,'CREATE','COMPLETE','cell1-ObjectStorage-wrx6rjipqxsc','7585cd69-d480-470b-983f-9e7db34c857f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(775,'ca3b2bd7-cf6c-4944-ad59-24051b5a476d','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:25:59',NULL,'CREATE','IN_PROGRESS','3','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-3-rli3gxeee5b5','state changed','OS::TripleO::Services::ComputeCeilometerAgent',NULL,574),(776,'b8dc90cb-bfc7-46dd-b9b2-a84f161035a0','29ffb44b-a679-486f-aefb-2d26246a23fa','2026-06-12 08:25:59',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-8-m6gwavvys337-RoleParametersValue-ck7snev2ao7i','state changed','OS::Heat::Value',NULL,579),(777,'58589631-aa86-440e-be92-ee85c02ca724','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:25:59',NULL,'CREATE','IN_PROGRESS','6','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-6-togxoevovf3t','state changed','OS::TripleO::Services::HAproxy',NULL,578),(778,'72751b59-2d0e-405a-b78b-170a2eac0cd5','5c998268-8060-4729-b055-5c45de716e21','2026-06-12 08:25:59',NULL,'CREATE','IN_PROGRESS','cell1-CephStorageIpListMap-vemgjlwrjbht','5c998268-8060-4729-b055-5c45de716e21','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(779,'ead719fa-1978-41c4-8904-b7db1065cad7','29ffb44b-a679-486f-aefb-2d26246a23fa','2026-06-12 08:25:59',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-8-m6gwavvys337-RoleParametersValue-ck7snev2ao7i','state changed','OS::Heat::Value',NULL,579),(780,'68236a91-67aa-43a7-9b3a-06e7f437a589','29ffb44b-a679-486f-aefb-2d26246a23fa','2026-06-12 08:25:59',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-8-m6gwavvys337','29ffb44b-a679-486f-aefb-2d26246a23fa','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(781,'39d67861-9101-4b97-80d2-4327631e91ea','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:59',NULL,'CREATE','IN_PROGRESS','ControllerServers','cell1-ControllerServers-eduxzxmy4hf5','state changed','OS::Heat::Value',NULL,581),(782,'32c60cd1-e711-4096-8e83-1b375e7f00fd','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:59',NULL,'CREATE','IN_PROGRESS','ControllerNetworkHostnameMap','cell1-ControllerNetworkHostnameMap-xkfnrqsca3ln','state changed','OS::Heat::Value',NULL,582),(783,'1e71695c-9bee-47c7-8568-ae77851d68fa','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:25:59',NULL,'CREATE','COMPLETE','5','359dc1b1-b997-4184-828b-7e29eb2f5921','state changed','OS::TripleO::Services::ContainersLogrotateCrond',NULL,489),(784,'51613e79-63a4-4c65-8397-6cd73002ff72','a2d6aeca-e7f4-4fff-ab84-c83863e19581','2026-06-12 08:25:59',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-3-rli3gxeee5b5','a2d6aeca-e7f4-4fff-ab84-c83863e19581','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(785,'6d76f63b-bf5f-4381-970e-57cbfc71297c','74eec8c4-422a-46d3-9ec6-f02901048161','2026-06-12 08:25:59',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-6-togxoevovf3t','74eec8c4-422a-46d3-9ec6-f02901048161','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(786,'3e15d47e-ac02-4e73-bd86-677f34d6707d','5c998268-8060-4729-b055-5c45de716e21','2026-06-12 08:25:59',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','cell1-CephStorageIpListMap-vemgjlwrjbht-EnabledServicesValue-r23uvd4db3en','state changed','OS::Heat::Value',NULL,584),(787,'8371116f-84db-42fb-9aef-c0c7a3db7c41','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:25:59',NULL,'CREATE','COMPLETE','1','37578041-f4dd-48f1-b1ae-95e1200aa4a4','state changed','OS::TripleO::Services::CACerts',NULL,532),(788,'a50bfb95-01c8-43b4-96d0-4d186948db30','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:59',NULL,'CREATE','COMPLETE','ControllerNetworkHostnameMap','cell1-ControllerNetworkHostnameMap-xkfnrqsca3ln','state changed','OS::Heat::Value',NULL,582),(789,'1f2e9c41-0c11-4f6b-b453-8f626bf3cea7','5c998268-8060-4729-b055-5c45de716e21','2026-06-12 08:25:59',NULL,'CREATE','COMPLETE','EnabledServicesValue','cell1-CephStorageIpListMap-vemgjlwrjbht-EnabledServicesValue-r23uvd4db3en','state changed','OS::Heat::Value',NULL,584),(790,'c327a497-8189-46ca-9b80-cede00f8871b','61fccc8d-01b4-4716-bdfa-37b1b4f1f8f1','2026-06-12 08:25:59',NULL,'CREATE','IN_PROGRESS','CeilometerAgentCentralBase','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-4-4pmbtyk4cwdx-CeilometerAgentCentralBase-sodg36cbj3zy','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml',NULL,585),(791,'eb79d7ee-0d83-42ab-b184-83ef44c68947','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:59',NULL,'CREATE','IN_PROGRESS','CellControllerComputeIpListMap','cell1-CellControllerComputeIpListMap-z5hijln7vyvd','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,586),(792,'f162e04e-e1d5-408e-a366-84122d6fae8e','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:59',NULL,'CREATE','COMPLETE','ControllerServers','cell1-ControllerServers-eduxzxmy4hf5','state changed','OS::Heat::Value',NULL,581),(793,'331ae732-ff9a-4e80-b1a0-71b6d05e885f','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:25:59',NULL,'CREATE','IN_PROGRESS','5','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-5-zrlgwyb34uiw','state changed','OS::TripleO::Services::Iscsid',NULL,591),(794,'e48d4a08-74af-44b5-b0c6-25751f5bc6db','c078fb68-eea1-4fe9-8563-30285f2f8085','2026-06-12 08:25:59',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-6-tfclxwc3mtfr-RoleParametersValue-4tvu3q4iw6wt','state changed','OS::Heat::Value',NULL,592),(795,'c561a107-75e4-463f-8347-77cd07372041','33071ff6-11f7-4e05-9afb-d1cb49009351','2026-06-12 08:25:59',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerComputeIpListMap-z5hijln7vyvd','33071ff6-11f7-4e05-9afb-d1cb49009351','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(796,'87feceae-6db8-4011-8f2b-7f8e06867e66','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:25:59',NULL,'CREATE','IN_PROGRESS','ControllerIpListMap','cell1-ControllerIpListMap-5bayqrhmxhw3','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,593),(797,'d050cd0a-5ab8-4b31-a162-487f140b965b','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:25:59',NULL,'CREATE','COMPLETE','3','775f7e6e-e594-45d1-bb15-35c6cf3a06fd','state changed','OS::TripleO::Services::Collectd',NULL,523),(798,'f4055597-346b-4b9e-a87e-25420f599dd9','fe913820-5914-4439-8fa6-4b68d78001ff','2026-06-12 08:25:59',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-4-4pmbtyk4cwdx-CeilometerAgentCentralBase-sodg36cbj3zy','fe913820-5914-4439-8fa6-4b68d78001ff','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(799,'9a3d231f-4a7c-4245-9cf2-b0388c13b0e5','c078fb68-eea1-4fe9-8563-30285f2f8085','2026-06-12 08:25:59',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-6-tfclxwc3mtfr-RoleParametersValue-4tvu3q4iw6wt','state changed','OS::Heat::Value',NULL,592),(800,'39a3d23c-ed3d-495b-9e68-eca49fdbe175','c078fb68-eea1-4fe9-8563-30285f2f8085','2026-06-12 08:25:59',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-6-tfclxwc3mtfr','c078fb68-eea1-4fe9-8563-30285f2f8085','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(801,'d3d212d6-fff0-448d-abd5-f22d5155f5a8','80f2ace2-f881-4110-bcea-a8e8c1c6ca4d','2026-06-12 08:25:59',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','cell1-BlockStorageIpListMap-kse3ivk3mc4x-NetIpMapValue-qywkwoknc7vs','state changed','OS::Heat::Value',NULL,596),(802,'35e7145f-fcfa-495d-8e90-840f9bffeb1b','74eec8c4-422a-46d3-9ec6-f02901048161','2026-06-12 08:25:59',NULL,'CREATE','IN_PROGRESS','HAProxyBase','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-6-togxoevovf3t-HAProxyBase-6zbqyap7csb2','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-container-puppet.yaml',NULL,597),(803,'b1fb7ecd-e787-44c4-8127-d518be3df2d6','33071ff6-11f7-4e05-9afb-d1cb49009351','2026-06-12 08:25:59',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','cell1-CellControllerComputeIpListMap-z5hijln7vyvd-EnabledServicesValue-lisf2ixvwyff','state changed','OS::Heat::Value',NULL,598),(804,'6cb46633-d863-48e6-8ddc-fc595a775fe3','eca3413a-162b-47ad-a8e9-736279b0dbcf','2026-06-12 08:25:59',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-5-zrlgwyb34uiw','eca3413a-162b-47ad-a8e9-736279b0dbcf','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(805,'fed79973-dcf9-4e8f-acb7-380941a441be','33071ff6-11f7-4e05-9afb-d1cb49009351','2026-06-12 08:25:59',NULL,'CREATE','COMPLETE','EnabledServicesValue','cell1-CellControllerComputeIpListMap-z5hijln7vyvd-EnabledServicesValue-lisf2ixvwyff','state changed','OS::Heat::Value',NULL,598),(806,'b1c31feb-4783-431a-b44a-a59011bc20b1','80f2ace2-f881-4110-bcea-a8e8c1c6ca4d','2026-06-12 08:25:59',NULL,'CREATE','COMPLETE','NetIpMapValue','cell1-BlockStorageIpListMap-kse3ivk3mc4x-NetIpMapValue-qywkwoknc7vs','state changed','OS::Heat::Value',NULL,596),(807,'e1361888-20cd-428c-90ed-fe29e268eebd','3ea5f60c-c110-4771-96e6-ffd95c93bbdd','2026-06-12 08:25:59',NULL,'CREATE','IN_PROGRESS','cell1-ControllerIpListMap-5bayqrhmxhw3','3ea5f60c-c110-4771-96e6-ffd95c93bbdd','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(808,'ed9e3f95-4733-431b-9385-ff070e2a79dd','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:25:59',NULL,'CREATE','IN_PROGRESS','9','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-9-37shjakopkwr','state changed','OS::TripleO::Services::MetricsQdr',NULL,599),(809,'d5ca597e-bb24-4c34-b7c0-df29cf11cab2','80f2ace2-f881-4110-bcea-a8e8c1c6ca4d','2026-06-12 08:25:59',NULL,'CREATE','COMPLETE','cell1-BlockStorageIpListMap-kse3ivk3mc4x','80f2ace2-f881-4110-bcea-a8e8c1c6ca4d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(810,'d5d3d4ca-f6f2-4bd0-86c6-da0fad10abd0','df5a343b-39ae-4424-a5b0-1cd4bf3907dc','2026-06-12 08:25:59',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','cell1-NetworkerIpListMap-e5z2h5cn4r4m-EnabledServicesValue-bd5fwagjoz34','state changed','OS::Heat::Value',NULL,602),(811,'e521df31-d52d-49cb-88e5-241a4dbfdcbe','94181640-aa6b-41b3-b276-5c77ec1866f8','2026-06-12 08:25:59',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-6-togxoevovf3t-HAProxyBase-6zbqyap7csb2','94181640-aa6b-41b3-b276-5c77ec1866f8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(812,'8253744b-8d49-4508-9463-c66d2181f920','df5a343b-39ae-4424-a5b0-1cd4bf3907dc','2026-06-12 08:25:59',NULL,'CREATE','COMPLETE','EnabledServicesValue','cell1-NetworkerIpListMap-e5z2h5cn4r4m-EnabledServicesValue-bd5fwagjoz34','state changed','OS::Heat::Value',NULL,602),(813,'3f786519-4bd4-480c-a59e-722b721eb597','df5a343b-39ae-4424-a5b0-1cd4bf3907dc','2026-06-12 08:25:59',NULL,'CREATE','COMPLETE','cell1-NetworkerIpListMap-e5z2h5cn4r4m','df5a343b-39ae-4424-a5b0-1cd4bf3907dc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(814,'22bfc01b-1c40-4593-a9ab-75363945abac','eca3413a-162b-47ad-a8e9-736279b0dbcf','2026-06-12 08:25:59',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-5-zrlgwyb34uiw-RoleParametersValue-i2ju4kxkvyzc','state changed','OS::Heat::Value',NULL,604),(815,'fc97938d-9271-4340-8038-29ff9206685a','eca3413a-162b-47ad-a8e9-736279b0dbcf','2026-06-12 08:25:59',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-5-zrlgwyb34uiw-RoleParametersValue-i2ju4kxkvyzc','state changed','OS::Heat::Value',NULL,604),(816,'4e743dbe-97f2-4a82-b782-60925b04bfaf','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:26:00',NULL,'CREATE','IN_PROGRESS','7','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-7-o4ave7onooif','state changed','OS::TripleO::Services::Iscsid',NULL,605),(817,'e5681ade-cad8-4896-a408-886c537f5b09','cea87c0a-ee6e-4f7d-b81a-20789d6ec2eb','2026-06-12 08:26:00',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-9-37shjakopkwr','cea87c0a-ee6e-4f7d-b81a-20789d6ec2eb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(818,'92135fc7-b31d-43b7-af71-e5af73443f16','a2d6aeca-e7f4-4fff-ab84-c83863e19581','2026-06-12 08:26:00',NULL,'CREATE','IN_PROGRESS','ContainersCommon','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-3-rli3gxeee5b5-ContainersCommon-kb4uizajoxiy','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(819,'c0dcdfa0-2f42-4251-9c43-70e2750a796b','94181640-aa6b-41b3-b276-5c77ec1866f8','2026-06-12 08:26:00',NULL,'CREATE','IN_PROGRESS','HAProxyLogging','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-6-togxoevovf3t-HAProxyBase-6zbqyap7csb2-HAProxyLogging-iwif4mon53pi','state changed','OS::TripleO::Services::Logging::HAProxy',NULL,NULL),(820,'1ae34e67-9840-4af1-8523-013c5f9f4ae3','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:26:00',NULL,'CREATE','COMPLETE','8','29ffb44b-a679-486f-aefb-2d26246a23fa','state changed','OS::TripleO::Services::Kernel',NULL,548),(821,'1b1ab70a-d5dc-40db-b603-72e7314d8f0d','4ba2b85b-ac30-4acb-90e6-6deb235112b0','2026-06-12 08:26:00',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-7-o4ave7onooif','4ba2b85b-ac30-4acb-90e6-6deb235112b0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(822,'f6ed5938-c878-4329-93e0-5f414024859f','01182743-a377-458c-8cf2-c7d479271280','2026-06-12 08:26:00',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-3-rli3gxeee5b5-ContainersCommon-kb4uizajoxiy','01182743-a377-458c-8cf2-c7d479271280','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(823,'33a9f1e7-50e7-4173-bef8-b9f6cda0a1e6','767a68f6-6951-43bf-ac97-9b6704aafebb','2026-06-12 08:26:00',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-6-togxoevovf3t-HAProxyBase-6zbqyap7csb2-HAProxyLogging-iwif4mon53pi','767a68f6-6951-43bf-ac97-9b6704aafebb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(824,'367dc76b-3db1-4e98-a66d-35acacf4e35f','01182743-a377-458c-8cf2-c7d479271280','2026-06-12 08:26:00',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-3-rli3gxeee5b5-ContainersCommon-kb4uizajoxiy','01182743-a377-458c-8cf2-c7d479271280','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(825,'1b9cd4da-4fd0-4c0e-9fd6-5b43d7f6c867','767a68f6-6951-43bf-ac97-9b6704aafebb','2026-06-12 08:26:00',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-6-togxoevovf3t-HAProxyBase-6zbqyap7csb2-HAProxyLogging-iwif4mon53pi','767a68f6-6951-43bf-ac97-9b6704aafebb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(826,'e11ec13b-cf90-4e6e-95e9-4d348c3a27cc','3ea5f60c-c110-4771-96e6-ffd95c93bbdd','2026-06-12 08:26:00',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','cell1-ControllerIpListMap-5bayqrhmxhw3-NetIpMapValue-z4ij5wncrj6w','state changed','OS::Heat::Value',NULL,606),(827,'7b0b1538-5c01-4865-afb6-a88d61efa9b4','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:00',NULL,'CREATE','COMPLETE','ObjectStorage','7585cd69-d480-470b-983f-9e7db34c857f','state changed','OS::Heat::ResourceGroup',NULL,547),(828,'a3884748-4fd2-47a5-bb81-bd3b270fb88c','3ea5f60c-c110-4771-96e6-ffd95c93bbdd','2026-06-12 08:26:00',NULL,'CREATE','COMPLETE','NetIpMapValue','cell1-ControllerIpListMap-5bayqrhmxhw3-NetIpMapValue-z4ij5wncrj6w','state changed','OS::Heat::Value',NULL,606),(829,'34ea39ee-654d-4c6a-a70e-5d9b629b6274','4ba2b85b-ac30-4acb-90e6-6deb235112b0','2026-06-12 08:26:00',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-7-o4ave7onooif-RoleParametersValue-feglpzozfz6t','state changed','OS::Heat::Value',NULL,608),(830,'2c715131-b1d9-4a69-bfba-4c800ed7afa1','4ba2b85b-ac30-4acb-90e6-6deb235112b0','2026-06-12 08:26:00',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-7-o4ave7onooif-RoleParametersValue-feglpzozfz6t','state changed','OS::Heat::Value',NULL,608),(831,'bc1d746a-59a9-42ec-92cb-be35bde92996','fe913820-5914-4439-8fa6-4b68d78001ff','2026-06-12 08:26:00',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-4-4pmbtyk4cwdx-CeilometerAgentCentralBase-sodg36cbj3zy-RoleParametersValue-wqu3el44fcke','state changed','OS::Heat::Value',NULL,610),(832,'d4a71f78-06fc-40f9-89cf-0fa74b1753e8','cea87c0a-ee6e-4f7d-b81a-20789d6ec2eb','2026-06-12 08:26:00',NULL,'CREATE','IN_PROGRESS','ContainersCommon','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-9-37shjakopkwr-ContainersCommon-imcpsvcjpwx7','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(833,'745d6c77-7fa0-4403-8384-e7976a19100e','fe913820-5914-4439-8fa6-4b68d78001ff','2026-06-12 08:26:00',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-4-4pmbtyk4cwdx-CeilometerAgentCentralBase-sodg36cbj3zy-RoleParametersValue-wqu3el44fcke','state changed','OS::Heat::Value',NULL,610),(834,'9909df73-74d0-4c5a-96cf-44f44e6a81dd','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:26:00',NULL,'CREATE','COMPLETE','6','c078fb68-eea1-4fe9-8563-30285f2f8085','state changed','OS::TripleO::Services::Kernel',NULL,570),(835,'07d0e991-a0e9-4f12-8580-ea63ca203b7e','be2da5c4-1fac-4f20-82d4-1b41e4a367f5','2026-06-12 08:26:00',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-9-37shjakopkwr-ContainersCommon-imcpsvcjpwx7','be2da5c4-1fac-4f20-82d4-1b41e4a367f5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(836,'f27fb07b-8c12-4269-b3d0-5c418129a59b','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:26:00',NULL,'CREATE','IN_PROGRESS','12','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-12-yus2rf76fg5v','state changed','OS::TripleO::Services::NovaConductor',NULL,611),(837,'a002390e-8c44-48d6-a97a-b065dbdbad7f','be2da5c4-1fac-4f20-82d4-1b41e4a367f5','2026-06-12 08:26:00',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-9-37shjakopkwr-ContainersCommon-imcpsvcjpwx7','be2da5c4-1fac-4f20-82d4-1b41e4a367f5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(838,'cda33e4c-01d7-482e-ad7c-6d1dd5bf80e9','63487f92-d728-402d-a5fe-0a2a7492ecaf','2026-06-12 08:26:00',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-12-yus2rf76fg5v','63487f92-d728-402d-a5fe-0a2a7492ecaf','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(839,'e3759a0f-1d4e-4431-b380-4c7839a7e2d1','5c998268-8060-4729-b055-5c45de716e21','2026-06-12 08:26:00',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','cell1-CephStorageIpListMap-vemgjlwrjbht-NetIpMapValue-2dbmj7cle5xv','state changed','OS::Heat::Value',NULL,613),(840,'2f567716-b3e6-48ce-8f3f-735e7503b913','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:00',NULL,'CREATE','IN_PROGRESS','ObjectStorageNetworkHostnameMap','cell1-ObjectStorageNetworkHostnameMap-ear6p5gzmnfk','state changed','OS::Heat::Value',NULL,614),(841,'f0a7bb4a-85ac-4c29-a24e-115ef06be496','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:00',NULL,'CREATE','COMPLETE','ObjectStorageNetworkHostnameMap','cell1-ObjectStorageNetworkHostnameMap-ear6p5gzmnfk','state changed','OS::Heat::Value',NULL,614),(842,'f28eb666-c671-46aa-9e41-08a7a90363d1','5c998268-8060-4729-b055-5c45de716e21','2026-06-12 08:26:00',NULL,'CREATE','COMPLETE','NetIpMapValue','cell1-CephStorageIpListMap-vemgjlwrjbht-NetIpMapValue-2dbmj7cle5xv','state changed','OS::Heat::Value',NULL,613),(843,'32d9cc6f-db43-435f-b65f-0a3938a7530b','5c998268-8060-4729-b055-5c45de716e21','2026-06-12 08:26:00',NULL,'CREATE','COMPLETE','cell1-CephStorageIpListMap-vemgjlwrjbht','5c998268-8060-4729-b055-5c45de716e21','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(844,'8d3cbc98-d6b6-4b17-9a44-c5a88082f8c2','61fccc8d-01b4-4716-bdfa-37b1b4f1f8f1','2026-06-12 08:26:00',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-4-4pmbtyk4cwdx-RoleParametersValue-ey5uc7jaxvkv','state changed','OS::Heat::Value',NULL,615),(845,'4532b20b-6a42-46a0-a888-611e9996e4ed','61fccc8d-01b4-4716-bdfa-37b1b4f1f8f1','2026-06-12 08:26:00',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-4-4pmbtyk4cwdx-RoleParametersValue-ey5uc7jaxvkv','state changed','OS::Heat::Value',NULL,615),(846,'5414a6a2-b0f3-4c61-b352-9b1525df5466','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:26:00',NULL,'CREATE','IN_PROGRESS','10','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-10-tniduxydeujc','state changed','OS::TripleO::Services::NovaLibvirt',NULL,619),(847,'1f8992ae-170e-4463-bf36-d543cf7d76d2','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:00',NULL,'CREATE','IN_PROGRESS','ObjectStorageServers','cell1-ObjectStorageServers-ii4drocowwj5','state changed','OS::Heat::Value',NULL,618),(848,'b8624151-65b0-49e5-a1e8-af83ee091f4e','63487f92-d728-402d-a5fe-0a2a7492ecaf','2026-06-12 08:26:00',NULL,'CREATE','IN_PROGRESS','NovaBase','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-12-yus2rf76fg5v-NovaBase-44updr5jzqd7','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,622),(849,'61a89ce9-de30-4bf8-8297-2e3b95e087d7','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:00',NULL,'CREATE','IN_PROGRESS','ObjectStorageIpListMap','cell1-ObjectStorageIpListMap-pnercozl4ipi','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,620),(850,'f6145023-ff03-40d1-a65d-68aa1a026c34','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:00',NULL,'CREATE','COMPLETE','ObjectStorageServers','cell1-ObjectStorageServers-ii4drocowwj5','state changed','OS::Heat::Value',NULL,618),(851,'023e550a-6a0f-4eef-8c69-11ca9a456df0','232678ff-8025-4d43-a51b-55f28f1d62fe','2026-06-12 08:26:00',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-12-yus2rf76fg5v-NovaBase-44updr5jzqd7','232678ff-8025-4d43-a51b-55f28f1d62fe','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(852,'2c8c35fc-d9eb-49eb-a9bd-d894b9ac2180','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:00',NULL,'CREATE','COMPLETE','BlockStorageIpListMap','80f2ace2-f881-4110-bcea-a8e8c1c6ca4d','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,540),(853,'783eaa94-07bd-4787-a4f1-447feb8a7b49','e07a6867-11cb-4e48-b7e6-f6bbf0eda32a','2026-06-12 08:26:00',NULL,'CREATE','IN_PROGRESS','cell1-ObjectStorageIpListMap-pnercozl4ipi','e07a6867-11cb-4e48-b7e6-f6bbf0eda32a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(854,'653d6e34-e82b-4fc2-8c01-ce05160d9a77','74eec8c4-422a-46d3-9ec6-f02901048161','2026-06-12 08:26:00',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-6-togxoevovf3t-RoleParametersValue-r4le5hcz544z','state changed','OS::Heat::Value',NULL,623),(855,'05e54fea-db0c-43dd-8a26-f9c29c1ce375','74eec8c4-422a-46d3-9ec6-f02901048161','2026-06-12 08:26:00',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-6-togxoevovf3t-RoleParametersValue-r4le5hcz544z','state changed','OS::Heat::Value',NULL,623),(856,'834428a3-6697-4890-9403-a3bb83b02d73','e7c153e6-8489-466b-b61f-c81ddd6112e4','2026-06-12 08:26:00',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-10-tniduxydeujc','e7c153e6-8489-466b-b61f-c81ddd6112e4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(857,'d772dc9c-1512-4b4f-84e3-75a16db56294','33071ff6-11f7-4e05-9afb-d1cb49009351','2026-06-12 08:26:00',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','cell1-CellControllerComputeIpListMap-z5hijln7vyvd-NetIpMapValue-puobyflbzbw5','state changed','OS::Heat::Value',NULL,625),(858,'87327499-fa0f-40d9-b5a7-e067a17eca16','e07a6867-11cb-4e48-b7e6-f6bbf0eda32a','2026-06-12 08:26:00',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','cell1-ObjectStorageIpListMap-pnercozl4ipi-EnabledServicesValue-f3ouhqbubasj','state changed','OS::Heat::Value',NULL,626),(859,'a2b6ecf8-9db9-409e-a705-f9d3dadb3c37','e07a6867-11cb-4e48-b7e6-f6bbf0eda32a','2026-06-12 08:26:00',NULL,'CREATE','COMPLETE','EnabledServicesValue','cell1-ObjectStorageIpListMap-pnercozl4ipi-EnabledServicesValue-f3ouhqbubasj','state changed','OS::Heat::Value',NULL,626),(860,'90a7648e-e9b5-4620-a5e9-49fde3f25dbf','33071ff6-11f7-4e05-9afb-d1cb49009351','2026-06-12 08:26:00',NULL,'CREATE','COMPLETE','NetIpMapValue','cell1-CellControllerComputeIpListMap-z5hijln7vyvd-NetIpMapValue-puobyflbzbw5','state changed','OS::Heat::Value',NULL,625),(861,'a98a8e10-c069-485c-8e6d-d6cf467a64e5','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:00',NULL,'CREATE','COMPLETE','NetworkerIpListMap','df5a343b-39ae-4424-a5b0-1cd4bf3907dc','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,550),(862,'3000d902-9988-4834-b244-299df7b2df61','232678ff-8025-4d43-a51b-55f28f1d62fe','2026-06-12 08:26:00',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-12-yus2rf76fg5v-NovaBase-44updr5jzqd7-RoleParametersValue-2swq4vezihou','state changed','OS::Heat::Value',NULL,627),(863,'f97a4382-99f8-479e-bc07-5fdecdc4712c','33071ff6-11f7-4e05-9afb-d1cb49009351','2026-06-12 08:26:00',NULL,'CREATE','COMPLETE','cell1-CellControllerComputeIpListMap-z5hijln7vyvd','33071ff6-11f7-4e05-9afb-d1cb49009351','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(864,'c67958ba-d90f-4142-ac52-8a0758ec2f03','232678ff-8025-4d43-a51b-55f28f1d62fe','2026-06-12 08:26:00',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-12-yus2rf76fg5v-NovaBase-44updr5jzqd7-RoleParametersValue-2swq4vezihou','state changed','OS::Heat::Value',NULL,627),(865,'72cd50a1-8f09-42ef-be98-376fdf7bfc40','232678ff-8025-4d43-a51b-55f28f1d62fe','2026-06-12 08:26:00',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-12-yus2rf76fg5v-NovaBase-44updr5jzqd7','232678ff-8025-4d43-a51b-55f28f1d62fe','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(866,'8a531cb7-0584-416b-bbb9-f1cf196cf977','eca3413a-162b-47ad-a8e9-736279b0dbcf','2026-06-12 08:26:00',NULL,'CREATE','IN_PROGRESS','ContainersCommon','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-5-zrlgwyb34uiw-ContainersCommon-avlpsdljbjdi','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(867,'ab719d1e-2040-4d47-b201-0dc29f318f0c','e7c153e6-8489-466b-b61f-c81ddd6112e4','2026-06-12 08:26:00',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-10-tniduxydeujc-RoleParametersValue-ne35axsnudus','state changed','OS::Heat::Value',NULL,628),(868,'b6b46877-36ce-4d6a-b687-f37d6912a469','e7c153e6-8489-466b-b61f-c81ddd6112e4','2026-06-12 08:26:01',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-10-tniduxydeujc-RoleParametersValue-ne35axsnudus','state changed','OS::Heat::Value',NULL,628),(869,'00d93971-3211-4bf1-8d65-d70d8e11cae4','571a8a99-1ba7-47cd-818b-29692f9441a5','2026-06-12 08:26:01',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-5-zrlgwyb34uiw-ContainersCommon-avlpsdljbjdi','571a8a99-1ba7-47cd-818b-29692f9441a5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(870,'44f65d17-6338-44af-a134-6e7b54080c62','a2d6aeca-e7f4-4fff-ab84-c83863e19581','2026-06-12 08:26:01',NULL,'CREATE','IN_PROGRESS','CeilometerServiceBase','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-3-rli3gxeee5b5-CeilometerServiceBase-ob7rpqzvzzgg','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,629),(871,'644ff636-6d95-4770-81b0-6bd197670296','571a8a99-1ba7-47cd-818b-29692f9441a5','2026-06-12 08:26:01',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-5-zrlgwyb34uiw-ContainersCommon-avlpsdljbjdi','571a8a99-1ba7-47cd-818b-29692f9441a5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(872,'7f41dbbb-d617-441f-a720-a667cbe8d08a','94181640-aa6b-41b3-b276-5c77ec1866f8','2026-06-12 08:26:01',NULL,'CREATE','IN_PROGRESS','HAProxyPublicTLS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-6-togxoevovf3t-HAProxyBase-6zbqyap7csb2-HAProxyPublicTLS-gayoqkswckck','state changed','OS::TripleO::Services::HAProxyPublicTLS',NULL,630),(873,'c4523b30-df3d-4df4-966a-3491d65f7462','3ea5f60c-c110-4771-96e6-ffd95c93bbdd','2026-06-12 08:26:01',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','cell1-ControllerIpListMap-5bayqrhmxhw3-EnabledServicesValue-wqixxrmnadtg','state changed','OS::Heat::Value',NULL,631),(874,'34fdf42c-7376-4cf0-84bd-804ee9a49aa8','50ffe175-2aba-4768-b923-2aad4a9d1f1b','2026-06-12 08:26:01',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-3-rli3gxeee5b5-CeilometerServiceBase-ob7rpqzvzzgg','50ffe175-2aba-4768-b923-2aad4a9d1f1b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(875,'505cb7d9-f706-4d0c-897e-223149d23d8f','3ea5f60c-c110-4771-96e6-ffd95c93bbdd','2026-06-12 08:26:01',NULL,'CREATE','COMPLETE','EnabledServicesValue','cell1-ControllerIpListMap-5bayqrhmxhw3-EnabledServicesValue-wqixxrmnadtg','state changed','OS::Heat::Value',NULL,631),(876,'1fff2872-3e03-4ef6-ac45-721d67f14f86','3ea5f60c-c110-4771-96e6-ffd95c93bbdd','2026-06-12 08:26:01',NULL,'CREATE','COMPLETE','cell1-ControllerIpListMap-5bayqrhmxhw3','3ea5f60c-c110-4771-96e6-ffd95c93bbdd','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(877,'b09b4848-b2a6-44dc-acac-8effb4b2e3ef','a2d6aeca-e7f4-4fff-ab84-c83863e19581','2026-06-12 08:26:01',NULL,'CREATE','COMPLETE','ContainersCommon','01182743-a377-458c-8cf2-c7d479271280','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(878,'1eeb01fd-d5b5-472a-b99f-65adb6bc7604','50ffe175-2aba-4768-b923-2aad4a9d1f1b','2026-06-12 08:26:01',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-3-rli3gxeee5b5-CeilometerServiceBase-ob7rpqzvzzgg','50ffe175-2aba-4768-b923-2aad4a9d1f1b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(879,'421ccd47-95d6-45a2-832d-ede5fa64880e','94181640-aa6b-41b3-b276-5c77ec1866f8','2026-06-12 08:26:01',NULL,'CREATE','COMPLETE','HAProxyLogging','767a68f6-6951-43bf-ac97-9b6704aafebb','state changed','OS::TripleO::Services::Logging::HAProxy',NULL,NULL),(880,'b154fb97-9f33-479e-8c13-85dbcafc86b1','4ba2b85b-ac30-4acb-90e6-6deb235112b0','2026-06-12 08:26:01',NULL,'CREATE','IN_PROGRESS','ContainersCommon','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-7-o4ave7onooif-ContainersCommon-ybx3lzqsyhlp','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(881,'a223affd-386b-4e8c-80d8-a5bcdc4dfea4','4d455de0-5ddb-4bae-84db-183477257bbb','2026-06-12 08:26:01',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-6-togxoevovf3t-HAProxyBase-6zbqyap7csb2-HAProxyPublicTLS-gayoqkswckck','4d455de0-5ddb-4bae-84db-183477257bbb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(882,'87fef332-3391-4b91-977e-cf7bff3b8b50','fe913820-5914-4439-8fa6-4b68d78001ff','2026-06-12 08:26:01',NULL,'CREATE','IN_PROGRESS','ContainersCommon','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-4-4pmbtyk4cwdx-CeilometerAgentCentralBase-sodg36cbj3zy-ContainersCommon-cvjqhx37h2tn','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(883,'a89d4f5b-abde-4829-924e-d593797358bf','cea87c0a-ee6e-4f7d-b81a-20789d6ec2eb','2026-06-12 08:26:01',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-9-37shjakopkwr-RoleParametersValue-zguitlkklunl','state changed','OS::Heat::Value',NULL,632),(884,'665735fa-ce3d-4fc0-a0fb-eb8ee241d523','73f62104-04f8-4c10-be43-1409c6d502f5','2026-06-12 08:26:01',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-7-o4ave7onooif-ContainersCommon-ybx3lzqsyhlp','73f62104-04f8-4c10-be43-1409c6d502f5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(885,'18eb5fcb-c780-49a7-990d-20741a496811','cea87c0a-ee6e-4f7d-b81a-20789d6ec2eb','2026-06-12 08:26:01',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-9-37shjakopkwr-RoleParametersValue-zguitlkklunl','state changed','OS::Heat::Value',NULL,632),(886,'04451bb1-a051-4423-9abc-e13158d704a6','4d455de0-5ddb-4bae-84db-183477257bbb','2026-06-12 08:26:01',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-6-togxoevovf3t-HAProxyBase-6zbqyap7csb2-HAProxyPublicTLS-gayoqkswckck','4d455de0-5ddb-4bae-84db-183477257bbb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(887,'153e6b32-7219-48d9-9298-e4d67399af9b','cea87c0a-ee6e-4f7d-b81a-20789d6ec2eb','2026-06-12 08:26:01',NULL,'CREATE','COMPLETE','ContainersCommon','be2da5c4-1fac-4f20-82d4-1b41e4a367f5','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(888,'80cfa7c8-30cb-4b3f-98d2-ff0c4826d74b','73f62104-04f8-4c10-be43-1409c6d502f5','2026-06-12 08:26:01',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-7-o4ave7onooif-ContainersCommon-ybx3lzqsyhlp','73f62104-04f8-4c10-be43-1409c6d502f5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(889,'a73f150b-aa8a-4f97-bbdb-eab6c1633694','f3efe154-db85-48bc-ad3b-ce8e4d3e061b','2026-06-12 08:26:01',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-4-4pmbtyk4cwdx-CeilometerAgentCentralBase-sodg36cbj3zy-ContainersCommon-cvjqhx37h2tn','f3efe154-db85-48bc-ad3b-ce8e4d3e061b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(890,'b81c0d1b-9c96-47f7-8ef2-1345b8f3bf35','cea87c0a-ee6e-4f7d-b81a-20789d6ec2eb','2026-06-12 08:26:01',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-9-37shjakopkwr','cea87c0a-ee6e-4f7d-b81a-20789d6ec2eb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(891,'abf63ee6-b05b-43f5-ae03-7fa1f3d397e0','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:01',NULL,'CREATE','COMPLETE','CephStorageIpListMap','5c998268-8060-4729-b055-5c45de716e21','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,575),(892,'9bf76b72-e94b-4f3f-8766-3b1bea2d568e','f3efe154-db85-48bc-ad3b-ce8e4d3e061b','2026-06-12 08:26:01',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-4-4pmbtyk4cwdx-CeilometerAgentCentralBase-sodg36cbj3zy-ContainersCommon-cvjqhx37h2tn','f3efe154-db85-48bc-ad3b-ce8e4d3e061b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(893,'b0554434-4159-421d-b65d-21e90ccaedf5','61fccc8d-01b4-4716-bdfa-37b1b4f1f8f1','2026-06-12 08:26:01',NULL,'CREATE','IN_PROGRESS','ContainersCommon','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-4-4pmbtyk4cwdx-ContainersCommon-3qybfu2enhlw','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(894,'138b1ced-872d-4e91-81be-bc6c5ba21bf9','b5fd51b3-cd5a-4f1f-acf8-7ee194cca190','2026-06-12 08:26:01',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-4-4pmbtyk4cwdx-ContainersCommon-3qybfu2enhlw','b5fd51b3-cd5a-4f1f-acf8-7ee194cca190','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(895,'7cba2586-7694-4463-945e-d84415a07a1f','b5fd51b3-cd5a-4f1f-acf8-7ee194cca190','2026-06-12 08:26:01',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-4-4pmbtyk4cwdx-ContainersCommon-3qybfu2enhlw','b5fd51b3-cd5a-4f1f-acf8-7ee194cca190','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(896,'90bff95e-470d-496c-8590-3b3a84112e87','63487f92-d728-402d-a5fe-0a2a7492ecaf','2026-06-12 08:26:01',NULL,'CREATE','IN_PROGRESS','MySQLClient','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-12-yus2rf76fg5v-MySQLClient-4wwt4reol43h','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(897,'6c1d481a-82ff-4bcd-bae7-9bf1da153288','9a969b8c-86b4-46f3-a037-6fb8e36798c2','2026-06-12 08:26:01',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-12-yus2rf76fg5v-MySQLClient-4wwt4reol43h','9a969b8c-86b4-46f3-a037-6fb8e36798c2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(898,'4c7cbf9c-458f-45fc-a50e-bfcf17805855','63487f92-d728-402d-a5fe-0a2a7492ecaf','2026-06-12 08:26:01',NULL,'CREATE','COMPLETE','NovaBase','232678ff-8025-4d43-a51b-55f28f1d62fe','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,622),(899,'3f864e30-5c75-42a2-b4d0-b7af9381cf88','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:01',NULL,'CREATE','COMPLETE','CellControllerComputeIpListMap','33071ff6-11f7-4e05-9afb-d1cb49009351','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,586),(900,'fd7ecfe2-0ee5-4d54-9475-bb9de01cb511','9a969b8c-86b4-46f3-a037-6fb8e36798c2','2026-06-12 08:26:01',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-12-yus2rf76fg5v-MySQLClient-4wwt4reol43h','9a969b8c-86b4-46f3-a037-6fb8e36798c2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(901,'8924893b-c20a-4bc2-bc08-9c0e013d32c0','74eec8c4-422a-46d3-9ec6-f02901048161','2026-06-12 08:26:01',NULL,'CREATE','IN_PROGRESS','HAProxyPublicTLS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-6-togxoevovf3t-HAProxyPublicTLS-sz72qycp2kgd','state changed','OS::TripleO::Services::HAProxyPublicTLS',NULL,633),(902,'61d7e5f4-bc91-4efc-b9ef-236714ab9676','e07a6867-11cb-4e48-b7e6-f6bbf0eda32a','2026-06-12 08:26:01',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','cell1-ObjectStorageIpListMap-pnercozl4ipi-NetIpMapValue-six7fsjaygxz','state changed','OS::Heat::Value',NULL,634),(903,'b596fa73-406f-40d0-9998-ad8f5b7dad40','60403623-27db-4a04-a4ec-f2da5f31f592','2026-06-12 08:26:01',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-6-togxoevovf3t-HAProxyPublicTLS-sz72qycp2kgd','60403623-27db-4a04-a4ec-f2da5f31f592','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(904,'cad92b52-27c7-4a4c-b6cc-0e3be336ff54','e07a6867-11cb-4e48-b7e6-f6bbf0eda32a','2026-06-12 08:26:01',NULL,'CREATE','COMPLETE','NetIpMapValue','cell1-ObjectStorageIpListMap-pnercozl4ipi-NetIpMapValue-six7fsjaygxz','state changed','OS::Heat::Value',NULL,634),(905,'2830b4ba-594b-4692-bfe2-3d4fbd939152','60403623-27db-4a04-a4ec-f2da5f31f592','2026-06-12 08:26:01',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-6-togxoevovf3t-HAProxyPublicTLS-sz72qycp2kgd','60403623-27db-4a04-a4ec-f2da5f31f592','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(906,'92587c4b-854f-4c5e-be10-0c47ce0b4900','e07a6867-11cb-4e48-b7e6-f6bbf0eda32a','2026-06-12 08:26:01',NULL,'CREATE','COMPLETE','cell1-ObjectStorageIpListMap-pnercozl4ipi','e07a6867-11cb-4e48-b7e6-f6bbf0eda32a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(907,'ed896c8f-39a3-4955-9ff3-1c8b4fd9bbf3','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:01',NULL,'CREATE','COMPLETE','ControllerIpListMap','3ea5f60c-c110-4771-96e6-ffd95c93bbdd','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,593),(908,'53decab7-1ead-449d-a66e-3fabe016b4dc','e7c153e6-8489-466b-b61f-c81ddd6112e4','2026-06-12 08:26:02',NULL,'CREATE','IN_PROGRESS','ContainersCommon','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-10-tniduxydeujc-ContainersCommon-2zgqg2zaxfe7','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(909,'f1f3d755-ea3e-45cf-bf6f-789735fb2540','eca3413a-162b-47ad-a8e9-736279b0dbcf','2026-06-12 08:26:02',NULL,'CREATE','COMPLETE','ContainersCommon','571a8a99-1ba7-47cd-818b-29692f9441a5','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(910,'15ef7863-bcfd-4e40-a3bc-afb2462140e2','a2d6aeca-e7f4-4fff-ab84-c83863e19581','2026-06-12 08:26:02',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-3-rli3gxeee5b5-RoleParametersValue-otgt757dh25t','state changed','OS::Heat::Value',NULL,635),(911,'2bd95bd6-6350-4c5c-b58a-a08fc3c45277','eca3413a-162b-47ad-a8e9-736279b0dbcf','2026-06-12 08:26:02',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-5-zrlgwyb34uiw','eca3413a-162b-47ad-a8e9-736279b0dbcf','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(912,'d676ad35-483b-4a73-907a-df9771a4bff9','94181640-aa6b-41b3-b276-5c77ec1866f8','2026-06-12 08:26:02',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-6-togxoevovf3t-HAProxyBase-6zbqyap7csb2-RoleParametersValue-d25g22afp4fc','state changed','OS::Heat::Value',NULL,636),(913,'b9d21b46-6209-474f-b98a-9e0450b85559','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:26:02',NULL,'CREATE','COMPLETE','9','cea87c0a-ee6e-4f7d-b81a-20789d6ec2eb','state changed','OS::TripleO::Services::MetricsQdr',NULL,599),(914,'b7b0404c-84bf-4eed-851d-97aff03a17ae','a1549018-61fe-4193-803c-f761aa6c32d7','2026-06-12 08:26:02',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-10-tniduxydeujc-ContainersCommon-2zgqg2zaxfe7','a1549018-61fe-4193-803c-f761aa6c32d7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(915,'13b800b7-a81b-4746-a4f1-7434c11402df','94181640-aa6b-41b3-b276-5c77ec1866f8','2026-06-12 08:26:02',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-6-togxoevovf3t-HAProxyBase-6zbqyap7csb2-RoleParametersValue-d25g22afp4fc','state changed','OS::Heat::Value',NULL,636),(916,'2920d3ee-abbf-4e9d-9aba-4a816c32f94d','a2d6aeca-e7f4-4fff-ab84-c83863e19581','2026-06-12 08:26:02',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-3-rli3gxeee5b5-RoleParametersValue-otgt757dh25t','state changed','OS::Heat::Value',NULL,635),(917,'e041416c-6b7f-429b-8af4-0c406b997854','a1549018-61fe-4193-803c-f761aa6c32d7','2026-06-12 08:26:02',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-10-tniduxydeujc-ContainersCommon-2zgqg2zaxfe7','a1549018-61fe-4193-803c-f761aa6c32d7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(918,'1c2d9bbf-25f5-4b1c-8dc1-0c1bfe8d7736','a2d6aeca-e7f4-4fff-ab84-c83863e19581','2026-06-12 08:26:02',NULL,'CREATE','COMPLETE','CeilometerServiceBase','50ffe175-2aba-4768-b923-2aad4a9d1f1b','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,629),(919,'fbee9fd8-01b5-4788-8428-7d927c9aa3b5','a2d6aeca-e7f4-4fff-ab84-c83863e19581','2026-06-12 08:26:02',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-3-rli3gxeee5b5','a2d6aeca-e7f4-4fff-ab84-c83863e19581','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(920,'03961df6-a425-431c-abad-eb7b51c16abe','fe913820-5914-4439-8fa6-4b68d78001ff','2026-06-12 08:26:02',NULL,'CREATE','IN_PROGRESS','CeilometerServiceBase','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-4-4pmbtyk4cwdx-CeilometerAgentCentralBase-sodg36cbj3zy-CeilometerServiceBase-coyfnoy7ulbf','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,640),(921,'bd942062-cd3c-48f2-9ef2-51a46e2cb994','94181640-aa6b-41b3-b276-5c77ec1866f8','2026-06-12 08:26:02',NULL,'CREATE','COMPLETE','HAProxyPublicTLS','4d455de0-5ddb-4bae-84db-183477257bbb','state changed','OS::TripleO::Services::HAProxyPublicTLS',NULL,630),(922,'fdad006c-195b-4509-b671-3204b95353ba','4ba2b85b-ac30-4acb-90e6-6deb235112b0','2026-06-12 08:26:02',NULL,'CREATE','COMPLETE','ContainersCommon','73f62104-04f8-4c10-be43-1409c6d502f5','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(923,'2fd4452c-fd8e-4390-9399-60c64b043acc','4ba2b85b-ac30-4acb-90e6-6deb235112b0','2026-06-12 08:26:02',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-7-o4ave7onooif','4ba2b85b-ac30-4acb-90e6-6deb235112b0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(924,'12938452-db42-4774-bf7c-75c3c930a2b4','fe913820-5914-4439-8fa6-4b68d78001ff','2026-06-12 08:26:02',NULL,'CREATE','COMPLETE','ContainersCommon','f3efe154-db85-48bc-ad3b-ce8e4d3e061b','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(925,'bdf44aef-cd7d-42e9-b651-cb3e6d0f312a','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:26:02',NULL,'CREATE','IN_PROGRESS','13','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-13-jy5vx4r5p7kb','state changed','OS::TripleO::Services::NovaMetadata',NULL,641),(926,'b5eec54d-fb31-45ff-904b-cf7cef032142','355779b0-966b-4404-a25c-db10872ce943','2026-06-12 08:26:02',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-4-4pmbtyk4cwdx-CeilometerAgentCentralBase-sodg36cbj3zy-CeilometerServiceBase-coyfnoy7ulbf','355779b0-966b-4404-a25c-db10872ce943','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(927,'ecaf92f7-cd81-469c-bd05-4ae93b41a365','355779b0-966b-4404-a25c-db10872ce943','2026-06-12 08:26:02',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-4-4pmbtyk4cwdx-CeilometerAgentCentralBase-sodg36cbj3zy-CeilometerServiceBase-coyfnoy7ulbf','355779b0-966b-4404-a25c-db10872ce943','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(928,'d66386d3-3ff1-4329-9017-189f24017b33','61fccc8d-01b4-4716-bdfa-37b1b4f1f8f1','2026-06-12 08:26:02',NULL,'CREATE','IN_PROGRESS','CeilometerServiceBase','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-4-4pmbtyk4cwdx-CeilometerServiceBase-v7vxzagw6jrm','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,642),(929,'dec977f8-f3f1-431f-8133-06bce9293ad5','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:26:02',NULL,'CREATE','COMPLETE','3','a2d6aeca-e7f4-4fff-ab84-c83863e19581','state changed','OS::TripleO::Services::ComputeCeilometerAgent',NULL,574),(930,'be652aef-254e-41ab-b13f-810cb6504923','98be2585-4dea-456a-96e8-bc0e4cc60166','2026-06-12 08:26:02',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-13-jy5vx4r5p7kb','98be2585-4dea-456a-96e8-bc0e4cc60166','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(931,'91fce911-6e22-4c5a-a8fb-8a4c16d7dd15','61fccc8d-01b4-4716-bdfa-37b1b4f1f8f1','2026-06-12 08:26:02',NULL,'CREATE','COMPLETE','ContainersCommon','b5fd51b3-cd5a-4f1f-acf8-7ee194cca190','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(932,'de7d4bfc-c2f3-49e4-8bdb-72ba3ba47180','63487f92-d728-402d-a5fe-0a2a7492ecaf','2026-06-12 08:26:02',NULL,'CREATE','IN_PROGRESS','ContainersCommon','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-12-yus2rf76fg5v-ContainersCommon-sngfymtoveiw','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(933,'45f2a012-2e05-45b3-bf41-bee45d3975ae','e169fb8a-0f31-408c-8c3a-34b4a3b93c2d','2026-06-12 08:26:02',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-4-4pmbtyk4cwdx-CeilometerServiceBase-v7vxzagw6jrm','e169fb8a-0f31-408c-8c3a-34b4a3b93c2d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(934,'06f35238-170d-4714-94af-12faae7e8615','e169fb8a-0f31-408c-8c3a-34b4a3b93c2d','2026-06-12 08:26:02',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-4-4pmbtyk4cwdx-CeilometerServiceBase-v7vxzagw6jrm','e169fb8a-0f31-408c-8c3a-34b4a3b93c2d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(935,'00449f86-7e36-4863-92e6-57cc1749527f','9a6af8e4-f747-46d2-bd64-a6c4bcf69179','2026-06-12 08:26:02',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-12-yus2rf76fg5v-ContainersCommon-sngfymtoveiw','9a6af8e4-f747-46d2-bd64-a6c4bcf69179','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(936,'1109771c-c84a-4b9a-8870-239d0fa3a871','63487f92-d728-402d-a5fe-0a2a7492ecaf','2026-06-12 08:26:02',NULL,'CREATE','COMPLETE','MySQLClient','9a969b8c-86b4-46f3-a037-6fb8e36798c2','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(937,'70a0b8ee-f988-43d9-8922-f3d168440fc3','9a6af8e4-f747-46d2-bd64-a6c4bcf69179','2026-06-12 08:26:02',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-12-yus2rf76fg5v-ContainersCommon-sngfymtoveiw','9a6af8e4-f747-46d2-bd64-a6c4bcf69179','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(938,'1a0b5573-7df6-44d4-982d-61c78fbf777f','74eec8c4-422a-46d3-9ec6-f02901048161','2026-06-12 08:26:02',NULL,'CREATE','IN_PROGRESS','HAProxyInternalTLS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-6-togxoevovf3t-HAProxyInternalTLS-sawsztidldkz','state changed','OS::TripleO::Services::HAProxyInternalTLS',NULL,NULL),(939,'c6bf1156-e45d-42dc-9292-272ab87a5225','74eec8c4-422a-46d3-9ec6-f02901048161','2026-06-12 08:26:02',NULL,'CREATE','COMPLETE','HAProxyInternalTLS','2ebfdeb0-4d98-420c-83d9-6b74461fb5d4','state changed','OS::TripleO::Services::HAProxyInternalTLS',NULL,NULL),(940,'cefa0717-e97a-4cad-a094-075bede6cec6','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:02',NULL,'CREATE','COMPLETE','ObjectStorageIpListMap','e07a6867-11cb-4e48-b7e6-f6bbf0eda32a','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,620),(941,'f7d76371-9403-47d6-b175-dfcb8eb5ad79','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:26:02',NULL,'CREATE','COMPLETE','5','eca3413a-162b-47ad-a8e9-736279b0dbcf','state changed','OS::TripleO::Services::Iscsid',NULL,591),(942,'13312caa-32b7-4730-921a-4bec4ccdf307','74eec8c4-422a-46d3-9ec6-f02901048161','2026-06-12 08:26:02',NULL,'CREATE','COMPLETE','HAProxyPublicTLS','60403623-27db-4a04-a4ec-f2da5f31f592','state changed','OS::TripleO::Services::HAProxyPublicTLS',NULL,633),(943,'e95f1463-3e36-46bc-9504-828bac1f5210','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:26:02',NULL,'CREATE','IN_PROGRESS','7','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-7-okda37e7kw2y','state changed','OS::TripleO::Services::MetricsQdr',NULL,647),(944,'afc2613e-ace5-460e-a2cb-8f5828e442e1','0e9ffab8-1eea-4486-9f74-3ad5619cbcb9','2026-06-12 08:26:03',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-7-okda37e7kw2y','0e9ffab8-1eea-4486-9f74-3ad5619cbcb9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(945,'45b19e67-68de-49ce-8946-74c7faa1e879','e7c153e6-8489-466b-b61f-c81ddd6112e4','2026-06-12 08:26:03',NULL,'CREATE','IN_PROGRESS','NovaBase','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-10-tniduxydeujc-NovaBase-gsn5ch26smzr','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,650),(946,'1ac3fa73-14cf-4ac4-bed4-58750f279ec1','98be2585-4dea-456a-96e8-bc0e4cc60166','2026-06-12 08:26:03',NULL,'CREATE','IN_PROGRESS','ContainersCommon','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-13-jy5vx4r5p7kb-ContainersCommon-4evqmhbyao24','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(947,'4e8030c7-05af-4a6e-b723-f14fb6f4ed66','0e9ffab8-1eea-4486-9f74-3ad5619cbcb9','2026-06-12 08:26:03',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-7-okda37e7kw2y-RoleParametersValue-livzpw2nvbki','state changed','OS::Heat::Value',NULL,652),(948,'bd29e701-7a23-476f-a9b7-1fe61ba3d40d','94181640-aa6b-41b3-b276-5c77ec1866f8','2026-06-12 08:26:03',NULL,'CREATE','IN_PROGRESS','HAProxyInternalTLS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-6-togxoevovf3t-HAProxyBase-6zbqyap7csb2-HAProxyInternalTLS-x7ioec7tyjni','state changed','OS::TripleO::Services::HAProxyInternalTLS',NULL,NULL),(949,'177b0423-6210-42a0-a9d2-9126cbdb3592','0e9ffab8-1eea-4486-9f74-3ad5619cbcb9','2026-06-12 08:26:03',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-7-okda37e7kw2y-RoleParametersValue-livzpw2nvbki','state changed','OS::Heat::Value',NULL,652),(950,'53fe49bc-16a5-42fd-85a3-389a3906524c','94181640-aa6b-41b3-b276-5c77ec1866f8','2026-06-12 08:26:03',NULL,'CREATE','COMPLETE','HAProxyInternalTLS','d2bf0a13-8c71-45bd-b656-e2eba3a6426b','state changed','OS::TripleO::Services::HAProxyInternalTLS',NULL,NULL),(951,'db4410b5-5145-467b-8577-c09757cf2091','6eed82e9-8e67-4b51-912a-4ec01b136e85','2026-06-12 08:26:03',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-13-jy5vx4r5p7kb-ContainersCommon-4evqmhbyao24','6eed82e9-8e67-4b51-912a-4ec01b136e85','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(952,'0f5c15ef-e31f-4ede-80ff-b842626c89d0','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:26:03',NULL,'CREATE','IN_PROGRESS','9','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-9-3viausvewaix','state changed','OS::TripleO::Services::NovaCompute',NULL,653),(953,'bdda0a43-58fc-4036-b854-18d5ec280549','6eed82e9-8e67-4b51-912a-4ec01b136e85','2026-06-12 08:26:03',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-13-jy5vx4r5p7kb-ContainersCommon-4evqmhbyao24','6eed82e9-8e67-4b51-912a-4ec01b136e85','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(954,'ada4fb4b-9cf1-4242-8adb-63d6c732e27e','e7c153e6-8489-466b-b61f-c81ddd6112e4','2026-06-12 08:26:03',NULL,'CREATE','COMPLETE','ContainersCommon','a1549018-61fe-4193-803c-f761aa6c32d7','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(955,'4334848b-f437-4d5d-9955-f6d944113997','481da614-a28c-455e-9add-8b0187d16d8f','2026-06-12 08:26:03',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-10-tniduxydeujc-NovaBase-gsn5ch26smzr','481da614-a28c-455e-9add-8b0187d16d8f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(956,'e34598a6-64d5-423d-82cc-2831e7245756','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:26:03',NULL,'CREATE','COMPLETE','7','4ba2b85b-ac30-4acb-90e6-6deb235112b0','state changed','OS::TripleO::Services::Iscsid',NULL,605),(957,'f236ac8f-3c2e-44ff-babb-47ce0e51b961','481da614-a28c-455e-9add-8b0187d16d8f','2026-06-12 08:26:03',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-10-tniduxydeujc-NovaBase-gsn5ch26smzr-RoleParametersValue-cxsz4f2owodh','state changed','OS::Heat::Value',NULL,654),(958,'5f0c7d09-9a07-45c0-a0b9-142f441a466b','481da614-a28c-455e-9add-8b0187d16d8f','2026-06-12 08:26:03',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-10-tniduxydeujc-NovaBase-gsn5ch26smzr-RoleParametersValue-cxsz4f2owodh','state changed','OS::Heat::Value',NULL,654),(959,'d1e8ec23-b940-4aab-8c04-a1b4108ab4c8','7013fd85-c572-4c24-baec-eb0567959817','2026-06-12 08:26:03',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-9-3viausvewaix','7013fd85-c572-4c24-baec-eb0567959817','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(960,'c729856f-84ba-4aeb-a4c7-c91add1694c3','481da614-a28c-455e-9add-8b0187d16d8f','2026-06-12 08:26:03',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-10-tniduxydeujc-NovaBase-gsn5ch26smzr','481da614-a28c-455e-9add-8b0187d16d8f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(961,'69fb4b9d-87f3-4a15-b4ea-d038bad2ea18','7013fd85-c572-4c24-baec-eb0567959817','2026-06-12 08:26:03',NULL,'CREATE','IN_PROGRESS','NovaComputeCommon','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-9-3viausvewaix-NovaComputeCommon-5gn6dkspsvaw','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-common-container-puppet.yaml',NULL,658),(962,'4b33c1d9-ba75-424f-a684-5b6a156fa3a9','fe913820-5914-4439-8fa6-4b68d78001ff','2026-06-12 08:26:03',NULL,'CREATE','COMPLETE','CeilometerServiceBase','355779b0-966b-4404-a25c-db10872ce943','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,640),(963,'b8ce2ac5-79dd-4696-bb5c-72240ee858f0','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:26:03',NULL,'CREATE','IN_PROGRESS','11','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-11-ntlazlcmces7','state changed','OS::TripleO::Services::MySQLClient',NULL,659),(964,'1cd0ca0c-4cb5-494b-a0e0-f1fb6d932829','fe913820-5914-4439-8fa6-4b68d78001ff','2026-06-12 08:26:03',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-4-4pmbtyk4cwdx-CeilometerAgentCentralBase-sodg36cbj3zy','fe913820-5914-4439-8fa6-4b68d78001ff','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(965,'8eaa5508-7fb5-4b08-b5a6-e2ba10ed610a','a068f209-41fb-48b2-904f-ec114defeff1','2026-06-12 08:26:03',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-9-3viausvewaix-NovaComputeCommon-5gn6dkspsvaw','a068f209-41fb-48b2-904f-ec114defeff1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(966,'eb6c7508-c37c-4a81-962c-4de30ea884a4','480626f9-6818-4fed-bdee-bbe72ca76d15','2026-06-12 08:26:03',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-11-ntlazlcmces7','480626f9-6818-4fed-bdee-bbe72ca76d15','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(967,'d2af894b-2253-46d4-ae35-0988fa343bd8','a068f209-41fb-48b2-904f-ec114defeff1','2026-06-12 08:26:03',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-9-3viausvewaix-NovaComputeCommon-5gn6dkspsvaw','a068f209-41fb-48b2-904f-ec114defeff1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(968,'a69a80f7-1bf0-4bf8-8b16-101285cbd028','63487f92-d728-402d-a5fe-0a2a7492ecaf','2026-06-12 08:26:03',NULL,'CREATE','IN_PROGRESS','NovaDBClient','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-12-yus2rf76fg5v-NovaDBClient-qr6ccj5z4ptu','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,660),(969,'13b9d16b-9f49-4c47-93d5-e03b0da9123d','480626f9-6818-4fed-bdee-bbe72ca76d15','2026-06-12 08:26:03',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-11-ntlazlcmces7','480626f9-6818-4fed-bdee-bbe72ca76d15','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(970,'9b890d29-01ea-4c31-92c7-0f2918fe463a','c95577ec-db60-41ba-a1d4-25c3b11d439a','2026-06-12 08:26:03',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-12-yus2rf76fg5v-NovaDBClient-qr6ccj5z4ptu','c95577ec-db60-41ba-a1d4-25c3b11d439a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(971,'c903b583-3fa9-440e-8b03-66d2678dc737','61fccc8d-01b4-4716-bdfa-37b1b4f1f8f1','2026-06-12 08:26:03',NULL,'CREATE','COMPLETE','CeilometerServiceBase','e169fb8a-0f31-408c-8c3a-34b4a3b93c2d','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,642),(972,'9753aaa9-225f-4cb7-b99a-72a57cfb7610','74eec8c4-422a-46d3-9ec6-f02901048161','2026-06-12 08:26:03',NULL,'CREATE','IN_PROGRESS','ContainersCommon','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-6-togxoevovf3t-ContainersCommon-whxj3syrjo3o','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(973,'da93fa0a-b321-482c-a819-11fe21dcff74','c95577ec-db60-41ba-a1d4-25c3b11d439a','2026-06-12 08:26:03',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-12-yus2rf76fg5v-NovaDBClient-qr6ccj5z4ptu','c95577ec-db60-41ba-a1d4-25c3b11d439a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(974,'f017688e-6e96-4dfd-8821-130e4d7bd64c','63487f92-d728-402d-a5fe-0a2a7492ecaf','2026-06-12 08:26:03',NULL,'CREATE','COMPLETE','ContainersCommon','9a6af8e4-f747-46d2-bd64-a6c4bcf69179','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(975,'524f2c5e-b57e-4c3e-afb6-1a14ae6a7548','61fccc8d-01b4-4716-bdfa-37b1b4f1f8f1','2026-06-12 08:26:03',NULL,'CREATE','COMPLETE','CeilometerAgentCentralBase','fe913820-5914-4439-8fa6-4b68d78001ff','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml',NULL,585),(976,'e104bc95-f635-4a01-940d-bb4b99e05145','61fccc8d-01b4-4716-bdfa-37b1b4f1f8f1','2026-06-12 08:26:03',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-4-4pmbtyk4cwdx','61fccc8d-01b4-4716-bdfa-37b1b4f1f8f1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(977,'a782b6f1-3a34-40c9-9d3b-fdeecb0197ca','2d0dec5a-55c7-4d9e-b416-2ced63b6bed3','2026-06-12 08:26:03',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-6-togxoevovf3t-ContainersCommon-whxj3syrjo3o','2d0dec5a-55c7-4d9e-b416-2ced63b6bed3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(978,'e7723cbc-642d-41f2-8ee7-58bfa28f5f3b','2d0dec5a-55c7-4d9e-b416-2ced63b6bed3','2026-06-12 08:26:03',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-6-togxoevovf3t-ContainersCommon-whxj3syrjo3o','2d0dec5a-55c7-4d9e-b416-2ced63b6bed3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(979,'8730a7f8-4606-4167-8d96-773f2a38e8b4','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:26:03',NULL,'CREATE','COMPLETE','4','61fccc8d-01b4-4716-bdfa-37b1b4f1f8f1','state changed','OS::TripleO::Services::CeilometerAgentIpmi',NULL,555),(980,'da4f5c04-d2d6-45c5-9542-0a7e995367a7','e7c153e6-8489-466b-b61f-c81ddd6112e4','2026-06-12 08:26:04',NULL,'CREATE','IN_PROGRESS','NovaLibvirtCommon','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-10-tniduxydeujc-NovaLibvirtCommon-dm6gw4yzns4c','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-common.yaml',NULL,NULL),(981,'9628fb73-2b9d-49c7-9f0a-ab79e62cfa12','0e9ffab8-1eea-4486-9f74-3ad5619cbcb9','2026-06-12 08:26:04',NULL,'CREATE','IN_PROGRESS','ContainersCommon','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-7-okda37e7kw2y-ContainersCommon-ihrffyoz7s62','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(982,'e4c7b3f2-89e7-4e29-b0d3-2b2c6d183220','98be2585-4dea-456a-96e8-bc0e4cc60166','2026-06-12 08:26:04',NULL,'CREATE','IN_PROGRESS','NovaBase','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-13-jy5vx4r5p7kb-NovaBase-h45wlot6ydqu','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,661),(983,'ca652139-66a1-4010-b8ae-ac9ec312700f','94181640-aa6b-41b3-b276-5c77ec1866f8','2026-06-12 08:26:04',NULL,'CREATE','IN_PROGRESS','ContainersCommon','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-6-togxoevovf3t-HAProxyBase-6zbqyap7csb2-ContainersCommon-tpxxuhqxj3vi','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(984,'eaf01e3a-f994-40e1-a9a4-b1e021f18fc3','b46559ab-2db3-4073-b491-96654d093670','2026-06-12 08:26:04',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-10-tniduxydeujc-NovaLibvirtCommon-dm6gw4yzns4c','b46559ab-2db3-4073-b491-96654d093670','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(985,'3c47eeae-17fd-4353-ba5e-7ad378d94795','98be2585-4dea-456a-96e8-bc0e4cc60166','2026-06-12 08:26:04',NULL,'CREATE','COMPLETE','ContainersCommon','6eed82e9-8e67-4b51-912a-4ec01b136e85','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(986,'65934b66-ef42-4b33-93b3-bc3af3a82a58','32dbd4eb-66ee-41ba-bbed-811846198f3f','2026-06-12 08:26:04',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-7-okda37e7kw2y-ContainersCommon-ihrffyoz7s62','32dbd4eb-66ee-41ba-bbed-811846198f3f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(987,'40efde53-2a49-4582-8302-f1dc89c12a10','afedfc1a-acbc-42b4-8996-9cba1f08c664','2026-06-12 08:26:04',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-6-togxoevovf3t-HAProxyBase-6zbqyap7csb2-ContainersCommon-tpxxuhqxj3vi','afedfc1a-acbc-42b4-8996-9cba1f08c664','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(988,'2d373a9a-4e9c-4e4f-b579-558fb7ae551c','32dbd4eb-66ee-41ba-bbed-811846198f3f','2026-06-12 08:26:04',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-7-okda37e7kw2y-ContainersCommon-ihrffyoz7s62','32dbd4eb-66ee-41ba-bbed-811846198f3f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(989,'76e00e9d-68d6-4cc3-893b-e926570cf586','afedfc1a-acbc-42b4-8996-9cba1f08c664','2026-06-12 08:26:04',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-6-togxoevovf3t-HAProxyBase-6zbqyap7csb2-ContainersCommon-tpxxuhqxj3vi','afedfc1a-acbc-42b4-8996-9cba1f08c664','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(990,'9d79e505-4429-4cea-b50b-2f2683827611','e7c153e6-8489-466b-b61f-c81ddd6112e4','2026-06-12 08:26:04',NULL,'CREATE','COMPLETE','NovaBase','481da614-a28c-455e-9add-8b0187d16d8f','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,650),(991,'d5110e65-01b4-4185-ad3c-7ea46f24ed25','0e9ffab8-1eea-4486-9f74-3ad5619cbcb9','2026-06-12 08:26:04',NULL,'CREATE','COMPLETE','ContainersCommon','32dbd4eb-66ee-41ba-bbed-811846198f3f','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(992,'206c49fb-60b8-4351-a7f2-f8d1ec54ad9d','19fb8b06-9569-412e-bc6b-355ba1e191cc','2026-06-12 08:26:04',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-13-jy5vx4r5p7kb-NovaBase-h45wlot6ydqu','19fb8b06-9569-412e-bc6b-355ba1e191cc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(993,'cc603c0f-c976-47ef-8b16-a4004199107f','0e9ffab8-1eea-4486-9f74-3ad5619cbcb9','2026-06-12 08:26:04',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-7-okda37e7kw2y','0e9ffab8-1eea-4486-9f74-3ad5619cbcb9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(994,'c3aa2057-0b94-426b-956e-c05b347afaa9','b46559ab-2db3-4073-b491-96654d093670','2026-06-12 08:26:04',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-10-tniduxydeujc-NovaLibvirtCommon-dm6gw4yzns4c-RoleParametersValue-lmmsz5avwlka','state changed','OS::Heat::Value',NULL,667),(995,'49d25700-5098-4dc5-b29e-8de7256fb537','19fb8b06-9569-412e-bc6b-355ba1e191cc','2026-06-12 08:26:04',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-13-jy5vx4r5p7kb-NovaBase-h45wlot6ydqu-RoleParametersValue-eqrnfuovgrb7','state changed','OS::Heat::Value',NULL,668),(996,'0144ccc9-f0a7-4fb9-93e4-3e1e08d7bbdf','b46559ab-2db3-4073-b491-96654d093670','2026-06-12 08:26:04',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-10-tniduxydeujc-NovaLibvirtCommon-dm6gw4yzns4c-RoleParametersValue-lmmsz5avwlka','state changed','OS::Heat::Value',NULL,667),(997,'278c7b0c-4276-49ff-ac8e-6a5c6244ff5b','19fb8b06-9569-412e-bc6b-355ba1e191cc','2026-06-12 08:26:04',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-13-jy5vx4r5p7kb-NovaBase-h45wlot6ydqu-RoleParametersValue-eqrnfuovgrb7','state changed','OS::Heat::Value',NULL,668),(998,'147e121e-e2d2-47fe-bcf5-8cac5a03347c','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:26:04',NULL,'CREATE','IN_PROGRESS','8','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-8-wh3maavghkrj','state changed','OS::TripleO::Services::MySQLClient',NULL,669),(999,'2371574f-256e-43e2-b0c5-a3f5bf81b177','19fb8b06-9569-412e-bc6b-355ba1e191cc','2026-06-12 08:26:04',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-13-jy5vx4r5p7kb-NovaBase-h45wlot6ydqu','19fb8b06-9569-412e-bc6b-355ba1e191cc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1000,'c12fe8e6-6043-4f5d-8730-852c10580ec4','b46559ab-2db3-4073-b491-96654d093670','2026-06-12 08:26:04',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-10-tniduxydeujc-NovaLibvirtCommon-dm6gw4yzns4c','b46559ab-2db3-4073-b491-96654d093670','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1001,'9c8727a9-96f2-4b6b-9404-c8b3ddb47321','7885a47d-4a35-48c8-8118-4a7733a5620b','2026-06-12 08:26:04',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-8-wh3maavghkrj','7885a47d-4a35-48c8-8118-4a7733a5620b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1002,'3d768537-4b73-4721-b12d-95ec6480cd67','7013fd85-c572-4c24-baec-eb0567959817','2026-06-12 08:26:04',NULL,'CREATE','IN_PROGRESS','ContainersCommon','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-9-3viausvewaix-ContainersCommon-bt7hn4q62xvh','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1003,'892ab835-59f4-4202-96b7-3797b2c3fc44','7885a47d-4a35-48c8-8118-4a7733a5620b','2026-06-12 08:26:04',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-8-wh3maavghkrj','7885a47d-4a35-48c8-8118-4a7733a5620b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1004,'83205a7b-ba79-4039-98c7-096b9830be03','a1739ef7-4ea1-4d5b-bd7a-d4ccf385455b','2026-06-12 08:26:04',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-9-3viausvewaix-ContainersCommon-bt7hn4q62xvh','a1739ef7-4ea1-4d5b-bd7a-d4ccf385455b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1005,'76169c4e-976e-45a9-8c6e-e0fff6697eb5','7013fd85-c572-4c24-baec-eb0567959817','2026-06-12 08:26:04',NULL,'CREATE','COMPLETE','NovaComputeCommon','a068f209-41fb-48b2-904f-ec114defeff1','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-common-container-puppet.yaml',NULL,658),(1006,'dede18e2-f40b-4bf6-98ff-c5246000140e','a1739ef7-4ea1-4d5b-bd7a-d4ccf385455b','2026-06-12 08:26:04',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-9-3viausvewaix-ContainersCommon-bt7hn4q62xvh','a1739ef7-4ea1-4d5b-bd7a-d4ccf385455b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1007,'de3c8c2a-a09c-45ba-9c0b-200fe2b717d1','63487f92-d728-402d-a5fe-0a2a7492ecaf','2026-06-12 08:26:04',NULL,'CREATE','IN_PROGRESS','NovaApiDBClient','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-12-yus2rf76fg5v-NovaApiDBClient-oglvhvontojg','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,670),(1008,'0c796dcd-419e-47a9-8b5a-d69fe6e95119','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:26:04',NULL,'CREATE','COMPLETE','11','480626f9-6818-4fed-bdee-bbe72ca76d15','state changed','OS::TripleO::Services::MySQLClient',NULL,659),(1009,'7d89ab8e-cb6f-4ea0-ab41-e1c89a69e119','63487f92-d728-402d-a5fe-0a2a7492ecaf','2026-06-12 08:26:04',NULL,'CREATE','COMPLETE','NovaDBClient','c95577ec-db60-41ba-a1d4-25c3b11d439a','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,660),(1010,'ad4b4b79-9c9b-4b22-954d-5aaa91fdf7d3','a7c776e2-632e-4ab3-a1ec-5d8fcb103932','2026-06-12 08:26:04',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-12-yus2rf76fg5v-NovaApiDBClient-oglvhvontojg','a7c776e2-632e-4ab3-a1ec-5d8fcb103932','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1011,'a06bfb2e-54a5-45d1-b47b-a10111c64410','a7c776e2-632e-4ab3-a1ec-5d8fcb103932','2026-06-12 08:26:04',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-12-yus2rf76fg5v-NovaApiDBClient-oglvhvontojg','a7c776e2-632e-4ab3-a1ec-5d8fcb103932','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1012,'2d478b44-6727-4f37-8710-f06a4215e8ff','74eec8c4-422a-46d3-9ec6-f02901048161','2026-06-12 08:26:04',NULL,'CREATE','COMPLETE','ContainersCommon','2d0dec5a-55c7-4d9e-b416-2ced63b6bed3','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1013,'1a2c0f6a-44c7-4a92-9460-c83d3994bd4a','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:26:04',NULL,'CREATE','IN_PROGRESS','15','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-15-zy2azprombbj','state changed','OS::TripleO::Services::OsloMessagingRpc',NULL,672),(1014,'2a267b8a-21a8-4a3b-a6f6-178684ea885d','cb8a8753-2b55-453a-b4c6-2526aac71ca5','2026-06-12 08:26:05',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-15-zy2azprombbj','cb8a8753-2b55-453a-b4c6-2526aac71ca5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1015,'df54985c-92b1-4ce3-86c3-7f302e76a61b','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:26:05',NULL,'CREATE','COMPLETE','7','0e9ffab8-1eea-4486-9f74-3ad5619cbcb9','state changed','OS::TripleO::Services::MetricsQdr',NULL,647),(1016,'6a441893-a663-4ae6-b48b-7cf8a701dd7d','e7c153e6-8489-466b-b61f-c81ddd6112e4','2026-06-12 08:26:05',NULL,'CREATE','IN_PROGRESS','NovaLibvirtLogging','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-10-tniduxydeujc-NovaLibvirtLogging-urzyvt3by4ti','state changed','OS::TripleO::Services::Logging::NovaLibvirt',NULL,NULL),(1017,'840cbd50-dc9e-4b9a-a81a-51449c45baf8','98be2585-4dea-456a-96e8-bc0e4cc60166','2026-06-12 08:26:05',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-13-jy5vx4r5p7kb-RoleParametersValue-fyenfogeolhp','state changed','OS::Heat::Value',NULL,673),(1018,'348b8db8-a883-4ede-ac03-210ffd12933f','5b8b7a1e-d040-43b8-bfc1-d61f5f6b2251','2026-06-12 08:26:05',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-10-tniduxydeujc-NovaLibvirtLogging-urzyvt3by4ti','5b8b7a1e-d040-43b8-bfc1-d61f5f6b2251','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1019,'78222f9e-a295-44a0-9c01-edcde92459d2','98be2585-4dea-456a-96e8-bc0e4cc60166','2026-06-12 08:26:05',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-13-jy5vx4r5p7kb-RoleParametersValue-fyenfogeolhp','state changed','OS::Heat::Value',NULL,673),(1020,'609053d7-26dc-48ac-a1be-facb2fa9b72c','5b8b7a1e-d040-43b8-bfc1-d61f5f6b2251','2026-06-12 08:26:05',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-10-tniduxydeujc-NovaLibvirtLogging-urzyvt3by4ti','5b8b7a1e-d040-43b8-bfc1-d61f5f6b2251','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1021,'3c078e1b-812a-452c-903a-99ebcf3332c1','e7c153e6-8489-466b-b61f-c81ddd6112e4','2026-06-12 08:26:05',NULL,'CREATE','COMPLETE','NovaLibvirtLogging','5b8b7a1e-d040-43b8-bfc1-d61f5f6b2251','state changed','OS::TripleO::Services::Logging::NovaLibvirt',NULL,NULL),(1022,'662b39a5-a9c4-4403-9b97-8bcc05230f80','cb8a8753-2b55-453a-b4c6-2526aac71ca5','2026-06-12 08:26:05',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-15-zy2azprombbj-RoleParametersValue-4ob2d2ny3n7q','state changed','OS::Heat::Value',NULL,674),(1023,'0789f7b4-d403-4b04-90bc-accc3d8c3907','cb8a8753-2b55-453a-b4c6-2526aac71ca5','2026-06-12 08:26:05',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-15-zy2azprombbj-RoleParametersValue-4ob2d2ny3n7q','state changed','OS::Heat::Value',NULL,674),(1024,'4410a932-5c05-4637-ac92-5fd2b64aea59','e7c153e6-8489-466b-b61f-c81ddd6112e4','2026-06-12 08:26:05',NULL,'CREATE','COMPLETE','NovaLibvirtCommon','b46559ab-2db3-4073-b491-96654d093670','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-common.yaml',NULL,NULL),(1025,'d87ae994-474c-40e0-9732-ed58257848c1','94181640-aa6b-41b3-b276-5c77ec1866f8','2026-06-12 08:26:05',NULL,'CREATE','COMPLETE','ContainersCommon','afedfc1a-acbc-42b4-8996-9cba1f08c664','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1026,'ceec9ce7-ab83-4350-b78c-7fc0c105cea6','e7c153e6-8489-466b-b61f-c81ddd6112e4','2026-06-12 08:26:05',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-10-tniduxydeujc','e7c153e6-8489-466b-b61f-c81ddd6112e4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1027,'a7a9a9db-5d33-4d0d-9008-3c84b127beba','94181640-aa6b-41b3-b276-5c77ec1866f8','2026-06-12 08:26:05',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-6-togxoevovf3t-HAProxyBase-6zbqyap7csb2','94181640-aa6b-41b3-b276-5c77ec1866f8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1028,'73d8fb48-5b75-4146-bc3f-f602ffb8495a','98be2585-4dea-456a-96e8-bc0e4cc60166','2026-06-12 08:26:05',NULL,'CREATE','COMPLETE','NovaBase','19fb8b06-9569-412e-bc6b-355ba1e191cc','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,661),(1029,'8e1c83b2-ffa5-460e-b0d4-d0da15582e5b','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:26:05',NULL,'CREATE','IN_PROGRESS','11','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-11-attrmedmsrtp','state changed','OS::TripleO::Services::NovaLibvirtGuests',NULL,678),(1030,'aa1ac34e-0882-4f49-a782-ae62290a61de','962b386f-38ad-49fa-a0fb-9ae9b9a2e0aa','2026-06-12 08:26:05',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-11-attrmedmsrtp','962b386f-38ad-49fa-a0fb-9ae9b9a2e0aa','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1031,'412ceded-b160-4d5b-ae43-ffa1c00a524a','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:26:05',NULL,'CREATE','COMPLETE','8','7885a47d-4a35-48c8-8118-4a7733a5620b','state changed','OS::TripleO::Services::MySQLClient',NULL,669),(1032,'64789886-95df-484c-a1d2-a3d3752afb96','7013fd85-c572-4c24-baec-eb0567959817','2026-06-12 08:26:05',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-9-3viausvewaix-RoleParametersValue-v2ancbjs7n6r','state changed','OS::Heat::Value',NULL,679),(1033,'1c669e00-e952-47bc-8226-cae6108dba5d','962b386f-38ad-49fa-a0fb-9ae9b9a2e0aa','2026-06-12 08:26:05',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-11-attrmedmsrtp-RoleParametersValue-fcp6y47xog6n','state changed','OS::Heat::Value',NULL,680),(1034,'2159200d-74f3-47a4-a8d6-6bfcb5b9cec8','7013fd85-c572-4c24-baec-eb0567959817','2026-06-12 08:26:05',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-9-3viausvewaix-RoleParametersValue-v2ancbjs7n6r','state changed','OS::Heat::Value',NULL,679),(1035,'d4cdba87-a1c8-4c8e-a9c0-b895b2289f40','962b386f-38ad-49fa-a0fb-9ae9b9a2e0aa','2026-06-12 08:26:05',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-11-attrmedmsrtp-RoleParametersValue-fcp6y47xog6n','state changed','OS::Heat::Value',NULL,680),(1036,'41a05c29-65e6-485d-a80c-15e11696cb82','962b386f-38ad-49fa-a0fb-9ae9b9a2e0aa','2026-06-12 08:26:05',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-11-attrmedmsrtp','962b386f-38ad-49fa-a0fb-9ae9b9a2e0aa','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1037,'e2385ae7-b310-4801-bd59-d99b43ebdd87','7013fd85-c572-4c24-baec-eb0567959817','2026-06-12 08:26:05',NULL,'CREATE','IN_PROGRESS','NovaLogging','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-9-3viausvewaix-NovaLogging-tss3gwjk3vtd','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,682),(1038,'aa7c4e56-3fb2-4bd1-a3e4-2d7878928f34','7013fd85-c572-4c24-baec-eb0567959817','2026-06-12 08:26:05',NULL,'CREATE','COMPLETE','ContainersCommon','a1739ef7-4ea1-4d5b-bd7a-d4ccf385455b','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1039,'37cbf6ec-d08c-4abe-b8bf-1caa988e7670','63487f92-d728-402d-a5fe-0a2a7492ecaf','2026-06-12 08:26:05',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-12-yus2rf76fg5v-RoleParametersValue-2qdcu45eouk4','state changed','OS::Heat::Value',NULL,684),(1040,'d32ef567-2267-4f1b-89f8-5dec0b2b8884','63487f92-d728-402d-a5fe-0a2a7492ecaf','2026-06-12 08:26:05',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-12-yus2rf76fg5v-RoleParametersValue-2qdcu45eouk4','state changed','OS::Heat::Value',NULL,684),(1041,'015dea3a-6f18-4981-a0a4-6d9c0c4d191c','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:26:05',NULL,'CREATE','IN_PROGRESS','12','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-12-kcz64m2w2r6w','state changed','OS::TripleO::Services::NovaMigrationTarget',NULL,686),(1042,'e20dbbc7-2db8-432e-a485-147aabb55453','63487f92-d728-402d-a5fe-0a2a7492ecaf','2026-06-12 08:26:05',NULL,'CREATE','IN_PROGRESS','NovaLogging','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-12-yus2rf76fg5v-NovaLogging-gqxzyvgirhjb','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,687),(1043,'592f2d11-d1d8-4cfd-963b-4aa940030e95','47d6c8d9-9829-40c4-8f4b-26b8eab62565','2026-06-12 08:26:05',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-9-3viausvewaix-NovaLogging-tss3gwjk3vtd','47d6c8d9-9829-40c4-8f4b-26b8eab62565','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1044,'5ff25726-f354-44b6-a05f-79cd8397a1d1','6b9ea3c7-59e8-474b-8aa6-d9051e421bc9','2026-06-12 08:26:05',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-12-kcz64m2w2r6w','6b9ea3c7-59e8-474b-8aa6-d9051e421bc9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1045,'6b4088cf-aa4b-4cba-8512-df0c0352a4bb','42b92b97-24cb-40d6-80fb-076591efe485','2026-06-12 08:26:05',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-12-yus2rf76fg5v-NovaLogging-gqxzyvgirhjb','42b92b97-24cb-40d6-80fb-076591efe485','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1046,'3e32ba74-86bc-4d83-9122-87eaf45b6425','63487f92-d728-402d-a5fe-0a2a7492ecaf','2026-06-12 08:26:05',NULL,'CREATE','COMPLETE','NovaApiDBClient','a7c776e2-632e-4ab3-a1ec-5d8fcb103932','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,670),(1047,'d2f008a6-17f8-4bae-9e86-413d7f692e40','47d6c8d9-9829-40c4-8f4b-26b8eab62565','2026-06-12 08:26:05',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-9-3viausvewaix-NovaLogging-tss3gwjk3vtd-RoleParametersValue-busmye6n5h7c','state changed','OS::Heat::Value',NULL,688),(1048,'7d4af32b-2a1f-4aae-8001-f78ca1c2eb97','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:26:05',NULL,'CREATE','COMPLETE','10','e7c153e6-8489-466b-b61f-c81ddd6112e4','state changed','OS::TripleO::Services::NovaLibvirt',NULL,619),(1049,'6cf2da6b-7fe4-4189-b550-1d635a6d8535','47d6c8d9-9829-40c4-8f4b-26b8eab62565','2026-06-12 08:26:05',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-9-3viausvewaix-NovaLogging-tss3gwjk3vtd-RoleParametersValue-busmye6n5h7c','state changed','OS::Heat::Value',NULL,688),(1050,'38895536-1d7e-48c6-9957-bf36a9dec18b','42b92b97-24cb-40d6-80fb-076591efe485','2026-06-12 08:26:05',NULL,'CREATE','IN_PROGRESS','InitLogContainerName','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-12-yus2rf76fg5v-NovaLogging-gqxzyvgirhjb-InitLogContainerName-6nksx2ki4ppx','state changed','OS::Heat::Value',NULL,689),(1051,'10d6566c-1e5f-4923-9ad9-b3d9ff4ede2d','42b92b97-24cb-40d6-80fb-076591efe485','2026-06-12 08:26:06',NULL,'CREATE','COMPLETE','InitLogContainerName','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-12-yus2rf76fg5v-NovaLogging-gqxzyvgirhjb-InitLogContainerName-6nksx2ki4ppx','state changed','OS::Heat::Value',NULL,689),(1052,'9461561c-122d-4928-a8e2-ecf1b97aec78','6b9ea3c7-59e8-474b-8aa6-d9051e421bc9','2026-06-12 08:26:06',NULL,'CREATE','IN_PROGRESS','SshdBase','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-12-kcz64m2w2r6w-SshdBase-kysvt5znxq5n','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-puppet.yaml',NULL,690),(1053,'dbf56a01-2064-4a1e-be06-ab2306e38ee7','7925e728-3592-4bc9-99ad-75440083e9a5','2026-06-12 08:26:06',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-12-kcz64m2w2r6w-SshdBase-kysvt5znxq5n','7925e728-3592-4bc9-99ad-75440083e9a5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1054,'a31f76b0-14ba-4871-8f31-ffdb34601ad6','74eec8c4-422a-46d3-9ec6-f02901048161','2026-06-12 08:26:06',NULL,'CREATE','COMPLETE','HAProxyBase','94181640-aa6b-41b3-b276-5c77ec1866f8','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-container-puppet.yaml',NULL,597),(1055,'9eb85e2a-878c-4dfe-b70d-fa7cee950e54','7925e728-3592-4bc9-99ad-75440083e9a5','2026-06-12 08:26:06',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-12-kcz64m2w2r6w-SshdBase-kysvt5znxq5n','7925e728-3592-4bc9-99ad-75440083e9a5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1056,'15ca7844-d9b5-46f8-805d-2a0146805b95','98be2585-4dea-456a-96e8-bc0e4cc60166','2026-06-12 08:26:06',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-13-jy5vx4r5p7kb-ApacheServiceBase-aldflma5b6br','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,694),(1057,'8c0fdd5e-8535-4ff4-8f63-86b143eddfa8','74eec8c4-422a-46d3-9ec6-f02901048161','2026-06-12 08:26:06',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-6-togxoevovf3t','74eec8c4-422a-46d3-9ec6-f02901048161','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1058,'6d2dc74c-6cbb-432e-8cf0-b0e0b660e9d6','cb8a8753-2b55-453a-b4c6-2526aac71ca5','2026-06-12 08:26:06',NULL,'CREATE','IN_PROGRESS','RabbitmqBase','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-15-zy2azprombbj-RabbitmqBase-uhedbv6o7ygf','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-container-puppet.yaml',NULL,697),(1059,'577104bd-07a5-4355-8288-627d1661c38a','ee57102c-f91b-4bb1-8edd-66a55e305393','2026-06-12 08:26:06',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-13-jy5vx4r5p7kb-ApacheServiceBase-aldflma5b6br','ee57102c-f91b-4bb1-8edd-66a55e305393','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1060,'6888723f-55a5-445d-bd7a-4f48420e37e0','2ed5ab20-4a87-4ed1-8b98-aa5acf725ca2','2026-06-12 08:26:06',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-15-zy2azprombbj-RabbitmqBase-uhedbv6o7ygf','2ed5ab20-4a87-4ed1-8b98-aa5acf725ca2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1061,'e963ee9a-37db-4944-83d0-513eb52c77ad','ee57102c-f91b-4bb1-8edd-66a55e305393','2026-06-12 08:26:06',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-13-jy5vx4r5p7kb-ApacheServiceBase-aldflma5b6br-ApacheNetworks-ytwqy66sko2g','state changed','OS::Heat::Value',NULL,700),(1062,'4a003e4d-2455-469f-9b10-4c329d785d9a','ee57102c-f91b-4bb1-8edd-66a55e305393','2026-06-12 08:26:06',NULL,'CREATE','COMPLETE','ApacheNetworks','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-13-jy5vx4r5p7kb-ApacheServiceBase-aldflma5b6br-ApacheNetworks-ytwqy66sko2g','state changed','OS::Heat::Value',NULL,700),(1063,'28dbda2e-36d5-49da-9875-7bc895a9f487','ee57102c-f91b-4bb1-8edd-66a55e305393','2026-06-12 08:26:06',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-13-jy5vx4r5p7kb-ApacheServiceBase-aldflma5b6br','ee57102c-f91b-4bb1-8edd-66a55e305393','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1064,'eec152cc-5f99-45a4-904d-a78765b6912b','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:26:06',NULL,'CREATE','COMPLETE','11','962b386f-38ad-49fa-a0fb-9ae9b9a2e0aa','state changed','OS::TripleO::Services::NovaLibvirtGuests',NULL,678),(1065,'0b06ef3a-c333-4ee4-bc38-4fd140044337','2ed5ab20-4a87-4ed1-8b98-aa5acf725ca2','2026-06-12 08:26:06',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-15-zy2azprombbj-RabbitmqBase-uhedbv6o7ygf-RoleParametersValue-c5lbo6ju37fd','state changed','OS::Heat::Value',NULL,702),(1066,'b28e69d2-e8c6-4a6e-93f1-7a3a46ec6be2','2ed5ab20-4a87-4ed1-8b98-aa5acf725ca2','2026-06-12 08:26:06',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-15-zy2azprombbj-RabbitmqBase-uhedbv6o7ygf-RoleParametersValue-c5lbo6ju37fd','state changed','OS::Heat::Value',NULL,702),(1067,'3debfc36-cc77-4d87-8bd5-845771740187','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:26:06',NULL,'CREATE','IN_PROGRESS','14','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-14-dgloj7jqktf3','state changed','OS::TripleO::Services::Podman',NULL,703),(1068,'0f07a26c-83fa-44e7-9e08-e3d1c600fca6','129042fb-556d-47f7-a0ad-32db33f551dd','2026-06-12 08:26:06',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-14-dgloj7jqktf3','129042fb-556d-47f7-a0ad-32db33f551dd','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1069,'3518aa4e-8e85-4c7c-bb29-d6df91e54ac2','7013fd85-c572-4c24-baec-eb0567959817','2026-06-12 08:26:06',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-9-3viausvewaix-CinderNVMeOF-gwag2mx563fb','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1070,'da2b2bbf-0ca4-4163-aa60-994ad5b1e226','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:26:06',NULL,'CREATE','COMPLETE','6','74eec8c4-422a-46d3-9ec6-f02901048161','state changed','OS::TripleO::Services::HAproxy',NULL,578),(1071,'573afc7f-b09e-42cd-855c-8ac93ac5b025','129042fb-556d-47f7-a0ad-32db33f551dd','2026-06-12 08:26:06',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-14-dgloj7jqktf3','129042fb-556d-47f7-a0ad-32db33f551dd','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1072,'c8e7c3c7-26c4-467f-bce0-bb74e299e3f8','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:26:06',NULL,'CREATE','COMPLETE','14','129042fb-556d-47f7-a0ad-32db33f551dd','state changed','OS::TripleO::Services::Podman',NULL,703),(1073,'18490ea7-579e-4ccd-963a-43bbee2998fc','7552cf4b-9c60-4d0e-9acc-890dc43789a7','2026-06-12 08:26:06',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-9-3viausvewaix-CinderNVMeOF-gwag2mx563fb','7552cf4b-9c60-4d0e-9acc-890dc43789a7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1074,'70b9272f-e634-4168-b831-d07fb39ae8ed','7552cf4b-9c60-4d0e-9acc-890dc43789a7','2026-06-12 08:26:06',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-9-3viausvewaix-CinderNVMeOF-gwag2mx563fb','7552cf4b-9c60-4d0e-9acc-890dc43789a7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1075,'4512663d-41e8-4324-9ab6-c0d9a7785bbe','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:26:06',NULL,'CREATE','IN_PROGRESS','15','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-15-ax2q5hnbe43b','state changed','OS::TripleO::Services::Rsyslog',NULL,709),(1076,'ad8a91a7-98a6-4d70-98e2-a5ff707f4ae8','89c2662a-59db-4817-8ce5-0b6679f9f98d','2026-06-12 08:26:06',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-15-ax2q5hnbe43b','89c2662a-59db-4817-8ce5-0b6679f9f98d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1077,'1e5f9197-0013-4171-9d54-4f941c12a88c','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:26:06',NULL,'CREATE','IN_PROGRESS','18','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-18-o5bppd7s5qkw','state changed','OS::TripleO::Services::Timesync',NULL,712),(1078,'ee548f7b-1436-4e7d-8cd9-c28dfd57d99f','47d6c8d9-9829-40c4-8f4b-26b8eab62565','2026-06-12 08:26:06',NULL,'CREATE','IN_PROGRESS','InitLogContainerName','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-9-3viausvewaix-NovaLogging-tss3gwjk3vtd-InitLogContainerName-7v565eji2b5u','state changed','OS::Heat::Value',NULL,714),(1079,'e26e2a7a-f12c-4b77-b45e-4e56d735ab03','47d6c8d9-9829-40c4-8f4b-26b8eab62565','2026-06-12 08:26:06',NULL,'CREATE','COMPLETE','InitLogContainerName','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-9-3viausvewaix-NovaLogging-tss3gwjk3vtd-InitLogContainerName-7v565eji2b5u','state changed','OS::Heat::Value',NULL,714),(1080,'82c21cec-b625-416a-9415-3efb279248ec','47d6c8d9-9829-40c4-8f4b-26b8eab62565','2026-06-12 08:26:06',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-9-3viausvewaix-NovaLogging-tss3gwjk3vtd','47d6c8d9-9829-40c4-8f4b-26b8eab62565','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1081,'cf1e4c2b-bf1b-4aba-b349-bd77223bb8a7','e308883d-0d2c-4932-8d10-2bd984920ccf','2026-06-12 08:26:06',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-18-o5bppd7s5qkw','e308883d-0d2c-4932-8d10-2bd984920ccf','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1082,'f95d06b1-0f2e-42c5-8d10-093076bb4627','89c2662a-59db-4817-8ce5-0b6679f9f98d','2026-06-12 08:26:06',NULL,'CREATE','IN_PROGRESS','ContainersCommon','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-15-ax2q5hnbe43b-ContainersCommon-g37aqhlo7x4k','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1083,'f1bff1fd-9e83-473e-8422-b8c26f35bb31','e308883d-0d2c-4932-8d10-2bd984920ccf','2026-06-12 08:26:06',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-18-o5bppd7s5qkw','e308883d-0d2c-4932-8d10-2bd984920ccf','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1084,'be024035-964d-4a02-bcb7-df6fb46e93d3','42b92b97-24cb-40d6-80fb-076591efe485','2026-06-12 08:26:06',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-12-yus2rf76fg5v-NovaLogging-gqxzyvgirhjb-RoleParametersValue-5mh4tjdx7mfs','state changed','OS::Heat::Value',NULL,716),(1085,'066adea6-240e-41bc-853d-08435bfc6597','42b92b97-24cb-40d6-80fb-076591efe485','2026-06-12 08:26:06',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-12-yus2rf76fg5v-NovaLogging-gqxzyvgirhjb-RoleParametersValue-5mh4tjdx7mfs','state changed','OS::Heat::Value',NULL,716),(1086,'a2b7f936-dd47-43de-8355-26cd9480c421','2db985e8-b159-44af-92a2-3f2031e1df36','2026-06-12 08:26:06',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-15-ax2q5hnbe43b-ContainersCommon-g37aqhlo7x4k','2db985e8-b159-44af-92a2-3f2031e1df36','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1087,'00a3bc15-fd27-48ad-8a40-58fc26d95f4d','6b9ea3c7-59e8-474b-8aa6-d9051e421bc9','2026-06-12 08:26:06',NULL,'CREATE','IN_PROGRESS','ContainersCommon','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-12-kcz64m2w2r6w-ContainersCommon-2q5ht7fnlz2e','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1088,'027f67f7-5dda-4c28-9e8e-bbeff43a80b2','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:26:07',NULL,'CREATE','COMPLETE','18','e308883d-0d2c-4932-8d10-2bd984920ccf','state changed','OS::TripleO::Services::Timesync',NULL,712),(1089,'5b4916fb-41d6-42dc-9312-06297109c359','42b92b97-24cb-40d6-80fb-076591efe485','2026-06-12 08:26:07',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-12-yus2rf76fg5v-NovaLogging-gqxzyvgirhjb','42b92b97-24cb-40d6-80fb-076591efe485','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1090,'e9e41650-58be-4f3c-8b86-92655704c929','2db985e8-b159-44af-92a2-3f2031e1df36','2026-06-12 08:26:07',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-15-ax2q5hnbe43b-ContainersCommon-g37aqhlo7x4k','2db985e8-b159-44af-92a2-3f2031e1df36','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1091,'a6abc186-95d8-4801-8e0e-bf07b78dcc50','6b9ea3c7-59e8-474b-8aa6-d9051e421bc9','2026-06-12 08:26:07',NULL,'CREATE','COMPLETE','SshdBase','7925e728-3592-4bc9-99ad-75440083e9a5','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-puppet.yaml',NULL,690),(1092,'b8671fb1-2f58-414d-ac6e-06af994a31d5','98be2585-4dea-456a-96e8-bc0e4cc60166','2026-06-12 08:26:07',NULL,'CREATE','IN_PROGRESS','MySQLClient','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-13-jy5vx4r5p7kb-MySQLClient-gn4gz4dbtpbj','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1093,'b7889473-6afd-4a3a-9fdd-8ad13797deae','cb8a8753-2b55-453a-b4c6-2526aac71ca5','2026-06-12 08:26:07',NULL,'CREATE','IN_PROGRESS','ContainersCommon','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-15-zy2azprombbj-ContainersCommon-g3vu6f6tyshs','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1094,'6ad630e6-037a-411f-b99a-6ba3b54ca8a4','1f6b524d-396c-4a86-8721-a3a304f7441a','2026-06-12 08:26:07',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-12-kcz64m2w2r6w-ContainersCommon-2q5ht7fnlz2e','1f6b524d-396c-4a86-8721-a3a304f7441a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1095,'256683fc-8b4a-44e5-824f-daed79f12ac9','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:26:07',NULL,'CREATE','IN_PROGRESS','22','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-22-y2v2rjfwvgh4','state changed','OS::TripleO::Services::Tuned',NULL,722),(1096,'3bbe3b22-af19-44f4-8590-429ac34fc147','2e1baf0f-bf16-4382-a5d1-abbc4cde44f6','2026-06-12 08:26:07',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-13-jy5vx4r5p7kb-MySQLClient-gn4gz4dbtpbj','2e1baf0f-bf16-4382-a5d1-abbc4cde44f6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1097,'e0437ae2-d250-4c2d-a90d-1bdfd59cab77','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:26:07',NULL,'CREATE','IN_PROGRESS','10','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-10-kzzpkilaoy4w','state changed','OS::TripleO::Services::MySQL',NULL,723),(1098,'cc2ca54d-802e-4e89-b39e-86ca5e189745','1f6b524d-396c-4a86-8721-a3a304f7441a','2026-06-12 08:26:07',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-12-kcz64m2w2r6w-ContainersCommon-2q5ht7fnlz2e','1f6b524d-396c-4a86-8721-a3a304f7441a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1099,'f825602e-6b9e-42b6-8a22-e0051e183e59','a8b31b16-9c56-4db4-8152-4399da5339ae','2026-06-12 08:26:07',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-15-zy2azprombbj-ContainersCommon-g3vu6f6tyshs','a8b31b16-9c56-4db4-8152-4399da5339ae','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1100,'d5c36e0b-2b7f-4f1f-8c8a-0b7b625aa693','a8b31b16-9c56-4db4-8152-4399da5339ae','2026-06-12 08:26:07',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-15-zy2azprombbj-ContainersCommon-g3vu6f6tyshs','a8b31b16-9c56-4db4-8152-4399da5339ae','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1101,'dc47864d-5a05-4f20-bb63-a32956b1d7db','2e1baf0f-bf16-4382-a5d1-abbc4cde44f6','2026-06-12 08:26:07',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-13-jy5vx4r5p7kb-MySQLClient-gn4gz4dbtpbj','2e1baf0f-bf16-4382-a5d1-abbc4cde44f6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1102,'95b1da42-6724-472d-adea-fa118a1d8ae8','98be2585-4dea-456a-96e8-bc0e4cc60166','2026-06-12 08:26:07',NULL,'CREATE','COMPLETE','ApacheServiceBase','ee57102c-f91b-4bb1-8edd-66a55e305393','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,694),(1103,'68abc441-37b6-4b23-a7e5-ee0fa870c12c','98be2585-4dea-456a-96e8-bc0e4cc60166','2026-06-12 08:26:07',NULL,'CREATE','COMPLETE','MySQLClient','2e1baf0f-bf16-4382-a5d1-abbc4cde44f6','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1104,'e6ecbaf1-d546-41ca-9206-bef37b9588fb','e4f0062f-2b0e-4787-a3ce-2a993af4322c','2026-06-12 08:26:07',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-22-y2v2rjfwvgh4','e4f0062f-2b0e-4787-a3ce-2a993af4322c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1105,'027f282c-2c53-4b1c-a716-626129e7c63a','1aad3162-cd66-4e3e-b4e0-55f4053378aa','2026-06-12 08:26:07',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-10-kzzpkilaoy4w','1aad3162-cd66-4e3e-b4e0-55f4053378aa','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1106,'1343707a-cc3e-4fb2-9d1b-0e9b30ca983f','e4f0062f-2b0e-4787-a3ce-2a993af4322c','2026-06-12 08:26:07',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-22-y2v2rjfwvgh4-RoleParametersValue-b6y7haz4lgaj','state changed','OS::Heat::Value',NULL,724),(1107,'5ce46b34-1101-427c-b272-1adae7f03ee4','e4f0062f-2b0e-4787-a3ce-2a993af4322c','2026-06-12 08:26:07',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-22-y2v2rjfwvgh4-RoleParametersValue-b6y7haz4lgaj','state changed','OS::Heat::Value',NULL,724),(1108,'d4de0704-a08b-4dd2-8ecd-7e8c826dc474','e4f0062f-2b0e-4787-a3ce-2a993af4322c','2026-06-12 08:26:07',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-22-y2v2rjfwvgh4','e4f0062f-2b0e-4787-a3ce-2a993af4322c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1109,'9b49b3b6-e0f1-4d5a-903c-9235d42a4a17','2ed5ab20-4a87-4ed1-8b98-aa5acf725ca2','2026-06-12 08:26:07',NULL,'CREATE','IN_PROGRESS','RabbitMQServiceBase','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-15-zy2azprombbj-RabbitmqBase-uhedbv6o7ygf-RabbitMQServiceBase-5q4oxzkyju4o','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-container-puppet.yaml',NULL,725),(1110,'fa61f828-1e97-476b-83ed-aff2a65cbaa7','1aad3162-cd66-4e3e-b4e0-55f4053378aa','2026-06-12 08:26:07',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-10-kzzpkilaoy4w-RoleParametersValue-owil5nb2tsxu','state changed','OS::Heat::Value',NULL,726),(1111,'0ad79d43-b380-4feb-b13c-8d3f1584a7bd','1aad3162-cd66-4e3e-b4e0-55f4053378aa','2026-06-12 08:26:07',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-10-kzzpkilaoy4w-RoleParametersValue-owil5nb2tsxu','state changed','OS::Heat::Value',NULL,726),(1112,'ce512cb2-2249-4809-95e4-07b6cea7eb3d','0c6ff9ba-129b-449c-aafa-4faf5c7f9d7b','2026-06-12 08:26:07',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-15-zy2azprombbj-RabbitmqBase-uhedbv6o7ygf-RabbitMQServiceBase-5q4oxzkyju4o','0c6ff9ba-129b-449c-aafa-4faf5c7f9d7b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1113,'ed9f7b22-7340-458a-816a-b6c015490609','7013fd85-c572-4c24-baec-eb0567959817','2026-06-12 08:26:07',NULL,'CREATE','IN_PROGRESS','NovaBase','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-9-3viausvewaix-NovaBase-egyl6vn2frbj','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,727),(1114,'d96c48c8-acad-4fde-b593-498480c4e8b8','087aed60-cdd5-48be-b850-006848d27d19','2026-06-12 08:26:07',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-9-3viausvewaix-NovaBase-egyl6vn2frbj','087aed60-cdd5-48be-b850-006848d27d19','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1115,'812c2896-fd19-4a1a-b26d-97b91d965a05','0c6ff9ba-129b-449c-aafa-4faf5c7f9d7b','2026-06-12 08:26:07',NULL,'CREATE','IN_PROGRESS','ContainersCommon','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-15-zy2azprombbj-RabbitmqBase-uhedbv6o7ygf-RabbitMQServiceBase-5q4oxzkyju4o-ContainersCommon-j3yyjc3kdq2q','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1116,'9270884c-46a6-46a9-890e-0a03d0c2933f','f767ffae-9142-4859-836d-cc60dd98559b','2026-06-12 08:26:07',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-15-zy2azprombbj-RabbitmqBase-uhedbv6o7ygf-RabbitMQServiceBase-5q4oxzkyju4o-ContainersCommon-j3yyjc3kdq2q','f767ffae-9142-4859-836d-cc60dd98559b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1117,'4bcfde95-8b7a-4ccb-8468-b808341b02eb','7013fd85-c572-4c24-baec-eb0567959817','2026-06-12 08:26:07',NULL,'CREATE','COMPLETE','CinderNVMeOF','7552cf4b-9c60-4d0e-9acc-890dc43789a7','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1118,'da1decf9-dee9-41a3-909c-38e8453de5ee','f767ffae-9142-4859-836d-cc60dd98559b','2026-06-12 08:26:07',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-15-zy2azprombbj-RabbitmqBase-uhedbv6o7ygf-RabbitMQServiceBase-5q4oxzkyju4o-ContainersCommon-j3yyjc3kdq2q','f767ffae-9142-4859-836d-cc60dd98559b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1119,'5ed4ad11-8fc4-4def-b3af-ed305371b839','087aed60-cdd5-48be-b850-006848d27d19','2026-06-12 08:26:07',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-9-3viausvewaix-NovaBase-egyl6vn2frbj-RoleParametersValue-yuevupsmzifk','state changed','OS::Heat::Value',NULL,728),(1120,'ce416746-8c83-46e9-a83a-6ca9a359a93e','087aed60-cdd5-48be-b850-006848d27d19','2026-06-12 08:26:07',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-9-3viausvewaix-NovaBase-egyl6vn2frbj-RoleParametersValue-yuevupsmzifk','state changed','OS::Heat::Value',NULL,728),(1121,'d0d9e774-c67a-459f-bf8d-1c4ba99d6879','7013fd85-c572-4c24-baec-eb0567959817','2026-06-12 08:26:07',NULL,'CREATE','COMPLETE','NovaLogging','47d6c8d9-9829-40c4-8f4b-26b8eab62565','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,682),(1122,'5515d82d-95cd-4afa-ade3-e486b14e004e','087aed60-cdd5-48be-b850-006848d27d19','2026-06-12 08:26:07',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-9-3viausvewaix-NovaBase-egyl6vn2frbj','087aed60-cdd5-48be-b850-006848d27d19','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1123,'df78415c-cce7-4a86-843e-1a3dcfdf0bd6','63487f92-d728-402d-a5fe-0a2a7492ecaf','2026-06-12 08:26:07',NULL,'CREATE','COMPLETE','NovaLogging','42b92b97-24cb-40d6-80fb-076591efe485','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,687),(1124,'8587efbf-92d5-4a0a-8aa9-0c1d0900c45b','63487f92-d728-402d-a5fe-0a2a7492ecaf','2026-06-12 08:26:07',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-12-yus2rf76fg5v','63487f92-d728-402d-a5fe-0a2a7492ecaf','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1125,'e5cf6ed8-7803-41b4-a7e0-83b7dcdec447','89c2662a-59db-4817-8ce5-0b6679f9f98d','2026-06-12 08:26:07',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-15-ax2q5hnbe43b-RoleParametersValue-vq6xn2dluznv','state changed','OS::Heat::Value',NULL,729),(1126,'30bc604d-15c1-408d-9541-cebea6595545','89c2662a-59db-4817-8ce5-0b6679f9f98d','2026-06-12 08:26:07',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-15-ax2q5hnbe43b-RoleParametersValue-vq6xn2dluznv','state changed','OS::Heat::Value',NULL,729),(1127,'16f66fb0-3a60-4d89-8c70-2e7713561080','6b9ea3c7-59e8-474b-8aa6-d9051e421bc9','2026-06-12 08:26:08',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-12-kcz64m2w2r6w-RoleParametersValue-r75v2hcoirlw','state changed','OS::Heat::Value',NULL,730),(1128,'afaca33e-937f-450b-9447-c65b473c21a0','6b9ea3c7-59e8-474b-8aa6-d9051e421bc9','2026-06-12 08:26:08',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-12-kcz64m2w2r6w-RoleParametersValue-r75v2hcoirlw','state changed','OS::Heat::Value',NULL,730),(1129,'6e116090-7764-4f58-a93c-34eec1c464a0','89c2662a-59db-4817-8ce5-0b6679f9f98d','2026-06-12 08:26:08',NULL,'CREATE','COMPLETE','ContainersCommon','2db985e8-b159-44af-92a2-3f2031e1df36','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1130,'db191bfa-6c4f-41a8-a4da-d3ca831de234','89c2662a-59db-4817-8ce5-0b6679f9f98d','2026-06-12 08:26:08',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-15-ax2q5hnbe43b','89c2662a-59db-4817-8ce5-0b6679f9f98d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1131,'620cc490-3ea4-4a62-9cad-44c61d85a05c','98be2585-4dea-456a-96e8-bc0e4cc60166','2026-06-12 08:26:08',NULL,'CREATE','IN_PROGRESS','NovaApiDBClient','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-13-jy5vx4r5p7kb-NovaApiDBClient-7fgmx57n66rx','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,731),(1132,'f005268f-6808-4bdf-afb2-591a386fa163','f06635c9-ac47-45d5-b86d-276caa29a581','2026-06-12 08:26:08',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-13-jy5vx4r5p7kb-NovaApiDBClient-7fgmx57n66rx','f06635c9-ac47-45d5-b86d-276caa29a581','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1133,'3ffd6d88-21fa-4178-ba26-55984e61fa65','f06635c9-ac47-45d5-b86d-276caa29a581','2026-06-12 08:26:08',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-13-jy5vx4r5p7kb-NovaApiDBClient-7fgmx57n66rx','f06635c9-ac47-45d5-b86d-276caa29a581','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1134,'2ca8b0a5-197c-4ee5-88fd-b07596bf1644','6b9ea3c7-59e8-474b-8aa6-d9051e421bc9','2026-06-12 08:26:08',NULL,'CREATE','COMPLETE','ContainersCommon','1f6b524d-396c-4a86-8721-a3a304f7441a','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1135,'34fc9788-df1b-420f-8dfc-817c79bff1cf','6b9ea3c7-59e8-474b-8aa6-d9051e421bc9','2026-06-12 08:26:08',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-12-kcz64m2w2r6w','6b9ea3c7-59e8-474b-8aa6-d9051e421bc9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1136,'148db6ec-253e-4cb7-bfc3-47ffb3417e2d','cb8a8753-2b55-453a-b4c6-2526aac71ca5','2026-06-12 08:26:08',NULL,'CREATE','COMPLETE','ContainersCommon','a8b31b16-9c56-4db4-8152-4399da5339ae','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1137,'f37352d3-2c87-4925-a7d3-474f17573f7d','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:26:08',NULL,'CREATE','COMPLETE','22','e4f0062f-2b0e-4787-a3ce-2a993af4322c','state changed','OS::TripleO::Services::Tuned',NULL,722),(1138,'d7a6ed16-b0e4-4be3-ac5c-7f208bd6330d','2ed5ab20-4a87-4ed1-8b98-aa5acf725ca2','2026-06-12 08:26:08',NULL,'CREATE','IN_PROGRESS','ContainersCommon','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-15-zy2azprombbj-RabbitmqBase-uhedbv6o7ygf-ContainersCommon-op5brffwkybd','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1139,'942d30b6-ec48-4f76-bdc7-71197e3af989','1aad3162-cd66-4e3e-b4e0-55f4053378aa','2026-06-12 08:26:08',NULL,'CREATE','IN_PROGRESS','ContainersCommon','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-10-kzzpkilaoy4w-ContainersCommon-otkprchygian','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1140,'897c9331-a4c6-448a-8faa-0da662694b16','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:26:08',NULL,'CREATE','COMPLETE','12','63487f92-d728-402d-a5fe-0a2a7492ecaf','state changed','OS::TripleO::Services::NovaConductor',NULL,611),(1141,'c6c90e7f-0f6f-492b-9ed3-42dc32a4abf9','0d70b1f3-6240-44fd-b74b-9a3be23c592a','2026-06-12 08:26:08',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-15-zy2azprombbj-RabbitmqBase-uhedbv6o7ygf-ContainersCommon-op5brffwkybd','0d70b1f3-6240-44fd-b74b-9a3be23c592a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1142,'22753f8c-b121-4f26-9a1d-ab6d53cc5cae','0d70b1f3-6240-44fd-b74b-9a3be23c592a','2026-06-12 08:26:08',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-15-zy2azprombbj-RabbitmqBase-uhedbv6o7ygf-ContainersCommon-op5brffwkybd','0d70b1f3-6240-44fd-b74b-9a3be23c592a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1143,'e12f169f-4dd4-4f09-a7fd-233650e4f443','2ed5ab20-4a87-4ed1-8b98-aa5acf725ca2','2026-06-12 08:26:08',NULL,'CREATE','COMPLETE','ContainersCommon','0d70b1f3-6240-44fd-b74b-9a3be23c592a','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1144,'9f5c0d42-7e7f-42f1-b688-840222776e72','0c6ff9ba-129b-449c-aafa-4faf5c7f9d7b','2026-06-12 08:26:08',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-15-zy2azprombbj-RabbitmqBase-uhedbv6o7ygf-RabbitMQServiceBase-5q4oxzkyju4o-RoleParametersValue-qjbc4w3qzcuv','state changed','OS::Heat::Value',NULL,732),(1145,'e64359dc-4238-4b30-9362-935b4dc90d4d','daeb119f-2ec7-4720-9918-fb376267863c','2026-06-12 08:26:08',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-10-kzzpkilaoy4w-ContainersCommon-otkprchygian','daeb119f-2ec7-4720-9918-fb376267863c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1146,'15f72098-2ec4-46e0-a954-dfa1469377a2','7013fd85-c572-4c24-baec-eb0567959817','2026-06-12 08:26:08',NULL,'CREATE','COMPLETE','NovaBase','087aed60-cdd5-48be-b850-006848d27d19','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,727),(1147,'b5d46b5c-f227-4fb0-a4bb-fbb6e025ae02','0c6ff9ba-129b-449c-aafa-4faf5c7f9d7b','2026-06-12 08:26:08',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-15-zy2azprombbj-RabbitmqBase-uhedbv6o7ygf-RabbitMQServiceBase-5q4oxzkyju4o-RoleParametersValue-qjbc4w3qzcuv','state changed','OS::Heat::Value',NULL,732),(1148,'6f1d0bb7-76fd-4931-9d55-85454d88f3c9','daeb119f-2ec7-4720-9918-fb376267863c','2026-06-12 08:26:08',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-10-kzzpkilaoy4w-ContainersCommon-otkprchygian','daeb119f-2ec7-4720-9918-fb376267863c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1149,'910701c8-6ee4-4627-a15f-5fd6ce8c9723','7013fd85-c572-4c24-baec-eb0567959817','2026-06-12 08:26:08',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-9-3viausvewaix','7013fd85-c572-4c24-baec-eb0567959817','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1150,'1ddd665e-eb60-4fdc-b891-eb8de63659c2','0c6ff9ba-129b-449c-aafa-4faf5c7f9d7b','2026-06-12 08:26:08',NULL,'CREATE','COMPLETE','ContainersCommon','f767ffae-9142-4859-836d-cc60dd98559b','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1151,'449065c2-3b83-4137-8907-aca73ca86269','0c6ff9ba-129b-449c-aafa-4faf5c7f9d7b','2026-06-12 08:26:08',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-15-zy2azprombbj-RabbitmqBase-uhedbv6o7ygf-RabbitMQServiceBase-5q4oxzkyju4o','0c6ff9ba-129b-449c-aafa-4faf5c7f9d7b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1152,'3e1dcf23-cb92-419c-affb-97d1f2c6da7e','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:26:08',NULL,'CREATE','COMPLETE','12','6b9ea3c7-59e8-474b-8aa6-d9051e421bc9','state changed','OS::TripleO::Services::NovaMigrationTarget',NULL,686),(1153,'5643c4e2-43fc-49be-a789-2ec4f3375bd9','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:26:08',NULL,'CREATE','COMPLETE','15','89c2662a-59db-4817-8ce5-0b6679f9f98d','state changed','OS::TripleO::Services::Rsyslog',NULL,709),(1154,'b7edb51b-fa91-4c4d-9c08-339cf7da32f0','98be2585-4dea-456a-96e8-bc0e4cc60166','2026-06-12 08:26:09',NULL,'CREATE','IN_PROGRESS','NovaMetadataLogging','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-13-jy5vx4r5p7kb-NovaMetadataLogging-m4hjacvd2key','state changed','OS::TripleO::Services::Logging::NovaMetadata',NULL,NULL),(1155,'d7bfad20-0a38-4b1c-bc8e-a2c41443c928','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:26:09',NULL,'CREATE','IN_PROGRESS','19','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-19-kh4f44chrjvj','state changed','OS::TripleO::Services::Timezone',NULL,746),(1156,'e4ac4124-1072-4736-9f38-801f3e34f93a','f0891a79-46ff-4628-93f4-47a8ec1104dc','2026-06-12 08:26:09',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-13-jy5vx4r5p7kb-NovaMetadataLogging-m4hjacvd2key','f0891a79-46ff-4628-93f4-47a8ec1104dc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1157,'ea42fade-7968-4230-8e04-6efdbe6236fb','f0891a79-46ff-4628-93f4-47a8ec1104dc','2026-06-12 08:26:09',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-13-jy5vx4r5p7kb-NovaMetadataLogging-m4hjacvd2key-RoleParametersValue-ib3nbzky33aq','state changed','OS::Heat::Value',NULL,750),(1158,'120c3df4-90c6-4ea7-ad0d-a213a7cd1ec8','f0891a79-46ff-4628-93f4-47a8ec1104dc','2026-06-12 08:26:09',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-13-jy5vx4r5p7kb-NovaMetadataLogging-m4hjacvd2key-RoleParametersValue-ib3nbzky33aq','state changed','OS::Heat::Value',NULL,750),(1159,'cebbbf5c-0e7b-4785-9e9b-04e1a23d4697','f0891a79-46ff-4628-93f4-47a8ec1104dc','2026-06-12 08:26:09',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-13-jy5vx4r5p7kb-NovaMetadataLogging-m4hjacvd2key','f0891a79-46ff-4628-93f4-47a8ec1104dc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1160,'7f5b2a9d-4500-4493-806e-addf6dd9b904','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:26:09',NULL,'CREATE','IN_PROGRESS','16','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-16-jhg4qep2h6ls','state changed','OS::TripleO::Services::Pacemaker',NULL,752),(1161,'f7dc9ad4-09cb-4090-b9bb-3a485cb751ea','480f919f-9b6d-4782-9b85-59f275a314e4','2026-06-12 08:26:09',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-19-kh4f44chrjvj','480f919f-9b6d-4782-9b85-59f275a314e4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1162,'dbe53771-8102-492c-bb82-28579a3b8d97','98be2585-4dea-456a-96e8-bc0e4cc60166','2026-06-12 08:26:09',NULL,'CREATE','COMPLETE','NovaApiDBClient','f06635c9-ac47-45d5-b86d-276caa29a581','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,731),(1163,'8c517d69-24c3-4d89-b8b6-d05ddeb38f56','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:26:09',NULL,'CREATE','IN_PROGRESS','16','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-16-6wpfyjpl2j2g','state changed','OS::TripleO::Services::Snmp',NULL,753),(1164,'5ec7b8a7-1709-42c1-b575-4c8ac86adbca','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:26:09',NULL,'CREATE','COMPLETE','9','7013fd85-c572-4c24-baec-eb0567959817','state changed','OS::TripleO::Services::NovaCompute',NULL,653),(1165,'0205bc72-014c-4863-9b4d-1a89b0e8ddd3','480f919f-9b6d-4782-9b85-59f275a314e4','2026-06-12 08:26:09',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-19-kh4f44chrjvj','480f919f-9b6d-4782-9b85-59f275a314e4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1166,'6171ba7b-84b0-4bc2-89a2-f8f8892ed3a6','bdc1b2a9-2a84-4e1b-8ab7-b8c5f752d2dc','2026-06-12 08:26:09',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-16-jhg4qep2h6ls','bdc1b2a9-2a84-4e1b-8ab7-b8c5f752d2dc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1167,'90f9b1a3-87b0-4a0d-9d3c-35d55632bcbb','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:26:09',NULL,'CREATE','COMPLETE','19','480f919f-9b6d-4782-9b85-59f275a314e4','state changed','OS::TripleO::Services::Timezone',NULL,746),(1168,'ab2e702a-404d-4473-8de2-d7af61c3af4b','bdc1b2a9-2a84-4e1b-8ab7-b8c5f752d2dc','2026-06-12 08:26:09',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-16-jhg4qep2h6ls','bdc1b2a9-2a84-4e1b-8ab7-b8c5f752d2dc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1169,'4287afa8-4ff6-4b81-a291-9b4bd37b8962','6b4ab937-ec09-42ad-8121-ec91a548c1e8','2026-06-12 08:26:09',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-16-6wpfyjpl2j2g','6b4ab937-ec09-42ad-8121-ec91a548c1e8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1170,'53803681-c372-4a83-88aa-641f277633d4','6b4ab937-ec09-42ad-8121-ec91a548c1e8','2026-06-12 08:26:09',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-16-6wpfyjpl2j2g','6b4ab937-ec09-42ad-8121-ec91a548c1e8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1171,'a3fa45a9-62c6-4cc9-812c-0dc9216c67a5','1aad3162-cd66-4e3e-b4e0-55f4053378aa','2026-06-12 08:26:09',NULL,'CREATE','IN_PROGRESS','MysqlBase','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-10-kzzpkilaoy4w-MysqlBase-ghaeak442oew','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-base.yaml',NULL,754),(1172,'852ebc3d-9b04-4c16-9c3d-82b96513cc1e','2ed5ab20-4a87-4ed1-8b98-aa5acf725ca2','2026-06-12 08:26:09',NULL,'CREATE','COMPLETE','RabbitMQServiceBase','0c6ff9ba-129b-449c-aafa-4faf5c7f9d7b','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-container-puppet.yaml',NULL,725),(1173,'60570aa8-86fe-486b-a764-a1cd7adf5712','cdd8e288-dace-495d-8dc6-a1c5df7c28ea','2026-06-12 08:26:09',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-10-kzzpkilaoy4w-MysqlBase-ghaeak442oew','cdd8e288-dace-495d-8dc6-a1c5df7c28ea','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1174,'a607c06f-071f-4abf-b8a6-7c0497977e6e','2ed5ab20-4a87-4ed1-8b98-aa5acf725ca2','2026-06-12 08:26:09',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-15-zy2azprombbj-RabbitmqBase-uhedbv6o7ygf','2ed5ab20-4a87-4ed1-8b98-aa5acf725ca2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1175,'a1b7c3d2-533d-404d-a2c1-46dcca91cb74','cdd8e288-dace-495d-8dc6-a1c5df7c28ea','2026-06-12 08:26:09',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-10-kzzpkilaoy4w-MysqlBase-ghaeak442oew','cdd8e288-dace-495d-8dc6-a1c5df7c28ea','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1176,'6a2ccb80-6199-4823-a31e-62b7f9cb373b','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:26:09',NULL,'CREATE','IN_PROGRESS','23','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-23-rinmc37pepoe','state changed','OS::TripleO::Services::OVNController',NULL,757),(1177,'8313bac4-f0e7-4c45-be94-5cbc34b01a70','1aad3162-cd66-4e3e-b4e0-55f4053378aa','2026-06-12 08:26:09',NULL,'CREATE','COMPLETE','ContainersCommon','daeb119f-2ec7-4720-9918-fb376267863c','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1178,'f88cb884-88f2-4590-ae1e-1473c59f4ebe','cfa9fd93-4264-4e93-9246-0dbf036d6018','2026-06-12 08:26:09',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-23-rinmc37pepoe','cfa9fd93-4264-4e93-9246-0dbf036d6018','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1179,'8c56ebc2-5ab1-4bc5-9247-189522294af9','cfa9fd93-4264-4e93-9246-0dbf036d6018','2026-06-12 08:26:09',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-23-rinmc37pepoe-RoleParametersValue-u53bt6yre2nu','state changed','OS::Heat::Value',NULL,764),(1180,'7efc6bd4-6911-4230-94cc-03c7270abd1c','cfa9fd93-4264-4e93-9246-0dbf036d6018','2026-06-12 08:26:09',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-23-rinmc37pepoe-RoleParametersValue-u53bt6yre2nu','state changed','OS::Heat::Value',NULL,764),(1181,'2b872b7b-2f2b-4aef-8415-6754fed749be','98be2585-4dea-456a-96e8-bc0e4cc60166','2026-06-12 08:26:10',NULL,'CREATE','IN_PROGRESS','NovaDBClient','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-13-jy5vx4r5p7kb-NovaDBClient-mbchkkeyboqv','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,767),(1182,'0a6d370d-e6c2-4a48-bb54-09f5de6913de','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:26:10',NULL,'CREATE','IN_PROGRESS','13','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-13-7us2mqxz5dgd','state changed','OS::TripleO::Services::ContainersLogrotateCrond',NULL,768),(1183,'a7757dd4-a82a-4821-9c52-f1d173852b21','ca9fed14-7fc8-44de-a671-261ce7f18967','2026-06-12 08:26:10',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-13-jy5vx4r5p7kb-NovaDBClient-mbchkkeyboqv','ca9fed14-7fc8-44de-a671-261ce7f18967','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1184,'ec306bf2-d156-4320-badf-1aa9bf381f8c','98be2585-4dea-456a-96e8-bc0e4cc60166','2026-06-12 08:26:10',NULL,'CREATE','COMPLETE','NovaMetadataLogging','f0891a79-46ff-4628-93f4-47a8ec1104dc','state changed','OS::TripleO::Services::Logging::NovaMetadata',NULL,NULL),(1185,'93d43f93-828e-41e2-9c13-4720a1c9254e','ca9fed14-7fc8-44de-a671-261ce7f18967','2026-06-12 08:26:10',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-13-jy5vx4r5p7kb-NovaDBClient-mbchkkeyboqv','ca9fed14-7fc8-44de-a671-261ce7f18967','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1186,'9f82ef8d-c25e-4de5-a94d-8e4f08b1dc4c','8e7df3a9-ec62-4124-95bf-ff95913a589d','2026-06-12 08:26:10',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-13-7us2mqxz5dgd','8e7df3a9-ec62-4124-95bf-ff95913a589d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1187,'9e5f1a1c-fadc-4bc1-89d3-4347bd85830e','8e7df3a9-ec62-4124-95bf-ff95913a589d','2026-06-12 08:26:10',NULL,'CREATE','IN_PROGRESS','ContainersCommon','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-13-7us2mqxz5dgd-ContainersCommon-zjce7auv4ipq','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1188,'7b5ec232-efa6-41d2-8cd2-3bf270edd33a','cb8a8753-2b55-453a-b4c6-2526aac71ca5','2026-06-12 08:26:10',NULL,'CREATE','COMPLETE','RabbitmqBase','2ed5ab20-4a87-4ed1-8b98-aa5acf725ca2','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-container-puppet.yaml',NULL,697),(1189,'e3ed1f6f-f8de-4462-bfad-c027810ee33a','52aeea09-a6b7-4ab4-9cda-b39b7a40ff8b','2026-06-12 08:26:10',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-13-7us2mqxz5dgd-ContainersCommon-zjce7auv4ipq','52aeea09-a6b7-4ab4-9cda-b39b7a40ff8b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1190,'3b7c02b3-abe6-4690-a9fa-b8aacfaf914f','cb8a8753-2b55-453a-b4c6-2526aac71ca5','2026-06-12 08:26:10',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-15-zy2azprombbj','cb8a8753-2b55-453a-b4c6-2526aac71ca5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1191,'12787c32-7dc9-43ec-b67f-1684f3f3493f','52aeea09-a6b7-4ab4-9cda-b39b7a40ff8b','2026-06-12 08:26:10',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-13-7us2mqxz5dgd-ContainersCommon-zjce7auv4ipq','52aeea09-a6b7-4ab4-9cda-b39b7a40ff8b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1192,'12d4cff9-1234-47e0-8b06-39cb90b64332','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:26:10',NULL,'CREATE','COMPLETE','16','bdc1b2a9-2a84-4e1b-8ab7-b8c5f752d2dc','state changed','OS::TripleO::Services::Pacemaker',NULL,752),(1193,'3d821bda-f9e6-425c-8234-8eb1c6b3e5bf','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:26:10',NULL,'CREATE','COMPLETE','16','6b4ab937-ec09-42ad-8121-ec91a548c1e8','state changed','OS::TripleO::Services::Snmp',NULL,753),(1194,'6ec37fb4-1327-44cd-ae62-9a758be81e5f','1aad3162-cd66-4e3e-b4e0-55f4053378aa','2026-06-12 08:26:10',NULL,'CREATE','COMPLETE','MysqlBase','cdd8e288-dace-495d-8dc6-a1c5df7c28ea','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-base.yaml',NULL,754),(1195,'759002e4-e25a-4e4b-864b-66855041e2e4','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:26:10',NULL,'CREATE','IN_PROGRESS','20','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-20-gpv3xk5qhh7h','state changed','OS::TripleO::Services::Sshd',NULL,771),(1196,'142ed4fc-719b-4bd5-ad03-0c1d49b0a55c','1aad3162-cd66-4e3e-b4e0-55f4053378aa','2026-06-12 08:26:10',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-10-kzzpkilaoy4w','1aad3162-cd66-4e3e-b4e0-55f4053378aa','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1197,'b49ad952-361a-4d68-9cb6-b6e6acc8c571','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:26:10',NULL,'CREATE','IN_PROGRESS','20','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-20-n66of4rmzpav','state changed','OS::TripleO::Services::TripleoFirewall',NULL,772),(1198,'4d6a1797-eada-4869-9dfa-b38e9f2d8d34','66e1b3ea-8f80-4ad2-84fa-32bce37e18d4','2026-06-12 08:26:10',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-20-gpv3xk5qhh7h','66e1b3ea-8f80-4ad2-84fa-32bce37e18d4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1199,'d54850cc-4bdb-410c-9879-b29ada5a621f','66e1b3ea-8f80-4ad2-84fa-32bce37e18d4','2026-06-12 08:26:10',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-20-gpv3xk5qhh7h','66e1b3ea-8f80-4ad2-84fa-32bce37e18d4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1200,'93fa9380-5c5e-4555-89dc-19dbf9091477','7df65be5-4b69-4735-8108-41c529af8923','2026-06-12 08:26:10',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-20-n66of4rmzpav','7df65be5-4b69-4735-8108-41c529af8923','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1201,'a1707340-fcdd-4324-a224-d9a001184053','7df65be5-4b69-4735-8108-41c529af8923','2026-06-12 08:26:10',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-20-n66of4rmzpav-RoleParametersValue-v42tay2hajus','state changed','OS::Heat::Value',NULL,773),(1202,'e15d1175-4ff0-491b-81e6-5b9816ed9eb0','7df65be5-4b69-4735-8108-41c529af8923','2026-06-12 08:26:10',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-20-n66of4rmzpav-RoleParametersValue-v42tay2hajus','state changed','OS::Heat::Value',NULL,773),(1203,'e6cf37b9-f2ce-4590-af3a-d0723c7bf32c','cfa9fd93-4264-4e93-9246-0dbf036d6018','2026-06-12 08:26:10',NULL,'CREATE','IN_PROGRESS','OVNBridgeMappingsValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-23-rinmc37pepoe-OVNBridgeMappingsValue-gxik46ou6de2','state changed','OS::Heat::Value',NULL,774),(1204,'ffd4e490-1a2c-45c7-95b0-81e182177ca9','7df65be5-4b69-4735-8108-41c529af8923','2026-06-12 08:26:10',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-20-n66of4rmzpav','7df65be5-4b69-4735-8108-41c529af8923','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1205,'baec96d9-51e9-4620-a03b-7166d978aba4','cfa9fd93-4264-4e93-9246-0dbf036d6018','2026-06-12 08:26:10',NULL,'CREATE','COMPLETE','OVNBridgeMappingsValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-23-rinmc37pepoe-OVNBridgeMappingsValue-gxik46ou6de2','state changed','OS::Heat::Value',NULL,774),(1206,'41a63b26-10b6-4506-bc97-441117bad386','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:26:11',NULL,'CREATE','COMPLETE','15','cb8a8753-2b55-453a-b4c6-2526aac71ca5','state changed','OS::TripleO::Services::OsloMessagingRpc',NULL,672),(1207,'d8b65e2f-b7c6-4ee2-a5fe-a181cde8cd41','98be2585-4dea-456a-96e8-bc0e4cc60166','2026-06-12 08:26:11',NULL,'CREATE','COMPLETE','NovaDBClient','ca9fed14-7fc8-44de-a671-261ce7f18967','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,767),(1208,'223ff0da-b677-4aef-b9f3-88620a5b2e9c','98be2585-4dea-456a-96e8-bc0e4cc60166','2026-06-12 08:26:11',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-13-jy5vx4r5p7kb','98be2585-4dea-456a-96e8-bc0e4cc60166','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1209,'12de1aa4-7e88-47c1-a5b3-28fe1868bf5c','8e7df3a9-ec62-4124-95bf-ff95913a589d','2026-06-12 08:26:11',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-13-7us2mqxz5dgd-RoleParametersValue-4hwo4uwzhcm5','state changed','OS::Heat::Value',NULL,777),(1210,'a3346883-c77d-4885-b7a1-328945745189','8e7df3a9-ec62-4124-95bf-ff95913a589d','2026-06-12 08:26:11',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-13-7us2mqxz5dgd-RoleParametersValue-4hwo4uwzhcm5','state changed','OS::Heat::Value',NULL,777),(1211,'1f82d92a-91da-4c4a-bd19-da44e54c0879','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:26:11',NULL,'CREATE','COMPLETE','10','1aad3162-cd66-4e3e-b4e0-55f4053378aa','state changed','OS::TripleO::Services::MySQL',NULL,723),(1212,'07ab2703-b761-40e4-a149-b02297a7a11a','8e7df3a9-ec62-4124-95bf-ff95913a589d','2026-06-12 08:26:11',NULL,'CREATE','COMPLETE','ContainersCommon','52aeea09-a6b7-4ab4-9cda-b39b7a40ff8b','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1213,'f0636e5d-d9c6-47be-86dd-f9d2be2ed936','8e7df3a9-ec62-4124-95bf-ff95913a589d','2026-06-12 08:26:11',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-13-7us2mqxz5dgd','8e7df3a9-ec62-4124-95bf-ff95913a589d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1214,'a4dbcd4f-ed90-4154-a5e3-16630ea9f5b8','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:26:11',NULL,'CREATE','COMPLETE','20','66e1b3ea-8f80-4ad2-84fa-32bce37e18d4','state changed','OS::TripleO::Services::Sshd',NULL,771),(1215,'8892c012-ceb6-49ac-a3ec-449bd2c29e30','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:26:11',NULL,'CREATE','IN_PROGRESS','14','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-14-fgxluvmrr44z','state changed','OS::TripleO::Services::NovaVncProxy',NULL,789),(1216,'a1664517-3128-487c-b9dd-03e69e11c53b','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:26:11',NULL,'CREATE','COMPLETE','13','98be2585-4dea-456a-96e8-bc0e4cc60166','state changed','OS::TripleO::Services::NovaMetadata',NULL,641),(1217,'74845c01-028f-4ebf-b34b-3701a37ec623','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:26:11',NULL,'CREATE','IN_PROGRESS','19','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-19-ivcfhamnsh2h','state changed','OS::TripleO::Services::Snmp',NULL,790),(1218,'05c3fa67-980a-4e31-9c40-0001a85f60da','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:26:11',NULL,'CREATE','COMPLETE','20','7df65be5-4b69-4735-8108-41c529af8923','state changed','OS::TripleO::Services::TripleoFirewall',NULL,772),(1219,'fed6cf96-19b3-4922-bddd-1dfccf0d2148','1e053a66-6010-4f1b-825f-d6c0dc5d8e92','2026-06-12 08:26:11',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-14-fgxluvmrr44z','1e053a66-6010-4f1b-825f-d6c0dc5d8e92','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1220,'3c673d6a-6ab6-4327-b8ee-82e805e28bba','cfa9fd93-4264-4e93-9246-0dbf036d6018','2026-06-12 08:26:11',NULL,'CREATE','IN_PROGRESS','ContainersCommon','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-23-rinmc37pepoe-ContainersCommon-z4ckshdyz256','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1221,'8506ef60-bb4e-43a5-afd2-9164b8c3df19','2f37f442-ab0c-4a71-87d1-55c02d42fc92','2026-06-12 08:26:11',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-19-ivcfhamnsh2h','2f37f442-ab0c-4a71-87d1-55c02d42fc92','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1222,'eced09d4-95fa-4169-92e7-e3fd93c7d8e5','91d1441a-f33b-477c-add7-0e2260f31584','2026-06-12 08:26:11',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-23-rinmc37pepoe-ContainersCommon-z4ckshdyz256','91d1441a-f33b-477c-add7-0e2260f31584','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1223,'8f51cf79-cd89-45b7-ad08-cfb4d1c80405','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:26:12',NULL,'CREATE','IN_PROGRESS','24','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-24-eckwqogigehr','state changed','OS::TripleO::Services::TripleoPackages',NULL,793),(1224,'d42d9b4c-83a5-4485-b435-c8cc2acbb911','2f37f442-ab0c-4a71-87d1-55c02d42fc92','2026-06-12 08:26:12',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-19-ivcfhamnsh2h','2f37f442-ab0c-4a71-87d1-55c02d42fc92','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1225,'a32351fe-3d37-4178-aa62-159015cd703e','91d1441a-f33b-477c-add7-0e2260f31584','2026-06-12 08:26:12',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-23-rinmc37pepoe-ContainersCommon-z4ckshdyz256','91d1441a-f33b-477c-add7-0e2260f31584','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1226,'be36204d-3860-431b-9065-6368931e867d','33bf28ea-c4b2-46f5-881c-a789b306762d','2026-06-12 08:26:12',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-24-eckwqogigehr','33bf28ea-c4b2-46f5-881c-a789b306762d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1227,'1c25f1ff-ae11-48d3-9083-b9b50e1a8be6','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:26:12',NULL,'CREATE','IN_PROGRESS','24','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-24-blfwj2nua73x','state changed','OS::TripleO::Services::OVNMetadataAgent',NULL,801),(1228,'25b791ee-5108-408c-a2f7-63339c348efd','33bf28ea-c4b2-46f5-881c-a789b306762d','2026-06-12 08:26:12',NULL,'CREATE','IN_PROGRESS','Podman','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-24-eckwqogigehr-Podman-wvq2vy5lxewn','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml',NULL,804),(1229,'ec0b4256-338a-4031-8a88-1417a2906d89','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:26:12',NULL,'CREATE','COMPLETE','13','8e7df3a9-ec62-4124-95bf-ff95913a589d','state changed','OS::TripleO::Services::ContainersLogrotateCrond',NULL,768),(1230,'7fed813f-07f0-43dd-91b4-5bc633e02dd0','6d8aa4b5-7b9b-4abd-a093-dcb859503516','2026-06-12 08:26:12',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-24-blfwj2nua73x','6d8aa4b5-7b9b-4abd-a093-dcb859503516','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1231,'07249785-2ccd-4304-ae20-285cd04341f9','1e053a66-6010-4f1b-825f-d6c0dc5d8e92','2026-06-12 08:26:12',NULL,'CREATE','IN_PROGRESS','NovaDBClient','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-14-fgxluvmrr44z-NovaDBClient-nvqpr56wptwu','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,807),(1232,'d18eb1a5-351a-4492-b6a9-d5c000b90f07','c77b84f2-0b08-417c-88f3-7181733daef5','2026-06-12 08:26:12',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-24-eckwqogigehr-Podman-wvq2vy5lxewn','c77b84f2-0b08-417c-88f3-7181733daef5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1233,'9597c9ab-bdac-4725-b30e-1d53e927a900','5134bd10-7992-46b4-a99c-7017300bb46a','2026-06-12 08:26:12',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-14-fgxluvmrr44z-NovaDBClient-nvqpr56wptwu','5134bd10-7992-46b4-a99c-7017300bb46a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1234,'68ada8ec-0439-4ffa-b6ae-8161ab2b02da','5134bd10-7992-46b4-a99c-7017300bb46a','2026-06-12 08:26:12',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-14-fgxluvmrr44z-NovaDBClient-nvqpr56wptwu','5134bd10-7992-46b4-a99c-7017300bb46a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1235,'8c62c131-6e17-4fbb-b7b6-409f21fdba71','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:26:12',NULL,'CREATE','IN_PROGRESS','17','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-17-vvgx62mrymlj','state changed','OS::TripleO::Services::Podman',NULL,813),(1236,'28e38b6a-eed2-4e61-a728-3c9b241bff00','c77b84f2-0b08-417c-88f3-7181733daef5','2026-06-12 08:26:12',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-24-eckwqogigehr-Podman-wvq2vy5lxewn','c77b84f2-0b08-417c-88f3-7181733daef5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1237,'092ef2a5-b382-438a-ba99-5e904661d44c','6d8aa4b5-7b9b-4abd-a093-dcb859503516','2026-06-12 08:26:12',NULL,'CREATE','IN_PROGRESS','NeutronLogging','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-24-blfwj2nua73x-NeutronLogging-hukp55n7npwi','state changed','OS::TripleO::Services::Logging::NeutronCommon',NULL,814),(1238,'a0fa4e00-e60d-4c11-a8e9-d67877e275f9','827e7c98-8400-49ce-a455-d35ac037d14c','2026-06-12 08:26:12',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-17-vvgx62mrymlj','827e7c98-8400-49ce-a455-d35ac037d14c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1239,'8cca0adb-dfa2-4379-a913-e45d22d607ec','827e7c98-8400-49ce-a455-d35ac037d14c','2026-06-12 08:26:12',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-17-vvgx62mrymlj','827e7c98-8400-49ce-a455-d35ac037d14c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1240,'89e341e7-e09b-4c5b-ae3a-78b825f08215','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:26:12',NULL,'CREATE','IN_PROGRESS','17','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-17-kifi22utvfuz','state changed','OS::TripleO::Services::Sshd',NULL,815),(1241,'8851f8d6-fb59-445e-9bf6-fcdb00f75b71','dc47bccf-a8c7-4a70-b98f-41ab53de6118','2026-06-12 08:26:12',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-24-blfwj2nua73x-NeutronLogging-hukp55n7npwi','dc47bccf-a8c7-4a70-b98f-41ab53de6118','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1242,'5995b680-7ee1-4933-971f-d63dbb7e2146','dc47bccf-a8c7-4a70-b98f-41ab53de6118','2026-06-12 08:26:12',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-24-blfwj2nua73x-NeutronLogging-hukp55n7npwi','dc47bccf-a8c7-4a70-b98f-41ab53de6118','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1243,'310d5a06-d924-4252-9085-3e744739c7c2','600ef5db-6ac9-4f2b-a2a5-2e9b3a80c1bd','2026-06-12 08:26:12',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-17-kifi22utvfuz','600ef5db-6ac9-4f2b-a2a5-2e9b3a80c1bd','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1244,'4bcffdca-a64f-45c3-a4d2-fe7d93949f31','600ef5db-6ac9-4f2b-a2a5-2e9b3a80c1bd','2026-06-12 08:26:12',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-17-kifi22utvfuz','600ef5db-6ac9-4f2b-a2a5-2e9b3a80c1bd','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1245,'7e4ec6e8-bb1c-4f77-a3f7-1cbb033c850d','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:26:12',NULL,'CREATE','COMPLETE','19','2f37f442-ab0c-4a71-87d1-55c02d42fc92','state changed','OS::TripleO::Services::Snmp',NULL,790),(1246,'903f1be4-5ee1-4e54-b124-8d9e69f23d62','cfa9fd93-4264-4e93-9246-0dbf036d6018','2026-06-12 08:26:13',NULL,'CREATE','COMPLETE','ContainersCommon','91d1441a-f33b-477c-add7-0e2260f31584','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1247,'33c038b2-5f1b-43d1-810e-4dfb8c784ce1','cfa9fd93-4264-4e93-9246-0dbf036d6018','2026-06-12 08:26:13',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-23-rinmc37pepoe','cfa9fd93-4264-4e93-9246-0dbf036d6018','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1248,'8946844a-1d21-46a1-93c3-ac3bf10c10e3','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:26:13',NULL,'CREATE','IN_PROGRESS','23','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-23-hxo57hiymryp','state changed','OS::TripleO::Services::TripleoFirewall',NULL,817),(1249,'88443bde-c3d8-4746-8e78-86e90f6d9535','33bf28ea-c4b2-46f5-881c-a789b306762d','2026-06-12 08:26:13',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-24-eckwqogigehr-RoleParametersValue-4jihz76mzzqj','state changed','OS::Heat::Value',NULL,818),(1250,'229be384-ff0c-463e-aa67-3fd9f0d48df5','3075783c-9399-48ec-bf60-e53e303b4d0a','2026-06-12 08:26:13',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-23-hxo57hiymryp','3075783c-9399-48ec-bf60-e53e303b4d0a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1251,'9f64a589-302b-4d94-8a65-973fe4ab880a','33bf28ea-c4b2-46f5-881c-a789b306762d','2026-06-12 08:26:13',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-24-eckwqogigehr-RoleParametersValue-4jihz76mzzqj','state changed','OS::Heat::Value',NULL,818),(1252,'5a6e9a33-1a6c-4e80-a725-a060cca5961d','1e053a66-6010-4f1b-825f-d6c0dc5d8e92','2026-06-12 08:26:13',NULL,'CREATE','IN_PROGRESS','MySQLClient','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-14-fgxluvmrr44z-MySQLClient-6h5rehi3gku4','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1253,'4dd45531-dbb3-4bc6-be39-3084291fd4f6','a25ce4d4-e35d-44bb-92d0-087f8650c85a','2026-06-12 08:26:13',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-14-fgxluvmrr44z-MySQLClient-6h5rehi3gku4','a25ce4d4-e35d-44bb-92d0-087f8650c85a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1254,'ae925481-35f4-4e1d-bb1e-d88b4022b556','a25ce4d4-e35d-44bb-92d0-087f8650c85a','2026-06-12 08:26:13',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-14-fgxluvmrr44z-MySQLClient-6h5rehi3gku4','a25ce4d4-e35d-44bb-92d0-087f8650c85a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1255,'d4870892-fffa-4177-86d9-71d6052aee41','33bf28ea-c4b2-46f5-881c-a789b306762d','2026-06-12 08:26:13',NULL,'CREATE','COMPLETE','Podman','c77b84f2-0b08-417c-88f3-7181733daef5','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml',NULL,804),(1256,'1fc919be-a934-40de-9fc1-5136c1dab1a7','3075783c-9399-48ec-bf60-e53e303b4d0a','2026-06-12 08:26:13',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-23-hxo57hiymryp-RoleParametersValue-cmlfrp7hmf4j','state changed','OS::Heat::Value',NULL,819),(1257,'43051733-6012-4487-a08c-6bd65f012356','1e053a66-6010-4f1b-825f-d6c0dc5d8e92','2026-06-12 08:26:13',NULL,'CREATE','COMPLETE','NovaDBClient','5134bd10-7992-46b4-a99c-7017300bb46a','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,807),(1258,'7f3a1e73-0701-4dd6-a597-89a061e0356d','33bf28ea-c4b2-46f5-881c-a789b306762d','2026-06-12 08:26:13',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-24-eckwqogigehr','33bf28ea-c4b2-46f5-881c-a789b306762d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1259,'1faf94e3-305e-481b-a31e-c07f3804a5d0','3075783c-9399-48ec-bf60-e53e303b4d0a','2026-06-12 08:26:13',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-23-hxo57hiymryp-RoleParametersValue-cmlfrp7hmf4j','state changed','OS::Heat::Value',NULL,819),(1260,'e32d8565-f86a-4482-b9a9-fe34b29b9864','3075783c-9399-48ec-bf60-e53e303b4d0a','2026-06-12 08:26:13',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-23-hxo57hiymryp','3075783c-9399-48ec-bf60-e53e303b4d0a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1261,'57c74c94-3dde-4553-a915-b3a65fc5eef5','6d8aa4b5-7b9b-4abd-a093-dcb859503516','2026-06-12 08:26:13',NULL,'CREATE','IN_PROGRESS','ContainersCommon','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-24-blfwj2nua73x-ContainersCommon-um5getqkzbi3','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1262,'46f7d01d-4853-46b8-8aa0-63344553b4f6','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:26:13',NULL,'CREATE','COMPLETE','17','827e7c98-8400-49ce-a455-d35ac037d14c','state changed','OS::TripleO::Services::Podman',NULL,813),(1263,'1b52dd00-2234-4257-b0e4-1744d7bbe421','f6ca0895-42f3-496c-b347-11f1817905e9','2026-06-12 08:26:13',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-24-blfwj2nua73x-ContainersCommon-um5getqkzbi3','f6ca0895-42f3-496c-b347-11f1817905e9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1264,'c954adc6-a540-48fe-90c9-c7ee97dc6e72','f6ca0895-42f3-496c-b347-11f1817905e9','2026-06-12 08:26:13',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-24-blfwj2nua73x-ContainersCommon-um5getqkzbi3','f6ca0895-42f3-496c-b347-11f1817905e9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1265,'39d2d31c-644c-44f0-90b2-d5d08a72f392','6d8aa4b5-7b9b-4abd-a093-dcb859503516','2026-06-12 08:26:13',NULL,'CREATE','COMPLETE','NeutronLogging','dc47bccf-a8c7-4a70-b98f-41ab53de6118','state changed','OS::TripleO::Services::Logging::NeutronCommon',NULL,814),(1266,'4c151321-a751-440a-9cd6-30c16dbf761f','6d8aa4b5-7b9b-4abd-a093-dcb859503516','2026-06-12 08:26:13',NULL,'CREATE','COMPLETE','ContainersCommon','f6ca0895-42f3-496c-b347-11f1817905e9','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1267,'a90ea2cf-9c08-4707-9f25-a0d647850318','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:26:13',NULL,'CREATE','COMPLETE','17','600ef5db-6ac9-4f2b-a2a5-2e9b3a80c1bd','state changed','OS::TripleO::Services::Sshd',NULL,815),(1268,'aefcbb19-822e-451c-821b-a2f0da4e6fea','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:26:13',NULL,'CREATE','IN_PROGRESS','21','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-21-6a62ahytv3k2','state changed','OS::TripleO::Services::Timesync',NULL,821),(1269,'54ad417c-912d-4641-9caa-f6bd7294fc66','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:26:13',NULL,'CREATE','COMPLETE','23','cfa9fd93-4264-4e93-9246-0dbf036d6018','state changed','OS::TripleO::Services::OVNController',NULL,757),(1270,'ad7cea40-99bf-41a8-9164-610ca94ab201','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:26:13',NULL,'CREATE','IN_PROGRESS','21','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-21-w6qr5wklurtu','state changed','OS::TripleO::Services::TripleoPackages',NULL,823),(1271,'54e90c7c-c928-4ef6-8115-2ab4993d646c','34171339-c991-4163-81ff-5a7fca79a533','2026-06-12 08:26:13',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-21-6a62ahytv3k2','34171339-c991-4163-81ff-5a7fca79a533','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1272,'324df47c-ffd8-4d33-beff-6d763658b7f1','34171339-c991-4163-81ff-5a7fca79a533','2026-06-12 08:26:13',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-21-6a62ahytv3k2','34171339-c991-4163-81ff-5a7fca79a533','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1273,'356f369b-c9f7-4359-8981-e4f9d61caf28','b626ee3d-e85e-4405-b1c7-2095eb0f5610','2026-06-12 08:26:13',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-21-w6qr5wklurtu','b626ee3d-e85e-4405-b1c7-2095eb0f5610','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1274,'87d0eb17-5a1f-4875-825f-410a11872848','b626ee3d-e85e-4405-b1c7-2095eb0f5610','2026-06-12 08:26:14',NULL,'CREATE','IN_PROGRESS','Podman','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-21-w6qr5wklurtu-Podman-sqjnyeav6ksg','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml',NULL,824),(1275,'1ed46ac1-491b-49f5-b0e1-93ae9dc92772','187f6e2a-6294-4923-abd1-b6be559adf30','2026-06-12 08:26:14',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-21-w6qr5wklurtu-Podman-sqjnyeav6ksg','187f6e2a-6294-4923-abd1-b6be559adf30','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1276,'f40f81a3-3dc1-45e3-8e75-bf0070f34505','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:26:14',NULL,'CREATE','COMPLETE','24','33bf28ea-c4b2-46f5-881c-a789b306762d','state changed','OS::TripleO::Services::TripleoPackages',NULL,793),(1277,'b3241239-fd9d-4523-9bc2-41417b199309','187f6e2a-6294-4923-abd1-b6be559adf30','2026-06-12 08:26:14',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-21-w6qr5wklurtu-Podman-sqjnyeav6ksg','187f6e2a-6294-4923-abd1-b6be559adf30','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1278,'18109177-6c28-4253-93f5-8f65d05dbb37','1e053a66-6010-4f1b-825f-d6c0dc5d8e92','2026-06-12 08:26:14',NULL,'CREATE','IN_PROGRESS','NovaBase','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-14-fgxluvmrr44z-NovaBase-r2rx26tzulln','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,825),(1279,'588b0680-40a6-42a7-961e-f4c985edb554','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:26:14',NULL,'CREATE','COMPLETE','23','3075783c-9399-48ec-bf60-e53e303b4d0a','state changed','OS::TripleO::Services::TripleoFirewall',NULL,817),(1280,'81e5d452-9335-48c6-b322-b45cd7aa428d','1e053a66-6010-4f1b-825f-d6c0dc5d8e92','2026-06-12 08:26:14',NULL,'CREATE','COMPLETE','MySQLClient','a25ce4d4-e35d-44bb-92d0-087f8650c85a','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1281,'a02b564a-6e85-4a03-b99f-90b023b19bd3','09878adf-e070-48c7-bf9f-7da7371c4ab1','2026-06-12 08:26:14',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-14-fgxluvmrr44z-NovaBase-r2rx26tzulln','09878adf-e070-48c7-bf9f-7da7371c4ab1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1282,'8598f051-e92a-4060-ad96-5188928a8c85','6d8aa4b5-7b9b-4abd-a093-dcb859503516','2026-06-12 08:26:14',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-24-blfwj2nua73x-RoleParametersValue-jqnhwwlrrpkh','state changed','OS::Heat::Value',NULL,826),(1283,'4020fd1a-4806-4966-927e-274728685146','6d8aa4b5-7b9b-4abd-a093-dcb859503516','2026-06-12 08:26:14',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-24-blfwj2nua73x-RoleParametersValue-jqnhwwlrrpkh','state changed','OS::Heat::Value',NULL,826),(1284,'19b20606-b1cf-4717-9322-10246ab8ea1b','09878adf-e070-48c7-bf9f-7da7371c4ab1','2026-06-12 08:26:14',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-14-fgxluvmrr44z-NovaBase-r2rx26tzulln-RoleParametersValue-yfsibkkz7dgi','state changed','OS::Heat::Value',NULL,827),(1285,'28d78818-884c-4712-9bee-7b48b26efa66','09878adf-e070-48c7-bf9f-7da7371c4ab1','2026-06-12 08:26:14',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-14-fgxluvmrr44z-NovaBase-r2rx26tzulln-RoleParametersValue-yfsibkkz7dgi','state changed','OS::Heat::Value',NULL,827),(1286,'4b9e1d84-2906-4bf9-bd13-eca7cfe4facb','09878adf-e070-48c7-bf9f-7da7371c4ab1','2026-06-12 08:26:14',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-14-fgxluvmrr44z-NovaBase-r2rx26tzulln','09878adf-e070-48c7-bf9f-7da7371c4ab1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1287,'029cfece-e1ef-4199-ab50-f57532dca4e5','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:26:14',NULL,'CREATE','COMPLETE','21','34171339-c991-4163-81ff-5a7fca79a533','state changed','OS::TripleO::Services::Timesync',NULL,821),(1288,'ceb568b7-d025-4c7d-8d74-10ed7ec293db','b626ee3d-e85e-4405-b1c7-2095eb0f5610','2026-06-12 08:26:15',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-21-w6qr5wklurtu-RoleParametersValue-3fljxeff5ghq','state changed','OS::Heat::Value',NULL,829),(1289,'3f876359-08ca-4146-8636-1a860f78d12b','b626ee3d-e85e-4405-b1c7-2095eb0f5610','2026-06-12 08:26:15',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-21-w6qr5wklurtu-RoleParametersValue-3fljxeff5ghq','state changed','OS::Heat::Value',NULL,829),(1290,'0fd1df9d-5e9c-43a9-8d7b-593e4c793dcd','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:26:15',NULL,'CREATE','IN_PROGRESS','25','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-25-krzaognth5c3','state changed','OS::TripleO::Services::Tuned',NULL,830),(1291,'9e1a8b1f-6db4-4281-bedb-d7a3481a27ba','b626ee3d-e85e-4405-b1c7-2095eb0f5610','2026-06-12 08:26:15',NULL,'CREATE','COMPLETE','Podman','187f6e2a-6294-4923-abd1-b6be559adf30','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml',NULL,824),(1292,'eb0bafd8-3aeb-401d-b4b4-fdfd2b686712','a7773d0c-f734-4e7a-b385-f1384ecac79d','2026-06-12 08:26:15',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-25-krzaognth5c3','a7773d0c-f734-4e7a-b385-f1384ecac79d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1293,'0c8b4089-e0be-473c-aadd-f29e250750e2','b626ee3d-e85e-4405-b1c7-2095eb0f5610','2026-06-12 08:26:15',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-21-w6qr5wklurtu','b626ee3d-e85e-4405-b1c7-2095eb0f5610','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1294,'9a294cdb-8597-4d22-b41d-5618b71c205c','1e053a66-6010-4f1b-825f-d6c0dc5d8e92','2026-06-12 08:26:15',NULL,'CREATE','IN_PROGRESS','ContainersCommon','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-14-fgxluvmrr44z-ContainersCommon-fkdvbxyf4llq','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1295,'d878fe16-5c09-4ab4-be55-3079e49140a4','a7773d0c-f734-4e7a-b385-f1384ecac79d','2026-06-12 08:26:15',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-25-krzaognth5c3-RoleParametersValue-6m23nfduasbu','state changed','OS::Heat::Value',NULL,831),(1296,'9aa00bca-f6fb-47c3-b38d-216658e0a935','a7773d0c-f734-4e7a-b385-f1384ecac79d','2026-06-12 08:26:15',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-25-krzaognth5c3-RoleParametersValue-6m23nfduasbu','state changed','OS::Heat::Value',NULL,831),(1297,'41265d15-3a0d-47c2-8012-e7c93fca4263','a7773d0c-f734-4e7a-b385-f1384ecac79d','2026-06-12 08:26:15',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-25-krzaognth5c3','a7773d0c-f734-4e7a-b385-f1384ecac79d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1298,'4cc5a401-42c2-48fd-9911-1d845065b3ec','86d097e7-d775-4e52-a9c3-c9d10ebd48b2','2026-06-12 08:26:15',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-14-fgxluvmrr44z-ContainersCommon-fkdvbxyf4llq','86d097e7-d775-4e52-a9c3-c9d10ebd48b2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1299,'df4c3a89-99ef-4cb4-84f1-1cd77b6c3e89','86d097e7-d775-4e52-a9c3-c9d10ebd48b2','2026-06-12 08:26:15',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-14-fgxluvmrr44z-ContainersCommon-fkdvbxyf4llq','86d097e7-d775-4e52-a9c3-c9d10ebd48b2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1300,'e419849f-a15c-4985-bc7b-61b45ee3a498','1e053a66-6010-4f1b-825f-d6c0dc5d8e92','2026-06-12 08:26:15',NULL,'CREATE','COMPLETE','NovaBase','09878adf-e070-48c7-bf9f-7da7371c4ab1','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,825),(1301,'fa4c5bf1-6d1c-432e-a7a0-72700417aba4','6d8aa4b5-7b9b-4abd-a093-dcb859503516','2026-06-12 08:26:15',NULL,'CREATE','IN_PROGRESS','NeutronBase','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-24-blfwj2nua73x-NeutronBase-iuxqtykiaiyh','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-base.yaml',NULL,832),(1302,'fd335ef8-a403-4047-8c48-b8912a3a43dc','d66ef0fc-c413-420e-adad-7c3266c20e87','2026-06-12 08:26:15',NULL,'CREATE','IN_PROGRESS','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-24-blfwj2nua73x-NeutronBase-iuxqtykiaiyh','d66ef0fc-c413-420e-adad-7c3266c20e87','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1303,'11e9e485-610a-49ad-9e4e-bd2f07f40c38','d66ef0fc-c413-420e-adad-7c3266c20e87','2026-06-12 08:26:15',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-24-blfwj2nua73x-NeutronBase-iuxqtykiaiyh','d66ef0fc-c413-420e-adad-7c3266c20e87','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1304,'7d39c48d-b20e-42df-bd5c-82e8c0d29681','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:26:16',NULL,'CREATE','COMPLETE','21','b626ee3d-e85e-4405-b1c7-2095eb0f5610','state changed','OS::TripleO::Services::TripleoPackages',NULL,823),(1305,'8dc277e4-6eed-42c5-9a6a-fe3bed929372','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:26:16',NULL,'CREATE','COMPLETE','25','a7773d0c-f734-4e7a-b385-f1384ecac79d','state changed','OS::TripleO::Services::Tuned',NULL,830),(1306,'4a0c0fa6-fc92-49f8-af21-41dd0a0607fc','1e053a66-6010-4f1b-825f-d6c0dc5d8e92','2026-06-12 08:26:16',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-14-fgxluvmrr44z-RoleParametersValue-yevetdxl3zzc','state changed','OS::Heat::Value',NULL,833),(1307,'ce07172e-648b-4a12-bd90-50a1a264742d','1e053a66-6010-4f1b-825f-d6c0dc5d8e92','2026-06-12 08:26:16',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-14-fgxluvmrr44z-RoleParametersValue-yevetdxl3zzc','state changed','OS::Heat::Value',NULL,833),(1308,'53f8a873-f17d-41a9-8b11-ad348111da31','1e053a66-6010-4f1b-825f-d6c0dc5d8e92','2026-06-12 08:26:16',NULL,'CREATE','IN_PROGRESS','NovaLogging','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-14-fgxluvmrr44z-NovaLogging-k22byaowwwm7','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,835),(1309,'7a9f7309-4828-47bc-bf0a-793b14ceda52','1e053a66-6010-4f1b-825f-d6c0dc5d8e92','2026-06-12 08:26:16',NULL,'CREATE','COMPLETE','ContainersCommon','86d097e7-d775-4e52-a9c3-c9d10ebd48b2','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1310,'71fa64c4-db4d-4097-a661-377527abce25','a26933b0-a83c-4c4f-8487-117ce0ff7241','2026-06-12 08:26:16',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-14-fgxluvmrr44z-NovaLogging-k22byaowwwm7','a26933b0-a83c-4c4f-8487-117ce0ff7241','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1311,'86e51f22-8b69-416d-8cd0-db3ca272b149','6d8aa4b5-7b9b-4abd-a093-dcb859503516','2026-06-12 08:26:16',NULL,'CREATE','COMPLETE','NeutronBase','d66ef0fc-c413-420e-adad-7c3266c20e87','state changed','file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-base.yaml',NULL,832),(1312,'2923ae7a-c3eb-4ec5-ac36-b26006b74b80','a26933b0-a83c-4c4f-8487-117ce0ff7241','2026-06-12 08:26:16',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-14-fgxluvmrr44z-NovaLogging-k22byaowwwm7-RoleParametersValue-z5xf63hcjmci','state changed','OS::Heat::Value',NULL,836),(1313,'5f0d83fc-c9a7-4b93-bf15-f88d64a95ec6','a26933b0-a83c-4c4f-8487-117ce0ff7241','2026-06-12 08:26:16',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-14-fgxluvmrr44z-NovaLogging-k22byaowwwm7-RoleParametersValue-z5xf63hcjmci','state changed','OS::Heat::Value',NULL,836),(1314,'d1a20be0-e516-4dec-9c1b-2e38cf7bc3c7','6d8aa4b5-7b9b-4abd-a093-dcb859503516','2026-06-12 08:26:16',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo-24-blfwj2nua73x','6d8aa4b5-7b9b-4abd-a093-dcb859503516','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1315,'6cc76df8-aedf-465b-97cc-5be708e9cf1e','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:26:17',NULL,'CREATE','COMPLETE','24','6d8aa4b5-7b9b-4abd-a093-dcb859503516','state changed','OS::TripleO::Services::OVNMetadataAgent',NULL,801),(1316,'42d54079-0a64-4300-9116-c5b436ef3a48','2a198607-a616-42e1-bc58-6127fed18088','2026-06-12 08:26:17',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4-ServiceChain-fxxi734bdeuo','2a198607-a616-42e1-bc58-6127fed18088','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1317,'5f935fe4-74aa-42f1-9372-bc0847f115e0','a26933b0-a83c-4c4f-8487-117ce0ff7241','2026-06-12 08:26:17',NULL,'CREATE','IN_PROGRESS','InitLogContainerName','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-14-fgxluvmrr44z-NovaLogging-k22byaowwwm7-InitLogContainerName-qa2lkvo3d57k','state changed','OS::Heat::Value',NULL,837),(1318,'a30e990e-369b-406d-975c-d5e02f0e3f85','a26933b0-a83c-4c4f-8487-117ce0ff7241','2026-06-12 08:26:17',NULL,'CREATE','COMPLETE','InitLogContainerName','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-14-fgxluvmrr44z-NovaLogging-k22byaowwwm7-InitLogContainerName-qa2lkvo3d57k','state changed','OS::Heat::Value',NULL,837),(1319,'fdf861e2-e76c-458f-af76-517a5c660f99','a26933b0-a83c-4c4f-8487-117ce0ff7241','2026-06-12 08:26:17',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-14-fgxluvmrr44z-NovaLogging-k22byaowwwm7','a26933b0-a83c-4c4f-8487-117ce0ff7241','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1320,'6ccf51fd-17f8-4f35-80ac-c3985886c53a','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:17',NULL,'CREATE','COMPLETE','ServiceChain','2a198607-a616-42e1-bc58-6127fed18088','state changed','OS::Heat::ResourceChain',NULL,85),(1321,'14669fdf-6e81-49de-8394-3e6b2b6fec9c','1e053a66-6010-4f1b-825f-d6c0dc5d8e92','2026-06-12 08:26:18',NULL,'CREATE','COMPLETE','NovaLogging','a26933b0-a83c-4c4f-8487-117ce0ff7241','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,835),(1322,'ec8237a9-a6f2-47bc-a2f0-2f4ec839cdd2','1e053a66-6010-4f1b-825f-d6c0dc5d8e92','2026-06-12 08:26:18',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-14-fgxluvmrr44z','1e053a66-6010-4f1b-825f-d6c0dc5d8e92','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1323,'1ce1a81e-fce9-4719-a2b7-55cb54031f22','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:18',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','cell1-ComputeServiceChain-egzxltenqxn4-HostFirewallTasks-2zpnioghgv5c','state changed','OS::Heat::Value',NULL,852),(1324,'bd9c9d53-1a8a-45e8-8781-b9fc246a0d8b','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:19',NULL,'CREATE','COMPLETE','HostFirewallTasks','cell1-ComputeServiceChain-egzxltenqxn4-HostFirewallTasks-2zpnioghgv5c','state changed','OS::Heat::Value',NULL,852),(1325,'011f0628-a805-47b0-84e9-2af941ae210f','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:26:19',NULL,'CREATE','COMPLETE','14','1e053a66-6010-4f1b-825f-d6c0dc5d8e92','state changed','OS::TripleO::Services::NovaVncProxy',NULL,789),(1326,'01af345f-ebbc-4e88-b2fd-6b8fe6e2f8b1','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:19',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','cell1-ComputeServiceChain-egzxltenqxn4-ExternalPostDeployTasks-bwvniqualduy','state changed','OS::Heat::Value',NULL,853),(1327,'82304b34-d658-48d8-91a7-92e769f850ee','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:19',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','cell1-ComputeServiceChain-egzxltenqxn4-DeployStepsTasks-dgvu7udwwshl','state changed','OS::Heat::Value',NULL,854),(1328,'18345902-6c20-4353-ab98-019d90559ea7','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:19',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','cell1-ComputeServiceChain-egzxltenqxn4-ExternalPostDeployTasks-bwvniqualduy','state changed','OS::Heat::Value',NULL,853),(1329,'102af9e5-1f44-46f7-b402-22252c30ed79','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:19',NULL,'CREATE','COMPLETE','DeployStepsTasks','cell1-ComputeServiceChain-egzxltenqxn4-DeployStepsTasks-dgvu7udwwshl','state changed','OS::Heat::Value',NULL,854),(1330,'8850d421-d190-4ddb-95c9-550ed9d3a348','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:19',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','cell1-ComputeServiceChain-egzxltenqxn4-UpgradeBatchTasks-yjghi5jemhg5','state changed','OS::Heat::Value',NULL,856),(1331,'cd9ddc27-c0f4-40d3-85ce-2ee65b15ecc7','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:19',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','cell1-ComputeServiceChain-egzxltenqxn4-PreUpgradeRollingTasks-6slk3prjq4yp','state changed','OS::Heat::Value',NULL,857),(1332,'2565d8f0-4aa5-4461-a411-26f95f80864e','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:19',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','cell1-ComputeServiceChain-egzxltenqxn4-UpgradeBatchTasks-yjghi5jemhg5','state changed','OS::Heat::Value',NULL,856),(1333,'3ae0460b-98e6-483e-b816-f98f86cc075f','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:19',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','cell1-ComputeServiceChain-egzxltenqxn4-PreUpgradeRollingTasks-6slk3prjq4yp','state changed','OS::Heat::Value',NULL,857),(1334,'146d18a4-982e-4b43-8639-1c1610d576b7','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:19',NULL,'CREATE','IN_PROGRESS','KollaConfig','cell1-ComputeServiceChain-egzxltenqxn4-KollaConfig-hpcxw7w3wzt3','state changed','OS::Heat::Value',NULL,859),(1335,'e37ff8af-987a-4424-b102-118011955388','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:19',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','cell1-ComputeServiceChain-egzxltenqxn4-ExternalUpdateTasks-hxymnfmfupxb','state changed','OS::Heat::Value',NULL,861),(1336,'b5c7b3ed-f08c-465a-a668-20a096fc3854','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:19',NULL,'CREATE','COMPLETE','KollaConfig','cell1-ComputeServiceChain-egzxltenqxn4-KollaConfig-hpcxw7w3wzt3','state changed','OS::Heat::Value',NULL,859),(1337,'38666589-e9da-43b3-a5dd-0d3d62330557','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:19',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','cell1-ComputeServiceChain-egzxltenqxn4-ExternalUpdateTasks-hxymnfmfupxb','state changed','OS::Heat::Value',NULL,861),(1338,'cf5f0d01-8923-465e-adf1-fe5cb8d87473','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:19',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','cell1-ComputeServiceChain-egzxltenqxn4-KeystoneResourcesConfigs-o5ltyi6pmenv','state changed','OS::Heat::Value',NULL,863),(1339,'ac253c22-4eaa-4929-b408-a1bdd2796fc8','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:19',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','cell1-ComputeServiceChain-egzxltenqxn4-KeystoneResourcesConfigs-o5ltyi6pmenv','state changed','OS::Heat::Value',NULL,863),(1340,'ca55207d-6853-4114-8cf8-c6d822fb6244','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:19',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','cell1-ComputeServiceChain-egzxltenqxn4-MonitoringSubscriptionsConfig-ifyqoxfi53qa','state changed','OS::Heat::Value',NULL,866),(1341,'475bbef6-943e-44a7-893e-9bcc74a79174','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:19',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','cell1-ComputeServiceChain-egzxltenqxn4-MonitoringSubscriptionsConfig-ifyqoxfi53qa','state changed','OS::Heat::Value',NULL,866),(1342,'81b5ed0f-06c1-4d37-bc08-efab7718601e','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:19',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','cell1-ComputeServiceChain-egzxltenqxn4-PuppetStepConfig-6ydbfiaxl77x','state changed','OS::Heat::Value',NULL,867),(1343,'6cd877dd-6926-46cf-9df2-c9fa648df8c9','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:19',NULL,'CREATE','IN_PROGRESS','PuppetConfig','cell1-ComputeServiceChain-egzxltenqxn4-PuppetConfig-fpikqbhdu6eg','state changed','OS::Heat::Value',NULL,869),(1344,'0cf17b19-c550-439c-b38b-5925060663c9','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:19',NULL,'CREATE','COMPLETE','PuppetStepConfig','cell1-ComputeServiceChain-egzxltenqxn4-PuppetStepConfig-6ydbfiaxl77x','state changed','OS::Heat::Value',NULL,867),(1345,'ffee6ebe-15d9-4c24-a002-c8aaf7a34150','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:19',NULL,'CREATE','COMPLETE','PuppetConfig','cell1-ComputeServiceChain-egzxltenqxn4-PuppetConfig-fpikqbhdu6eg','state changed','OS::Heat::Value',NULL,869),(1346,'91050ec9-477e-47d6-a46b-f9a91024286b','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:19',NULL,'CREATE','IN_PROGRESS','DockerConfig','cell1-ComputeServiceChain-egzxltenqxn4-DockerConfig-vbxi5sxotoft','state changed','OS::Heat::Value',NULL,872),(1347,'aebef20e-0fa3-44f9-aa92-d4d9b8dd718a','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:19',NULL,'CREATE','COMPLETE','DockerConfig','cell1-ComputeServiceChain-egzxltenqxn4-DockerConfig-vbxi5sxotoft','state changed','OS::Heat::Value',NULL,872),(1348,'fe55e9ae-ec8d-4d40-885d-604eb5ba0c92','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:26:19',NULL,'CREATE','IN_PROGRESS','18','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-18-jgpjjbslgup5','state changed','OS::TripleO::Services::Rsyslog',NULL,873),(1349,'d97cc0a0-17f1-46de-8d5f-a8ad4b4517a3','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:20',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','cell1-ComputeServiceChain-egzxltenqxn4-DockerPuppetTasks-52ewjgby2hwd','state changed','OS::Heat::Value',NULL,874),(1350,'ae2a6728-2ee9-4205-a52b-541314ae4726','bcdf10c3-4f5c-42d6-be17-19a5c573c9a3','2026-06-12 08:26:20',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-18-jgpjjbslgup5','bcdf10c3-4f5c-42d6-be17-19a5c573c9a3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1351,'930faaee-70e5-4706-a47c-f0046acb36d2','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:20',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','cell1-ComputeServiceChain-egzxltenqxn4-ExternalUpgradeTasks-lwqbq47xjb6s','state changed','OS::Heat::Value',NULL,875),(1352,'710a1a29-6140-4a61-a451-06b55a0ebedd','bcdf10c3-4f5c-42d6-be17-19a5c573c9a3','2026-06-12 08:26:20',NULL,'CREATE','IN_PROGRESS','ContainersCommon','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-18-jgpjjbslgup5-ContainersCommon-rj6flxpegtfa','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1353,'91a9c2dd-69ee-48db-b036-efb965b24e0e','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:20',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','cell1-ComputeServiceChain-egzxltenqxn4-ExternalUpgradeTasks-lwqbq47xjb6s','state changed','OS::Heat::Value',NULL,875),(1354,'933c3ffb-8bbc-4f75-bfc5-1ee1d8f0ad52','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:20',NULL,'CREATE','COMPLETE','DockerPuppetTasks','cell1-ComputeServiceChain-egzxltenqxn4-DockerPuppetTasks-52ewjgby2hwd','state changed','OS::Heat::Value',NULL,874),(1355,'434b00c6-a3db-4968-b11d-e0358f75f9c4','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:20',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','cell1-ComputeServiceChain-egzxltenqxn4-UpgradeTasks-7j3n6bzo5rhz','state changed','OS::Heat::Value',NULL,876),(1356,'516df924-f1e7-4b4f-aab4-6f9e0137071f','82776dde-367c-49ae-94d9-8504fe2b84a0','2026-06-12 08:26:20',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-18-jgpjjbslgup5-ContainersCommon-rj6flxpegtfa','82776dde-367c-49ae-94d9-8504fe2b84a0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1357,'33eaa842-beb7-4fba-9007-d046060317e0','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:20',NULL,'CREATE','COMPLETE','UpgradeTasks','cell1-ComputeServiceChain-egzxltenqxn4-UpgradeTasks-7j3n6bzo5rhz','state changed','OS::Heat::Value',NULL,876),(1358,'a3f130e7-fa32-4c3e-aed2-18c2c3149701','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:20',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','cell1-ComputeServiceChain-egzxltenqxn4-PostUpgradeTasks-h6vdoucagiw6','state changed','OS::Heat::Value',NULL,877),(1359,'8ae2ebae-4d5f-4fff-a695-7091bc56d7aa','82776dde-367c-49ae-94d9-8504fe2b84a0','2026-06-12 08:26:20',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-18-jgpjjbslgup5-ContainersCommon-rj6flxpegtfa','82776dde-367c-49ae-94d9-8504fe2b84a0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1360,'a63ded3a-5991-461b-885a-40c693ed3e7f','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:20',NULL,'CREATE','IN_PROGRESS','ScaleTasks','cell1-ComputeServiceChain-egzxltenqxn4-ScaleTasks-aou5fsnnkfqc','state changed','OS::Heat::Value',NULL,878),(1361,'26d319a0-7f80-481b-a597-8b450aeaddb9','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:20',NULL,'CREATE','COMPLETE','ScaleTasks','cell1-ComputeServiceChain-egzxltenqxn4-ScaleTasks-aou5fsnnkfqc','state changed','OS::Heat::Value',NULL,878),(1362,'723e11b6-5638-4fc5-a204-80176e5d035e','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:20',NULL,'CREATE','COMPLETE','PostUpgradeTasks','cell1-ComputeServiceChain-egzxltenqxn4-PostUpgradeTasks-h6vdoucagiw6','state changed','OS::Heat::Value',NULL,877),(1363,'c7f68d00-7168-4988-80c2-6166ca49ea89','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:20',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','cell1-ComputeServiceChain-egzxltenqxn4-ServiceServerMetadataHook-t2sgze7onfz5','state changed','OS::TripleO::ComputeServiceServerMetadataHook',NULL,NULL),(1364,'ebb168ab-5667-43e1-90f4-cbe9d5bac30a','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:20',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','c396305f-c55f-42b1-b09b-56ba945374c7','state changed','OS::TripleO::ComputeServiceServerMetadataHook',NULL,NULL),(1365,'39108f89-1765-4947-b0eb-e9be9abe8374','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:20',NULL,'CREATE','IN_PROGRESS','ServiceNames','cell1-ComputeServiceChain-egzxltenqxn4-ServiceNames-vx7rk6ptalok','state changed','OS::Heat::Value',NULL,879),(1366,'d06c8be3-51a0-42ec-9cb3-615e5a100ba1','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:20',NULL,'CREATE','COMPLETE','ServiceNames','cell1-ComputeServiceChain-egzxltenqxn4-ServiceNames-vx7rk6ptalok','state changed','OS::Heat::Value',NULL,879),(1367,'7608eef5-f327-4afe-8c42-ff65999b1da5','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:20',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','cell1-ComputeServiceChain-egzxltenqxn4-DockerConfigScripts-zm7ar7nirxv7','state changed','OS::Heat::Value',NULL,880),(1368,'026b94a8-8825-4afa-b3cd-5649a78b98fe','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:20',NULL,'CREATE','COMPLETE','DockerConfigScripts','cell1-ComputeServiceChain-egzxltenqxn4-DockerConfigScripts-zm7ar7nirxv7','state changed','OS::Heat::Value',NULL,880),(1369,'5e48eea9-8694-45a0-aa87-b6fd6a58cf56','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:20',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','cell1-ComputeServiceChain-egzxltenqxn4-IpaRegistrationTasks-3naka5lim2xz','state changed','OS::Heat::Value',NULL,881),(1370,'4aaa206e-5203-49bf-8831-1381d359f9e9','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:20',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','cell1-ComputeServiceChain-egzxltenqxn4-IpaRegistrationTasks-3naka5lim2xz','state changed','OS::Heat::Value',NULL,881),(1371,'89931b68-24c7-4e22-b620-d8061e8fe48c','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:20',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','cell1-ComputeServiceChain-egzxltenqxn4-ServiceConfigSettings-tu5xi7igpn7k','state changed','OS::Heat::Value',NULL,882),(1372,'57a94719-5c6b-485f-bc79-1dbfd11d4e93','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:20',NULL,'CREATE','COMPLETE','ServiceConfigSettings','cell1-ComputeServiceChain-egzxltenqxn4-ServiceConfigSettings-tu5xi7igpn7k','state changed','OS::Heat::Value',NULL,882),(1373,'ff8e1fbb-8263-4523-8b46-2c6ab19c1e4a','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:20',NULL,'CREATE','IN_PROGRESS','UpdateTasks','cell1-ComputeServiceChain-egzxltenqxn4-UpdateTasks-x5g3aoxswhsd','state changed','OS::Heat::Value',NULL,883),(1374,'0e103d7a-c5ff-4352-99c2-b15a06be697c','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:20',NULL,'CREATE','COMPLETE','UpdateTasks','cell1-ComputeServiceChain-egzxltenqxn4-UpdateTasks-x5g3aoxswhsd','state changed','OS::Heat::Value',NULL,883),(1375,'e4e6c7f9-6ee7-4746-b284-1a7671df4a8d','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:20',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','cell1-ComputeServiceChain-egzxltenqxn4-AnsibleGroupVars-u6v45rqml2hm','state changed','OS::Heat::Value',NULL,884),(1376,'76bf7181-9cef-4093-8637-df472b32f145','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:21',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','cell1-ComputeServiceChain-egzxltenqxn4-PostUpdateTasks-rwzwh6ecywfp','state changed','OS::Heat::Value',NULL,885),(1377,'f998ecde-7ea9-4143-9075-0edf67c3a658','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:21',NULL,'CREATE','COMPLETE','PostUpdateTasks','cell1-ComputeServiceChain-egzxltenqxn4-PostUpdateTasks-rwzwh6ecywfp','state changed','OS::Heat::Value',NULL,885),(1378,'8e5c38be-6c69-4b7b-aad8-cb89e7104b94','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:21',NULL,'CREATE','COMPLETE','AnsibleGroupVars','cell1-ComputeServiceChain-egzxltenqxn4-AnsibleGroupVars-u6v45rqml2hm','state changed','OS::Heat::Value',NULL,884),(1379,'0ac591aa-dfb4-46d5-8ceb-3866209a28e3','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:21',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','cell1-ComputeServiceChain-egzxltenqxn4-HostPrepTasks-fim23vgspaqz','state changed','OS::Heat::Value',NULL,886),(1380,'851a913a-18d5-4402-86bf-a23f1df01349','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:21',NULL,'CREATE','COMPLETE','HostPrepTasks','cell1-ComputeServiceChain-egzxltenqxn4-HostPrepTasks-fim23vgspaqz','state changed','OS::Heat::Value',NULL,886),(1381,'b22f644f-4d45-4c2a-b7dd-f6aded498cc6','bcdf10c3-4f5c-42d6-be17-19a5c573c9a3','2026-06-12 08:26:21',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-18-jgpjjbslgup5-RoleParametersValue-coo6t3xs55av','state changed','OS::Heat::Value',NULL,887),(1382,'7a4f5697-30ea-4fe3-b569-fb399dacd833','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:21',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','cell1-ComputeServiceChain-egzxltenqxn4-ContainerPuppetTasks-gtrqsb2nweos','state changed','OS::Heat::Value',NULL,888),(1383,'5d79dde8-c290-4fd1-8bc8-2e9717c89df0','bcdf10c3-4f5c-42d6-be17-19a5c573c9a3','2026-06-12 08:26:21',NULL,'CREATE','COMPLETE','RoleParametersValue','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-18-jgpjjbslgup5-RoleParametersValue-coo6t3xs55av','state changed','OS::Heat::Value',NULL,887),(1384,'e563dccb-e659-4fcc-a461-1951022d85a2','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:21',NULL,'CREATE','IN_PROGRESS','FirewallRules','cell1-ComputeServiceChain-egzxltenqxn4-FirewallRules-3iiron4e2ban','state changed','OS::Heat::Value',NULL,889),(1385,'e1664f62-6321-468c-82b2-104d19a60f74','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:21',NULL,'CREATE','COMPLETE','FirewallRules','cell1-ComputeServiceChain-egzxltenqxn4-FirewallRules-3iiron4e2ban','state changed','OS::Heat::Value',NULL,889),(1386,'9a36d263-89e5-4faf-a61a-30641a8b1b97','bcdf10c3-4f5c-42d6-be17-19a5c573c9a3','2026-06-12 08:26:21',NULL,'CREATE','COMPLETE','ContainersCommon','82776dde-367c-49ae-94d9-8504fe2b84a0','state changed','file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1387,'72213ccd-30e6-473b-8ccb-e0189d94ec26','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:21',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','cell1-ComputeServiceChain-egzxltenqxn4-FirewallFrontendRules-d3tgzwfcxaz7','state changed','OS::Heat::Value',NULL,890),(1388,'7726cb30-297e-45f7-a508-2c9cd29d66e5','bcdf10c3-4f5c-42d6-be17-19a5c573c9a3','2026-06-12 08:26:21',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-18-jgpjjbslgup5','bcdf10c3-4f5c-42d6-be17-19a5c573c9a3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1389,'6728db9c-00ca-4e68-835d-f1416be7be16','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:21',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','cell1-ComputeServiceChain-egzxltenqxn4-ContainerPuppetTasks-gtrqsb2nweos','state changed','OS::Heat::Value',NULL,888),(1390,'6093d6dd-05f5-4a67-9b75-1c4f29447ee4','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:21',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','cell1-ComputeServiceChain-egzxltenqxn4-PreDeployStepTasks-aqsmwd3eeyr5','state changed','OS::Heat::Value',NULL,891),(1391,'ea09cc67-9894-4351-ad8b-562ddc554f36','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:21',NULL,'CREATE','COMPLETE','PreDeployStepTasks','cell1-ComputeServiceChain-egzxltenqxn4-PreDeployStepTasks-aqsmwd3eeyr5','state changed','OS::Heat::Value',NULL,891),(1392,'a4af008a-d278-4e5a-bea7-aa7196b1eec1','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:21',NULL,'CREATE','COMPLETE','FirewallFrontendRules','cell1-ComputeServiceChain-egzxltenqxn4-FirewallFrontendRules-d3tgzwfcxaz7','state changed','OS::Heat::Value',NULL,890),(1393,'c7b6b50e-3262-42f6-bb16-e8499db0c789','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:21',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','cell1-ComputeServiceChain-egzxltenqxn4-ExternalDeployTasks-cd4wsv4lqokk','state changed','OS::Heat::Value',NULL,892),(1394,'af05ee0a-15b5-4bfa-9988-b84d9f5486ca','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:21',NULL,'CREATE','COMPLETE','ExternalDeployTasks','cell1-ComputeServiceChain-egzxltenqxn4-ExternalDeployTasks-cd4wsv4lqokk','state changed','OS::Heat::Value',NULL,892),(1395,'00ff7f81-c6b7-4b87-90dd-b1dbda5c4ba6','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:21',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','cell1-ComputeServiceChain-egzxltenqxn4-GlobalConfigSettings-fjue2gm3ki7x','state changed','OS::Heat::Value',NULL,894),(1396,'b7405d3d-b9c7-443c-ae56-0b3edc1d472a','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:21',NULL,'CREATE','COMPLETE','GlobalConfigSettings','cell1-ComputeServiceChain-egzxltenqxn4-GlobalConfigSettings-fjue2gm3ki7x','state changed','OS::Heat::Value',NULL,894),(1397,'714d82ec-71af-4e36-ab33-2148f9bbfc19','145e1916-db5b-4baa-b2e0-d4a4af571da7','2026-06-12 08:26:21',NULL,'CREATE','COMPLETE','cell1-ComputeServiceChain-egzxltenqxn4','145e1916-db5b-4baa-b2e0-d4a4af571da7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1398,'41801c8c-a03a-4bca-9d79-784d1e5f8bf2','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:26:22',NULL,'CREATE','COMPLETE','18','bcdf10c3-4f5c-42d6-be17-19a5c573c9a3','state changed','OS::TripleO::Services::Rsyslog',NULL,873),(1399,'910c68c0-f172-427d-926d-b0351926148a','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:26:22',NULL,'CREATE','IN_PROGRESS','22','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-22-qeitfohukanm','state changed','OS::TripleO::Services::Timezone',NULL,898),(1400,'7cbaaedd-fe98-4ed7-bc01-d30a380b2ef4','4ef7f5e0-dd46-4fa9-b580-5522ccabc707','2026-06-12 08:26:22',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-22-qeitfohukanm','4ef7f5e0-dd46-4fa9-b580-5522ccabc707','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1401,'f7bdf18e-8dee-4384-a5d8-99c6abdfadcb','4ef7f5e0-dd46-4fa9-b580-5522ccabc707','2026-06-12 08:26:22',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt-22-qeitfohukanm','4ef7f5e0-dd46-4fa9-b580-5522ccabc707','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1402,'0478c279-b6c4-4b2a-8e6d-aa095f5fb045','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:22',NULL,'CREATE','COMPLETE','ComputeServiceChain','145e1916-db5b-4baa-b2e0-d4a4af571da7','state changed','OS::TripleO::ComputeServices',NULL,72),(1403,'ef4acbbf-75c0-489f-8998-d01d90140269','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:23',NULL,'CREATE','IN_PROGRESS','ComputeServiceChainRoleData','cell1-ComputeServiceChainRoleData-l4vdiivxoaul','state changed','OS::Heat::Value',NULL,932),(1404,'2ab770f3-75d3-4909-a380-c08316d63de0','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:23',NULL,'CREATE','COMPLETE','ComputeServiceChainRoleData','cell1-ComputeServiceChainRoleData-l4vdiivxoaul','state changed','OS::Heat::Value',NULL,932),(1405,'e763fb32-d96d-4649-9c91-42f828c12563','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:26:23',NULL,'CREATE','COMPLETE','22','4ef7f5e0-dd46-4fa9-b580-5522ccabc707','state changed','OS::TripleO::Services::Timezone',NULL,898),(1406,'43efc435-6831-415e-8ea4-5a9d679a31dc','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:23',NULL,'CREATE','IN_PROGRESS','ComputeServiceNames','cell1-ComputeServiceNames-fquu4ejistm5','state changed','OS::Heat::Value',NULL,933),(1407,'50e702e8-16fd-4aa2-83bc-7eecee3f8cc6','a465b367-1cd1-49f7-9936-052ba909fd04','2026-06-12 08:26:23',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceChain-xbvc7lrtmkdt','a465b367-1cd1-49f7-9936-052ba909fd04','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1408,'cd8f187b-9bd2-4800-b749-e19acbefbbf0','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:23',NULL,'CREATE','COMPLETE','ComputeServiceNames','cell1-ComputeServiceNames-fquu4ejistm5','state changed','OS::Heat::Value',NULL,933),(1409,'bbe2d6b7-e743-4521-9bb8-aef2ffa2e1c1','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:23',NULL,'CREATE','COMPLETE','ServiceChain','a465b367-1cd1-49f7-9936-052ba909fd04','state changed','OS::Heat::ResourceChain',NULL,86),(1410,'679ed6da-292a-4d85-87a9-2509a7c7dd0e','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:23',NULL,'CREATE','IN_PROGRESS','Compute','cell1-Compute-i4fnxllhuqlt','state changed','OS::Heat::ResourceGroup',NULL,935),(1411,'68438625-1afc-4793-8669-610acc7f3f19','d9b1942a-b512-41cf-8930-ff20a5f2f41d','2026-06-12 08:26:23',NULL,'CREATE','IN_PROGRESS','cell1-Compute-i4fnxllhuqlt','d9b1942a-b512-41cf-8930-ff20a5f2f41d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1412,'39e09dbd-7cbb-43e2-9ee1-193d38eed281','d9b1942a-b512-41cf-8930-ff20a5f2f41d','2026-06-12 08:26:23',NULL,'CREATE','COMPLETE','cell1-Compute-i4fnxllhuqlt','d9b1942a-b512-41cf-8930-ff20a5f2f41d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1413,'46af9f0d-8f8f-48f3-b40a-2d696654ceca','d9b1942a-b512-41cf-8930-ff20a5f2f41d','2026-06-12 08:26:23',NULL,'UPDATE','IN_PROGRESS','cell1-Compute-i4fnxllhuqlt','d9b1942a-b512-41cf-8930-ff20a5f2f41d','Stack UPDATE started','OS::Heat::Stack',NULL,NULL),(1414,'850d561b-e5b3-4cd3-bfdc-d07339bbba1b','d9b1942a-b512-41cf-8930-ff20a5f2f41d','2026-06-12 08:26:24',NULL,'CREATE','IN_PROGRESS','0','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz','state changed','OS::TripleO::Compute',NULL,937),(1415,'01b2cc64-156b-46dd-8e8e-0d6b468fb61b','005044b3-c8a4-4671-baac-b6e476540d1a','2026-06-12 08:26:24',NULL,'CREATE','IN_PROGRESS','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz','005044b3-c8a4-4671-baac-b6e476540d1a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1416,'a789742d-781d-4672-be26-1e1cd407b6ce','005044b3-c8a4-4671-baac-b6e476540d1a','2026-06-12 08:26:24',NULL,'CREATE','IN_PROGRESS','NovaCompute','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz-NovaCompute-qzfq7rtmqelw','state changed','OS::TripleO::ComputeServer',NULL,946),(1417,'e3f18c20-d5e5-446e-9385-72c5388e8d4c','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:24',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','cell1-CellControllerServiceChain-sfzpnsimaenh-AnsibleGroupVars-bkp64rxrrjvz','state changed','OS::Heat::Value',NULL,947),(1418,'7e2e45e7-18f6-4c08-b90b-a0ce88c80579','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:24',NULL,'CREATE','COMPLETE','AnsibleGroupVars','cell1-CellControllerServiceChain-sfzpnsimaenh-AnsibleGroupVars-bkp64rxrrjvz','state changed','OS::Heat::Value',NULL,947),(1419,'90f2fa73-644e-403b-8bae-8195ac82338c','26c54eb2-2780-4b7b-bcdf-41980cc85dca','2026-06-12 08:26:24',NULL,'CREATE','IN_PROGRESS','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz-NovaCompute-qzfq7rtmqelw','26c54eb2-2780-4b7b-bcdf-41980cc85dca','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1420,'b2b86473-02c5-45ec-8c4e-284bed56f099','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:24',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','cell1-CellControllerServiceChain-sfzpnsimaenh-PostUpdateTasks-pdmnuq2urc7l','state changed','OS::Heat::Value',NULL,948),(1421,'d5b86313-6318-4d10-99ea-5252b9fdd438','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:24',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','cell1-CellControllerServiceChain-sfzpnsimaenh-DockerPuppetTasks-2ios2faafgcl','state changed','OS::Heat::Value',NULL,949),(1422,'ec2eeffc-bda0-4a85-925a-604ce94e50e4','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:24',NULL,'CREATE','COMPLETE','PostUpdateTasks','cell1-CellControllerServiceChain-sfzpnsimaenh-PostUpdateTasks-pdmnuq2urc7l','state changed','OS::Heat::Value',NULL,948),(1423,'43604c3d-4151-4d4c-a064-d9bf07981a20','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:24',NULL,'CREATE','COMPLETE','DockerPuppetTasks','cell1-CellControllerServiceChain-sfzpnsimaenh-DockerPuppetTasks-2ios2faafgcl','state changed','OS::Heat::Value',NULL,949),(1424,'94970f7d-62a8-44f6-9cd1-d7bd2fd0755b','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:24',NULL,'CREATE','IN_PROGRESS','DockerConfig','cell1-CellControllerServiceChain-sfzpnsimaenh-DockerConfig-znyr7cj3ksrz','state changed','OS::Heat::Value',NULL,950),(1425,'b562e69e-4974-4110-929a-d16ffb26d5e7','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:24',NULL,'CREATE','COMPLETE','DockerConfig','cell1-CellControllerServiceChain-sfzpnsimaenh-DockerConfig-znyr7cj3ksrz','state changed','OS::Heat::Value',NULL,950),(1426,'c9f732ae-7e06-4178-8483-5a4e9b776bb0','26c54eb2-2780-4b7b-bcdf-41980cc85dca','2026-06-12 08:26:24',NULL,'CREATE','IN_PROGRESS','deployed-server','ce-aCompute-qzfq7rtmqelw-deployed-server-xerezsohjznt','state changed','OS::Heat::DeployedServer',NULL,951),(1427,'f7eda959-4573-4ce9-9e5e-fd83d2603fa8','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:25',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','cell1-CellControllerServiceChain-sfzpnsimaenh-FirewallFrontendRules-avbj7mbiwust','state changed','OS::Heat::Value',NULL,952),(1428,'50d4b5ce-0009-4c4e-a3fb-6cad9b9e9748','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:25',NULL,'CREATE','IN_PROGRESS','ServiceNames','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceNames-slkopgtpvbnv','state changed','OS::Heat::Value',NULL,953),(1429,'08baeab3-2c55-4d45-b7bd-21c8220af3a2','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:25',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','cell1-CellControllerServiceChain-sfzpnsimaenh-UpgradeTasks-g545uyieyjav','state changed','OS::Heat::Value',NULL,954),(1430,'b79defae-9cb5-4d1b-b2a1-040773943f5b','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:25',NULL,'CREATE','COMPLETE','ServiceNames','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceNames-slkopgtpvbnv','state changed','OS::Heat::Value',NULL,953),(1431,'c037fa29-9707-4d7d-ae02-770f9fadb82f','26c54eb2-2780-4b7b-bcdf-41980cc85dca','2026-06-12 08:26:25',NULL,'CREATE','COMPLETE','deployed-server','9c74e5b3-24cc-4b92-a048-87963237f199','state changed','OS::Heat::DeployedServer',NULL,951),(1432,'4c6a097b-ca02-4682-9b02-3741ca6de390','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:25',NULL,'CREATE','COMPLETE','UpgradeTasks','cell1-CellControllerServiceChain-sfzpnsimaenh-UpgradeTasks-g545uyieyjav','state changed','OS::Heat::Value',NULL,954),(1433,'df551832-b4ba-426b-be45-266fea824357','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:25',NULL,'CREATE','COMPLETE','FirewallFrontendRules','cell1-CellControllerServiceChain-sfzpnsimaenh-FirewallFrontendRules-avbj7mbiwust','state changed','OS::Heat::Value',NULL,952),(1434,'2efd4c2c-e147-48a9-b2e3-76c8ee4c4159','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:25',NULL,'CREATE','IN_PROGRESS','ScaleTasks','cell1-CellControllerServiceChain-sfzpnsimaenh-ScaleTasks-hxlt6dymg5od','state changed','OS::Heat::Value',NULL,955),(1435,'da616b05-c8da-4344-b1aa-ca35f52204b2','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:25',NULL,'CREATE','COMPLETE','ScaleTasks','cell1-CellControllerServiceChain-sfzpnsimaenh-ScaleTasks-hxlt6dymg5od','state changed','OS::Heat::Value',NULL,955),(1436,'84cfb02c-5a6a-4715-b028-bf54e3b8f753','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:25',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','cell1-CellControllerServiceChain-sfzpnsimaenh-UpgradeBatchTasks-p56qi2kwhpui','state changed','OS::Heat::Value',NULL,956),(1437,'d9d1f709-bc92-49dc-ac01-69d3cb7c3303','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:25',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','cell1-CellControllerServiceChain-sfzpnsimaenh-HostFirewallTasks-sf6wreli2agk','state changed','OS::Heat::Value',NULL,957),(1438,'9afb6b23-8b1c-48df-ba42-19bebf8aaede','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:25',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','cell1-CellControllerServiceChain-sfzpnsimaenh-UpgradeBatchTasks-p56qi2kwhpui','state changed','OS::Heat::Value',NULL,956),(1439,'45bb7097-135e-4335-bb83-bd94adf4fff0','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:25',NULL,'CREATE','COMPLETE','HostFirewallTasks','cell1-CellControllerServiceChain-sfzpnsimaenh-HostFirewallTasks-sf6wreli2agk','state changed','OS::Heat::Value',NULL,957),(1440,'5b20605d-06d6-496f-a449-6a296a9dad6a','005044b3-c8a4-4671-baac-b6e476540d1a','2026-06-12 08:26:25',NULL,'CREATE','IN_PROGRESS','DeploymentActions','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz-DeploymentActions-d2bpbhi6dwmt','state changed','OS::Heat::Value',NULL,958),(1441,'bbf58513-6a48-48d5-b3ff-494ebc504fb1','005044b3-c8a4-4671-baac-b6e476540d1a','2026-06-12 08:26:25',NULL,'CREATE','COMPLETE','DeploymentActions','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz-DeploymentActions-d2bpbhi6dwmt','state changed','OS::Heat::Value',NULL,958),(1442,'63f10c58-f935-48f4-8479-98f4aa4f07a4','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:25',NULL,'CREATE','IN_PROGRESS','UpdateTasks','cell1-CellControllerServiceChain-sfzpnsimaenh-UpdateTasks-6dzfi72h4trp','state changed','OS::Heat::Value',NULL,959),(1443,'7b4c6e6a-cc49-4bdd-bef4-3c974e743c4d','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:25',NULL,'CREATE','COMPLETE','UpdateTasks','cell1-CellControllerServiceChain-sfzpnsimaenh-UpdateTasks-6dzfi72h4trp','state changed','OS::Heat::Value',NULL,959),(1444,'6dcca2c8-97f8-496d-98f1-f2b8ff9bc707','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:25',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','cell1-CellControllerServiceChain-sfzpnsimaenh-ExternalPostDeployTasks-nmxkijzdhjne','state changed','OS::Heat::Value',NULL,961),(1445,'e3201aea-9895-4c61-a4a6-370d3a1842c2','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:25',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','cell1-CellControllerServiceChain-sfzpnsimaenh-PreUpgradeRollingTasks-ppyhhy2zyz3v','state changed','OS::Heat::Value',NULL,962),(1446,'2979e5b5-9010-4509-9efa-7297ce1cc8e2','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:25',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','cell1-CellControllerServiceChain-sfzpnsimaenh-PreUpgradeRollingTasks-ppyhhy2zyz3v','state changed','OS::Heat::Value',NULL,962),(1447,'aac7d6db-abe0-4cc9-b5e9-aa5dc051bf14','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:25',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','cell1-CellControllerServiceChain-sfzpnsimaenh-ExternalPostDeployTasks-nmxkijzdhjne','state changed','OS::Heat::Value',NULL,961),(1448,'0f32b67b-9d6f-4b43-ae1e-3b8e0136381c','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:25',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','cell1-CellControllerServiceChain-sfzpnsimaenh-MonitoringSubscriptionsConfig-5fobp77m5iu2','state changed','OS::Heat::Value',NULL,963),(1449,'5ed67230-4cca-4734-b104-786c2b73ef6c','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:25',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','cell1-CellControllerServiceChain-sfzpnsimaenh-MonitoringSubscriptionsConfig-5fobp77m5iu2','state changed','OS::Heat::Value',NULL,963),(1450,'704c0ef1-bb4c-411b-8f07-b64ba0416170','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:25',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','cell1-CellControllerServiceChain-sfzpnsimaenh-HostPrepTasks-cciqv6lcybuo','state changed','OS::Heat::Value',NULL,964),(1451,'86229c14-752c-4422-9307-3a2d38299af0','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:25',NULL,'CREATE','COMPLETE','HostPrepTasks','cell1-CellControllerServiceChain-sfzpnsimaenh-HostPrepTasks-cciqv6lcybuo','state changed','OS::Heat::Value',NULL,964),(1452,'4eeac621-374d-49e1-92fa-bde300a2c7d9','26c54eb2-2780-4b7b-bcdf-41980cc85dca','2026-06-12 08:26:25',NULL,'CREATE','IN_PROGRESS','ControlPlanePort','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz-NovaCompute-qzfq7rtmqelw-ControlPlanePort-kvqufn5fbcrt','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,966),(1453,'467e850b-b852-491a-a6fb-5b12e6ac0a78','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:25',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','cell1-CellControllerServiceChain-sfzpnsimaenh-PuppetStepConfig-afzspvczdrup','state changed','OS::Heat::Value',NULL,965),(1454,'48f6fa6a-761f-443d-8377-21c309396b85','153e5839-3ef6-4f1b-b594-4b814d2d54a6','2026-06-12 08:26:25',NULL,'CREATE','IN_PROGRESS','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz-NovaCompute-qzfq7rtmqelw-ControlPlanePort-kvqufn5fbcrt','153e5839-3ef6-4f1b-b594-4b814d2d54a6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1455,'807179e4-844f-453d-b1a3-ea68e3bebc03','153e5839-3ef6-4f1b-b594-4b814d2d54a6','2026-06-12 08:26:26',NULL,'CREATE','COMPLETE','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz-NovaCompute-qzfq7rtmqelw-ControlPlanePort-kvqufn5fbcrt','153e5839-3ef6-4f1b-b594-4b814d2d54a6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1456,'00a078d9-1d00-49d9-b7cc-1493577aa236','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:26',NULL,'CREATE','COMPLETE','PuppetStepConfig','cell1-CellControllerServiceChain-sfzpnsimaenh-PuppetStepConfig-afzspvczdrup','state changed','OS::Heat::Value',NULL,965),(1457,'7ed6e2f2-9314-43cc-86f6-70da61ac3d5d','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:26',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','cell1-CellControllerServiceChain-sfzpnsimaenh-ContainerPuppetTasks-7qq625bto3re','state changed','OS::Heat::Value',NULL,967),(1458,'46eaa524-4059-4510-bab5-338f97e3c312','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:26',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceConfigSettings-4x2bhdnfkc45','state changed','OS::Heat::Value',NULL,968),(1459,'470c7d8a-0ce5-4788-814c-cd8976d25b05','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:26',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','cell1-CellControllerServiceChain-sfzpnsimaenh-ContainerPuppetTasks-7qq625bto3re','state changed','OS::Heat::Value',NULL,967),(1460,'dc4b0fde-f6a0-4520-85c8-399a1885a758','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:26',NULL,'CREATE','COMPLETE','ServiceConfigSettings','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceConfigSettings-4x2bhdnfkc45','state changed','OS::Heat::Value',NULL,968),(1461,'1ea9b059-c2ed-4e8a-8ca2-74272455a5b8','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:26',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','cell1-CellControllerServiceChain-sfzpnsimaenh-PreDeployStepTasks-gbxtcqaiqjje','state changed','OS::Heat::Value',NULL,969),(1462,'25f15d7c-323a-438b-90c0-e14a37f39f27','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:26',NULL,'CREATE','COMPLETE','PreDeployStepTasks','cell1-CellControllerServiceChain-sfzpnsimaenh-PreDeployStepTasks-gbxtcqaiqjje','state changed','OS::Heat::Value',NULL,969),(1463,'e30484d4-292c-42ce-8386-48dd0946c92b','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:26',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','cell1-CellControllerServiceChain-sfzpnsimaenh-ExternalDeployTasks-atprgd5epqxm','state changed','OS::Heat::Value',NULL,970),(1464,'49e76d0b-fb66-4571-9b2e-870971526c9a','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:26',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','cell1-CellControllerServiceChain-sfzpnsimaenh-PostUpgradeTasks-q4sdpolmorlu','state changed','OS::Heat::Value',NULL,971),(1465,'890b8030-9fda-46fd-940e-41ed22d2fe1a','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:26',NULL,'CREATE','COMPLETE','ExternalDeployTasks','cell1-CellControllerServiceChain-sfzpnsimaenh-ExternalDeployTasks-atprgd5epqxm','state changed','OS::Heat::Value',NULL,970),(1466,'09024dad-7463-4193-90f4-e7c531265140','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:26',NULL,'CREATE','COMPLETE','PostUpgradeTasks','cell1-CellControllerServiceChain-sfzpnsimaenh-PostUpgradeTasks-q4sdpolmorlu','state changed','OS::Heat::Value',NULL,971),(1467,'5adda639-80ae-4882-8319-efab41a5fc92','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:26',NULL,'CREATE','IN_PROGRESS','KollaConfig','cell1-CellControllerServiceChain-sfzpnsimaenh-KollaConfig-zltgb22hpn7f','state changed','OS::Heat::Value',NULL,972),(1468,'fc6c81b7-4bf7-469f-84f4-02f274c10da3','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:26',NULL,'CREATE','COMPLETE','KollaConfig','cell1-CellControllerServiceChain-sfzpnsimaenh-KollaConfig-zltgb22hpn7f','state changed','OS::Heat::Value',NULL,972),(1469,'6f60fc15-0ad2-40be-8b26-cf756f3a401e','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:26',NULL,'CREATE','IN_PROGRESS','PuppetConfig','cell1-CellControllerServiceChain-sfzpnsimaenh-PuppetConfig-qsim6hhmg36c','state changed','OS::Heat::Value',NULL,973),(1470,'60cf123c-d119-44e8-a0cc-6fde9485e599','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:26',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','cell1-CellControllerServiceChain-sfzpnsimaenh-GlobalConfigSettings-3rqcgd676prw','state changed','OS::Heat::Value',NULL,974),(1471,'5f101460-97a4-40e9-bb37-5bbc57e42581','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:26',NULL,'CREATE','COMPLETE','PuppetConfig','cell1-CellControllerServiceChain-sfzpnsimaenh-PuppetConfig-qsim6hhmg36c','state changed','OS::Heat::Value',NULL,973),(1472,'76c37aff-5ac7-43b8-b5a3-267162ba59bd','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:26',NULL,'CREATE','COMPLETE','GlobalConfigSettings','cell1-CellControllerServiceChain-sfzpnsimaenh-GlobalConfigSettings-3rqcgd676prw','state changed','OS::Heat::Value',NULL,974),(1473,'26e49283-20c0-4519-8e0d-cbfe1659e68c','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:26',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','cell1-CellControllerServiceChain-sfzpnsimaenh-ServiceServerMetadataHook-tpyzqfhr6ako','state changed','OS::TripleO::CellControllerServiceServerMetadataHook',NULL,NULL),(1474,'df1ee162-7230-49be-9136-0d002c6dbc1a','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:26',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','6c98ea3b-8b03-4f37-b860-43c0b3be9cd4','state changed','OS::TripleO::CellControllerServiceServerMetadataHook',NULL,NULL),(1475,'7ecdd528-9904-4fe2-b28a-edd81a270d4d','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:26',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','cell1-CellControllerServiceChain-sfzpnsimaenh-DockerConfigScripts-vzkqd3kootl5','state changed','OS::Heat::Value',NULL,975),(1476,'0c4352c5-3906-4eae-8de4-b08a0e2bea0f','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:26',NULL,'CREATE','COMPLETE','DockerConfigScripts','cell1-CellControllerServiceChain-sfzpnsimaenh-DockerConfigScripts-vzkqd3kootl5','state changed','OS::Heat::Value',NULL,975),(1477,'ecab294b-628e-4895-9dec-15c106b7f118','26c54eb2-2780-4b7b-bcdf-41980cc85dca','2026-06-12 08:26:27',NULL,'CREATE','COMPLETE','ControlPlanePort','153e5839-3ef6-4f1b-b594-4b814d2d54a6','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,966),(1478,'4a405e6d-8531-4697-a306-1fbb6272c5f2','26c54eb2-2780-4b7b-bcdf-41980cc85dca','2026-06-12 08:26:27',NULL,'CREATE','COMPLETE','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz-NovaCompute-qzfq7rtmqelw','26c54eb2-2780-4b7b-bcdf-41980cc85dca','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1479,'ca56bbb4-f2ca-4d2b-9471-ce83e262300f','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:27',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','cell1-CellControllerServiceChain-sfzpnsimaenh-ExternalUpgradeTasks-rvw6n5zbesmy','state changed','OS::Heat::Value',NULL,976),(1480,'2abc87cf-fd11-4cd2-a0fc-2e2ca9b9c48b','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:27',NULL,'CREATE','IN_PROGRESS','FirewallRules','cell1-CellControllerServiceChain-sfzpnsimaenh-FirewallRules-a5bvjg4kayhy','state changed','OS::Heat::Value',NULL,977),(1481,'b189f8a1-c406-4393-bd4f-5ffb0a62eed0','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:27',NULL,'CREATE','COMPLETE','FirewallRules','cell1-CellControllerServiceChain-sfzpnsimaenh-FirewallRules-a5bvjg4kayhy','state changed','OS::Heat::Value',NULL,977),(1482,'dbabff89-ebd4-447f-8035-4faafef669a3','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:27',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','cell1-CellControllerServiceChain-sfzpnsimaenh-ExternalUpgradeTasks-rvw6n5zbesmy','state changed','OS::Heat::Value',NULL,976),(1483,'b6df99a7-c413-4116-a95f-32deb50cece2','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:27',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','cell1-CellControllerServiceChain-sfzpnsimaenh-DeployStepsTasks-csipjajybvq4','state changed','OS::Heat::Value',NULL,978),(1484,'f6021afe-56ec-4b01-b9bf-dd4275328819','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:27',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','cell1-CellControllerServiceChain-sfzpnsimaenh-ExternalUpdateTasks-dyfmxm6chuyr','state changed','OS::Heat::Value',NULL,979),(1485,'fa3fe7d6-d360-46fb-bceb-c4b4ad6faa85','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:27',NULL,'CREATE','COMPLETE','DeployStepsTasks','cell1-CellControllerServiceChain-sfzpnsimaenh-DeployStepsTasks-csipjajybvq4','state changed','OS::Heat::Value',NULL,978),(1486,'ccde3f28-c176-4d10-b01a-d61d61ae5254','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:27',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','cell1-CellControllerServiceChain-sfzpnsimaenh-ExternalUpdateTasks-dyfmxm6chuyr','state changed','OS::Heat::Value',NULL,979),(1487,'04a2634e-0066-49da-96c9-deebbca2fde2','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:27',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','cell1-CellControllerServiceChain-sfzpnsimaenh-KeystoneResourcesConfigs-6odn4l5hz5pn','state changed','OS::Heat::Value',NULL,980),(1488,'cde96ad7-a38e-4cfe-8bf7-24fe06e4eb3a','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:27',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','cell1-CellControllerServiceChain-sfzpnsimaenh-KeystoneResourcesConfigs-6odn4l5hz5pn','state changed','OS::Heat::Value',NULL,980),(1489,'b0fb2e9d-6854-4751-ae9c-6c7fe96d346a','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:27',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','cell1-CellControllerServiceChain-sfzpnsimaenh-IpaRegistrationTasks-thiwm5yphbvv','state changed','OS::Heat::Value',NULL,982),(1490,'dbc193b1-1f47-4498-bcf1-c935b06e5a76','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:27',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','cell1-CellControllerServiceChain-sfzpnsimaenh-IpaRegistrationTasks-thiwm5yphbvv','state changed','OS::Heat::Value',NULL,982),(1491,'1c3acb24-af5e-4d71-8f96-e9f38ae5ac79','30720dfb-21ea-49b3-a244-ecd4aa95b259','2026-06-12 08:26:27',NULL,'CREATE','COMPLETE','cell1-CellControllerServiceChain-sfzpnsimaenh','30720dfb-21ea-49b3-a244-ecd4aa95b259','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1492,'175d4994-4f38-4b3c-b2dc-93757d226718','005044b3-c8a4-4671-baac-b6e476540d1a','2026-06-12 08:26:27',NULL,'CREATE','COMPLETE','NovaCompute','26c54eb2-2780-4b7b-bcdf-41980cc85dca','state changed','OS::TripleO::ComputeServer',NULL,946),(1493,'d7cc269e-8384-45be-860e-d25b7c1e78fc','005044b3-c8a4-4671-baac-b6e476540d1a','2026-06-12 08:26:27',NULL,'CREATE','IN_PROGRESS','StoragePort','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz-StoragePort-3hlb3qbjmell','state changed','OS::TripleO::Compute::Ports::StoragePort',NULL,984),(1494,'594dd87c-ec5f-439b-a676-118c5a23fb81','005044b3-c8a4-4671-baac-b6e476540d1a','2026-06-12 08:26:28',NULL,'CREATE','IN_PROGRESS','TenantPort','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz-TenantPort-layixbxp2iix','state changed','OS::TripleO::Compute::Ports::TenantPort',NULL,985),(1495,'aad17792-fb71-4ab9-bc5a-ac55b0ece44f','005044b3-c8a4-4671-baac-b6e476540d1a','2026-06-12 08:26:28',NULL,'CREATE','IN_PROGRESS','NetHostMap','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz-NetHostMap-unzyvmb2evw7','state changed','OS::Heat::Value',NULL,986),(1496,'5f38bddb-a384-4215-b152-8eceb5310d4d','005044b3-c8a4-4671-baac-b6e476540d1a','2026-06-12 08:26:28',NULL,'CREATE','COMPLETE','NetHostMap','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz-NetHostMap-unzyvmb2evw7','state changed','OS::Heat::Value',NULL,986),(1497,'8ee4b9ee-7008-4047-aa5b-8972e8c4de80','005044b3-c8a4-4671-baac-b6e476540d1a','2026-06-12 08:26:28',NULL,'CREATE','IN_PROGRESS','ComputeExtraConfigPre','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz-ComputeExtraConfigPre-ngh2csyjszxn','state changed','OS::TripleO::ComputeExtraConfigPre',NULL,987),(1498,'25a39628-2373-4ac9-96ee-3a088d037605','005044b3-c8a4-4671-baac-b6e476540d1a','2026-06-12 08:26:28',NULL,'CREATE','IN_PROGRESS','PreNetworkConfig','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz-PreNetworkConfig-i2vkfmznxtkr','state changed','OS::TripleO::Compute::PreNetworkConfig',NULL,NULL),(1499,'9b13934e-c324-4890-86e3-cb647ca99d4a','3c6267b4-fba3-4c1d-af0c-e0426f4c3ebf','2026-06-12 08:26:28',NULL,'CREATE','IN_PROGRESS','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz-StoragePort-3hlb3qbjmell','3c6267b4-fba3-4c1d-af0c-e0426f4c3ebf','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1500,'930b307a-08c3-4126-bbaa-f6073f625d83','581565b6-8a52-4109-bda0-4596a49bb028','2026-06-12 08:26:28',NULL,'CREATE','IN_PROGRESS','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz-TenantPort-layixbxp2iix','581565b6-8a52-4109-bda0-4596a49bb028','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1501,'9faeef98-7204-4836-a1bd-a804deb24f99','005044b3-c8a4-4671-baac-b6e476540d1a','2026-06-12 08:26:28',NULL,'CREATE','COMPLETE','PreNetworkConfig','34258eaf-2c8d-4313-b98e-c4a528a36520','state changed','OS::TripleO::Compute::PreNetworkConfig',NULL,NULL),(1502,'c4fd9651-7302-4edf-a1ab-cbdf880355c0','005044b3-c8a4-4671-baac-b6e476540d1a','2026-06-12 08:26:28',NULL,'CREATE','IN_PROGRESS','InternalApiPort','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz-InternalApiPort-umskyqlqho4y','state changed','OS::TripleO::Compute::Ports::InternalApiPort',NULL,989),(1503,'cce524cf-c076-4844-9d57-04ac7e2072b0','005044b3-c8a4-4671-baac-b6e476540d1a','2026-06-12 08:26:28',NULL,'CREATE','IN_PROGRESS','NodeTLSCAData','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz-NodeTLSCAData-ukuxzjlwjig3','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(1504,'53210d20-c744-48b5-8ca5-84c5bf234527','005044b3-c8a4-4671-baac-b6e476540d1a','2026-06-12 08:26:28',NULL,'CREATE','IN_PROGRESS','NovaComputeAnsibleHostVars','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz-NovaComputeAnsibleHostVars-4e5vaiy5scec','state changed','OS::Heat::Value',NULL,991),(1505,'c793fa87-e3a1-49de-bb03-506d20274768','005044b3-c8a4-4671-baac-b6e476540d1a','2026-06-12 08:26:28',NULL,'CREATE','COMPLETE','NovaComputeAnsibleHostVars','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz-NovaComputeAnsibleHostVars-4e5vaiy5scec','state changed','OS::Heat::Value',NULL,991),(1506,'c4af8375-3849-44ce-ba30-f2bfc260554c','6e2d3681-b39e-494c-971a-dd6fff875c7e','2026-06-12 08:26:28',NULL,'CREATE','IN_PROGRESS','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz-ComputeExtraConfigPre-ngh2csyjszxn','6e2d3681-b39e-494c-971a-dd6fff875c7e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1507,'28fd65cd-06ee-4537-8dc6-739427869af0','005044b3-c8a4-4671-baac-b6e476540d1a','2026-06-12 08:26:28',NULL,'CREATE','COMPLETE','NodeTLSCAData','142b3950-414f-4782-b8fc-568ed5a9c98c','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(1508,'fae4e1d5-06a9-4bf7-a6f8-db3fdde21aac','62c22519-8060-40cd-af51-8e1d4ca367de','2026-06-12 08:26:28',NULL,'CREATE','IN_PROGRESS','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz-InternalApiPort-umskyqlqho4y','62c22519-8060-40cd-af51-8e1d4ca367de','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1509,'0293edb4-7cd1-4170-a7d4-f2c21d5f1b90','3c6267b4-fba3-4c1d-af0c-e0426f4c3ebf','2026-06-12 08:26:28',NULL,'CREATE','IN_PROGRESS','StorageDeployedPort','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz-StoragePort-3hlb3qbjmell-StorageDeployedPort-dn3dbik6od2k','state changed','OS::Heat::Value',NULL,992),(1510,'ce26d00e-80b0-4fa1-95c3-8fc7d1d02028','3c6267b4-fba3-4c1d-af0c-e0426f4c3ebf','2026-06-12 08:26:28',NULL,'CREATE','COMPLETE','StorageDeployedPort','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz-StoragePort-3hlb3qbjmell-StorageDeployedPort-dn3dbik6od2k','state changed','OS::Heat::Value',NULL,992),(1511,'958e6c39-4c37-414a-a5d0-53703dbd60f0','3c6267b4-fba3-4c1d-af0c-e0426f4c3ebf','2026-06-12 08:26:28',NULL,'CREATE','COMPLETE','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz-StoragePort-3hlb3qbjmell','3c6267b4-fba3-4c1d-af0c-e0426f4c3ebf','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1512,'537837f8-c707-48b9-ae35-2f2c86b54559','6e2d3681-b39e-494c-971a-dd6fff875c7e','2026-06-12 08:26:28',NULL,'CREATE','COMPLETE','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz-ComputeExtraConfigPre-ngh2csyjszxn','6e2d3681-b39e-494c-971a-dd6fff875c7e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1513,'44ccde41-421b-4af6-b38b-42fb50aacf1d','581565b6-8a52-4109-bda0-4596a49bb028','2026-06-12 08:26:28',NULL,'CREATE','IN_PROGRESS','TenantDeployedPort','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz-TenantPort-layixbxp2iix-TenantDeployedPort-avxlbkjlvrdi','state changed','OS::Heat::Value',NULL,993),(1514,'f9b4e77a-a2a2-4896-92ee-08c056a60a5a','581565b6-8a52-4109-bda0-4596a49bb028','2026-06-12 08:26:28',NULL,'CREATE','COMPLETE','TenantDeployedPort','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz-TenantPort-layixbxp2iix-TenantDeployedPort-avxlbkjlvrdi','state changed','OS::Heat::Value',NULL,993),(1515,'55d291fa-52a4-4849-8d17-9f89a835f8a9','581565b6-8a52-4109-bda0-4596a49bb028','2026-06-12 08:26:28',NULL,'CREATE','COMPLETE','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz-TenantPort-layixbxp2iix','581565b6-8a52-4109-bda0-4596a49bb028','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1516,'c9ec4796-52bf-439f-bf16-ba0238ef6153','62c22519-8060-40cd-af51-8e1d4ca367de','2026-06-12 08:26:28',NULL,'CREATE','IN_PROGRESS','InternalApiDeployedPort','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz-InternalApiPort-umskyqlqho4y-InternalApiDeployedPort-pcocz4r6c57e','state changed','OS::Heat::Value',NULL,994),(1517,'01d3c0c0-1541-4784-be16-77e820c5801e','62c22519-8060-40cd-af51-8e1d4ca367de','2026-06-12 08:26:28',NULL,'CREATE','COMPLETE','InternalApiDeployedPort','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz-InternalApiPort-umskyqlqho4y-InternalApiDeployedPort-pcocz4r6c57e','state changed','OS::Heat::Value',NULL,994),(1518,'2730bc88-061f-49da-9906-57ad1a0ca6b9','62c22519-8060-40cd-af51-8e1d4ca367de','2026-06-12 08:26:28',NULL,'CREATE','COMPLETE','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz-InternalApiPort-umskyqlqho4y','62c22519-8060-40cd-af51-8e1d4ca367de','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1519,'a44edb62-f6ee-425d-a000-d048a570e13a','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:28',NULL,'CREATE','COMPLETE','CellControllerServiceChain','30720dfb-21ea-49b3-a244-ecd4aa95b259','state changed','OS::TripleO::CellControllerServices',NULL,74),(1520,'99b89361-f56b-41b3-8df2-cd8d42a6f755','005044b3-c8a4-4671-baac-b6e476540d1a','2026-06-12 08:26:29',NULL,'CREATE','COMPLETE','StoragePort','3c6267b4-fba3-4c1d-af0c-e0426f4c3ebf','state changed','OS::TripleO::Compute::Ports::StoragePort',NULL,984),(1521,'bc64de30-a065-419a-a952-dfd6c8303ac6','005044b3-c8a4-4671-baac-b6e476540d1a','2026-06-12 08:26:29',NULL,'CREATE','COMPLETE','TenantPort','581565b6-8a52-4109-bda0-4596a49bb028','state changed','OS::TripleO::Compute::Ports::TenantPort',NULL,985),(1522,'0100bfff-3d31-4119-9365-46a366cbc74b','005044b3-c8a4-4671-baac-b6e476540d1a','2026-06-12 08:26:29',NULL,'CREATE','COMPLETE','InternalApiPort','62c22519-8060-40cd-af51-8e1d4ca367de','state changed','OS::TripleO::Compute::Ports::InternalApiPort',NULL,989),(1523,'e986f385-7ca8-4d47-8dcc-41a7f103d88c','005044b3-c8a4-4671-baac-b6e476540d1a','2026-06-12 08:26:29',NULL,'CREATE','COMPLETE','ComputeExtraConfigPre','6e2d3681-b39e-494c-971a-dd6fff875c7e','state changed','OS::TripleO::ComputeExtraConfigPre',NULL,987),(1524,'4b6d8eb4-ed17-4b99-9c2a-3e09379c3e3a','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:29',NULL,'CREATE','IN_PROGRESS','CellControllerServiceChainRoleData','cell1-CellControllerServiceChainRoleData-b5q4efqi7hkw','state changed','OS::Heat::Value',NULL,1032),(1525,'248fd4f4-8bba-4e65-8854-f13af0d4a626','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:29',NULL,'CREATE','COMPLETE','CellControllerServiceChainRoleData','cell1-CellControllerServiceChainRoleData-b5q4efqi7hkw','state changed','OS::Heat::Value',NULL,1032),(1526,'1c2f5d2d-4917-4b51-baaa-f346eda653d8','005044b3-c8a4-4671-baac-b6e476540d1a','2026-06-12 08:26:29',NULL,'CREATE','IN_PROGRESS','NodeExtraConfig','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz-NodeExtraConfig-nkwpjyed445o','state changed','OS::TripleO::NodeExtraConfig',NULL,1035),(1527,'cea94ec3-cdfe-497a-8af7-a4bd8ba1d022','005044b3-c8a4-4671-baac-b6e476540d1a','2026-06-12 08:26:29',NULL,'CREATE','IN_PROGRESS','NetIpMap','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz-NetIpMap-pqk76wxqbpqk','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1037),(1528,'6d7b1ce2-0c98-4a91-bef5-83c0cb6962b3','6ef8a9fb-2630-4121-a2e5-9c6176b2d72c','2026-06-12 08:26:29',NULL,'CREATE','IN_PROGRESS','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz-NetIpMap-pqk76wxqbpqk','6ef8a9fb-2630-4121-a2e5-9c6176b2d72c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1529,'d13cce9f-0376-4c7b-9062-3eab123740df','4202c238-5ec7-408a-858a-40a1fbb642bb','2026-06-12 08:26:29',NULL,'CREATE','IN_PROGRESS','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz-NodeExtraConfig-nkwpjyed445o','4202c238-5ec7-408a-858a-40a1fbb642bb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1530,'adc56212-980a-43ea-9255-7b58cfec8539','6ef8a9fb-2630-4121-a2e5-9c6176b2d72c','2026-06-12 08:26:29',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz-NetIpMap-pqk76wxqbpqk-NetIpMapValue-xfrbhwiaw6fj','state changed','OS::Heat::Value',NULL,1038),(1531,'58f0f3f9-d5c1-4aca-8777-25c1060c4923','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:29',NULL,'CREATE','IN_PROGRESS','ComputeServiceConfigSettings','cell1-ComputeServiceConfigSettings-34hgldg5ywef','state changed','OS::Heat::Value',NULL,1039),(1532,'d442b57c-9389-4c7b-9973-0f0a5faf229d','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:29',NULL,'CREATE','COMPLETE','ComputeServiceConfigSettings','cell1-ComputeServiceConfigSettings-34hgldg5ywef','state changed','OS::Heat::Value',NULL,1039),(1533,'15204c66-0158-4e00-9dc3-3dbbaf06fca5','4202c238-5ec7-408a-858a-40a1fbb642bb','2026-06-12 08:26:29',NULL,'CREATE','COMPLETE','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz-NodeExtraConfig-nkwpjyed445o','4202c238-5ec7-408a-858a-40a1fbb642bb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1534,'c3ece436-19b0-4200-8ad8-159b553114d9','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:29',NULL,'CREATE','IN_PROGRESS','CellControllerServiceNames','cell1-CellControllerServiceNames-y5jcix3qudkj','state changed','OS::Heat::Value',NULL,1041),(1535,'b04e133c-e2f6-45dd-9045-61d9b3c4d62a','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:29',NULL,'CREATE','COMPLETE','CellControllerServiceNames','cell1-CellControllerServiceNames-y5jcix3qudkj','state changed','OS::Heat::Value',NULL,1041),(1536,'21f51280-ee0c-45f2-b95f-b6239cdec091','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:29',NULL,'CREATE','IN_PROGRESS','CephStorageServiceConfigSettings','cell1-CephStorageServiceConfigSettings-fqqtytkfi4ne','state changed','OS::Heat::Value',NULL,1042),(1537,'734dd898-e81a-45b9-8efe-d4c5620112fb','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:29',NULL,'CREATE','COMPLETE','CephStorageServiceConfigSettings','cell1-CephStorageServiceConfigSettings-fqqtytkfi4ne','state changed','OS::Heat::Value',NULL,1042),(1538,'04c9f655-a39e-41ec-8fb4-1118f5f8ceec','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:29',NULL,'CREATE','IN_PROGRESS','ComputeConfigData','cell1-ComputeConfigData-5w3ettqlugaw','state changed','OS::Heat::Value',NULL,1043),(1539,'07175213-f46b-4cda-b6f1-26fc28a47373','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:29',NULL,'CREATE','COMPLETE','ComputeConfigData','cell1-ComputeConfigData-5w3ettqlugaw','state changed','OS::Heat::Value',NULL,1043),(1540,'461e2b1c-2e29-4314-954a-90be9191342d','6ef8a9fb-2630-4121-a2e5-9c6176b2d72c','2026-06-12 08:26:29',NULL,'CREATE','COMPLETE','NetIpMapValue','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz-NetIpMap-pqk76wxqbpqk-NetIpMapValue-xfrbhwiaw6fj','state changed','OS::Heat::Value',NULL,1038),(1541,'7bda3d0d-8ae2-4637-a446-6dbe56067104','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:29',NULL,'CREATE','IN_PROGRESS','CephStorageConfigData','cell1-CephStorageConfigData-vjxzq6hzljj4','state changed','OS::Heat::Value',NULL,1046),(1542,'da238707-4e3e-4938-9a17-efbcf40b5f8c','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:29',NULL,'CREATE','COMPLETE','CephStorageConfigData','cell1-CephStorageConfigData-vjxzq6hzljj4','state changed','OS::Heat::Value',NULL,1046),(1543,'6fc82c7c-8eac-4578-b5a1-5cef8c4686be','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:30',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServiceConfigSettings','cell1-CellControllerComputeServiceConfigSettings-72bn42b4elms','state changed','OS::Heat::Value',NULL,1045),(1544,'e78ac064-ac9c-4ecf-8057-5b3214e2d0a5','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:30',NULL,'CREATE','COMPLETE','CellControllerComputeServiceConfigSettings','cell1-CellControllerComputeServiceConfigSettings-72bn42b4elms','state changed','OS::Heat::Value',NULL,1045),(1545,'8d545501-0769-4714-a9b8-26190e03a9c9','6ef8a9fb-2630-4121-a2e5-9c6176b2d72c','2026-06-12 08:26:30',NULL,'CREATE','COMPLETE','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz-NetIpMap-pqk76wxqbpqk','6ef8a9fb-2630-4121-a2e5-9c6176b2d72c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1546,'2a3be4c1-8434-48f3-a1e8-6af49715d744','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:30',NULL,'CREATE','IN_PROGRESS','BlockStorageServiceConfigSettings','cell1-BlockStorageServiceConfigSettings-cw4cf2sdxmyr','state changed','OS::Heat::Value',NULL,1048),(1547,'4e0a8aaa-389b-4cc3-b310-49311f0f3a6b','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:30',NULL,'CREATE','COMPLETE','BlockStorageServiceConfigSettings','cell1-BlockStorageServiceConfigSettings-cw4cf2sdxmyr','state changed','OS::Heat::Value',NULL,1048),(1548,'531c09cc-2332-43f9-86d9-f6c0d683cbb7','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:30',NULL,'CREATE','IN_PROGRESS','CellControllerComputeConfigData','cell1-CellControllerComputeConfigData-pixrjubj5yci','state changed','OS::Heat::Value',NULL,1051),(1549,'7fbb7104-ddda-4f98-8990-16e911caac6a','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:30',NULL,'CREATE','IN_PROGRESS','ControllerServiceConfigSettings','cell1-ControllerServiceConfigSettings-cvoyawjuhxbq','state changed','OS::Heat::Value',NULL,1052),(1550,'03441a5c-78b5-48e6-b0e3-eeb048814c6c','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:30',NULL,'CREATE','IN_PROGRESS','BlockStorageConfigData','cell1-BlockStorageConfigData-pwe3vjjak5jr','state changed','OS::Heat::Value',NULL,1053),(1551,'fee0ce65-6a0a-4ef9-8dcb-299cf3669f8e','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:30',NULL,'CREATE','COMPLETE','CellControllerComputeConfigData','cell1-CellControllerComputeConfigData-pixrjubj5yci','state changed','OS::Heat::Value',NULL,1051),(1552,'1380125b-9ed3-4993-a5ee-d07b3cc6f91a','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:30',NULL,'CREATE','COMPLETE','BlockStorageConfigData','cell1-BlockStorageConfigData-pwe3vjjak5jr','state changed','OS::Heat::Value',NULL,1053),(1553,'b14f8118-9f9e-4990-ab7c-858728bb73f4','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:30',NULL,'CREATE','COMPLETE','ControllerServiceConfigSettings','cell1-ControllerServiceConfigSettings-cvoyawjuhxbq','state changed','OS::Heat::Value',NULL,1052),(1554,'188dba2d-0ee8-448c-b09d-2c0552dce876','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:30',NULL,'CREATE','IN_PROGRESS','CellControllerServiceConfigSettings','cell1-CellControllerServiceConfigSettings-p6wuykrklp3k','state changed','OS::Heat::Value',NULL,1055),(1555,'5104693b-135b-4e14-bdfc-1aaec996cd9b','005044b3-c8a4-4671-baac-b6e476540d1a','2026-06-12 08:26:30',NULL,'CREATE','COMPLETE','NetIpMap','6ef8a9fb-2630-4121-a2e5-9c6176b2d72c','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1037),(1556,'6cf144a3-6c81-40f9-aa3f-dc27528ca807','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:30',NULL,'CREATE','COMPLETE','CellControllerServiceConfigSettings','cell1-CellControllerServiceConfigSettings-p6wuykrklp3k','state changed','OS::Heat::Value',NULL,1055),(1557,'64d38910-2c5f-4164-a97c-eaad66a2bcd2','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:30',NULL,'CREATE','IN_PROGRESS','ControllerConfigData','cell1-ControllerConfigData-7lpoqjl5c2ft','state changed','OS::Heat::Value',NULL,1057),(1558,'00603696-6ba5-4fb6-9633-ca1559ac8d23','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:30',NULL,'CREATE','COMPLETE','ControllerConfigData','cell1-ControllerConfigData-7lpoqjl5c2ft','state changed','OS::Heat::Value',NULL,1057),(1559,'84c39d23-239d-47df-ad57-6cd030c5dcba','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:30',NULL,'CREATE','IN_PROGRESS','GlobalConfig','cell1-GlobalConfig-3bo4ksega4vu','state changed','OS::Heat::Value',NULL,1058),(1560,'d28d1e1e-1ff8-4f3f-9190-62589190ff12','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:30',NULL,'CREATE','COMPLETE','GlobalConfig','cell1-GlobalConfig-3bo4ksega4vu','state changed','OS::Heat::Value',NULL,1058),(1561,'6b9ed988-e1df-475a-aa88-9d400e872d5a','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:30',NULL,'CREATE','IN_PROGRESS','ObjectStorageServiceConfigSettings','cell1-ObjectStorageServiceConfigSettings-yk6qlfprqctt','state changed','OS::Heat::Value',NULL,1059),(1562,'597febdf-77ee-4a39-9ba8-925a379c00e1','005044b3-c8a4-4671-baac-b6e476540d1a','2026-06-12 08:26:30',NULL,'CREATE','COMPLETE','NodeExtraConfig','4202c238-5ec7-408a-858a-40a1fbb642bb','state changed','OS::TripleO::NodeExtraConfig',NULL,1035),(1563,'bcc7e9fa-7a92-4341-a672-b46d45efb6bc','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:30',NULL,'CREATE','COMPLETE','ObjectStorageServiceConfigSettings','cell1-ObjectStorageServiceConfigSettings-yk6qlfprqctt','state changed','OS::Heat::Value',NULL,1059),(1564,'74ea231d-f460-4859-9cbb-9220166f0b91','005044b3-c8a4-4671-baac-b6e476540d1a','2026-06-12 08:26:30',NULL,'CREATE','COMPLETE','cell1-Compute-i4fnxllhuqlt-0-7vaqbgvti2rz','005044b3-c8a4-4671-baac-b6e476540d1a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1565,'fc851635-f7d8-4978-aa8c-c085577d5059','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:30',NULL,'CREATE','IN_PROGRESS','CellControllerConfigData','cell1-CellControllerConfigData-xdq3yquonc5e','state changed','OS::Heat::Value',NULL,1060),(1566,'eb56bad7-30b4-4298-865f-6e3534bbbfd7','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:30',NULL,'CREATE','COMPLETE','CellControllerConfigData','cell1-CellControllerConfigData-xdq3yquonc5e','state changed','OS::Heat::Value',NULL,1060),(1567,'9ad03e97-8052-402b-aac2-0aa919963079','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:30',NULL,'CREATE','IN_PROGRESS','ObjectStorageConfigData','cell1-ObjectStorageConfigData-rg5onluyzykd','state changed','OS::Heat::Value',NULL,1062),(1568,'5006fef2-a275-4273-80e0-3bbdc48ee16b','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:30',NULL,'CREATE','IN_PROGRESS','NetworkerServiceConfigSettings','cell1-NetworkerServiceConfigSettings-4tiocevocal6','state changed','OS::Heat::Value',NULL,1063),(1569,'febb76e0-ef08-4165-8f3d-d5fb1026e3cf','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:30',NULL,'CREATE','COMPLETE','ObjectStorageConfigData','cell1-ObjectStorageConfigData-rg5onluyzykd','state changed','OS::Heat::Value',NULL,1062),(1570,'27cd18bb-436c-45b4-adfe-8ad3fc8d70be','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:31',NULL,'CREATE','COMPLETE','NetworkerServiceConfigSettings','cell1-NetworkerServiceConfigSettings-4tiocevocal6','state changed','OS::Heat::Value',NULL,1063),(1571,'ecd9e823-180c-4987-813a-8759bfc01e6d','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:31',NULL,'CREATE','IN_PROGRESS','CellController','cell1-CellController-bajiesbmvbnn','state changed','OS::Heat::ResourceGroup',NULL,1064),(1572,'1437fb87-4772-43fa-9c28-87a7428caf6a','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:31',NULL,'CREATE','IN_PROGRESS','NetworkerConfigData','cell1-NetworkerConfigData-ztvawp3dutcb','state changed','OS::Heat::Value',NULL,1067),(1573,'b1b43dab-57b2-48cf-b3d2-561099c9bc28','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:31',NULL,'CREATE','COMPLETE','NetworkerConfigData','cell1-NetworkerConfigData-ztvawp3dutcb','state changed','OS::Heat::Value',NULL,1067),(1574,'98ce9f91-cfdc-41e4-8bab-b7dc63697adb','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:31',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','cell1-FirewallFrontendRules-6qhug7ou6jk2','state changed','OS::Heat::Value',NULL,1068),(1575,'950fcdb4-bb79-430d-a20b-012733017de8','981ae83c-ed43-46a9-98c5-2e054d3f88ab','2026-06-12 08:26:31',NULL,'CREATE','IN_PROGRESS','cell1-CellController-bajiesbmvbnn','981ae83c-ed43-46a9-98c5-2e054d3f88ab','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1576,'2c74e074-2019-4c8c-9d9b-64884f3a8cf1','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:31',NULL,'CREATE','COMPLETE','FirewallFrontendRules','cell1-FirewallFrontendRules-6qhug7ou6jk2','state changed','OS::Heat::Value',NULL,1068),(1577,'00ba1f56-8da1-46aa-bd90-d1f34907b4dd','981ae83c-ed43-46a9-98c5-2e054d3f88ab','2026-06-12 08:26:31',NULL,'CREATE','COMPLETE','cell1-CellController-bajiesbmvbnn','981ae83c-ed43-46a9-98c5-2e054d3f88ab','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1578,'abee5285-c4d7-445d-8d25-bb41ec842bfe','d9b1942a-b512-41cf-8930-ff20a5f2f41d','2026-06-12 08:26:31',NULL,'CREATE','COMPLETE','0','005044b3-c8a4-4671-baac-b6e476540d1a','state changed','OS::TripleO::Compute',NULL,937),(1579,'760e36c2-b841-487c-8d18-51ca2b8a2096','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:31',NULL,'CREATE','IN_PROGRESS','CephStorageGroupVars','cell1-CephStorageGroupVars-aya3fhtwwfi2','state changed','OS::Heat::Value',NULL,1069),(1580,'553c363a-a513-47ea-9425-a7058af7e9e2','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:31',NULL,'CREATE','IN_PROGRESS','ControllerGroupVars','cell1-ControllerGroupVars-obnql6uoadna','state changed','OS::Heat::Value',NULL,1070),(1581,'b37a5523-9b27-4a77-9e3f-dcaed88313f6','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:31',NULL,'CREATE','COMPLETE','CephStorageGroupVars','cell1-CephStorageGroupVars-aya3fhtwwfi2','state changed','OS::Heat::Value',NULL,1069),(1582,'d68a4346-3596-41cd-b834-752a81f81638','d9b1942a-b512-41cf-8930-ff20a5f2f41d','2026-06-12 08:26:31',NULL,'UPDATE','COMPLETE','cell1-Compute-i4fnxllhuqlt','d9b1942a-b512-41cf-8930-ff20a5f2f41d','Stack UPDATE completed successfully','OS::Heat::Stack',NULL,NULL),(1583,'0c360364-996d-4942-954b-8401823fc71f','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:31',NULL,'CREATE','COMPLETE','ControllerGroupVars','cell1-ControllerGroupVars-obnql6uoadna','state changed','OS::Heat::Value',NULL,1070),(1584,'4c3e49df-94a7-4bac-a4b5-ea46104e858d','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:31',NULL,'CREATE','IN_PROGRESS','NetworkerGroupVars','cell1-NetworkerGroupVars-65r6i7imxxs7','state changed','OS::Heat::Value',NULL,1071),(1585,'0f920549-c013-4a62-b163-f3d499357d0d','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:31',NULL,'CREATE','COMPLETE','NetworkerGroupVars','cell1-NetworkerGroupVars-65r6i7imxxs7','state changed','OS::Heat::Value',NULL,1071),(1586,'702b0bcd-91c2-48e1-9fd9-5b3c0dc24aa6','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:31',NULL,'CREATE','IN_PROGRESS','CellControllerGroupVars','cell1-CellControllerGroupVars-4x5wtublqrj2','state changed','OS::Heat::Value',NULL,1072),(1587,'784b582b-76ef-4d06-86d3-8e4a2d2f8594','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:31',NULL,'CREATE','COMPLETE','CellControllerGroupVars','cell1-CellControllerGroupVars-4x5wtublqrj2','state changed','OS::Heat::Value',NULL,1072),(1588,'6ce6d803-263c-4eff-9da6-da1ecfb177b5','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:31',NULL,'CREATE','IN_PROGRESS','ComputeGroupVars','cell1-ComputeGroupVars-hpvy3it3wtke','state changed','OS::Heat::Value',NULL,1073),(1589,'e09a2441-cfbe-4297-bd4f-6e84e23cafe4','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:31',NULL,'CREATE','IN_PROGRESS','ObjectStorageGroupVars','cell1-ObjectStorageGroupVars-oxe6prfqxztz','state changed','OS::Heat::Value',NULL,1074),(1590,'3d8d6dc9-1988-49c2-9f7f-32d224a0e916','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:31',NULL,'CREATE','COMPLETE','ComputeGroupVars','cell1-ComputeGroupVars-hpvy3it3wtke','state changed','OS::Heat::Value',NULL,1073),(1591,'cec1b4fb-fd0c-45e9-b94f-14fa42fd7bf3','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:31',NULL,'CREATE','COMPLETE','ObjectStorageGroupVars','cell1-ObjectStorageGroupVars-oxe6prfqxztz','state changed','OS::Heat::Value',NULL,1074),(1592,'aa5f737f-dcad-440e-a6b3-7bf7b4c34bd8','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:31',NULL,'CREATE','IN_PROGRESS','CellControllerComputeGroupVars','cell1-CellControllerComputeGroupVars-tdprwxmmvwm7','state changed','OS::Heat::Value',NULL,1076),(1593,'da389f5b-8983-4fae-8291-d55d6f572f4a','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:31',NULL,'CREATE','COMPLETE','CellControllerComputeGroupVars','cell1-CellControllerComputeGroupVars-tdprwxmmvwm7','state changed','OS::Heat::Value',NULL,1076),(1594,'b1838083-94b8-47d4-988a-7e5f561a0c8a','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:31',NULL,'CREATE','IN_PROGRESS','BlockStorageGroupVars','cell1-BlockStorageGroupVars-jlk7y2o7qwyb','state changed','OS::Heat::Value',NULL,1077),(1595,'1bdc35de-587b-4038-ab5a-540c4adc6f93','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:31',NULL,'CREATE','COMPLETE','BlockStorageGroupVars','cell1-BlockStorageGroupVars-jlk7y2o7qwyb','state changed','OS::Heat::Value',NULL,1077),(1596,'d5bda935-f26e-41e4-b60a-ced2f3b0bb1f','981ae83c-ed43-46a9-98c5-2e054d3f88ab','2026-06-12 08:26:32',NULL,'UPDATE','IN_PROGRESS','cell1-CellController-bajiesbmvbnn','981ae83c-ed43-46a9-98c5-2e054d3f88ab','Stack UPDATE started','OS::Heat::Stack',NULL,NULL),(1597,'aeb341ab-56e3-427c-9b85-787a984f81f8','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:32',NULL,'CREATE','COMPLETE','Compute','d9b1942a-b512-41cf-8930-ff20a5f2f41d','state changed','OS::Heat::ResourceGroup',NULL,935),(1598,'1a3f350d-a749-41af-9ca8-930426a69afc','981ae83c-ed43-46a9-98c5-2e054d3f88ab','2026-06-12 08:26:32',NULL,'CREATE','IN_PROGRESS','0','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k','state changed','OS::TripleO::CellController',NULL,1078),(1599,'d49b1c07-50c9-413f-8540-40fdba05c752','54e78176-3f06-4be6-9b5c-2ef71d89e834','2026-06-12 08:26:32',NULL,'CREATE','IN_PROGRESS','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k','54e78176-3f06-4be6-9b5c-2ef71d89e834','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1600,'5677a0b8-81e1-4a8d-881f-11a8e01e048e','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:32',NULL,'CREATE','IN_PROGRESS','ComputeServers','cell1-ComputeServers-ktsflt2of3j7','state changed','OS::Heat::Value',NULL,1085),(1601,'82322063-d872-46fd-a568-744f08992dee','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:32',NULL,'CREATE','COMPLETE','ComputeServers','cell1-ComputeServers-ktsflt2of3j7','state changed','OS::Heat::Value',NULL,1085),(1602,'0f698700-4309-4895-96f5-3d0bc8a63189','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:32',NULL,'CREATE','IN_PROGRESS','ComputeNetworkHostnameMap','cell1-ComputeNetworkHostnameMap-nuymluaas5cg','state changed','OS::Heat::Value',NULL,1086),(1603,'8827e1c2-fe9f-473a-960d-f9e65fcda209','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:32',NULL,'CREATE','COMPLETE','ComputeNetworkHostnameMap','cell1-ComputeNetworkHostnameMap-nuymluaas5cg','state changed','OS::Heat::Value',NULL,1086),(1604,'21f6496c-6d3e-492a-bbbb-93b329e09cc0','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:33',NULL,'CREATE','IN_PROGRESS','ComputeIpListMap','cell1-ComputeIpListMap-kuej7p2q3vhr','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,1089),(1605,'025db97b-59ce-4524-9177-ea0577086efd','54e78176-3f06-4be6-9b5c-2ef71d89e834','2026-06-12 08:26:33',NULL,'CREATE','IN_PROGRESS','DeploymentActions','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-DeploymentActions-v5uwaj2rrmah','state changed','OS::Heat::Value',NULL,1090),(1606,'97eb86d5-9321-44e0-aeaf-3befdaa8e7cc','54e78176-3f06-4be6-9b5c-2ef71d89e834','2026-06-12 08:26:33',NULL,'CREATE','COMPLETE','DeploymentActions','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-DeploymentActions-v5uwaj2rrmah','state changed','OS::Heat::Value',NULL,1090),(1607,'3cf0909a-c3c3-45a1-bd75-5d4359174f3f','2cfa992e-d0c6-4a3f-91d2-52ea9e6fcba3','2026-06-12 08:26:33',NULL,'CREATE','IN_PROGRESS','cell1-ComputeIpListMap-kuej7p2q3vhr','2cfa992e-d0c6-4a3f-91d2-52ea9e6fcba3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1608,'78cd5dae-756d-489b-89e9-48c57cd03b30','2cfa992e-d0c6-4a3f-91d2-52ea9e6fcba3','2026-06-12 08:26:33',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','cell1-ComputeIpListMap-kuej7p2q3vhr-EnabledServicesValue-z25vtqxvmxvw','state changed','OS::Heat::Value',NULL,1092),(1609,'a0ae0c7e-d895-4933-bc09-09d1a559809b','2cfa992e-d0c6-4a3f-91d2-52ea9e6fcba3','2026-06-12 08:26:33',NULL,'CREATE','COMPLETE','EnabledServicesValue','cell1-ComputeIpListMap-kuej7p2q3vhr-EnabledServicesValue-z25vtqxvmxvw','state changed','OS::Heat::Value',NULL,1092),(1610,'f87bb6f1-b7c9-43de-a535-c474af6c3835','54e78176-3f06-4be6-9b5c-2ef71d89e834','2026-06-12 08:26:34',NULL,'CREATE','IN_PROGRESS','CellController','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-CellController-pu4kwqtle4ya','state changed','OS::TripleO::CellControllerServer',NULL,1093),(1611,'a047a36b-701e-4fa0-944a-090936839966','76ce8df6-7dfb-4f8c-bd62-16403bda990c','2026-06-12 08:26:34',NULL,'CREATE','IN_PROGRESS','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-CellController-pu4kwqtle4ya','76ce8df6-7dfb-4f8c-bd62-16403bda990c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1612,'d940675f-2173-48eb-97fa-7762102087bd','2cfa992e-d0c6-4a3f-91d2-52ea9e6fcba3','2026-06-12 08:26:34',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','cell1-ComputeIpListMap-kuej7p2q3vhr-NetIpMapValue-js6kzmhpwrue','state changed','OS::Heat::Value',NULL,1094),(1613,'1c614919-aa24-43f1-a939-2049e54fe06e','2cfa992e-d0c6-4a3f-91d2-52ea9e6fcba3','2026-06-12 08:26:34',NULL,'CREATE','COMPLETE','NetIpMapValue','cell1-ComputeIpListMap-kuej7p2q3vhr-NetIpMapValue-js6kzmhpwrue','state changed','OS::Heat::Value',NULL,1094),(1614,'3c51c4ef-ed88-4aa0-ae97-e636b4c30571','2cfa992e-d0c6-4a3f-91d2-52ea9e6fcba3','2026-06-12 08:26:34',NULL,'CREATE','COMPLETE','cell1-ComputeIpListMap-kuej7p2q3vhr','2cfa992e-d0c6-4a3f-91d2-52ea9e6fcba3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1615,'52421e54-e498-4f5b-b4ce-9cb86ee7d91d','76ce8df6-7dfb-4f8c-bd62-16403bda990c','2026-06-12 08:26:34',NULL,'CREATE','IN_PROGRESS','deployed-server','ce-ntroller-pu4kwqtle4ya-deployed-server-tmcop7673gbr','state changed','OS::Heat::DeployedServer',NULL,1095),(1616,'aec428e5-ee4b-41c5-a725-10933da74852','76ce8df6-7dfb-4f8c-bd62-16403bda990c','2026-06-12 08:26:34',NULL,'CREATE','COMPLETE','deployed-server','fdfd9831-4e7f-49b0-88e6-ee2bc9bc0add','state changed','OS::Heat::DeployedServer',NULL,1095),(1617,'9fa1c92a-4904-41a1-a0b2-c2674c6c8452','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:35',NULL,'CREATE','COMPLETE','ComputeIpListMap','2cfa992e-d0c6-4a3f-91d2-52ea9e6fcba3','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,1089),(1618,'4ff5ac37-5f31-4541-b223-f79c74499611','76ce8df6-7dfb-4f8c-bd62-16403bda990c','2026-06-12 08:26:35',NULL,'CREATE','IN_PROGRESS','ControlPlanePort','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-CellController-pu4kwqtle4ya-ControlPlanePort-77x4gbtpzohv','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1096),(1619,'036756ef-67d9-4775-94a7-7e754107a406','f0a9bfa8-9fef-493c-bdaa-2fc71b062999','2026-06-12 08:26:35',NULL,'CREATE','IN_PROGRESS','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-CellController-pu4kwqtle4ya-ControlPlanePort-77x4gbtpzohv','f0a9bfa8-9fef-493c-bdaa-2fc71b062999','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1620,'402544ce-4469-42c4-9ae0-db0f3416e1e0','f0a9bfa8-9fef-493c-bdaa-2fc71b062999','2026-06-12 08:26:35',NULL,'CREATE','COMPLETE','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-CellController-pu4kwqtle4ya-ControlPlanePort-77x4gbtpzohv','f0a9bfa8-9fef-493c-bdaa-2fc71b062999','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1621,'8abc783b-c196-4ab3-b50b-661b5659f48f','76ce8df6-7dfb-4f8c-bd62-16403bda990c','2026-06-12 08:26:36',NULL,'CREATE','COMPLETE','ControlPlanePort','f0a9bfa8-9fef-493c-bdaa-2fc71b062999','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1096),(1622,'ab1dc301-8ceb-40a2-887c-8ab9a009aa34','76ce8df6-7dfb-4f8c-bd62-16403bda990c','2026-06-12 08:26:36',NULL,'CREATE','COMPLETE','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-CellController-pu4kwqtle4ya','76ce8df6-7dfb-4f8c-bd62-16403bda990c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1623,'4c8b0c80-27c5-42c5-95b2-746549986ab8','54e78176-3f06-4be6-9b5c-2ef71d89e834','2026-06-12 08:26:37',NULL,'CREATE','COMPLETE','CellController','76ce8df6-7dfb-4f8c-bd62-16403bda990c','state changed','OS::TripleO::CellControllerServer',NULL,1093),(1624,'bb964639-d8f3-4a48-ba05-9f06c2efc093','54e78176-3f06-4be6-9b5c-2ef71d89e834','2026-06-12 08:26:37',NULL,'CREATE','IN_PROGRESS','PreNetworkConfig','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-PreNetworkConfig-yjbtvbo62ha7','state changed','OS::TripleO::CellController::PreNetworkConfig',NULL,NULL),(1625,'f423cb1f-1ea1-48fa-800b-f5cccd7e5adc','54e78176-3f06-4be6-9b5c-2ef71d89e834','2026-06-12 08:26:37',NULL,'CREATE','COMPLETE','PreNetworkConfig','be2326cb-16af-474d-a695-d20e007fc54e','state changed','OS::TripleO::CellController::PreNetworkConfig',NULL,NULL),(1626,'4709cdf1-432d-4125-badb-b09c37bbb089','54e78176-3f06-4be6-9b5c-2ef71d89e834','2026-06-12 08:26:37',NULL,'CREATE','IN_PROGRESS','NetHostMap','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-NetHostMap-flayqgcw3yzc','state changed','OS::Heat::Value',NULL,1098),(1627,'ee7247f5-4cf1-4571-80b3-f38dd6be0077','54e78176-3f06-4be6-9b5c-2ef71d89e834','2026-06-12 08:26:37',NULL,'CREATE','COMPLETE','NetHostMap','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-NetHostMap-flayqgcw3yzc','state changed','OS::Heat::Value',NULL,1098),(1628,'3d409099-6859-4b79-974f-5d0e5ab02458','54e78176-3f06-4be6-9b5c-2ef71d89e834','2026-06-12 08:26:37',NULL,'CREATE','IN_PROGRESS','StorageMgmtPort','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-StorageMgmtPort-pkzyylasct3v','state changed','OS::TripleO::CellController::Ports::StorageMgmtPort',NULL,1099),(1629,'57d545a0-2eab-44c8-8271-8be17feb7f4b','54e78176-3f06-4be6-9b5c-2ef71d89e834','2026-06-12 08:26:37',NULL,'CREATE','IN_PROGRESS','NodeTLSCAData','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-NodeTLSCAData-kowcyqq63tei','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(1630,'4642dcc6-e6b1-4014-ac55-b0ec7eee8224','54e78176-3f06-4be6-9b5c-2ef71d89e834','2026-06-12 08:26:37',NULL,'CREATE','IN_PROGRESS','CellControllerExtraConfigPre','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-CellControllerExtraConfigPre-vzzllka2etvy','state changed','OS::TripleO::CellControllerExtraConfigPre',NULL,1100),(1631,'86a95716-dfb3-4d41-abac-729909f19fac','54e78176-3f06-4be6-9b5c-2ef71d89e834','2026-06-12 08:26:37',NULL,'CREATE','IN_PROGRESS','TenantPort','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-TenantPort-fruowxbaszq6','state changed','OS::TripleO::CellController::Ports::TenantPort',NULL,1103),(1632,'8b4f3f35-7c0f-4c77-964a-99248be802a1','54e78176-3f06-4be6-9b5c-2ef71d89e834','2026-06-12 08:26:37',NULL,'CREATE','IN_PROGRESS','CellControllerAnsibleHostVars','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-CellControllerAnsibleHostVars-ucurzxmng3gi','state changed','OS::Heat::Value',NULL,1104),(1633,'06f96a7c-edca-4a91-9cc9-ea36508f5ccf','54e78176-3f06-4be6-9b5c-2ef71d89e834','2026-06-12 08:26:37',NULL,'CREATE','IN_PROGRESS','InternalApiPort','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-InternalApiPort-q3begecg4tk5','state changed','OS::TripleO::CellController::Ports::InternalApiPort',NULL,1105),(1634,'ea7b4b89-0aa5-4ac5-99ca-365426953efd','54e78176-3f06-4be6-9b5c-2ef71d89e834','2026-06-12 08:26:37',NULL,'CREATE','COMPLETE','NodeTLSCAData','70042f96-a0be-4c0f-b245-3d2bd4995a6e','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(1635,'125524c7-0ccd-4d5c-bf35-d4eef7fae326','54e78176-3f06-4be6-9b5c-2ef71d89e834','2026-06-12 08:26:37',NULL,'CREATE','IN_PROGRESS','StoragePort','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-StoragePort-uj2keur3gqkm','state changed','OS::TripleO::CellController::Ports::StoragePort',NULL,1106),(1636,'24803c78-f7f3-4fe3-8439-d865abde9bdd','54e78176-3f06-4be6-9b5c-2ef71d89e834','2026-06-12 08:26:37',NULL,'CREATE','COMPLETE','CellControllerAnsibleHostVars','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-CellControllerAnsibleHostVars-ucurzxmng3gi','state changed','OS::Heat::Value',NULL,1104),(1637,'30cf873f-4849-4469-946b-95fb7cd5e358','b3e634bf-9dc3-48c6-8ed4-241d1fb64b05','2026-06-12 08:26:37',NULL,'CREATE','IN_PROGRESS','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-TenantPort-fruowxbaszq6','b3e634bf-9dc3-48c6-8ed4-241d1fb64b05','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1638,'2b3d2030-5261-439c-9d37-3f4975a70c26','ccbdf115-2171-43d8-9fbd-b7e54b4a2bc7','2026-06-12 08:26:37',NULL,'CREATE','IN_PROGRESS','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-CellControllerExtraConfigPre-vzzllka2etvy','ccbdf115-2171-43d8-9fbd-b7e54b4a2bc7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1639,'74c1e37c-795f-48c9-8c3a-ad0e47561341','41f6411b-2586-4dee-b6e2-38efc46dba2c','2026-06-12 08:26:37',NULL,'CREATE','IN_PROGRESS','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-StorageMgmtPort-pkzyylasct3v','41f6411b-2586-4dee-b6e2-38efc46dba2c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1640,'6a8d25ed-6f73-4fcc-95bd-1a3f261fba21','ccbdf115-2171-43d8-9fbd-b7e54b4a2bc7','2026-06-12 08:26:37',NULL,'CREATE','COMPLETE','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-CellControllerExtraConfigPre-vzzllka2etvy','ccbdf115-2171-43d8-9fbd-b7e54b4a2bc7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1641,'0abfb575-8615-4c08-86d2-1d82b853e278','38df99dd-3192-4ff9-837c-2d71ec43f6b1','2026-06-12 08:26:37',NULL,'CREATE','IN_PROGRESS','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-InternalApiPort-q3begecg4tk5','38df99dd-3192-4ff9-837c-2d71ec43f6b1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1642,'fef0cc5e-abff-4787-adff-5a982813bc17','343d6a5e-45b9-4a1f-88a1-68f12c42f95e','2026-06-12 08:26:37',NULL,'CREATE','IN_PROGRESS','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-StoragePort-uj2keur3gqkm','343d6a5e-45b9-4a1f-88a1-68f12c42f95e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1643,'83231d6c-1c74-4a96-a384-95fd24b1b60d','41f6411b-2586-4dee-b6e2-38efc46dba2c','2026-06-12 08:26:37',NULL,'CREATE','IN_PROGRESS','StorageMgmtDeployedPort','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-StorageMgmtPort-pkzyylasct3v-StorageMgmtDeployedPort-usc25p25xxeu','state changed','OS::Heat::Value',NULL,1107),(1644,'44e2e6e6-4a6d-4cf2-9221-a32d84051a59','38df99dd-3192-4ff9-837c-2d71ec43f6b1','2026-06-12 08:26:37',NULL,'CREATE','IN_PROGRESS','InternalApiDeployedPort','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-InternalApiPort-q3begecg4tk5-InternalApiDeployedPort-whvqq2uiqnzk','state changed','OS::Heat::Value',NULL,1108),(1645,'4cb68181-0cae-4f0c-b04f-087fd9395776','41f6411b-2586-4dee-b6e2-38efc46dba2c','2026-06-12 08:26:37',NULL,'CREATE','COMPLETE','StorageMgmtDeployedPort','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-StorageMgmtPort-pkzyylasct3v-StorageMgmtDeployedPort-usc25p25xxeu','state changed','OS::Heat::Value',NULL,1107),(1646,'fc2230fd-5705-405f-95ed-e8bfd974d026','38df99dd-3192-4ff9-837c-2d71ec43f6b1','2026-06-12 08:26:37',NULL,'CREATE','COMPLETE','InternalApiDeployedPort','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-InternalApiPort-q3begecg4tk5-InternalApiDeployedPort-whvqq2uiqnzk','state changed','OS::Heat::Value',NULL,1108),(1647,'50437a4a-7322-4c6b-9d0d-b3fdf0becc2f','b3e634bf-9dc3-48c6-8ed4-241d1fb64b05','2026-06-12 08:26:37',NULL,'CREATE','IN_PROGRESS','TenantDeployedPort','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-TenantPort-fruowxbaszq6-TenantDeployedPort-md4oi6myulok','state changed','OS::Heat::Value',NULL,1109),(1648,'bd80c124-2645-4b23-9c66-6dcd24181b78','41f6411b-2586-4dee-b6e2-38efc46dba2c','2026-06-12 08:26:37',NULL,'CREATE','COMPLETE','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-StorageMgmtPort-pkzyylasct3v','41f6411b-2586-4dee-b6e2-38efc46dba2c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1649,'e31c75cd-cdae-4f91-85be-bf1a06429ee3','343d6a5e-45b9-4a1f-88a1-68f12c42f95e','2026-06-12 08:26:37',NULL,'CREATE','IN_PROGRESS','StorageDeployedPort','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-StoragePort-uj2keur3gqkm-StorageDeployedPort-rwqrkdgsklmj','state changed','OS::Heat::Value',NULL,1110),(1650,'64adc857-6cef-4227-8d3d-1e52ec2c64ba','38df99dd-3192-4ff9-837c-2d71ec43f6b1','2026-06-12 08:26:37',NULL,'CREATE','COMPLETE','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-InternalApiPort-q3begecg4tk5','38df99dd-3192-4ff9-837c-2d71ec43f6b1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1651,'152eb25b-17b1-4530-8d26-2d6c3423aad6','b3e634bf-9dc3-48c6-8ed4-241d1fb64b05','2026-06-12 08:26:37',NULL,'CREATE','COMPLETE','TenantDeployedPort','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-TenantPort-fruowxbaszq6-TenantDeployedPort-md4oi6myulok','state changed','OS::Heat::Value',NULL,1109),(1652,'419ba43d-3521-4e9f-a3dc-fb6dbc17bcf8','343d6a5e-45b9-4a1f-88a1-68f12c42f95e','2026-06-12 08:26:37',NULL,'CREATE','COMPLETE','StorageDeployedPort','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-StoragePort-uj2keur3gqkm-StorageDeployedPort-rwqrkdgsklmj','state changed','OS::Heat::Value',NULL,1110),(1653,'956630ad-4971-4eb2-a318-424dbc1860ea','b3e634bf-9dc3-48c6-8ed4-241d1fb64b05','2026-06-12 08:26:37',NULL,'CREATE','COMPLETE','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-TenantPort-fruowxbaszq6','b3e634bf-9dc3-48c6-8ed4-241d1fb64b05','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1654,'5fee1f85-04fd-49d0-9799-d26f19f8a96a','343d6a5e-45b9-4a1f-88a1-68f12c42f95e','2026-06-12 08:26:37',NULL,'CREATE','COMPLETE','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-StoragePort-uj2keur3gqkm','343d6a5e-45b9-4a1f-88a1-68f12c42f95e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1655,'8e065c91-f6e6-4974-a292-85265bf2e8a9','54e78176-3f06-4be6-9b5c-2ef71d89e834','2026-06-12 08:26:38',NULL,'CREATE','COMPLETE','TenantPort','b3e634bf-9dc3-48c6-8ed4-241d1fb64b05','state changed','OS::TripleO::CellController::Ports::TenantPort',NULL,1103),(1656,'ee58f386-f13e-428b-91da-624fb098e9ae','54e78176-3f06-4be6-9b5c-2ef71d89e834','2026-06-12 08:26:38',NULL,'CREATE','COMPLETE','CellControllerExtraConfigPre','ccbdf115-2171-43d8-9fbd-b7e54b4a2bc7','state changed','OS::TripleO::CellControllerExtraConfigPre',NULL,1100),(1657,'bf43b57c-1720-48f5-91bb-58fbcab47063','54e78176-3f06-4be6-9b5c-2ef71d89e834','2026-06-12 08:26:38',NULL,'CREATE','COMPLETE','StorageMgmtPort','41f6411b-2586-4dee-b6e2-38efc46dba2c','state changed','OS::TripleO::CellController::Ports::StorageMgmtPort',NULL,1099),(1658,'84619b3b-bd58-4034-ba14-8a376141c874','54e78176-3f06-4be6-9b5c-2ef71d89e834','2026-06-12 08:26:38',NULL,'CREATE','COMPLETE','InternalApiPort','38df99dd-3192-4ff9-837c-2d71ec43f6b1','state changed','OS::TripleO::CellController::Ports::InternalApiPort',NULL,1105),(1659,'7d8cc537-291b-4cf2-a94d-1f1a5f41924f','54e78176-3f06-4be6-9b5c-2ef71d89e834','2026-06-12 08:26:38',NULL,'CREATE','COMPLETE','StoragePort','343d6a5e-45b9-4a1f-88a1-68f12c42f95e','state changed','OS::TripleO::CellController::Ports::StoragePort',NULL,1106),(1660,'40e4c047-e824-4db6-9b65-0a85e2671d02','54e78176-3f06-4be6-9b5c-2ef71d89e834','2026-06-12 08:26:38',NULL,'CREATE','IN_PROGRESS','NodeExtraConfig','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-NodeExtraConfig-f24bhlu5ob3n','state changed','OS::TripleO::NodeExtraConfig',NULL,1114),(1661,'88dbd87f-ff17-4f5e-bb39-026d459f997f','54e78176-3f06-4be6-9b5c-2ef71d89e834','2026-06-12 08:26:38',NULL,'CREATE','IN_PROGRESS','NetIpMap','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-NetIpMap-qibooduejfry','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1121),(1662,'923a24ed-753d-44f3-9795-a42b1fe6c43f','1605ac2b-bcf7-43f5-9025-d0ee52f552fc','2026-06-12 08:26:38',NULL,'CREATE','IN_PROGRESS','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-NodeExtraConfig-f24bhlu5ob3n','1605ac2b-bcf7-43f5-9025-d0ee52f552fc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1663,'ad1451a6-0c85-4dbb-82d5-27d410869c2f','1605ac2b-bcf7-43f5-9025-d0ee52f552fc','2026-06-12 08:26:39',NULL,'CREATE','COMPLETE','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-NodeExtraConfig-f24bhlu5ob3n','1605ac2b-bcf7-43f5-9025-d0ee52f552fc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1664,'a1f9cfc5-ac69-4262-8f23-bf27267f9239','c88ef7f3-d731-42fa-9722-a83088ad3dd1','2026-06-12 08:26:39',NULL,'CREATE','IN_PROGRESS','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-NetIpMap-qibooduejfry','c88ef7f3-d731-42fa-9722-a83088ad3dd1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1665,'ffa2092f-574e-4d85-b736-5aee9f48e20b','c88ef7f3-d731-42fa-9722-a83088ad3dd1','2026-06-12 08:26:39',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-NetIpMap-qibooduejfry-NetIpMapValue-frefot7ua3q6','state changed','OS::Heat::Value',NULL,1122),(1666,'495f8ab4-8fdb-4334-9284-a51ca08063d0','c88ef7f3-d731-42fa-9722-a83088ad3dd1','2026-06-12 08:26:39',NULL,'CREATE','COMPLETE','NetIpMapValue','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-NetIpMap-qibooduejfry-NetIpMapValue-frefot7ua3q6','state changed','OS::Heat::Value',NULL,1122),(1667,'ebc2a67e-c73f-4130-bc09-c41f35e19d90','c88ef7f3-d731-42fa-9722-a83088ad3dd1','2026-06-12 08:26:39',NULL,'CREATE','COMPLETE','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k-NetIpMap-qibooduejfry','c88ef7f3-d731-42fa-9722-a83088ad3dd1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1668,'903152b4-e52b-4560-a08b-d69e3c92fde2','54e78176-3f06-4be6-9b5c-2ef71d89e834','2026-06-12 08:26:40',NULL,'CREATE','COMPLETE','NodeExtraConfig','1605ac2b-bcf7-43f5-9025-d0ee52f552fc','state changed','OS::TripleO::NodeExtraConfig',NULL,1114),(1669,'3a4edfb6-f0c1-48b7-8f05-f2484d64b4f8','54e78176-3f06-4be6-9b5c-2ef71d89e834','2026-06-12 08:26:40',NULL,'CREATE','COMPLETE','NetIpMap','c88ef7f3-d731-42fa-9722-a83088ad3dd1','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1121),(1670,'5383716f-e7ca-4aa0-b3aa-7cd49e972e4c','54e78176-3f06-4be6-9b5c-2ef71d89e834','2026-06-12 08:26:40',NULL,'CREATE','COMPLETE','cell1-CellController-bajiesbmvbnn-0-7oflvo6ejo5k','54e78176-3f06-4be6-9b5c-2ef71d89e834','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1671,'69329d08-f4a7-4970-8972-5cf49f2b11b6','981ae83c-ed43-46a9-98c5-2e054d3f88ab','2026-06-12 08:26:40',NULL,'CREATE','COMPLETE','0','54e78176-3f06-4be6-9b5c-2ef71d89e834','state changed','OS::TripleO::CellController',NULL,1078),(1672,'84f1027a-f6d1-4d0e-897b-65b9d257ca6b','981ae83c-ed43-46a9-98c5-2e054d3f88ab','2026-06-12 08:26:40',NULL,'UPDATE','COMPLETE','cell1-CellController-bajiesbmvbnn','981ae83c-ed43-46a9-98c5-2e054d3f88ab','Stack UPDATE completed successfully','OS::Heat::Stack',NULL,NULL),(1673,'480f5608-771e-4ac6-b83b-4c389a8c4c36','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:41',NULL,'CREATE','COMPLETE','CellController','981ae83c-ed43-46a9-98c5-2e054d3f88ab','state changed','OS::Heat::ResourceGroup',NULL,1064),(1674,'987ce422-374b-4535-b5cc-7f4c1caa62c4','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:41',NULL,'CREATE','IN_PROGRESS','HostsEntryValue','cell1-HostsEntryValue-6vru5l23b2yd','state changed','OS::Heat::Value',NULL,1128),(1675,'ca18c272-e841-49b5-bcc2-32564dd4f1ef','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:41',NULL,'CREATE','COMPLETE','HostsEntryValue','cell1-HostsEntryValue-6vru5l23b2yd','state changed','OS::Heat::Value',NULL,1128),(1676,'a6a564d3-8d5b-4e98-a198-f98f99e3e2da','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:41',NULL,'CREATE','IN_PROGRESS','CellControllerServers','cell1-CellControllerServers-fiwiiod7bss4','state changed','OS::Heat::Value',NULL,1129),(1677,'159549a4-d57f-4c52-b70f-9cb0bfb55479','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:41',NULL,'CREATE','IN_PROGRESS','BlacklistedHostnames','cell1-BlacklistedHostnames-lpnntvpieigo','state changed','OS::Heat::Value',NULL,1130),(1678,'86e1dec9-4ed1-43f5-878f-2f93969cdd8a','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:41',NULL,'CREATE','COMPLETE','CellControllerServers','cell1-CellControllerServers-fiwiiod7bss4','state changed','OS::Heat::Value',NULL,1129),(1679,'5494c204-3b20-4155-85d3-f05c70eef96c','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:41',NULL,'CREATE','COMPLETE','BlacklistedHostnames','cell1-BlacklistedHostnames-lpnntvpieigo','state changed','OS::Heat::Value',NULL,1130),(1680,'18791c28-05f3-430a-b80b-ce4e393e3e99','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:42',NULL,'CREATE','IN_PROGRESS','AnsibleHostVars','cell1-AnsibleHostVars-zzxrx2jriqqg','state changed','OS::Heat::Value',NULL,1134),(1681,'aaf78d7b-69fe-4aaa-98ad-13b159ccb7b7','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:42',NULL,'CREATE','IN_PROGRESS','BlacklistedIpAddresses','cell1-BlacklistedIpAddresses-yr67ofjkcmx7','state changed','OS::Heat::Value',NULL,1135),(1682,'3942ecee-4e65-4e33-aa58-90aaff3b4160','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:42',NULL,'CREATE','COMPLETE','AnsibleHostVars','cell1-AnsibleHostVars-zzxrx2jriqqg','state changed','OS::Heat::Value',NULL,1134),(1683,'39d9e6bc-1218-41ae-9d6d-8e995b1c384b','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:42',NULL,'CREATE','COMPLETE','BlacklistedIpAddresses','cell1-BlacklistedIpAddresses-yr67ofjkcmx7','state changed','OS::Heat::Value',NULL,1135),(1684,'f4d76eb1-17e2-4006-9b17-cf113c5b5c9f','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:42',NULL,'CREATE','IN_PROGRESS','ServerIdMap','cell1-ServerIdMap-6izr5bue5ndt','state changed','OS::Heat::Value',NULL,1133),(1685,'95c130ee-ff94-4f80-bbbe-f610bf0d72c4','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:42',NULL,'CREATE','COMPLETE','ServerIdMap','cell1-ServerIdMap-6izr5bue5ndt','state changed','OS::Heat::Value',NULL,1133),(1686,'886f402e-82a3-4299-9c84-334d10fcdb80','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:42',NULL,'CREATE','IN_PROGRESS','CellControllerNetworkHostnameMap','cell1-CellControllerNetworkHostnameMap-kdf6osyo3mn2','state changed','OS::Heat::Value',NULL,1132),(1687,'c78e1c77-1bcc-4f37-8946-557cbe3de4bf','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:42',NULL,'CREATE','IN_PROGRESS','AllNodesExtraConfig','cell1-AllNodesExtraConfig-dgwtxqlztpue','state changed','OS::TripleO::AllNodesExtraConfig',NULL,NULL),(1688,'ae9193ed-493a-4b63-a63f-64d420c87099','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:42',NULL,'CREATE','COMPLETE','CellControllerNetworkHostnameMap','cell1-CellControllerNetworkHostnameMap-kdf6osyo3mn2','state changed','OS::Heat::Value',NULL,1132),(1689,'f911bc7c-eccc-41ce-a9df-1acd844ad743','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:42',NULL,'CREATE','COMPLETE','AllNodesExtraConfig','86332ec9-c563-4499-9c3f-03b835849666','state changed','OS::TripleO::AllNodesExtraConfig',NULL,NULL),(1690,'d9b0e939-3348-4225-8a90-7d389409bc68','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:42',NULL,'CREATE','IN_PROGRESS','CellControllerIpListMap','cell1-CellControllerIpListMap-zutcqz3fiywv','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,1139),(1691,'c0da5fb2-5de3-451e-b8c2-aa9d8b978636','01cb1dfa-a250-4ece-bd9c-eef5bd565ab4','2026-06-12 08:26:42',NULL,'CREATE','IN_PROGRESS','cell1-CellControllerIpListMap-zutcqz3fiywv','01cb1dfa-a250-4ece-bd9c-eef5bd565ab4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1692,'ef228d02-6b08-409e-a948-2e7f53d4ff61','01cb1dfa-a250-4ece-bd9c-eef5bd565ab4','2026-06-12 08:26:42',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','cell1-CellControllerIpListMap-zutcqz3fiywv-EnabledServicesValue-e2jrirvw67rw','state changed','OS::Heat::Value',NULL,1140),(1693,'e5f9b2ed-6e2d-4765-a1b8-9080b890c813','01cb1dfa-a250-4ece-bd9c-eef5bd565ab4','2026-06-12 08:26:42',NULL,'CREATE','COMPLETE','EnabledServicesValue','cell1-CellControllerIpListMap-zutcqz3fiywv-EnabledServicesValue-e2jrirvw67rw','state changed','OS::Heat::Value',NULL,1140),(1694,'5acfa0a2-2ba9-434d-8cee-b80be11c4222','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:42',NULL,'CREATE','IN_PROGRESS','AllNodesDeploySteps','cell1-AllNodesDeploySteps-jtldmdegg4wt','state changed','OS::TripleO::PostDeploySteps',NULL,1141),(1695,'155c48ef-db48-409e-aa60-6abdeee0e979','910c56fe-55bb-4a6c-a9ef-f5db3a808aeb','2026-06-12 08:26:42',NULL,'CREATE','IN_PROGRESS','cell1-AllNodesDeploySteps-jtldmdegg4wt','910c56fe-55bb-4a6c-a9ef-f5db3a808aeb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1696,'b1e8067e-80f3-4bec-814e-e003f68f2a6b','910c56fe-55bb-4a6c-a9ef-f5db3a808aeb','2026-06-12 08:26:43',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','cell1-AllNodesDeploySteps-jtldmdegg4wt-PreDeployStepTasks-bkyhznzbokvq','state changed','OS::Heat::Value',NULL,1142),(1697,'ae8dedbe-acd9-4bab-983f-a59edd54b69a','910c56fe-55bb-4a6c-a9ef-f5db3a808aeb','2026-06-12 08:26:43',NULL,'CREATE','COMPLETE','PreDeployStepTasks','cell1-AllNodesDeploySteps-jtldmdegg4wt-PreDeployStepTasks-bkyhznzbokvq','state changed','OS::Heat::Value',NULL,1142),(1698,'7a0c6605-0715-454c-b4c6-5c75892ce352','01cb1dfa-a250-4ece-bd9c-eef5bd565ab4','2026-06-12 08:26:43',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','cell1-CellControllerIpListMap-zutcqz3fiywv-NetIpMapValue-47565zrgo53t','state changed','OS::Heat::Value',NULL,1143),(1699,'523576bb-3ec7-4397-99c9-fe2380dd61b5','01cb1dfa-a250-4ece-bd9c-eef5bd565ab4','2026-06-12 08:26:43',NULL,'CREATE','COMPLETE','NetIpMapValue','cell1-CellControllerIpListMap-zutcqz3fiywv-NetIpMapValue-47565zrgo53t','state changed','OS::Heat::Value',NULL,1143),(1700,'b8c9d539-cb28-4de6-85e4-93ada66a3a9e','01cb1dfa-a250-4ece-bd9c-eef5bd565ab4','2026-06-12 08:26:43',NULL,'CREATE','COMPLETE','cell1-CellControllerIpListMap-zutcqz3fiywv','01cb1dfa-a250-4ece-bd9c-eef5bd565ab4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1701,'57e43104-fa87-4f0f-8c6e-492591fe7b96','910c56fe-55bb-4a6c-a9ef-f5db3a808aeb','2026-06-12 08:26:44',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','cell1-AllNodesDeploySteps-jtldmdegg4wt-ExternalPostDeployTasks-ccbemt3nv2ai','state changed','OS::Heat::Value',NULL,1144),(1702,'462bace4-b44f-42a9-931d-fd6d5fc4bc39','910c56fe-55bb-4a6c-a9ef-f5db3a808aeb','2026-06-12 08:26:44',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','cell1-AllNodesDeploySteps-jtldmdegg4wt-ExternalPostDeployTasks-ccbemt3nv2ai','state changed','OS::Heat::Value',NULL,1144),(1703,'c7407470-2bfe-4500-8a8f-0874f587acfb','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:44',NULL,'CREATE','COMPLETE','CellControllerIpListMap','01cb1dfa-a250-4ece-bd9c-eef5bd565ab4','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,1139),(1704,'41cd8804-1789-4600-88dd-f3dd937c86d3','910c56fe-55bb-4a6c-a9ef-f5db3a808aeb','2026-06-12 08:26:45',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','cell1-AllNodesDeploySteps-jtldmdegg4wt-ExternalUpgradeTasks-k2tuotdupdxk','state changed','OS::Heat::Value',NULL,1145),(1705,'3d9acf04-9b7e-4d10-9a83-bb4a2e658dd3','910c56fe-55bb-4a6c-a9ef-f5db3a808aeb','2026-06-12 08:26:45',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','cell1-AllNodesDeploySteps-jtldmdegg4wt-ExternalUpgradeTasks-k2tuotdupdxk','state changed','OS::Heat::Value',NULL,1145),(1706,'47c5532e-f04b-41b4-b313-30be64bd92db','910c56fe-55bb-4a6c-a9ef-f5db3a808aeb','2026-06-12 08:26:46',NULL,'CREATE','IN_PROGRESS','BootstrapServerId','cell1-AllNodesDeploySteps-jtldmdegg4wt-BootstrapServerId-vidz2xatwhx7','state changed','OS::Heat::Value',NULL,1146),(1707,'6b497dd6-da0b-48b0-85e1-002faf7a4dee','910c56fe-55bb-4a6c-a9ef-f5db3a808aeb','2026-06-12 08:26:46',NULL,'CREATE','COMPLETE','BootstrapServerId','cell1-AllNodesDeploySteps-jtldmdegg4wt-BootstrapServerId-vidz2xatwhx7','state changed','OS::Heat::Value',NULL,1146),(1708,'de25c871-f716-4be5-a5f1-695dbfa58a4f','910c56fe-55bb-4a6c-a9ef-f5db3a808aeb','2026-06-12 08:26:47',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','cell1-AllNodesDeploySteps-jtldmdegg4wt-ExternalUpdateTasks-bqq3zeyrxrrd','state changed','OS::Heat::Value',NULL,1147),(1709,'348b8da3-9153-4c2e-a6eb-549b8127450d','910c56fe-55bb-4a6c-a9ef-f5db3a808aeb','2026-06-12 08:26:47',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','cell1-AllNodesDeploySteps-jtldmdegg4wt-ExternalUpdateTasks-bqq3zeyrxrrd','state changed','OS::Heat::Value',NULL,1147),(1710,'decdc107-b7d8-4b45-8bb7-799d5c53411a','910c56fe-55bb-4a6c-a9ef-f5db3a808aeb','2026-06-12 08:26:48',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','cell1-AllNodesDeploySteps-jtldmdegg4wt-ExternalDeployTasks-ywp2e6gutaw5','state changed','OS::Heat::Value',NULL,1148),(1711,'8efbb7ae-dec0-4b68-872e-5c5adc01e398','910c56fe-55bb-4a6c-a9ef-f5db3a808aeb','2026-06-12 08:26:48',NULL,'CREATE','COMPLETE','ExternalDeployTasks','cell1-AllNodesDeploySteps-jtldmdegg4wt-ExternalDeployTasks-ywp2e6gutaw5','state changed','OS::Heat::Value',NULL,1148),(1712,'d7e7a6c7-5145-4421-a37e-7dc884ecca8a','910c56fe-55bb-4a6c-a9ef-f5db3a808aeb','2026-06-12 08:26:49',NULL,'CREATE','IN_PROGRESS','CellControllerExtraConfigPost','cell1-AllNodesDeploySteps-jtldmdegg4wt-CellControllerExtraConfigPost-7poinj3cujlk','state changed','OS::TripleO::NodeExtraConfigPost',NULL,1149),(1713,'4eb8eb08-7394-4775-af05-b090eb45c492','2bb810dd-a5b6-4fd5-b61f-ef3ee14602cd','2026-06-12 08:26:49',NULL,'CREATE','IN_PROGRESS','cell1-AllNodesDeploySteps-jtldmdegg4wt-CellControllerExtraConfigPost-7poinj3cujlk','2bb810dd-a5b6-4fd5-b61f-ef3ee14602cd','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1714,'b0fe6673-6842-45bd-91ef-8e9c6201bee9','2bb810dd-a5b6-4fd5-b61f-ef3ee14602cd','2026-06-12 08:26:49',NULL,'CREATE','COMPLETE','cell1-AllNodesDeploySteps-jtldmdegg4wt-CellControllerExtraConfigPost-7poinj3cujlk','2bb810dd-a5b6-4fd5-b61f-ef3ee14602cd','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1715,'96ee03fe-5ec8-4b07-ba39-098789b84e56','910c56fe-55bb-4a6c-a9ef-f5db3a808aeb','2026-06-12 08:26:50',NULL,'CREATE','IN_PROGRESS','ScaleTasks','cell1-AllNodesDeploySteps-jtldmdegg4wt-ScaleTasks-osg7p5vm32au','state changed','OS::Heat::Value',NULL,1150),(1716,'8aec13a5-1f2e-42a4-b4e1-bdfe760c538c','910c56fe-55bb-4a6c-a9ef-f5db3a808aeb','2026-06-12 08:26:50',NULL,'CREATE','COMPLETE','ScaleTasks','cell1-AllNodesDeploySteps-jtldmdegg4wt-ScaleTasks-osg7p5vm32au','state changed','OS::Heat::Value',NULL,1150),(1717,'55bc60a2-7fe8-4519-9c52-990a0efe10e8','910c56fe-55bb-4a6c-a9ef-f5db3a808aeb','2026-06-12 08:26:50',NULL,'CREATE','COMPLETE','CellControllerExtraConfigPost','2bb810dd-a5b6-4fd5-b61f-ef3ee14602cd','state changed','OS::TripleO::NodeExtraConfigPost',NULL,1149),(1718,'38a1234e-132b-4ae2-8a2e-f28024986bf4','910c56fe-55bb-4a6c-a9ef-f5db3a808aeb','2026-06-12 08:26:51',NULL,'CREATE','IN_PROGRESS','ComputeExtraConfigPost','cell1-AllNodesDeploySteps-jtldmdegg4wt-ComputeExtraConfigPost-ynuco2zp5ups','state changed','OS::TripleO::NodeExtraConfigPost',NULL,1152),(1719,'e3c5b617-ec63-46bb-b6f0-1cae2b4a9e64','e8b52e98-bda5-443a-8741-3ac2067d4525','2026-06-12 08:26:51',NULL,'CREATE','IN_PROGRESS','cell1-AllNodesDeploySteps-jtldmdegg4wt-ComputeExtraConfigPost-ynuco2zp5ups','e8b52e98-bda5-443a-8741-3ac2067d4525','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1720,'994c868b-5234-4c72-a9cb-06fb8906b921','e8b52e98-bda5-443a-8741-3ac2067d4525','2026-06-12 08:26:51',NULL,'CREATE','COMPLETE','cell1-AllNodesDeploySteps-jtldmdegg4wt-ComputeExtraConfigPost-ynuco2zp5ups','e8b52e98-bda5-443a-8741-3ac2067d4525','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1721,'ba26c3a8-a7cc-4305-9d62-6b644a41ec22','910c56fe-55bb-4a6c-a9ef-f5db3a808aeb','2026-06-12 08:26:52',NULL,'CREATE','COMPLETE','ComputeExtraConfigPost','e8b52e98-bda5-443a-8741-3ac2067d4525','state changed','OS::TripleO::NodeExtraConfigPost',NULL,1152),(1722,'261423a3-dd9e-40d3-89be-9154e40e6b4a','910c56fe-55bb-4a6c-a9ef-f5db3a808aeb','2026-06-12 08:26:52',NULL,'CREATE','IN_PROGRESS','ComputePostConfig','cell1-AllNodesDeploySteps-jtldmdegg4wt-ComputePostConfig-h6uoi3kri6kr','state changed','OS::TripleO::Tasks::ComputePostConfig',NULL,NULL),(1723,'42c7e7ba-3722-4fd2-9ada-c5f34a36664b','910c56fe-55bb-4a6c-a9ef-f5db3a808aeb','2026-06-12 08:26:52',NULL,'CREATE','COMPLETE','ComputePostConfig','9733dc8d-5589-45ba-8b96-1bed6c24e640','state changed','OS::TripleO::Tasks::ComputePostConfig',NULL,NULL),(1724,'21a28f98-0b9e-4dd1-a8b8-c0fd08cdb542','910c56fe-55bb-4a6c-a9ef-f5db3a808aeb','2026-06-12 08:26:52',NULL,'CREATE','IN_PROGRESS','CellControllerPostConfig','cell1-AllNodesDeploySteps-jtldmdegg4wt-CellControllerPostConfig-arjj4huqszgf','state changed','OS::TripleO::Tasks::CellControllerPostConfig',NULL,NULL),(1725,'8982b0d4-67b8-4133-bec9-cacc1f0401b1','910c56fe-55bb-4a6c-a9ef-f5db3a808aeb','2026-06-12 08:26:52',NULL,'CREATE','COMPLETE','CellControllerPostConfig','16ed1f94-d745-4a3e-83f6-4a3001d7c104','state changed','OS::TripleO::Tasks::CellControllerPostConfig',NULL,NULL),(1726,'534ea130-451f-419d-9ee5-88f3f716f3da','910c56fe-55bb-4a6c-a9ef-f5db3a808aeb','2026-06-12 08:26:52',NULL,'CREATE','COMPLETE','cell1-AllNodesDeploySteps-jtldmdegg4wt','910c56fe-55bb-4a6c-a9ef-f5db3a808aeb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1727,'83dd137e-4e8f-47f7-8a12-bcf0219f9563','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:52',NULL,'CREATE','COMPLETE','AllNodesDeploySteps','910c56fe-55bb-4a6c-a9ef-f5db3a808aeb','state changed','OS::TripleO::PostDeploySteps',NULL,1141),(1728,'ffbd839e-8f18-4ad7-b42e-757495167a35','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','2026-06-12 08:26:53',NULL,'CREATE','COMPLETE','cell1','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL);
/*!40000 ALTER TABLE `event` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `migrate_version`
--

DROP TABLE IF EXISTS `migrate_version`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `migrate_version` (
  `repository_id` varchar(250) NOT NULL,
  `repository_path` text DEFAULT NULL,
  `version` int(11) DEFAULT NULL,
  PRIMARY KEY (`repository_id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1 COLLATE=latin1_swedish_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `migrate_version`
--

LOCK TABLES `migrate_version` WRITE;
/*!40000 ALTER TABLE `migrate_version` DISABLE KEYS */;
INSERT INTO `migrate_version` VALUES ('heat','/usr/lib/python3.9/site-packages/heat/db/sqlalchemy/migrate_repo',86);
/*!40000 ALTER TABLE `migrate_version` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `raw_template`
--

DROP TABLE IF EXISTS `raw_template`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `raw_template` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `template` longtext DEFAULT NULL,
  `files` longtext DEFAULT NULL,
  `environment` longtext DEFAULT NULL,
  `files_id` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `raw_tmpl_files_fkey_ref` (`files_id`),
  CONSTRAINT `raw_tmpl_files_fkey_ref` FOREIGN KEY (`files_id`) REFERENCES `raw_template_files` (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=198 DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `raw_template`
--

LOCK TABLES `raw_template` WRITE;
/*!40000 ALTER TABLE `raw_template` DISABLE KEYS */;
INSERT INTO `raw_template` VALUES (1,'2026-06-12 08:25:34',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deploy an OpenStack environment, consisting of several node types (roles), Controller, Compute, BlockStorage, SwiftStorage and CephStorage. The Storage roles enable independent scaling of the storage components, but the minimal deployment is one Controller and one Compute node.\\n\", \"parameters\": {\"CloudNameStorage\": {\"default\": \"overcloud.storage.localdomain\", \"description\": \"The DNS name of this cloud\'s storage endpoint. E.g. \'ci-overcloud.storage.tripleo.org\'.\\n\", \"type\": \"string\"}, \"StorageVirtualFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the StorageVirtualInterface port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"CloudNameStorageManagement\": {\"default\": \"overcloud.storagemgmt.localdomain\", \"description\": \"The DNS name of this cloud\'s storage_mgmt endpoint. E.g. \'ci-overcloud.storagemgmt.tripleo.org\'.\\n\", \"type\": \"string\"}, \"StorageMgmtVirtualFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the StorageMgmtVirtualInterface port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"CloudNameInternal\": {\"default\": \"overcloud.internalapi.localdomain\", \"description\": \"The DNS name of this cloud\'s internal_api endpoint. E.g. \'ci-overcloud.internalapi.tripleo.org\'.\\n\", \"type\": \"string\"}, \"InternalApiVirtualFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the InternalApiVirtualInterface port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"CloudName\": {\"default\": \"overcloud.localdomain\", \"description\": \"The DNS name of this cloud. E.g. ci-overcloud.tripleo.org\", \"type\": \"string\"}, \"PublicVirtualFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the PublicVirtualInterface port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"ExternalVirtualFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the ExternalVirtualInterface port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"CloudNameCtlplane\": {\"default\": \"overcloud.ctlplane.localdomain\", \"description\": \"The DNS name of this cloud\'s provisioning network endpoint. E.g. \'ci-overcloud.ctlplane.tripleo.org\'.\\n\", \"type\": \"string\"}, \"ExtraHostFileEntries\": {\"default\": [], \"description\": \"List of extra hosts entries to be appended to /etc/hosts\", \"type\": \"comma_delimited_list\"}, \"UndercloudHostsEntries\": {\"default\": [], \"description\": \"List of undercloud hosts entries to be appended to /etc/hosts. The value is populated with the HEAT_HOSTS entries on the undercloud by tripleoclient when running deploy.\\n\", \"type\": \"comma_delimited_list\"}, \"EndpointMapOverride\": {\"default\": {}, \"description\": \"Can be used to override the calcluated EndpointMap\", \"type\": \"json\"}, \"ExtraConfig\": {\"default\": {}, \"description\": \"Additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"DeployedServerPortMap\": {\"default\": {}, \"type\": \"json\"}, \"NeutronControlPlaneID\": {\"default\": \"ctlplane\", \"type\": \"string\", \"description\": \"Neutron ID or name for ctlplane network.\"}, \"NeutronPhysicalBridge\": {\"default\": \"br-ex\", \"description\": \"An OVS bridge to create for accessing external networks.\", \"type\": \"string\"}, \"NeutronPublicInterface\": {\"default\": \"nic1\", \"description\": \"Which interface to add to the NeutronPhysicalBridge.\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"DnsSearchDomains\": {\"default\": [], \"description\": \"A list of DNS search domains to be added (in order) to resolv.conf.\", \"type\": \"comma_delimited_list\"}, \"ControlFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the ControlVirtualIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"RabbitCookieSalt\": {\"type\": \"string\", \"default\": \"unset\", \"description\": \"Salt for the rabbit cookie, change this to force the randomly generated rabbit cookie to change.\"}, \"CloudDomain\": {\"default\": \"localdomain\", \"type\": \"string\", \"description\": \"The DNS domain used for the hosts. This must match the overcloud_domain_name configured on the undercloud.\\n\"}, \"ServerMetadata\": {\"default\": {}, \"description\": \"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API.\\n\", \"type\": \"json\"}, \"HypervisorNeutronPhysicalBridge\": {\"default\": \"br-ex\", \"description\": \"An OVS bridge to create on each hypervisor. This defaults to br-ex the same as the control plane nodes, as we have a uniform configuration of the openvswitch agent. Typically should not need to be changed.\\n\", \"type\": \"string\"}, \"HypervisorNeutronPublicInterface\": {\"default\": \"nic1\", \"description\": \"What interface to add to the HypervisorNeutronPhysicalBridge.\", \"type\": \"string\"}, \"NodeCreateBatchSize\": {\"default\": 30, \"description\": \"Maxiumum batch size for creating nodes\", \"type\": \"number\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"NovaLocalMetadataPerCell\": {\"default\": false, \"description\": \"Indicates that the nova-metadata API service has been deployed per-cell, so that we can have better performance and data isolation in a multi-cell deployment. Users should consider the use of this configuration depending on how neutron is setup. If networks span cells, you might need to run nova-metadata API service globally. If your networks are segmented along cell boundaries, then you can run nova-metadata API service per cell. When running nova-metadata API service per cell, you should also configure each Neutron metadata-agent to point to the corresponding nova-metadata API service.\\n\", \"type\": \"boolean\"}, \"BondInterfaceOvsOptions\": {\"default\": \"\", \"description\": \"The ovs_options or bonding_options string for the bond interface. Set things like lacp=active and/or bond_mode=balance-slb for OVS bonds or like mode=4 for Linux bonds using this option.\", \"type\": \"string\", \"constraints\": [{\"allowed_pattern\": \"^((?!balance.tcp).)*$\", \"description\": \"The balance-tcp bond mode is known to cause packet loss and should not be used in BondInterfaceOvsOptions.\"}]}, \"NetworkConfigWithAnsible\": {\"description\": \"NetworkConfig with ansible flag\", \"type\": \"boolean\", \"default\": true}, \"ControllerLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"ControllerNetworkConfigTemplate\": {\"description\": \"Controller NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"ControllerExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"controllerExtraConfig\": {\"default\": {}, \"description\": \"DEPRECATED use CellControllerComputeExtraConfig instead\\n\", \"type\": \"json\"}, \"ControllerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Controller role.\", \"type\": \"comma_delimited_list\"}, \"ControllerNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"ControllerUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"ControllerIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"ControllerUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"ControllerAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"ControllerMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"ControllerCount\": {\"description\": \"Number of Controller nodes to deploy\", \"type\": \"number\", \"default\": 1}, \"ControllerHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for Controller node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-controller-%index%\"}, \"ControllerRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from Controller ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"ControllerRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for Controller ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"ControllerSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"ControllerParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"ControllerExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"ControllerControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"ControllerServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nControllerServiceChain resource and the Controller resource group.\\nFor example:\\nControllerServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"ControllerNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"CellControllerLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"CellControllerNetworkConfigTemplate\": {\"description\": \"CellController NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"CellControllerExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"CellControllerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CellController role.\", \"type\": \"comma_delimited_list\"}, \"CellControllerNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"CellControllerUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"CellControllerMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"CellControllerCount\": {\"description\": \"Number of CellController nodes to deploy\", \"type\": \"number\", \"default\": 1}, \"CellControllerHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for CellController node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-controller-%index%\"}, \"CellControllerRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from CellController ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"CellControllerRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for CellController ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"CellControllerSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"CellControllerParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"CellControllerExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"CellControllerControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"CellControllerServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nCellControllerServiceChain resource and the CellController resource group.\\nFor example:\\nCellControllerServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"CellControllerNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"CellControllerComputeLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"CellControllerComputeNetworkConfigTemplate\": {\"description\": \"CellControllerCompute NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"CellControllerComputeExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"CellControllerComputeServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CellControllerCompute role.\", \"type\": \"comma_delimited_list\"}, \"CellControllerComputeNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerComputeUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerComputeIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"CellControllerComputeUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerComputeAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"CellControllerComputeMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"CellControllerComputeCount\": {\"description\": \"Number of CellControllerCompute nodes to deploy\", \"type\": \"number\", \"default\": 1}, \"CellControllerComputeHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for CellControllerCompute node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-controller-compute-%index%\"}, \"CellControllerComputeRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from CellControllerCompute ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"CellControllerComputeRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for CellControllerCompute ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"CellControllerComputeSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"CellControllerComputeParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"CellControllerComputeExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"CellControllerComputeControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"CellControllerComputeServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nCellControllerComputeServiceChain resource and the CellControllerCompute resource group.\\nFor example:\\nCellControllerComputeServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"CellControllerComputeNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"ComputeLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"ComputeNetworkConfigTemplate\": {\"description\": \"Compute NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"ComputeExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"NovaComputeExtraConfig\": {\"default\": {}, \"description\": \"DEPRECATED use ComputeExtraConfig instead\\n\", \"type\": \"json\"}, \"ComputeServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Compute role.\", \"type\": \"comma_delimited_list\"}, \"ComputeNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"ComputeUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"ComputeIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"ComputeUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"ComputeAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"ComputeMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"ComputeCount\": {\"description\": \"Number of Compute nodes to deploy\", \"type\": \"number\", \"default\": 1}, \"ComputeHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for Compute node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-novacompute-%index%\"}, \"ComputeRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from Compute ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"ComputeRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for Compute ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"ComputeSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"NovaComputeSchedulerHints\": {\"type\": \"json\", \"description\": \"DEPRECATED - use ComputeSchedulerHints instead\", \"default\": {}}, \"ComputeParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"ComputeExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"ComputeControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"ComputeServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nComputeServiceChain resource and the Compute resource group.\\nFor example:\\nComputeServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"ComputeNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"BlockStorageLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"BlockStorageNetworkConfigTemplate\": {\"description\": \"BlockStorage NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"BlockStorageExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"BlockStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the BlockStorage role.\", \"type\": \"comma_delimited_list\"}, \"BlockStorageNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"BlockStorageUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"BlockStorageIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"BlockStorageUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"BlockStorageAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"BlockStorageMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"BlockStorageCount\": {\"description\": \"Number of BlockStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"BlockStorageHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for BlockStorage node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-blockstorage-%index%\"}, \"BlockStorageRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from BlockStorage ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"BlockStorageRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for BlockStorage ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"BlockStorageSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"BlockStorageParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"BlockStorageExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"BlockStorageControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"BlockStorageServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nBlockStorageServiceChain resource and the BlockStorage resource group.\\nFor example:\\nBlockStorageServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"BlockStorageNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"ObjectStorageLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"ObjectStorageNetworkConfigTemplate\": {\"description\": \"ObjectStorage NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"ObjectStorageExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"ObjectStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the ObjectStorage role.\", \"type\": \"comma_delimited_list\"}, \"ObjectStorageNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"ObjectStorageUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"ObjectStorageIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"ObjectStorageUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"ObjectStorageAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"ObjectStorageMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"ObjectStorageCount\": {\"description\": \"Number of ObjectStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"ObjectStorageHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for ObjectStorage node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-objectstorage-%index%\"}, \"ObjectStorageRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from ObjectStorage ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"ObjectStorageRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for ObjectStorage ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"ObjectStorageSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"ObjectStorageParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"ObjectStorageExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"ObjectStorageControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"ObjectStorageServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nObjectStorageServiceChain resource and the ObjectStorage resource group.\\nFor example:\\nObjectStorageServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"ObjectStorageNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"CephStorageLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"CephStorageNetworkConfigTemplate\": {\"description\": \"CephStorage NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"CephStorageExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"CephStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CephStorage role.\", \"type\": \"comma_delimited_list\"}, \"CephStorageNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"CephStorageUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"CephStorageIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"CephStorageUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"CephStorageAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"CephStorageMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"CephStorageCount\": {\"description\": \"Number of CephStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"CephStorageHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for CephStorage node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-cephstorage-%index%\"}, \"CephStorageRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from CephStorage ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"CephStorageRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for CephStorage ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"CephStorageSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"CephStorageParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"CephStorageExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"CephStorageControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"CephStorageServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nCephStorageServiceChain resource and the CephStorage resource group.\\nFor example:\\nCephStorageServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"CephStorageNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"NetworkerLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"NetworkerNetworkConfigTemplate\": {\"description\": \"Networker NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"NetworkerExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"NetworkerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Networker role.\", \"type\": \"comma_delimited_list\"}, \"NetworkerNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"NetworkerUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"NetworkerIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"NetworkerUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"NetworkerAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"NetworkerMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"NetworkerCount\": {\"description\": \"Number of Networker nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"NetworkerHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for Networker node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-networker-%index%\"}, \"NetworkerRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from Networker ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"NetworkerRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for Networker ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"NetworkerSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"NetworkerParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"NetworkerExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"NetworkerControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"NetworkerServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nNetworkerServiceChain resource and the Networker resource group.\\nFor example:\\nNetworkerServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"NetworkerNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"UpdateIdentifier\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Setting to a previously unused value during stack-update will trigger package update on all nodes\\n\"}, \"DeployIdentifier\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"AddVipsToEtcHosts\": {\"default\": true, \"type\": \"boolean\", \"description\": \"Set to true to append per network Vips to /etc/hosts on each node.\\n\"}, \"DeploymentServerBlacklist\": {\"default\": [], \"type\": \"comma_delimited_list\", \"description\": \"List of server hostnames to blacklist from any triggered deployments.\\n\"}, \"GlobalConfigExtraMapData\": {\"type\": \"json\", \"default\": {}, \"description\": \"Map of extra global_config_settings data to set on each node.\"}, \"NetConfigDataLookup\": {\"type\": \"json\", \"default\": {}, \"description\": \"Configure os-net-config mappings for specific nodes Your environment file needs to look like:\\n  parameter_defaults:\\n    NetConfigDataLookup:\\n      node1:\\n        nic1: \\\"00:c8:7c:e6:f0:2e\\\"\\n      node2:\\n        nic1: \\\"00:18:7d:99:0c:b6\\\"\\n      node3:\\n        dmiString: \'system-uuid\'\\n        id: \'A8C85861-1B16-4803-8689-AFC62984F8F6\'\\n        nic1: em3\\n      # Dell PowerEdge\\n      nodegroup1:\\n        dmiString: \\\"system-product-name\\\"\\n        id: \\\"PowerEdge R630\\\"\\n        nic1: em3\\n        nic2: em1\\n        nic3: em2\\n      # Cisco UCS B200-M4\\\"\\n      nodegroup2:\\n        dmiString: \\\"system-product-name\\\"\\n        id: \\\"UCSB-B200-M4\\\"\\n        nic1: enp7s0\\n        nic2: enp6s0\\n\\nThis will result in the first node* entry where either a mac matches a local device or a DMI String matches the specified id being written as a mapping file for os-net-config. (/etc/os-net-config/mapping.yaml)\\n\"}, \"DnsServers\": {\"default\": [], \"description\": \"DNS servers to use for the Overcloud (2 max for some implementations). If not set the nameservers configured in the ctlplane subnet\'s dns_nameservers attribute will be used.\\n\", \"type\": \"comma_delimited_list\"}, \"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\"}, \"AdminPassword\": {\"description\": \"The password for the keystone admin account, used for monitoring, querying neutron etc.\", \"type\": \"string\", \"hidden\": true}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"Do not use deprecated params, they will be removed.\", \"parameters\": [\"DnsServers\", \"NovaComputeSchedulerHints\", \"NovaComputeExtraConfig\"]}], \"conditions\": {\"add_vips_to_etc_hosts\": {\"equals\": [{\"get_param\": \"AddVipsToEtcHosts\"}, true]}, \"control_fixed_ip_not_set\": {\"equals\": [{\"get_param\": \"ControlFixedIPs\"}, []]}, \"storage_virtual_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": \"StorageVirtualFixedIPs\"}, []]}}, \"storage_mgmt_virtual_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": \"StorageMgmtVirtualFixedIPs\"}, []]}}, \"internal_api_virtual_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": \"InternalApiVirtualFixedIPs\"}, []]}}, \"tenant_virtual_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": \"TenantVirtualFixedIPs\"}, []]}}, \"public_virtual_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": \"PublicVirtualFixedIPs\"}, []]}}, \"set_default_mysql_cell_internal\": {\"or\": [{\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}, {\"and\": [{\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, false]}, {\"equals\": [{\"get_param\": [\"EndpointMapOverride\", \"MysqlCellInternal\"]}, \"\"]}]}]}, \"set_default_nova_vnc_proxy_cell_public\": {\"or\": [{\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}, {\"and\": [{\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, false]}, {\"equals\": [{\"get_param\": [\"EndpointMapOverride\", \"NovaVNCProxyCellPublic\"]}, \"\"]}]}]}, \"set_default_nova_metadata_cell_internal\": {\"or\": [{\"equals\": [{\"get_param\": \"NovaLocalMetadataPerCell\"}, true]}, {\"and\": [{\"equals\": [{\"get_param\": \"NovaLocalMetadataPerCell\"}, false]}, {\"equals\": [{\"get_param\": [\"EndpointMapOverride\", \"NovaMetadataCellInternal\"]}, \"\"]}]}]}, \"dnsservers_set\": {\"not\": {\"equals\": [{\"get_param\": \"DnsServers\"}, []]}}}, \"resources\": {\"VipHosts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": [{\"str_replace\": {\"template\": \"IP  HOST\", \"params\": {\"IP\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", \"ctlplane\"]}, \"HOST\": {\"get_param\": \"CloudNameCtlplane\"}}}}, {\"str_replace\": {\"template\": \"IP  HOST\", \"params\": {\"IP\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", \"storage\"]}, \"HOST\": {\"get_param\": \"CloudNameStorage\"}}}}, {\"str_replace\": {\"template\": \"IP  HOST\", \"params\": {\"IP\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", \"storage_mgmt\"]}, \"HOST\": {\"get_param\": \"CloudNameStorageManagement\"}}}}, {\"str_replace\": {\"template\": \"IP  HOST\", \"params\": {\"IP\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", \"internal_api\"]}, \"HOST\": {\"get_param\": \"CloudNameInternal\"}}}}, {\"str_replace\": {\"template\": \"IP  HOST\", \"params\": {\"IP\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", \"external\"]}, \"HOST\": {\"get_param\": \"CloudName\"}}}}]}}, \"NetCidrMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_merge\": [{\"get_attr\": [\"Networks\", \"net_cidr_map\"]}, {\"ctlplane\": {\"get_attr\": [\"ControlVirtualIP\", \"network\", \"tags\"]}}]}, {\"keys\": {\"ctlplane\": {\"get_param\": \"NeutronControlPlaneID\"}}}]}}}, \"NetIpVersionMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_merge\": [{\"get_attr\": [\"Networks\", \"net_ip_version_map\"]}, {\"ctlplane\": {\"get_attr\": [\"ControlVirtualIP\", \"subnets\", 0, \"ip_version\"]}}]}, {\"keys\": {\"ctlplane\": {\"get_param\": \"NeutronControlPlaneID\"}}}]}}}, \"ServiceNetMap\": {\"type\": \"OS::TripleO::ServiceNetMap\"}, \"EndpointMap\": {\"type\": \"OS::TripleO::EndpointMap\", \"properties\": {\"CloudEndpoints\": {\"ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}, \"storage\": {\"get_param\": \"CloudNameStorage\"}, \"storage_mgmt\": {\"get_param\": \"CloudNameStorageManagement\"}, \"internal_api\": {\"get_param\": \"CloudNameInternal\"}, \"external\": {\"get_param\": \"CloudName\"}}, \"NetIpMap\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"ServiceNetMap\": {\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}}}, \"EndpointMapData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_attr\": [\"EndpointMap\", \"endpoint_map\"]}, {\"get_param\": \"EndpointMapOverride\"}, {\"if\": [\"set_default_mysql_cell_internal\", {\"MysqlCellInternal\": {\"get_attr\": [\"EndpointMap\", \"endpoint_map\", \"MysqlInternal\"]}}, {}]}, {\"if\": [\"set_default_nova_vnc_proxy_cell_public\", {\"NovaVNCProxyCellPublic\": {\"get_attr\": [\"EndpointMap\", \"endpoint_map\", \"NovaVNCProxyPublic\"]}}, {}]}, {\"if\": [\"set_default_nova_metadata_cell_internal\", {\"NovaMetadataCellInternal\": {\"get_attr\": [\"EndpointMap\", \"endpoint_map\", \"NovaMetadataInternal\"]}}, {}]}]}}}, \"NodeAdminUserData\": {\"type\": \"OS::TripleO::NodeAdminUserData\"}, \"NodeTimesyncUserData\": {\"type\": \"OS::TripleO::NodeTimesyncUserData\"}, \"NodeUserData\": {\"type\": \"OS::TripleO::NodeUserData\"}, \"ControllerServiceChain\": {\"type\": \"OS::TripleO::ControllerServices\", \"properties\": {\"Services\": {\"get_param\": \"ControllerServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ControllerServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"ControllerParameters\"}]}}}, \"ControllerServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"ControllerServiceChain\", \"role_data\"]}}}, \"ControllerConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"ControllerServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"ControllerServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"controllerExtraConfig\"}, {\"get_param\": \"ControllerExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"ControllerServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"ControllerServiceNames\", \"value\"]}}}}]}}}, \"ControllerServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"ControllerServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"ControllerServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"ControllerServiceNetMap\"}}}}]}}}, \"ControllerIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"Controller\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"Controller\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"Controller\", \"storage_mgmt_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"Controller\", \"internal_api_ip_address\"]}, \"TenantIpList\": {\"get_attr\": [\"Controller\", \"tenant_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"tenant\"], \"EnabledServices\": {\"get_attr\": [\"ControllerServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"ControllerServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"Controller\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"ControllerNetworkHostnameMap\", \"value\"]}}}, \"ControllerNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"Controller\", \"hostname_map\"]}]}}}}, \"ControllerUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"ControllerRoleUserData\"}, \"type\": \"multipart\"}]}}, \"ControllerRoleUserData\": {\"type\": \"OS::TripleO::Controller::NodeUserData\"}, \"Controller\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"ControllerCount\"}, \"removal_policies\": {\"get_param\": \"ControllerRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"ControllerRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::Controller\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ControllerServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"ControllerHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"ControllerSchedulerHints\": {\"map_merge\": [{\"get_param\": \"ControllerSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"ControllerServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"ControllerParameters\"}]}, \"UserData\": {\"get_resource\": \"ControllerUserData\"}}}}}, \"CellControllerServiceChain\": {\"type\": \"OS::TripleO::CellControllerServices\", \"properties\": {\"Services\": {\"get_param\": \"CellControllerServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CellControllerServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"CellControllerParameters\"}]}}}, \"CellControllerServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"CellControllerServiceChain\", \"role_data\"]}}}, \"CellControllerConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"CellControllerServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"controllerExtraConfig\"}, {\"get_param\": \"CellControllerExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"CellControllerServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}}}}]}}}, \"CellControllerServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CellControllerServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"CellControllerServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"CellControllerServiceNetMap\"}}}}]}}}, \"CellControllerIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"CellController\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"CellController\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"CellController\", \"storage_mgmt_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"CellController\", \"internal_api_ip_address\"]}, \"TenantIpList\": {\"get_attr\": [\"CellController\", \"tenant_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"tenant\"], \"EnabledServices\": {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"CellControllerServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"CellController\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"CellControllerNetworkHostnameMap\", \"value\"]}}}, \"CellControllerNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"CellController\", \"hostname_map\"]}]}}}}, \"CellControllerUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"CellControllerRoleUserData\"}, \"type\": \"multipart\"}]}}, \"CellControllerRoleUserData\": {\"type\": \"OS::TripleO::CellController::NodeUserData\"}, \"CellController\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"CellControllerCount\"}, \"removal_policies\": {\"get_param\": \"CellControllerRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"CellControllerRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::CellController\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CellControllerServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"CellControllerHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"CellControllerSchedulerHints\": {\"map_merge\": [{\"get_param\": \"CellControllerSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"CellControllerParameters\"}]}, \"UserData\": {\"get_resource\": \"CellControllerUserData\"}}}}}, \"CellControllerComputeServiceChain\": {\"type\": \"OS::TripleO::CellControllerComputeServices\", \"properties\": {\"Services\": {\"get_param\": \"CellControllerComputeServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CellControllerComputeServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"CellControllerCompute\", \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"CellControllerComputeParameters\"}]}}}, \"CellControllerComputeServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"CellControllerComputeServiceChain\", \"role_data\"]}}}, \"CellControllerComputeConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"CellControllerComputeServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"controllerExtraConfig\"}, {\"get_param\": \"CellControllerComputeExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"CellControllerComputeServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}}}}]}}}, \"CellControllerComputeServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CellControllerComputeServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"CellControllerComputeServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"CellControllerComputeServiceNetMap\"}}}}]}}}, \"CellControllerComputeIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"CellControllerCompute\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"CellControllerCompute\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"CellControllerCompute\", \"storage_mgmt_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"CellControllerCompute\", \"internal_api_ip_address\"]}, \"TenantIpList\": {\"get_attr\": [\"CellControllerCompute\", \"tenant_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"tenant\"], \"EnabledServices\": {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"CellControllerComputeServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"CellControllerCompute\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"CellControllerComputeNetworkHostnameMap\", \"value\"]}}}, \"CellControllerComputeNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"CellControllerCompute\", \"hostname_map\"]}]}}}}, \"CellControllerComputeUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"CellControllerComputeRoleUserData\"}, \"type\": \"multipart\"}]}}, \"CellControllerComputeRoleUserData\": {\"type\": \"OS::TripleO::CellControllerCompute::NodeUserData\"}, \"CellControllerCompute\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"CellControllerComputeCount\"}, \"removal_policies\": {\"get_param\": \"CellControllerComputeRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"CellControllerComputeRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::CellControllerCompute\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CellControllerComputeServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"CellControllerComputeHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"CellControllerComputeSchedulerHints\": {\"map_merge\": [{\"get_param\": \"CellControllerComputeSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"CellControllerComputeParameters\"}]}, \"UserData\": {\"get_resource\": \"CellControllerComputeUserData\"}}}}}, \"ComputeServiceChain\": {\"type\": \"OS::TripleO::ComputeServices\", \"properties\": {\"Services\": {\"get_param\": \"ComputeServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ComputeServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"map_merge\": [{\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, {\"get_param\": \"ComputeParameters\"}]}}}, \"ComputeServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"ComputeServiceChain\", \"role_data\"]}}}, \"ComputeConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"ComputeServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"NovaComputeExtraConfig\"}, {\"get_param\": \"ComputeExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"ComputeServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}}}}]}}}, \"ComputeServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"ComputeServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"ComputeServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"ComputeServiceNetMap\"}}}}]}}}, \"ComputeIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"Compute\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"Compute\", \"storage_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"Compute\", \"internal_api_ip_address\"]}, \"TenantIpList\": {\"get_attr\": [\"Compute\", \"tenant_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"internal_api\", \"tenant\"], \"EnabledServices\": {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"ComputeServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"Compute\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"ComputeNetworkHostnameMap\", \"value\"]}}}, \"ComputeNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"Compute\", \"hostname_map\"]}]}}}}, \"ComputeUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"ComputeRoleUserData\"}, \"type\": \"multipart\"}]}}, \"ComputeRoleUserData\": {\"type\": \"OS::TripleO::Compute::NodeUserData\"}, \"Compute\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"ComputeCount\"}, \"removal_policies\": {\"get_param\": \"ComputeRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"ComputeRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::Compute\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ComputeServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"ComputeHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"ComputeSchedulerHints\": {\"map_merge\": [{\"get_param\": \"NovaComputeSchedulerHints\"}, {\"get_param\": \"ComputeSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, {\"get_param\": \"ComputeParameters\"}]}, \"UserData\": {\"get_resource\": \"ComputeUserData\"}}}}}, \"BlockStorageServiceChain\": {\"type\": \"OS::TripleO::BlockStorageServices\", \"properties\": {\"Services\": {\"get_param\": \"BlockStorageServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"BlockStorageServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"BlockStorage\", \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"BlockStorageParameters\"}]}}}, \"BlockStorageServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"BlockStorageServiceChain\", \"role_data\"]}}}, \"BlockStorageConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"BlockStorageServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"BlockStorageExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"BlockStorageServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}}}}]}}}, \"BlockStorageServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"BlockStorageServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"BlockStorageServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"BlockStorageServiceNetMap\"}}}}]}}}, \"BlockStorageIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"BlockStorage\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"BlockStorage\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"BlockStorage\", \"storage_mgmt_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"BlockStorage\", \"internal_api_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"EnabledServices\": {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"BlockStorageServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"BlockStorage\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"BlockStorageNetworkHostnameMap\", \"value\"]}}}, \"BlockStorageNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"BlockStorage\", \"hostname_map\"]}]}}}}, \"BlockStorageUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"BlockStorageRoleUserData\"}, \"type\": \"multipart\"}]}}, \"BlockStorageRoleUserData\": {\"type\": \"OS::TripleO::BlockStorage::NodeUserData\"}, \"BlockStorage\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"BlockStorageCount\"}, \"removal_policies\": {\"get_param\": \"BlockStorageRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"BlockStorageRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::BlockStorage\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"BlockStorageServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"BlockStorageHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"BlockStorageSchedulerHints\": {\"map_merge\": [{\"get_param\": \"BlockStorageSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"BlockStorageParameters\"}]}, \"UserData\": {\"get_resource\": \"BlockStorageUserData\"}}}}}, \"ObjectStorageServiceChain\": {\"type\": \"OS::TripleO::ObjectStorageServices\", \"properties\": {\"Services\": {\"get_param\": \"ObjectStorageServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ObjectStorageServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"ObjectStorage\", \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"ObjectStorageParameters\"}]}}}, \"ObjectStorageServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"ObjectStorageServiceChain\", \"role_data\"]}}}, \"ObjectStorageConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"ObjectStorageServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"ObjectStorageExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"ObjectStorageServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}}}}]}}}, \"ObjectStorageServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"ObjectStorageServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"ObjectStorageServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"ObjectStorageServiceNetMap\"}}}}]}}}, \"ObjectStorageIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"ObjectStorage\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"ObjectStorage\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"ObjectStorage\", \"storage_mgmt_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"ObjectStorage\", \"internal_api_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"EnabledServices\": {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"ObjectStorageServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"ObjectStorage\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"ObjectStorageNetworkHostnameMap\", \"value\"]}}}, \"ObjectStorageNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"ObjectStorage\", \"hostname_map\"]}]}}}}, \"ObjectStorageUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"ObjectStorageRoleUserData\"}, \"type\": \"multipart\"}]}}, \"ObjectStorageRoleUserData\": {\"type\": \"OS::TripleO::ObjectStorage::NodeUserData\"}, \"ObjectStorage\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"ObjectStorageCount\"}, \"removal_policies\": {\"get_param\": \"ObjectStorageRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"ObjectStorageRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::ObjectStorage\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ObjectStorageServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"ObjectStorageHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"ObjectStorageSchedulerHints\": {\"map_merge\": [{\"get_param\": \"ObjectStorageSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"ObjectStorageParameters\"}]}, \"UserData\": {\"get_resource\": \"ObjectStorageUserData\"}}}}}, \"CephStorageServiceChain\": {\"type\": \"OS::TripleO::CephStorageServices\", \"properties\": {\"Services\": {\"get_param\": \"CephStorageServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CephStorageServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"CephStorage\", \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"CephStorageParameters\"}]}}}, \"CephStorageServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"CephStorageServiceChain\", \"role_data\"]}}}, \"CephStorageConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"CephStorageServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"CephStorageExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"CephStorageServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}}}}]}}}, \"CephStorageServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CephStorageServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"CephStorageServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"CephStorageServiceNetMap\"}}}}]}}}, \"CephStorageIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"CephStorage\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"CephStorage\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"CephStorage\", \"storage_mgmt_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"EnabledServices\": {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"CephStorageServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"CephStorage\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"CephStorageNetworkHostnameMap\", \"value\"]}}}, \"CephStorageNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"CephStorage\", \"hostname_map\"]}]}}}}, \"CephStorageUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"CephStorageRoleUserData\"}, \"type\": \"multipart\"}]}}, \"CephStorageRoleUserData\": {\"type\": \"OS::TripleO::CephStorage::NodeUserData\"}, \"CephStorage\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"CephStorageCount\"}, \"removal_policies\": {\"get_param\": \"CephStorageRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"CephStorageRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::CephStorage\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CephStorageServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"CephStorageHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"CephStorageSchedulerHints\": {\"map_merge\": [{\"get_param\": \"CephStorageSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"CephStorageParameters\"}]}, \"UserData\": {\"get_resource\": \"CephStorageUserData\"}}}}}, \"NetworkerServiceChain\": {\"type\": \"OS::TripleO::NetworkerServices\", \"properties\": {\"Services\": {\"get_param\": \"NetworkerServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"NetworkerServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"Networker\", \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"NetworkerParameters\"}]}}}, \"NetworkerServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"NetworkerServiceChain\", \"role_data\"]}}}, \"NetworkerConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"NetworkerServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"NetworkerExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"NetworkerServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}}}}]}}}, \"NetworkerServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"NetworkerServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetworkerServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"NetworkerServiceNetMap\"}}}}]}}}, \"NetworkerIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"Networker\", \"ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"Networker\", \"internal_api_ip_address\"]}, \"TenantIpList\": {\"get_attr\": [\"Networker\", \"tenant_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"internal_api\", \"tenant\"], \"EnabledServices\": {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"NetworkerServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"Networker\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"NetworkerNetworkHostnameMap\", \"value\"]}}}, \"NetworkerNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"Networker\", \"hostname_map\"]}]}}}}, \"NetworkerUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NetworkerRoleUserData\"}, \"type\": \"multipart\"}]}}, \"NetworkerRoleUserData\": {\"type\": \"OS::TripleO::Networker::NodeUserData\"}, \"Networker\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"NetworkerCount\"}, \"removal_policies\": {\"get_param\": \"NetworkerRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"NetworkerRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::Networker\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"NetworkerServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"NetworkerHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"NetworkerSchedulerHints\": {\"map_merge\": [{\"get_param\": \"NetworkerSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"NetworkerParameters\"}]}, \"UserData\": {\"get_resource\": \"NetworkerUserData\"}}}}}, \"ControllerServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"Controller\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"Controller\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"CellControllerServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CellController\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"CellController\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"CellControllerComputeServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CellControllerCompute\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"CellControllerCompute\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"ComputeServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"Compute\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"Compute\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"BlockStorageServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"BlockStorage\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"BlockStorage\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"ObjectStorageServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"ObjectStorage\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"ObjectStorage\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"CephStorageServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CephStorage\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"CephStorage\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"NetworkerServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"Networker\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"Networker\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"ServerIdMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"server_ids\": {\"Controller\": {\"get_attr\": [\"Controller\", \"nova_server_resource\"]}, \"CellController\": {\"get_attr\": [\"CellController\", \"nova_server_resource\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerCompute\", \"nova_server_resource\"]}, \"Compute\": {\"get_attr\": [\"Compute\", \"nova_server_resource\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorage\", \"nova_server_resource\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorage\", \"nova_server_resource\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorage\", \"nova_server_resource\"]}, \"Networker\": {\"get_attr\": [\"Networker\", \"nova_server_resource\"]}}, \"bootstrap_server_id\": {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"nova_server_resource\"]}}}}}}, \"DeploymentServerBlacklistDict\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"hostname\": 1}, \"for_each\": {\"hostname\": {\"get_param\": \"DeploymentServerBlacklist\"}}}}}}}, \"HostsEntryValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"list_concat_unique\": {\"list_concat\": [[{\"get_param\": \"UndercloudHostsEntries\"}], [{\"if\": [\"add_vips_to_etc_hosts\", {\"get_attr\": [\"VipHosts\", \"value\"]}, []]}], {\"get_attr\": [\"Controller\", \"hosts_entry\"]}, {\"get_attr\": [\"CellController\", \"hosts_entry\"]}, {\"get_attr\": [\"CellControllerCompute\", \"hosts_entry\"]}, {\"get_attr\": [\"Compute\", \"hosts_entry\"]}, {\"get_attr\": [\"BlockStorage\", \"hosts_entry\"]}, {\"get_attr\": [\"ObjectStorage\", \"hosts_entry\"]}, {\"get_attr\": [\"CephStorage\", \"hosts_entry\"]}, {\"get_attr\": [\"Networker\", \"hosts_entry\"]}, [{\"get_param\": \"ExtraHostFileEntries\"}]]}}}}, \"CloudNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"cloud_name_storage\": {\"get_param\": \"CloudNameStorage\"}, \"cloud_name_storage_mgmt\": {\"get_param\": \"CloudNameStorageManagement\"}, \"cloud_name_internal_api\": {\"get_param\": \"CloudNameInternal\"}, \"cloud_name_external\": {\"get_param\": \"CloudName\"}, \"cloud_name_ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}}}}, \"GlobalConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}]}}}, \"Networks\": {\"type\": \"OS::TripleO::Network\", \"depends_on\": \"ServiceNetMap\", \"properties\": {\"CtlplaneNetworkCidrs\": {\"get_attr\": [\"ControlVirtualIP\", \"network\", \"tags\"]}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}]}, \"ssl_frontend\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}]}, \"edge_frontend\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}]}, \"edge_ssl_frontend\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}]}}}}, \"ControllerGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"tenant_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, \"tenant_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"tenant_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"Tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"ControllerLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"ControllerNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"primary\", \"controller\", \"external_bridge\"], \"service_net_map\": {\"get_attr\": [\"ControllerServiceNetMapLower\", \"value\"]}}}}, \"ControllerNetworkConfig\": {\"type\": \"OS::TripleO::Controller::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"TenantIpSubnet\": \"{{ tenant_ip ~ \'/\' ~ tenant_cidr }}\", \"TenantInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"TenantMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"TenantNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}}}, \"CellControllerGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"tenant_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, \"tenant_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"tenant_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"Tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"CellControllerLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"CellControllerNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"primary\", \"controller\"], \"service_net_map\": {\"get_attr\": [\"CellControllerServiceNetMapLower\", \"value\"]}}}}, \"CellControllerNetworkConfig\": {\"type\": \"OS::TripleO::CellController::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"TenantIpSubnet\": \"{{ tenant_ip ~ \'/\' ~ tenant_cidr }}\", \"TenantInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"TenantMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"TenantNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}}}, \"CellControllerComputeGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"tenant_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, \"tenant_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"tenant_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"Tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"CellControllerComputeLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"CellControllerComputeNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"primary\", \"controller\", \"external_bridge\"], \"service_net_map\": {\"get_attr\": [\"CellControllerComputeServiceNetMapLower\", \"value\"]}}}}, \"CellControllerComputeNetworkConfig\": {\"type\": \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"TenantIpSubnet\": \"{{ tenant_ip ~ \'/\' ~ tenant_cidr }}\", \"TenantInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"TenantMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"TenantNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}}}, \"ComputeGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"tenant_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, \"tenant_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"tenant_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"Tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"ComputeLocalMtu\"}, \"role_networks\": [\"Storage\", \"InternalApi\", \"Tenant\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"ComputeNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"compute\", \"external_bridge\"], \"service_net_map\": {\"get_attr\": [\"ComputeServiceNetMapLower\", \"value\"]}}}}, \"ComputeNetworkConfig\": {\"type\": \"OS::TripleO::Compute::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"TenantIpSubnet\": \"{{ tenant_ip ~ \'/\' ~ tenant_cidr }}\", \"TenantInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"TenantMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"TenantNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}}}, \"BlockStorageGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"BlockStorageLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"BlockStorageNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"storage\"], \"service_net_map\": {\"get_attr\": [\"BlockStorageServiceNetMapLower\", \"value\"]}}}}, \"BlockStorageNetworkConfig\": {\"type\": \"OS::TripleO::BlockStorage::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}}}, \"ObjectStorageGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"ObjectStorageLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"ObjectStorageNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"storage\"], \"service_net_map\": {\"get_attr\": [\"ObjectStorageServiceNetMapLower\", \"value\"]}}}}, \"ObjectStorageNetworkConfig\": {\"type\": \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}}}, \"CephStorageGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"CephStorageLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"CephStorageNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"ceph\", \"storage\"], \"service_net_map\": {\"get_attr\": [\"CephStorageServiceNetMapLower\", \"value\"]}}}}, \"CephStorageNetworkConfig\": {\"type\": \"OS::TripleO::CephStorage::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}}}, \"NetworkerGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"tenant_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, \"tenant_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"tenant_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"Tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"NetworkerLocalMtu\"}, \"role_networks\": [\"InternalApi\", \"Tenant\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"NetworkerNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"external_bridge\"], \"service_net_map\": {\"get_attr\": [\"NetworkerServiceNetMapLower\", \"value\"]}}}}, \"NetworkerNetworkConfig\": {\"type\": \"OS::TripleO::Networker::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"TenantIpSubnet\": \"{{ tenant_ip ~ \'/\' ~ tenant_cidr }}\", \"TenantInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"TenantMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"TenantNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}}}, \"ControlVirtualIP\": {\"depends_on\": \"ServiceNetMap\", \"type\": \"OS::TripleO::Network::Ports::ControlPlaneVipPort\", \"properties\": {\"name\": \"control_virtual_ip\", \"dns_name\": {\"str_split\": [\".\", {\"get_param\": \"CloudNameCtlplane\"}, 0]}, \"network\": {\"get_param\": \"NeutronControlPlaneID\"}, \"fixed_ips\": {\"if\": [\"control_fixed_ip_not_set\", [{\"subnet\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}}], {\"get_param\": \"ControlFixedIPs\"}]}, \"replacement_policy\": \"AUTO\", \"tags\": [\"tripleo_vip_net=ctlplane\", {\"str_replace\": {\"template\": \"tripleo_stack_name=$STACK_NAME\", \"params\": {\"$STACK_NAME\": {\"get_param\": \"OS::stack_name\"}}}}]}}, \"StorageVirtualIP\": {\"depends_on\": [\"Networks\", \"ServiceNetMap\"], \"type\": \"OS::TripleO::Network::Ports::StorageVipPort\", \"properties\": {\"ControlPlaneIP\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}, \"cidr\"]}, 1]}, \"PortName\": \"storage_virtual_ip\", \"DnsName\": {\"str_split\": [\".\", {\"get_param\": \"CloudNameStorage\"}, 0]}, \"FixedIPs\": {\"if\": [\"storage_virtual_fixed_ip_set\", {\"get_param\": \"StorageVirtualFixedIPs\"}, [{\"subnet\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"Storage\"]}}]]}, \"IsVirtualIP\": true}}, \"StorageMgmtVirtualIP\": {\"depends_on\": [\"Networks\", \"ServiceNetMap\"], \"type\": \"OS::TripleO::Network::Ports::StorageMgmtVipPort\", \"properties\": {\"ControlPlaneIP\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}, \"cidr\"]}, 1]}, \"PortName\": \"storage_mgmt_virtual_ip\", \"DnsName\": {\"str_split\": [\".\", {\"get_param\": \"CloudNameStorageManagement\"}, 0]}, \"FixedIPs\": {\"if\": [\"storage_mgmt_virtual_fixed_ip_set\", {\"get_param\": \"StorageMgmtVirtualFixedIPs\"}, [{\"subnet\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"StorageMgmt\"]}}]]}, \"IsVirtualIP\": true}}, \"InternalApiVirtualIP\": {\"depends_on\": [\"Networks\", \"ServiceNetMap\"], \"type\": \"OS::TripleO::Network::Ports::InternalApiVipPort\", \"properties\": {\"ControlPlaneIP\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}, \"cidr\"]}, 1]}, \"PortName\": \"internal_api_virtual_ip\", \"DnsName\": {\"str_split\": [\".\", {\"get_param\": \"CloudNameInternal\"}, 0]}, \"FixedIPs\": {\"if\": [\"internal_api_virtual_fixed_ip_set\", {\"get_param\": \"InternalApiVirtualFixedIPs\"}, [{\"subnet\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"InternalApi\"]}}]]}, \"IsVirtualIP\": true}}, \"PublicVirtualIP\": {\"depends_on\": [\"Networks\", \"ServiceNetMap\"], \"type\": \"OS::TripleO::Network::Ports::ExternalVipPort\", \"properties\": {\"ControlPlaneIP\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}, \"cidr\"]}, 1]}, \"PortName\": \"external_virtual_ip\", \"DnsName\": {\"str_split\": [\".\", {\"get_param\": \"CloudName\"}, 0]}, \"FixedIPs\": {\"if\": [\"public_virtual_fixed_ip_set\", {\"get_param\": \"PublicVirtualFixedIPs\"}, [{\"subnet\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"External\"]}}]]}, \"IsVirtualIP\": true}}, \"VipMap\": {\"type\": \"OS::TripleO::Network::Ports::NetVipMap\", \"properties\": {\"ControlPlaneIp\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}, \"cidr\"]}, 1]}, \"StorageIp\": {\"get_attr\": [\"StorageVirtualIP\", \"ip_address\"]}, \"StorageIpUri\": {\"get_attr\": [\"StorageVirtualIP\", \"ip_address_uri\"]}, \"StorageMgmtIp\": {\"get_attr\": [\"StorageMgmtVirtualIP\", \"ip_address\"]}, \"StorageMgmtIpUri\": {\"get_attr\": [\"StorageMgmtVirtualIP\", \"ip_address_uri\"]}, \"InternalApiIp\": {\"get_attr\": [\"InternalApiVirtualIP\", \"ip_address\"]}, \"InternalApiIpUri\": {\"get_attr\": [\"InternalApiVirtualIP\", \"ip_address_uri\"]}, \"ExternalIp\": {\"get_attr\": [\"PublicVirtualIP\", \"ip_address\"]}, \"ExternalIpUri\": {\"get_attr\": [\"PublicVirtualIP\", \"ip_address_uri\"]}}, \"depends_on\": \"ServiceNetMap\"}, \"AllNodesExtraConfig\": {\"type\": \"OS::TripleO::AllNodesExtraConfig\", \"properties\": {\"servers\": {\"Controller\": {\"get_attr\": [\"ControllerServers\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerServers\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeServers\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeServers\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageServers\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageServers\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageServers\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerServers\", \"value\"]}}}}, \"BlacklistedIpAddresses\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"list_concat\": [{\"get_attr\": [\"Controller\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"CellController\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"CellControllerCompute\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"Compute\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"BlockStorage\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"ObjectStorage\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"CephStorage\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"Networker\", \"blacklist_ip_address\"]}]}}}, \"AnsibleHostVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"Controller\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"Controller\", \"ansible_host_vars_map\"]}]}}, \"CellController\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"CellController\", \"ansible_host_vars_map\"]}]}}, \"CellControllerCompute\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"CellControllerCompute\", \"ansible_host_vars_map\"]}]}}, \"Compute\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"Compute\", \"ansible_host_vars_map\"]}]}}, \"BlockStorage\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"BlockStorage\", \"ansible_host_vars_map\"]}]}}, \"ObjectStorage\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"ObjectStorage\", \"ansible_host_vars_map\"]}]}}, \"CephStorage\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"CephStorage\", \"ansible_host_vars_map\"]}]}}, \"Networker\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"Networker\", \"ansible_host_vars_map\"]}]}}}}}, \"BlacklistedHostnames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"list_concat\": [{\"get_attr\": [\"Controller\", \"blacklist_hostname\"]}, {\"get_attr\": [\"CellController\", \"blacklist_hostname\"]}, {\"get_attr\": [\"CellControllerCompute\", \"blacklist_hostname\"]}, {\"get_attr\": [\"Compute\", \"blacklist_hostname\"]}, {\"get_attr\": [\"BlockStorage\", \"blacklist_hostname\"]}, {\"get_attr\": [\"ObjectStorage\", \"blacklist_hostname\"]}, {\"get_attr\": [\"CephStorage\", \"blacklist_hostname\"]}, {\"get_attr\": [\"Networker\", \"blacklist_hostname\"]}]}}}, \"AllNodesDeploySteps\": {\"type\": \"OS::TripleO::PostDeploySteps\", \"depends_on\": [\"AllNodesExtraConfig\"], \"properties\": {\"servers\": {\"Controller\": {\"get_attr\": [\"ControllerServers\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerServers\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeServers\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeServers\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageServers\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageServers\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageServers\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerServers\", \"value\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"role_data\": {\"Controller\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\"]}}, \"ControllerCount\": {\"get_param\": \"ControllerCount\"}, \"CellControllerCount\": {\"get_param\": \"CellControllerCount\"}, \"CellControllerComputeCount\": {\"get_param\": \"CellControllerComputeCount\"}, \"ComputeCount\": {\"get_param\": \"ComputeCount\"}, \"BlockStorageCount\": {\"get_param\": \"BlockStorageCount\"}, \"ObjectStorageCount\": {\"get_param\": \"ObjectStorageCount\"}, \"CephStorageCount\": {\"get_param\": \"CephStorageCount\"}, \"NetworkerCount\": {\"get_param\": \"NetworkerCount\"}, \"ServiceNetMapLower\": {\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, \"PingTestGatewayIPsMap\": {\"Controller\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}]}}, \"CellController\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}]}}, \"CellControllerCompute\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}]}}, \"Compute\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}]}}, \"BlockStorage\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}]}}, \"ObjectStorage\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}]}}, \"CephStorage\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}]}}, \"Networker\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}]}}}, \"PingTestIpsMap\": {\"Controller\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Controller\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Controller\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Controller\", \"storage_mgmt_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Controller\", \"internal_api_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Controller\", \"tenant_ip_address\"]}}}]]}, \"CellController\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellController\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellController\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellController\", \"storage_mgmt_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellController\", \"internal_api_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellController\", \"tenant_ip_address\"]}}}]]}, \"CellControllerCompute\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"storage_mgmt_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"internal_api_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"tenant_ip_address\"]}}}]]}, \"Compute\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Compute\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Compute\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Compute\", \"internal_api_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Compute\", \"tenant_ip_address\"]}}}]]}, \"BlockStorage\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"BlockStorage\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"BlockStorage\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"BlockStorage\", \"storage_mgmt_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"BlockStorage\", \"internal_api_ip_address\"]}}}]]}, \"ObjectStorage\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"ObjectStorage\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"ObjectStorage\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"ObjectStorage\", \"storage_mgmt_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"ObjectStorage\", \"internal_api_ip_address\"]}}}]]}, \"CephStorage\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CephStorage\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CephStorage\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CephStorage\", \"storage_mgmt_ip_address\"]}}}]]}, \"Networker\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Networker\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Networker\", \"internal_api_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Networker\", \"tenant_ip_address\"]}}}]]}}, \"HostsEntry\": {\"get_attr\": [\"HostsEntryValue\", \"value\"]}, \"EnabledServices\": {\"list_concat\": [{\"get_attr\": [\"ControllerServiceNames\", \"value\"]}, {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}, {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}, {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}, {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}, {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}, {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}, {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}]}, \"ControlVirtualIP\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"EnabledNetworks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"NetVipMap\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"CloudNames\": {\"get_attr\": [\"CloudNames\", \"value\"]}, \"UndercloudHostsEntries\": {\"get_param\": \"UndercloudHostsEntries\"}, \"ExtraHostsEntries\": {\"get_param\": \"ExtraHostFileEntries\"}, \"VipHostsEntries\": {\"if\": [\"add_vips_to_etc_hosts\", {\"get_attr\": [\"VipHosts\", \"value\"]}, []]}, \"KeystoneResourcesConfigs\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"keystone_resources\"]}]}, \"NetCidrMap\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}}}}, \"outputs\": {\"ManagedEndpoints\": {\"description\": \"Asserts that the keystone endpoints have been provisioned.\", \"value\": true}, \"KeystoneURL\": {\"description\": \"URL for the Overcloud Keystone service\", \"value\": {\"get_attr\": [\"EndpointMapData\", \"value\", \"KeystonePublic\", \"uri_no_suffix\"]}}, \"KeystoneAdminVip\": {\"description\": \"Keystone Admin VIP endpoint\", \"value\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", {\"get_attr\": [\"ServiceNetMap\", \"service_net_map\", \"KeystoneAdminApiNetwork\"]}]}}, \"EndpointMap\": {\"description\": \"Mapping of the resources with the needed info for their endpoints.\\nThis includes the protocol used, the IP, port and also a full\\nrepresentation of the URI.\\n\", \"value\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}}, \"HostsEntry\": {\"description\": \"The content that should be appended to your /etc/hosts if you want to get\\nhostname-based access to the deployed nodes (useful for testing without\\nsetting up a DNS).\\n\", \"value\": {\"list_concat_unique\": [{\"get_attr\": [\"HostsEntryValue\", \"value\"]}, {\"get_attr\": [\"VipHosts\", \"value\"]}]}}, \"EnabledServices\": {\"description\": \"The services enabled on each role\", \"value\": {\"Controller\": {\"get_attr\": [\"ControllerServiceNames\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}}}, \"RoleData\": {\"description\": \"The configuration data associated with each role\", \"value\": {\"Controller\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\"]}}}, \"RoleConfig\": {\"description\": \"The configuration workflows associated with each role\", \"value\": {\"get_attr\": [\"AllNodesDeploySteps\", \"RoleConfig\"]}}, \"RoleNetIpMap\": {\"description\": \"Mapping of each network to a list of IPs for each role\", \"value\": {\"Controller\": {\"get_attr\": [\"ControllerIpListMap\", \"net_ip_map\"]}, \"CellController\": {\"get_attr\": [\"CellControllerIpListMap\", \"net_ip_map\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeIpListMap\", \"net_ip_map\"]}, \"Compute\": {\"get_attr\": [\"ComputeIpListMap\", \"net_ip_map\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageIpListMap\", \"net_ip_map\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageIpListMap\", \"net_ip_map\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageIpListMap\", \"net_ip_map\"]}, \"Networker\": {\"get_attr\": [\"NetworkerIpListMap\", \"net_ip_map\"]}}}, \"RoleGroupVars\": {\"description\": \"Mapping of roles to ansible group_vars to be applied config in those roles\", \"value\": {\"Controller\": {\"map_merge\": [{\"get_attr\": [\"ControllerGroupVars\", \"value\"]}, {\"get_attr\": [\"ControllerConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"ControllerAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"ControllerMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"ControllerNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"ControllerUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"ControllerIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"ControllerNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"ControllerExtraGroupVars\"}]}, \"CellController\": {\"map_merge\": [{\"get_attr\": [\"CellControllerGroupVars\", \"value\"]}, {\"get_attr\": [\"CellControllerConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"CellControllerAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"CellControllerMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"CellControllerNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"CellControllerUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"CellControllerIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"CellControllerNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"CellControllerExtraGroupVars\"}]}, \"CellControllerCompute\": {\"map_merge\": [{\"get_attr\": [\"CellControllerComputeGroupVars\", \"value\"]}, {\"get_attr\": [\"CellControllerComputeConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"CellControllerComputeAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"CellControllerComputeMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"CellControllerComputeNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"CellControllerComputeUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"CellControllerComputeIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"CellControllerComputeNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"CellControllerComputeExtraGroupVars\"}]}, \"Compute\": {\"map_merge\": [{\"get_attr\": [\"ComputeGroupVars\", \"value\"]}, {\"get_attr\": [\"ComputeConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"ComputeAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"ComputeMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"ComputeNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"ComputeUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"ComputeIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"ComputeNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"ComputeExtraGroupVars\"}]}, \"BlockStorage\": {\"map_merge\": [{\"get_attr\": [\"BlockStorageGroupVars\", \"value\"]}, {\"get_attr\": [\"BlockStorageConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"BlockStorageAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"BlockStorageMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"BlockStorageNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"BlockStorageUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"BlockStorageIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"BlockStorageNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"BlockStorageExtraGroupVars\"}]}, \"ObjectStorage\": {\"map_merge\": [{\"get_attr\": [\"ObjectStorageGroupVars\", \"value\"]}, {\"get_attr\": [\"ObjectStorageConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"ObjectStorageAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"ObjectStorageMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"ObjectStorageNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"ObjectStorageUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"ObjectStorageIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"ObjectStorageNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"ObjectStorageExtraGroupVars\"}]}, \"CephStorage\": {\"map_merge\": [{\"get_attr\": [\"CephStorageGroupVars\", \"value\"]}, {\"get_attr\": [\"CephStorageConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"CephStorageAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"CephStorageMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"CephStorageNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"CephStorageUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"CephStorageIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"CephStorageNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"CephStorageExtraGroupVars\"}]}, \"Networker\": {\"map_merge\": [{\"get_attr\": [\"NetworkerGroupVars\", \"value\"]}, {\"get_attr\": [\"NetworkerConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"NetworkerAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"NetworkerMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"NetworkerNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"NetworkerUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"NetworkerIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"NetworkerNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"NetworkerExtraGroupVars\"}]}}}, \"RoleNetHostnameMap\": {\"description\": \"Mapping of each network to a list of hostnames for each role\", \"value\": {\"Controller\": {\"get_attr\": [\"ControllerNetworkHostnameMap\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerNetworkHostnameMap\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeNetworkHostnameMap\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeNetworkHostnameMap\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageNetworkHostnameMap\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageNetworkHostnameMap\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageNetworkHostnameMap\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerNetworkHostnameMap\", \"value\"]}}}, \"RoleTags\": {\"description\": \"Tags for each role, as defined in roles_data.yaml\", \"value\": {\"Controller\": [\"primary\", \"controller\", \"external_bridge\"], \"CellController\": [\"primary\", \"controller\"], \"CellControllerCompute\": [\"primary\", \"controller\", \"external_bridge\"], \"Compute\": [\"compute\", \"external_bridge\"], \"BlockStorage\": [\"storage\"], \"ObjectStorage\": [\"storage\"], \"CephStorage\": [\"ceph\", \"storage\"], \"Networker\": [\"external_bridge\"]}}, \"VipMap\": {\"description\": \"Mapping of each network to VIP addresses. Also includes the Redis and OVN DBs VIPs.\", \"value\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}}, \"ServerIdData\": {\"description\": \"Mapping of each role to a list of nova server IDs and the bootstrap ID\", \"value\": {\"get_attr\": [\"ServerIdMap\", \"value\"]}}, \"BlacklistedHostnames\": {\"description\": \"List of blacklisted hostnames\", \"value\": {\"get_attr\": [\"BlacklistedHostnames\", \"value\"]}}, \"BlacklistedIpAddresses\": {\"description\": \"List of blacklisted ctlplane IP addresses\", \"value\": {\"get_attr\": [\"BlacklistedIpAddresses\", \"value\"]}}, \"GlobalConfig\": {\"description\": \"The global_config (hieradata).\", \"value\": {\"get_attr\": [\"GlobalConfig\", \"value\"]}}, \"RoleNetworkConfigMap\": {\"description\": \"Mapping of roles to network config\", \"value\": {\"Controller\": {\"get_attr\": [\"ControllerNetworkConfig\", \"config\"]}, \"CellController\": {\"get_attr\": [\"CellControllerNetworkConfig\", \"config\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeNetworkConfig\", \"config\"]}, \"Compute\": {\"get_attr\": [\"ComputeNetworkConfig\", \"config\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageNetworkConfig\", \"config\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageNetworkConfig\", \"config\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageNetworkConfig\", \"config\"]}, \"Networker\": {\"get_attr\": [\"NetworkerNetworkConfig\", \"config\"]}}}, \"AnsibleHostVarsMap\": {\"description\": \"Map of Ansible Host variables per role\", \"value\": {\"get_attr\": [\"AnsibleHostVars\", \"value\"]}}, \"TripleoHeatTemplatesJinja2RenderingDataSources\": {\"description\": \"The role_data and the network_data used when rendering the THT Jinja2 templates\", \"value\": {\"roles_data\": [{\"name\": \"Controller\", \"description\": \"Controller role that has all the controler services loaded and handles\\\\nDatabase, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\", \"external_bridge\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BarbicanApi\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\", \"OS::TripleO::Services::BarbicanBackendDogtag\", \"OS::TripleO::Services::BarbicanBackendKmip\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::CephGrafana\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CephNfs\", \"OS::TripleO::Services::CephRbdMirror\", \"OS::TripleO::Services::CephRgw\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackendDellSc\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\", \"OS::TripleO::Services::CinderBackendDellEMCSc\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\", \"OS::TripleO::Services::CinderBackendNetApp\", \"OS::TripleO::Services::CinderBackendPure\", \"OS::TripleO::Services::CinderBackendScaleIO\", \"OS::TripleO::Services::CinderBackendNVMeOF\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::DesignateApi\", \"OS::TripleO::Services::DesignateCentral\", \"OS::TripleO::Services::DesignateProducer\", \"OS::TripleO::Services::DesignateWorker\", \"OS::TripleO::Services::DesignateMDNS\", \"OS::TripleO::Services::DesignateSink\", \"OS::TripleO::Services::DesignateBind\", \"OS::TripleO::Services::Etcd\", \"OS::TripleO::Services::ExternalSwiftProxy\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::IronicApi\", \"OS::TripleO::Services::IronicConductor\", \"OS::TripleO::Services::IronicInspector\", \"OS::TripleO::Services::IronicPxe\", \"OS::TripleO::Services::IronicNeutronAgent\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaBackendFlashBlade\", \"OS::TripleO::Services::ManilaBackendIsilon\", \"OS::TripleO::Services::ManilaBackendNetapp\", \"OS::TripleO::Services::ManilaBackendPowerMax\", \"OS::TripleO::Services::ManilaBackendUnity\", \"OS::TripleO::Services::ManilaBackendVNX\", \"OS::TripleO::Services::ManilaBackendVMAX\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronBgpVpnApi\", \"OS::TripleO::Services::NeutronSfcApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NeutronDhcpAgent\", \"OS::TripleO::Services::NeutronL2gwAgent\", \"OS::TripleO::Services::NeutronL2gwApi\", \"OS::TripleO::Services::NeutronL3Agent\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NeutronOvsAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NeutronAgentsIBConfig\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaIronic\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OctaviaApi\", \"OS::TripleO::Services::OctaviaDeploymentConfig\", \"OS::TripleO::Services::OctaviaHealthManager\", \"OS::TripleO::Services::OctaviaHousekeeping\", \"OS::TripleO::Services::OctaviaWorker\", \"OS::TripleO::Services::OpenStackClients\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftDispersion\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Unbound\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"CellController\", \"description\": \"Controller role that has the cell controler specific\\\\nservices and handles Database, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Ptp\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"CellControllerCompute\", \"description\": \"Controller and Compute AIO role that has compute and cell controler specific\\\\nservices loaded and handles Database, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\", \"external_bridge\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-compute-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\", \"OS::TripleO::Services::ComputeNeutronL3Agent\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NovaAZConfig\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Ptp\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"Compute\", \"description\": \"Basic Compute Node role\\\\n\", \"CountDefault\": 1, \"tags\": [\"compute\", \"external_bridge\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-novacompute-%index%\", \"RoleParametersDefault\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"uses_deprecated_params\": true, \"deprecated_param_image\": \"NovaImage\", \"deprecated_param_extraconfig\": \"NovaComputeExtraConfig\", \"deprecated_param_metadata\": \"NovaComputeServerMetadata\", \"deprecated_param_scheduler_hints\": \"NovaComputeSchedulerHints\", \"deprecated_param_ips\": \"NovaComputeIPs\", \"deprecated_server_resource_name\": \"NovaCompute\", \"deprecated_nic_config_name\": \"compute.yaml\", \"update_serial\": 25, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\", \"OS::TripleO::Services::ComputeNeutronL3Agent\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NovaAZConfig\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"]}, {\"name\": \"BlockStorage\", \"description\": \"Cinder Block Storage node role\\\\n\", \"tags\": [\"storage\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": false, \"deprecated_nic_config_name\": \"cinder-storage.yaml\", \"update_serial\": 25, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BlockStorageCinderVolume\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}, {\"name\": \"ObjectStorage\", \"description\": \"Swift Object Storage node role\\\\n\", \"tags\": [\"storage\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": true, \"deprecated_param_metadata\": \"SwiftStorageServerMetadata\", \"deprecated_param_ips\": \"SwiftStorageIPs\", \"deprecated_param_image\": \"SwiftStorageImage\", \"deprecated_param_flavor\": \"OvercloudSwiftStorageFlavor\", \"deprecated_nic_config_name\": \"swift-storage.yaml\", \"deprecated_server_resource_name\": \"SwiftStorage\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Ptp\"]}, {\"name\": \"CephStorage\", \"description\": \"Ceph OSD Storage node role\\\\n\", \"tags\": [\"ceph\", \"storage\"], \"networks\": {\"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": false, \"HostnameFormatDefault\": \"%stackname%-cephstorage-%index%\", \"deprecated_nic_config_name\": \"ceph-storage.yaml\", \"update_serial\": 1, \"rhsm_enforce\": false, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}, {\"name\": \"Networker\", \"description\": \"Standalone networking role to run Neutron agents on their own.\\\\n\", \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"tags\": [\"external_bridge\"], \"HostnameFormatDefault\": \"%stackname%-networker-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::IronicNeutronAgent\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronDhcpAgent\", \"OS::TripleO::Services::NeutronL2gwAgent\", \"OS::TripleO::Services::NeutronL3Agent\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NeutronOvsAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OctaviaDeploymentConfig\", \"OS::TripleO::Services::OctaviaHealthManager\", \"OS::TripleO::Services::OctaviaHousekeeping\", \"OS::TripleO::Services::OctaviaWorker\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}], \"networks_data\": [{\"name\": \"Storage\", \"mtu\": 1500, \"vip\": true, \"name_lower\": \"storage\", \"dns_domain\": \"storage.ooo.test.\", \"service_net_map_replace\": \"storage\", \"subnets\": {\"storage_subnet\": {\"vlan\": 21, \"ip_subnet\": \"172.18.0.0/24\", \"allocation_pools\": [{\"start\": \"172.18.0.160\", \"end\": \"172.18.0.250\"}]}}, \"idx\": 0}, {\"name\": \"StorageMgmt\", \"mtu\": 1500, \"vip\": true, \"name_lower\": \"storage_mgmt\", \"dns_domain\": \"storagemgmt.ooo.test.\", \"service_net_map_replace\": \"storage_mgmt\", \"subnets\": {\"storage_mgmt_subnet\": {\"vlan\": 23, \"ip_subnet\": \"172.20.0.0/24\", \"allocation_pools\": [{\"start\": \"172.20.0.160\", \"end\": \"172.20.0.250\"}]}}, \"idx\": 1}, {\"name\": \"InternalApi\", \"mtu\": 1500, \"vip\": true, \"name_lower\": \"internal_api\", \"dns_domain\": \"internal-api.ooo.test.\", \"service_net_map_replace\": \"internal_api\", \"subnets\": {\"internal_api_subnet\": {\"vlan\": 20, \"ip_subnet\": \"172.17.0.0/24\", \"allocation_pools\": [{\"start\": \"172.17.0.160\", \"end\": \"172.17.0.250\"}]}}, \"idx\": 2}, {\"name\": \"Tenant\", \"mtu\": 1500, \"vip\": false, \"name_lower\": \"tenant\", \"dns_domain\": \"tenant.ooo.test.\", \"service_net_map_replace\": \"tenant\", \"subnets\": {\"tenant_subnet\": {\"vlan\": 22, \"ip_subnet\": \"172.19.0.0/24\", \"allocation_pools\": [{\"start\": \"172.19.0.160\", \"end\": \"172.19.0.250\"}]}}, \"idx\": 3}, {\"name\": \"External\", \"mtu\": 1500, \"vip\": true, \"name_lower\": \"external\", \"dns_domain\": \"external.ooo.test.\", \"service_net_map_replace\": \"external\", \"subnets\": {\"external_subnet\": {\"gateway_ip\": \"172.21.0.1\", \"vlan\": 44, \"ip_subnet\": \"172.21.0.0/24\", \"allocation_pools\": [{\"start\": \"172.21.0.160\", \"end\": \"172.21.0.250\"}]}}, \"idx\": 4}]}}, \"AdminPassword\": {\"description\": \"The password for the keystone admin account, used for monitoring, querying neutron etc.\", \"value\": {\"get_param\": \"AdminPassword\"}}, \"KeystoneRegion\": {\"description\": \"Keystone region for endpoint\", \"value\": {\"get_param\": \"KeystoneRegion\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(2,'2026-06-12 08:25:37',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mapping of service_name_network -> network name\\n\", \"parameters\": {\"ServiceNetMap\": {\"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults. Note that the key in this map must match the service_name in the service template, e.g if the service_name is heat_api the key must be either heat_api_network, or optionally HeatApiNetwork (which will be internally converted to transform captalization to underscores).\", \"type\": \"json\", \"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"VipSubnetMap\": {\"description\": \"Map of (network_name or service_name) -> subnet_name that defines which subnet to host the VIP. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\", \"default\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMapDeprecatedMapping\": {\"default\": {\"RabbitMqNetwork\": \"RabbitmqNetwork\", \"CephPublicNetwork\": \"CephMonNetwork\", \"SwiftMgmtNetwork\": \"SwiftStorageNetwork\"}, \"description\": \"Mapping older deprecated service names, intended for internal use only, this will be removed in future.\", \"type\": \"json\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"Do not use deprecated params, they will be removed.\", \"parameters\": [\"ServiceNetMapDeprecatedMapping\"]}], \"resources\": {\"ServiceNetMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"map_replace\": [{\"get_param\": \"ServiceNetMap\"}, {\"values\": {\"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}, \"keys\": {\"get_param\": \"ServiceNetMapDeprecatedMapping\"}}]}, {\"NovaVncProxyNetwork\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}]}}}}, \"outputs\": {\"service_net_map\": {\"value\": {\"get_attr\": [\"ServiceNetMapValue\", \"value\"]}}, \"service_net_map_lower\": {\"value\": {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_attr\": [\"ServiceNetMapValue\", \"value\"]}}}}}, \"vip_subnet_map\": {\"value\": {\"map_replace\": [{\"get_param\": \"VipSubnetMap\"}, {\"values\": {\"ctlplane-subnet\": {\"get_param\": \"ControlPlaneSubnet\"}}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(3,'2026-06-12 08:25:38',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(4,'2026-06-12 08:25:39',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed VIP port on the Control Plane network.\\n\", \"parameters\": {\"name\": {\"default\": \"\", \"type\": \"string\"}, \"dns_name\": {\"default\": \"\", \"type\": \"string\"}, \"network\": {\"default\": \"\", \"type\": \"string\"}, \"fixed_ips\": {\"default\": \"\", \"type\": \"comma_delimited_list\"}, \"replacement_policy\": {\"default\": \"\", \"type\": \"string\"}, \"tags\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ControlPlaneVipData\": {\"description\": \"Control Plane Virtual IP data\\n\", \"default\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"type\": \"json\"}}, \"outputs\": {\"name\": {\"value\": {\"get_param\": [\"ControlPlaneVipData\", \"name\"]}}, \"fixed_ips\": {\"value\": {\"get_param\": [\"ControlPlaneVipData\", \"fixed_ips\"]}}, \"network\": {\"value\": {\"get_param\": [\"ControlPlaneVipData\", \"network\"]}}, \"subnets\": {\"value\": {\"get_param\": [\"ControlPlaneVipData\", \"subnets\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"name\": \"control_virtual_ip\", \"dns_name\": \"multicell\", \"network\": \"ctlplane\", \"fixed_ips\": \".member.0.subnet=ctlplane-subnet\", \"replacement_policy\": \"AUTO\", \"tags\": \"tripleo_vip_net=ctlplane,tripleo_stack_name=cell1\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(5,'2026-06-12 08:25:40',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(6,'2026-06-12 08:25:40',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Create networks to split out Overcloud traffic\", \"parameters\": {\"DeployedNetworkEnvironment\": {\"type\": \"json\", \"description\": \"Deployed network environment\", \"default\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}}, \"CtlplaneNetworkCidrs\": {\"type\": \"json\", \"description\": \"Cidrs for the ctlplane network.\"}, \"CtlplaneNetworkAttributes\": {\"type\": \"json\", \"default\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"description\": \"A map containing attributes of the undercloud ctlplane network and subnets. NOTE: The value for this parameter is automatically populated in the plan environment by tripleoclient.\\n\"}}, \"resources\": {\"NetworkExtraConfig\": {\"type\": \"OS::TripleO::Network::ExtraConfig\"}, \"NetworkAttributesMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"ctlplane\": {\"get_param\": \"CtlplaneNetworkAttributes\"}}, {\"get_param\": [\"DeployedNetworkEnvironment\", \"net_attributes_map\"]}]}}}, \"NetworkCidrMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"ctlplane\": {\"get_param\": \"CtlplaneNetworkCidrs\"}}, {\"get_param\": [\"DeployedNetworkEnvironment\", \"net_cidr_map\"]}]}}}, \"NetworkIpVersionMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"ctlplane\": {\"yaql\": {\"expression\": \"$.data.items().first().last().ip_version\", \"data\": {\"get_param\": [\"CtlplaneNetworkAttributes\", \"subnets\"]}}}}, {\"get_param\": [\"DeployedNetworkEnvironment\", \"net_ip_version_map\"]}]}}}}, \"outputs\": {\"net_cidr_map\": {\"value\": {\"get_attr\": [\"NetworkCidrMap\", \"value\"]}}, \"net_ip_version_map\": {\"value\": {\"get_attr\": [\"NetworkIpVersionMap\", \"value\"]}}, \"net_attributes_map\": {\"value\": {\"get_attr\": [\"NetworkAttributesMap\", \"value\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"CtlplaneNetworkCidrs\": \"[\\\"192.168.122.0/24\\\"]\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(7,'2026-06-12 08:25:41',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (8,'2026-06-12 08:25:42',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(9,'2026-06-12 08:25:43',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(10,'2026-06-12 08:25:44',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"node_admin_username\": {\"type\": \"string\", \"default\": \"heat-admin\"}, \"node_admin_extra_ssh_keys\": {\"type\": \"comma_delimited_list\", \"default\": []}}, \"description\": \"Uses cloud-init to create an additional user with a known name, in addition to the distro-default user created by the cloud-init default.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"user_config\"}}]}}, \"user_config\": {\"type\": \"OS::Heat::CloudConfig\", \"properties\": {\"cloud_config\": {\"user\": {\"get_param\": \"node_admin_username\"}, \"ssh_authorized_keys\": {\"get_param\": \"node_admin_extra_ssh_keys\"}}}}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(11,'2026-06-12 08:25:44',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed VIP port on the InternalApi network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"VipPortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"type\": \"json\"}}, \"outputs\": {\"ip_address\": {\"description\": \"InternalApi network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"internal_api\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"InternalApi network VIP (with brackets for IPv6 URLs)\", \"value\": {\"get_param\": [\"VipPortMap\", \"internal_api\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the InternalApi network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"internal_api\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"internal_api_virtual_ip\", \"DnsName\": \"multicell\", \"ControlPlaneIP\": \"192.168.122.93\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"internal_api_subnet\\\"}]\", \"IsVirtualIP\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(12,'2026-06-12 08:25:44',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed VIP port on the External network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"VipPortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"type\": \"json\"}}, \"outputs\": {\"ip_address\": {\"description\": \"External network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"external\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"External network VIP (with brackets for IPv6 URLs)\", \"value\": {\"get_param\": [\"VipPortMap\", \"external\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the External network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"external\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"external_virtual_ip\", \"DnsName\": \"multicell\", \"ControlPlaneIP\": \"192.168.122.93\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"external_subnet\\\"}]\", \"IsVirtualIP\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(13,'2026-06-12 08:25:45',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(14,'2026-06-12 08:25:45',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed VIP port on the Storage network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"VipPortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"type\": \"json\"}}, \"outputs\": {\"ip_address\": {\"description\": \"Storage network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"Storage network VIP (with brackets for IPv6 URLs)\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the Storage network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"storage_virtual_ip\", \"DnsName\": \"multicell\", \"ControlPlaneIP\": \"192.168.122.93\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"storage_subnet\\\"}]\", \"IsVirtualIP\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(15,'2026-06-12 08:25:45',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed VIP port on the StorageMgmt network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"VipPortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"type\": \"json\"}}, \"outputs\": {\"ip_address\": {\"description\": \"StorageMgmt network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage_mgmt\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"StorageMgmt network VIP (with brackets for IPv6 URLs)\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage_mgmt\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the StorageMgmt network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage_mgmt\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"storage_mgmt_virtual_ip\", \"DnsName\": \"multicell\", \"ControlPlaneIP\": \"192.168.122.93\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"storage_mgmt_subnet\\\"}]\", \"IsVirtualIP\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(16,'2026-06-12 08:25:46',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(17,'2026-06-12 08:25:46',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIp\": {\"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"StorageIp\": {\"default\": \"\", \"type\": \"string\"}, \"StorageIpSubnet\": {\"description\": \"IP address/subnet on the storage network\", \"default\": \"\", \"type\": \"string\"}, \"StorageIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIp\": {\"default\": \"\", \"type\": \"string\"}, \"StorageMgmtIpSubnet\": {\"description\": \"IP address/subnet on the storage_mgmt network\", \"default\": \"\", \"type\": \"string\"}, \"StorageMgmtIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIp\": {\"default\": \"\", \"type\": \"string\"}, \"InternalApiIpSubnet\": {\"description\": \"IP address/subnet on the internal_api network\", \"default\": \"\", \"type\": \"string\"}, \"InternalApiIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIp\": {\"default\": \"\", \"type\": \"string\"}, \"TenantIpSubnet\": {\"description\": \"IP address/subnet on the tenant network\", \"default\": \"\", \"type\": \"string\"}, \"TenantIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIp\": {\"default\": \"\", \"type\": \"string\"}, \"ExternalIpSubnet\": {\"description\": \"IP address/subnet on the external network\", \"default\": \"\", \"type\": \"string\"}, \"ExternalIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}}, \"resources\": {\"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"ctlplane\": {\"get_param\": \"ControlPlaneIp\"}, \"ctlplane_subnet\": {\"list_join\": [\"\", [{\"get_param\": \"ControlPlaneIp\"}, \"/\", {\"get_param\": \"ControlPlaneSubnetCidr\"}]]}, \"ctlplane_uri\": {\"str_replace\": {\"template\": {\"make_url\": {\"host\": {\"get_param\": \"ControlPlaneIp\"}}}, \"params\": {\"//\": \"\"}}}, \"storage\": {\"get_param\": \"StorageIp\"}, \"storage_subnet\": {\"get_param\": \"StorageIpSubnet\"}, \"storage_uri\": {\"get_param\": \"StorageIpUri\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIp\"}, \"storage_mgmt_subnet\": {\"get_param\": \"StorageMgmtIpSubnet\"}, \"storage_mgmt_uri\": {\"get_param\": \"StorageMgmtIpUri\"}, \"internal_api\": {\"get_param\": \"InternalApiIp\"}, \"internal_api_subnet\": {\"get_param\": \"InternalApiIpSubnet\"}, \"internal_api_uri\": {\"get_param\": \"InternalApiIpUri\"}, \"tenant\": {\"get_param\": \"TenantIp\"}, \"tenant_subnet\": {\"get_param\": \"TenantIpSubnet\"}, \"tenant_uri\": {\"get_param\": \"TenantIpUri\"}, \"external\": {\"get_param\": \"ExternalIp\"}, \"external_subnet\": {\"get_param\": \"ExternalIpSubnet\"}, \"external_uri\": {\"get_param\": \"ExternalIpUri\"}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"StorageNetName\"}}}}, \"storage_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"StorageNetName\"}}}}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"storage_mgmt_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"StorageMgmtNetName\"}}}}, \"storage_mgmt_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"StorageMgmtNetName\"}}}}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"internal_api_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"InternalApiNetName\"}}}}, \"internal_api_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"InternalApiNetName\"}}}}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"tenant_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"TenantNetName\"}}}}, \"tenant_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"TenantNetName\"}}}}, \"external\": {\"get_param\": \"ExternalNetName\"}, \"external_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"ExternalNetName\"}}}}, \"external_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"ExternalNetName\"}}}}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned IPs for a specific machine.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIp\": \"192.168.122.93\", \"ControlPlaneSubnetCidr\": \"24\", \"StorageIp\": \"172.18.0.143\", \"StorageIpUri\": \"172.18.0.143\", \"StorageMgmtIp\": \"172.20.0.153\", \"StorageMgmtIpUri\": \"172.20.0.153\", \"InternalApiIp\": \"172.17.0.133\", \"InternalApiIpUri\": \"172.17.0.133\", \"ExternalIp\": \"172.21.0.83\", \"ExternalIpUri\": \"172.21.0.83\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (18,'2026-06-12 08:25:48',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"A map of OpenStack endpoints. Since the endpoints are URLs, we need to have brackets around IPv6 IP addresses. The inputs to these parameters come from net_ip_uri_map, which will include these brackets in IPv6 addresses.\", \"parameters\": {\"NetIpMap\": {\"type\": \"json\", \"default\": {}, \"description\": \"The Net IP map\"}, \"ServiceNetMap\": {\"type\": \"json\", \"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"The Service Net map\"}, \"EndpointMap\": {\"type\": \"json\", \"default\": {\"AodhAdmin\": {\"protocol\": \"http\", \"port\": \"8042\", \"host\": \"IP_ADDRESS\"}, \"AodhInternal\": {\"protocol\": \"http\", \"port\": \"8042\", \"host\": \"IP_ADDRESS\"}, \"AodhPublic\": {\"protocol\": \"http\", \"port\": \"8042\", \"host\": \"IP_ADDRESS\"}, \"BarbicanAdmin\": {\"protocol\": \"http\", \"port\": \"9311\", \"host\": \"IP_ADDRESS\"}, \"BarbicanInternal\": {\"protocol\": \"http\", \"port\": \"9311\", \"host\": \"IP_ADDRESS\"}, \"BarbicanPublic\": {\"protocol\": \"http\", \"port\": \"9311\", \"host\": \"IP_ADDRESS\"}, \"CephDashboardInternal\": {\"protocol\": \"http\", \"port\": \"8444\", \"host\": \"IP_ADDRESS\"}, \"CephGrafanaInternal\": {\"protocol\": \"http\", \"port\": \"3100\", \"host\": \"IP_ADDRESS\"}, \"CephRgwAdmin\": {\"protocol\": \"http\", \"port\": \"8080\", \"host\": \"IP_ADDRESS\"}, \"CephRgwInternal\": {\"protocol\": \"http\", \"port\": \"8080\", \"host\": \"IP_ADDRESS\"}, \"CephRgwPublic\": {\"protocol\": \"http\", \"port\": \"8080\", \"host\": \"IP_ADDRESS\"}, \"CinderAdmin\": {\"protocol\": \"http\", \"port\": \"8776\", \"host\": \"IP_ADDRESS\"}, \"CinderInternal\": {\"protocol\": \"http\", \"port\": \"8776\", \"host\": \"IP_ADDRESS\"}, \"CinderPublic\": {\"protocol\": \"http\", \"port\": \"8776\", \"host\": \"IP_ADDRESS\"}, \"DesignateAdmin\": {\"protocol\": \"http\", \"port\": \"9001\", \"host\": \"IP_ADDRESS\"}, \"DesignateInternal\": {\"protocol\": \"http\", \"port\": \"9001\", \"host\": \"IP_ADDRESS\"}, \"DesignatePublic\": {\"protocol\": \"http\", \"port\": \"9001\", \"host\": \"IP_ADDRESS\"}, \"DockerRegistryInternal\": {\"protocol\": \"http\", \"port\": \"8787\", \"host\": \"IP_ADDRESS\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"http\", \"port\": \"9293\", \"host\": \"IP_ADDRESS\"}, \"GlanceInternal\": {\"protocol\": \"http\", \"port\": \"9293\", \"host\": \"IP_ADDRESS\"}, \"GlancePublic\": {\"protocol\": \"http\", \"port\": \"9292\", \"host\": \"IP_ADDRESS\"}, \"GnocchiAdmin\": {\"protocol\": \"http\", \"port\": \"8041\", \"host\": \"IP_ADDRESS\"}, \"GnocchiInternal\": {\"protocol\": \"http\", \"port\": \"8041\", \"host\": \"IP_ADDRESS\"}, \"GnocchiPublic\": {\"protocol\": \"http\", \"port\": \"8041\", \"host\": \"IP_ADDRESS\"}, \"HeatAdmin\": {\"protocol\": \"http\", \"port\": \"8004\", \"host\": \"IP_ADDRESS\"}, \"HeatInternal\": {\"protocol\": \"http\", \"port\": \"8004\", \"host\": \"IP_ADDRESS\"}, \"HeatPublic\": {\"protocol\": \"http\", \"port\": \"8004\", \"host\": \"IP_ADDRESS\"}, \"HeatCfnAdmin\": {\"protocol\": \"http\", \"port\": \"8000\", \"host\": \"IP_ADDRESS\"}, \"HeatCfnInternal\": {\"protocol\": \"http\", \"port\": \"8000\", \"host\": \"IP_ADDRESS\"}, \"HeatCfnPublic\": {\"protocol\": \"http\", \"port\": \"8000\", \"host\": \"IP_ADDRESS\"}, \"HorizonPublic\": {\"protocol\": \"http\", \"port\": \"80\", \"host\": \"IP_ADDRESS\"}, \"IronicAdmin\": {\"protocol\": \"http\", \"port\": \"6385\", \"host\": \"IP_ADDRESS\"}, \"IronicInternal\": {\"protocol\": \"http\", \"port\": \"6385\", \"host\": \"IP_ADDRESS\"}, \"IronicPublic\": {\"protocol\": \"http\", \"port\": \"6385\", \"host\": \"IP_ADDRESS\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"IP_ADDRESS\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"IP_ADDRESS\"}, \"IronicInspectorPublic\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"IP_ADDRESS\"}, \"KeystoneAdmin\": {\"protocol\": \"http\", \"port\": \"35357\", \"host\": \"IP_ADDRESS\"}, \"KeystoneInternal\": {\"protocol\": \"http\", \"port\": \"5000\", \"host\": \"IP_ADDRESS\"}, \"KeystonePublic\": {\"protocol\": \"http\", \"port\": \"5000\", \"host\": \"IP_ADDRESS\"}, \"ManilaAdmin\": {\"protocol\": \"http\", \"port\": \"8786\", \"host\": \"IP_ADDRESS\"}, \"ManilaInternal\": {\"protocol\": \"http\", \"port\": \"8786\", \"host\": \"IP_ADDRESS\"}, \"ManilaPublic\": {\"protocol\": \"http\", \"port\": \"8786\", \"host\": \"IP_ADDRESS\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"IP_ADDRESS\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"IP_ADDRESS\"}, \"NeutronAdmin\": {\"protocol\": \"http\", \"port\": \"9696\", \"host\": \"IP_ADDRESS\"}, \"NeutronInternal\": {\"protocol\": \"http\", \"port\": \"9696\", \"host\": \"IP_ADDRESS\"}, \"NeutronPublic\": {\"protocol\": \"http\", \"port\": \"9696\", \"host\": \"IP_ADDRESS\"}, \"NovaAdmin\": {\"protocol\": \"http\", \"port\": \"8774\", \"host\": \"IP_ADDRESS\"}, \"NovaInternal\": {\"protocol\": \"http\", \"port\": \"8774\", \"host\": \"IP_ADDRESS\"}, \"NovaPublic\": {\"protocol\": \"http\", \"port\": \"8774\", \"host\": \"IP_ADDRESS\"}, \"NovaMetadataInternal\": {\"protocol\": \"http\", \"port\": \"8775\", \"host\": \"IP_ADDRESS\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"http\", \"port\": \"6080\", \"host\": \"IP_ADDRESS\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"http\", \"port\": \"6080\", \"host\": \"IP_ADDRESS\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"http\", \"port\": \"6080\", \"host\": \"IP_ADDRESS\"}, \"NovajoinAdmin\": {\"protocol\": \"http\", \"port\": \"9090\", \"host\": \"IP_ADDRESS\"}, \"NovajoinInternal\": {\"protocol\": \"http\", \"port\": \"9090\", \"host\": \"IP_ADDRESS\"}, \"NovajoinPublic\": {\"protocol\": \"http\", \"port\": \"9090\", \"host\": \"IP_ADDRESS\"}, \"OctaviaAdmin\": {\"protocol\": \"http\", \"port\": \"9876\", \"host\": \"IP_ADDRESS\"}, \"OctaviaInternal\": {\"protocol\": \"http\", \"port\": \"9876\", \"host\": \"IP_ADDRESS\"}, \"OctaviaPublic\": {\"protocol\": \"http\", \"port\": \"9876\", \"host\": \"IP_ADDRESS\"}, \"PlacementAdmin\": {\"protocol\": \"http\", \"port\": \"8778\", \"host\": \"IP_ADDRESS\"}, \"PlacementInternal\": {\"protocol\": \"http\", \"port\": \"8778\", \"host\": \"IP_ADDRESS\"}, \"PlacementPublic\": {\"protocol\": \"http\", \"port\": \"8778\", \"host\": \"IP_ADDRESS\"}, \"SwiftAdmin\": {\"protocol\": \"http\", \"port\": \"8080\", \"host\": \"IP_ADDRESS\"}, \"SwiftInternal\": {\"protocol\": \"http\", \"port\": \"8080\", \"host\": \"IP_ADDRESS\"}, \"SwiftPublic\": {\"protocol\": \"http\", \"port\": \"8080\", \"host\": \"IP_ADDRESS\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}, \"CloudEndpoints\": {\"type\": \"json\", \"default\": {}, \"description\": \"A map containing the DNS names for the different endpoints (external, internal_api, etc.)\"}}, \"outputs\": {\"endpoint_map\": {\"value\": {\"AodhAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"port\"]}}}}, \"AodhInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"port\"]}}}}, \"AodhPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"port\"]}}}}, \"BarbicanAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"port\"]}}}}, \"BarbicanInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"port\"]}}}}, \"BarbicanPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"port\"]}}}}, \"CephDashboardInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"port\"]}}}}, \"CephGrafanaInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"port\"]}}}}, \"CephRgwAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"port\"]}, \"path\": \"/swift/v1/AUTH_\"}}, \"%(project_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"port\"]}}}}, \"CephRgwInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"port\"]}, \"path\": \"/swift/v1/AUTH_\"}}, \"%(project_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"port\"]}}}}, \"CephRgwPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"port\"]}, \"path\": \"/swift/v1/AUTH_\"}}, \"%(project_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"port\"]}}}}, \"CinderAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}}}}, \"CinderInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}}}}, \"CinderPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}}}}, \"CinderV2Admin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"path\": \"/v2/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}}}}, \"CinderV2Internal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"path\": \"/v2/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}}}}, \"CinderV2Public\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"path\": \"/v2/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}}}}, \"CinderV3Admin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"path\": \"/v3/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}}}}, \"CinderV3Internal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"path\": \"/v3/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}}}}, \"CinderV3Public\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"path\": \"/v3/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}}}}, \"DesignateAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"port\"]}}}}, \"DesignateInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"port\"]}}}}, \"DesignatePublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"port\"]}}}}, \"DockerRegistryInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"port\"]}}}}, \"GaneshaInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"port\"]}}}}, \"GlanceAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"port\"]}}}}, \"GlanceInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}}, \"GlancePublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"port\"]}}}}, \"GnocchiAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"port\"]}}}}, \"GnocchiInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"port\"]}}}}, \"GnocchiPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"port\"]}}}}, \"HeatAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"port\"]}}}}, \"HeatInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"port\"]}}}}, \"HeatPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"port\"]}}}}, \"HeatCfnAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"port\"]}}}}, \"HeatCfnInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"port\"]}}}}, \"HeatCfnPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"port\"]}}}}, \"HorizonPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"port\"]}, \"path\": \"/dashboard\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"port\"]}}}}, \"IronicAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"port\"]}}}}, \"IronicInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"port\"]}}}}, \"IronicPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"port\"]}}}}, \"IronicInspectorAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"port\"]}}}}, \"IronicInspectorInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"port\"]}}}}, \"IronicInspectorPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"port\"]}}}}, \"KeystoneAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}, \"path\": \"/\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}}}}, \"KeystoneInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}, \"path\": \"/\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}}}}, \"KeystonePublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}, \"path\": \"/\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}}}}, \"KeystoneV3Admin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}, \"path\": \"/v3\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}}}}, \"KeystoneV3Internal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}, \"path\": \"/v3\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}}}}, \"KeystoneV3Public\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}, \"path\": \"/v3\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}}}}, \"ManilaAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}}}}, \"ManilaInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}}}}, \"ManilaPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}}}}, \"ManilaV1Admin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}}}}, \"ManilaV1Internal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}}}}, \"ManilaV1Public\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}}}}, \"MetricsQdrPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"port\"]}}}}, \"MysqlInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"port\"]}}}}, \"NeutronAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"port\"]}}}}, \"NeutronInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"port\"]}}}}, \"NeutronPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"port\"]}}}}, \"NovaAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"port\"]}, \"path\": \"/v2.1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"port\"]}}}}, \"NovaInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"port\"]}, \"path\": \"/v2.1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"port\"]}}}}, \"NovaPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"port\"]}, \"path\": \"/v2.1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"port\"]}}}}, \"NovaMetadataInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"port\"]}}}}, \"NovaVNCProxyAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"port\"]}}}}, \"NovaVNCProxyInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"port\"]}}}}, \"NovaVNCProxyPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"port\"]}}}}, \"NovajoinAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"port\"]}}}}, \"NovajoinInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"port\"]}}}}, \"NovajoinPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"port\"]}}}}, \"OctaviaAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"port\"]}}}}, \"OctaviaInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"port\"]}}}}, \"OctaviaPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"port\"]}}}}, \"PlacementAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"port\"]}, \"path\": \"/placement\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"port\"]}}}}, \"PlacementInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"port\"]}, \"path\": \"/placement\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"port\"]}}}}, \"PlacementPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"port\"]}, \"path\": \"/placement\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"port\"]}}}}, \"SwiftAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}}}}, \"SwiftInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}, \"path\": \"/v1/AUTH_\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}}}}, \"SwiftPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}, \"path\": \"/v1/AUTH_\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}}}}, \"SwiftS3Admin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}}}}, \"SwiftS3Internal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}}}}, \"SwiftS3Public\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"NetIpMap\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"CloudEndpoints\": {\"ctlplane\": \"multicell.ctlplane.localdomain\", \"storage\": \"multicell.storage.localdomain\", \"storage_mgmt\": \"multicell.storagemgmt.localdomain\", \"internal_api\": \"multicell.internalapi.localdomain\", \"external\": \"multicell.ooo.test\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(19,'2026-06-12 08:25:48',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"NtpServer\": {\"default\": \"pool.ntp.org\", \"description\": \"NTP servers list. Defaulted to a set of pool.ntp.org servers in order to have a sane default for Pacemaker deployments when not configuring this parameter by default.\", \"type\": \"comma_delimited_list\"}, \"NtpPool\": {\"default\": [], \"description\": \"NTP pool list.  Defaults to [], so only NtpServer is used by default.\", \"type\": \"comma_delimited_list\"}, \"NtpService\": {\"default\": \"chrony\", \"description\": \"NTP Service to use for the timesync bootstrap.\", \"type\": \"string\"}}, \"description\": \"Uses cloud-init to bootstrap timesync configuration to ensure it is done as soon as possible. We do additional and more complex configurations as part of the deployment itself.\\n\", \"conditions\": {\"use_chrony\": {\"equals\": [{\"get_param\": \"NtpService\"}, \"chrony\"]}}, \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"timesync_chrony\"}}, {\"config\": {\"get_resource\": \"timesync_sync\"}}]}}, \"timesync_chrony\": {\"type\": \"OS::Heat::SoftwareConfig\", \"properties\": {\"config\": {\"str_replace\": {\"template\": \"#!/bin/bash\\nif [ \\\"$service\\\" != \\\"chrony\\\" ]; then\\n  exit 0\\nfi\\nset -x\\nSERVERS=\\\"$ntp_servers\\\"\\nPOOLS=\\\"$ntp_pools\\\"\\nsystemctl is-active --quiet chronyd || systemctl start chronyd\\nfor server in $SERVERS; do\\n  chronyc add server \\\"${server}\\\" iburst\\ndone\\nfor pool in $POOLS; do\\n  chronyc add server \\\"${pool}\\\" iburst\\ndone\\nchronyc sources\\n\", \"params\": {\"$ntp_servers\": {\"list_join\": [\" \", {\"get_param\": \"NtpServer\"}]}, \"$ntp_pools\": {\"list_join\": [\" \", {\"get_param\": \"NtpPool\"}]}, \"$service\": {\"get_param\": \"NtpService\"}}}}}}, \"timesync_sync\": {\"type\": \"OS::Heat::SoftwareConfig\", \"properties\": {\"config\": {\"str_replace\": {\"template\": \"#!/bin/bash\\nset -x\\nif [ \\\"$service\\\" = \\\"chrony\\\" ]; then\\n    if command -v chronyc >/dev/null; then\\n        chronyc makestep\\n        chronyc waitsync 30\\n    else\\n        echo \\\"No chronyc available, skipping sync\\\"\\n    fi\\nelif [ \\\"$service\\\" = \\\"ntp\\\" ]; then\\n    if command -v ntpdate >/dev/null; then\\n        ntpdate -u $ntp_servers\\n    else\\n        echo \\\"No ntpdate available, skipping sync\\\"\\n    fi\\nfi\\nhwclock --systohc --utc\\n\", \"params\": {\"$service\": {\"get_param\": \"NtpService\"}, \"$ntp_servers\": {\"list_join\": [\" \", {\"get_param\": \"NtpServer\"}]}}}}}}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(20,'2026-06-12 08:25:48',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::NetworkerServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"Networker\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(21,'2026-06-12 08:25:48',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::ObjectStorageServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"ObjectStorage\", \"RoleParameters\": {}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(22,'2026-06-12 08:25:48',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::BlockStorageServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"BlockStorage\", \"RoleParameters\": {}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(23,'2026-06-12 08:25:48',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::CephStorageServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"CephStorage\", \"RoleParameters\": {}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (24,'2026-06-12 08:25:49',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(25,'2026-06-12 08:25:49',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::ControllerServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(26,'2026-06-12 08:25:49',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::ComputeServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"OS::TripleO::Services::BootParams,OS::TripleO::Services::CACerts,OS::TripleO::Services::Collectd,OS::TripleO::Services::ComputeCeilometerAgent,OS::TripleO::Services::CeilometerAgentIpmi,OS::TripleO::Services::Iscsid,OS::TripleO::Services::Kernel,OS::TripleO::Services::MetricsQdr,OS::TripleO::Services::MySQLClient,OS::TripleO::Services::NovaCompute,OS::TripleO::Services::NovaLibvirt,OS::TripleO::Services::NovaLibvirtGuests,OS::TripleO::Services::NovaMigrationTarget,OS::TripleO::Services::ContainersLogrotateCrond,OS::TripleO::Services::Podman,OS::TripleO::Services::Rsyslog,OS::TripleO::Services::Snmp,OS::TripleO::Services::Sshd,OS::TripleO::Services::Timesync,OS::TripleO::Services::Timezone,OS::TripleO::Services::TripleoFirewall,OS::TripleO::Services::TripleoPackages,OS::TripleO::Services::Tuned,OS::TripleO::Services::OVNController,OS::TripleO::Services::OVNMetadataAgent\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(27,'2026-06-12 08:25:49',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"CellControllerCompute\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(28,'2026-06-12 08:25:49',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::CellControllerServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"OS::TripleO::Services::BootParams,OS::TripleO::Services::CACerts,OS::TripleO::Services::Clustercheck,OS::TripleO::Services::Collectd,OS::TripleO::Services::ContainerImagePrepare,OS::TripleO::Services::ContainersLogrotateCrond,OS::TripleO::Services::HAproxy,OS::TripleO::Services::Iscsid,OS::TripleO::Services::Kernel,OS::TripleO::Services::MetricsQdr,OS::TripleO::Services::MySQL,OS::TripleO::Services::MySQLClient,OS::TripleO::Services::NovaConductor,OS::TripleO::Services::NovaMetadata,OS::TripleO::Services::NovaVncProxy,OS::TripleO::Services::OsloMessagingRpc,OS::TripleO::Services::Pacemaker,OS::TripleO::Services::Podman,OS::TripleO::Services::Rsyslog,OS::TripleO::Services::Snmp,OS::TripleO::Services::Sshd,OS::TripleO::Services::Timesync,OS::TripleO::Services::Timezone,OS::TripleO::Services::TripleoFirewall,OS::TripleO::Services::TripleoPackages,OS::TripleO::Services::Tuned\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(29,'2026-06-12 08:25:50',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, container_config_scripts\": {\"value\": []}, \"role_data, step_config\": {\"value\": []}, \"role_data, service_name\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}, \"role_data, docker_config\": {\"value\": []}, \"role_data\": {\"value\": []}, \"role_data, service_names\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(30,'2026-06-12 08:25:50',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(31,'2026-06-12 08:25:50',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, container_config_scripts\": {\"value\": []}, \"role_data, step_config\": {\"value\": []}, \"role_data, service_name\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}, \"role_data, docker_config\": {\"value\": []}, \"role_data\": {\"value\": []}, \"role_data, service_names\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (32,'2026-06-12 08:25:50',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, container_config_scripts\": {\"value\": []}, \"role_data, step_config\": {\"value\": []}, \"role_data, service_name\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}, \"role_data, docker_config\": {\"value\": []}, \"role_data\": {\"value\": []}, \"role_data, service_names\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(33,'2026-06-12 08:25:50',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, container_config_scripts\": {\"value\": []}, \"role_data, step_config\": {\"value\": []}, \"role_data, service_name\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}, \"role_data, docker_config\": {\"value\": []}, \"role_data\": {\"value\": []}, \"role_data, service_names\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(34,'2026-06-12 08:25:50',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, container_config_scripts\": {\"value\": []}, \"role_data, step_config\": {\"value\": []}, \"role_data, service_name\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}, \"role_data, docker_config\": {\"value\": []}, \"role_data\": {\"value\": []}, \"role_data, service_names\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(35,'2026-06-12 08:25:51',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, container_config_scripts\": {\"value\": []}, \"role_data, step_config\": {\"value\": []}, \"role_data, service_name\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}, \"role_data, docker_config\": {\"value\": []}, \"role_data\": {\"value\": []}, \"role_data, service_names\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (36,'2026-06-12 08:25:51',NULL,'{\"heat_template_version\": \"2015-04-30\", \"resources\": {\"0\": {\"type\": \"OS::TripleO::Services::BootParams\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}}, \"1\": {\"type\": \"OS::TripleO::Services::CACerts\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}}, \"2\": {\"type\": \"OS::TripleO::Services::Collectd\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}}, \"3\": {\"type\": \"OS::TripleO::Services::ComputeCeilometerAgent\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}}, \"4\": {\"type\": \"OS::TripleO::Services::CeilometerAgentIpmi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"0\"]}, \"5\": {\"type\": \"OS::TripleO::Services::Iscsid\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"1\"]}, \"6\": {\"type\": \"OS::TripleO::Services::Kernel\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"2\"]}, \"7\": {\"type\": \"OS::TripleO::Services::MetricsQdr\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"3\"]}, \"8\": {\"type\": \"OS::TripleO::Services::MySQLClient\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"4\"]}, \"9\": {\"type\": \"OS::TripleO::Services::NovaCompute\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"5\"]}, \"10\": {\"type\": \"OS::TripleO::Services::NovaLibvirt\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"6\"]}, \"11\": {\"type\": \"OS::TripleO::Services::NovaLibvirtGuests\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"7\"]}, \"12\": {\"type\": \"OS::TripleO::Services::NovaMigrationTarget\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"8\"]}, \"13\": {\"type\": \"OS::TripleO::Services::ContainersLogrotateCrond\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"9\"]}, \"14\": {\"type\": \"OS::TripleO::Services::Podman\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"10\"]}, \"15\": {\"type\": \"OS::TripleO::Services::Rsyslog\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"11\"]}, \"16\": {\"type\": \"OS::TripleO::Services::Snmp\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"12\"]}, \"17\": {\"type\": \"OS::TripleO::Services::Sshd\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"13\"]}, \"18\": {\"type\": \"OS::TripleO::Services::Timesync\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"14\"]}, \"19\": {\"type\": \"OS::TripleO::Services::Timezone\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"15\"]}, \"20\": {\"type\": \"OS::TripleO::Services::TripleoFirewall\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"16\"]}, \"21\": {\"type\": \"OS::TripleO::Services::TripleoPackages\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"17\"]}, \"22\": {\"type\": \"OS::TripleO::Services::Tuned\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"18\"]}, \"23\": {\"type\": \"OS::TripleO::Services::OVNController\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"19\"]}, \"24\": {\"type\": \"OS::TripleO::Services::OVNMetadataAgent\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"20\"]}}, \"outputs\": {\"role_data, container_config_scripts\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"1\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"2\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"3\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"4\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"5\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"6\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"7\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"8\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"9\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"10\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"11\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"12\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"13\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"14\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"15\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"16\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"17\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"18\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"19\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"20\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"21\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"22\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"23\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"24\", \"role_data\", \"container_config_scripts\"]}]}, \"role_data, step_config\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"1\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"2\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"3\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"4\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"5\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"6\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"7\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"8\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"9\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"10\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"11\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"12\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"13\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"14\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"15\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"16\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"17\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"18\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"19\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"20\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"21\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"22\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"23\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"24\", \"role_data\", \"step_config\"]}]}, \"role_data, service_name\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"1\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"2\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"3\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"4\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"5\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"6\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"7\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"8\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"9\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"10\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"11\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"12\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"13\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"14\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"15\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"16\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"17\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"18\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"19\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"20\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"21\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"22\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"23\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"24\", \"role_data\", \"service_name\"]}]}, \"role_data, config_settings\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"1\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"2\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"3\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"4\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"5\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"6\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"7\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"8\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"9\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"10\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"11\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"12\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"13\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"14\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"15\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"16\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"17\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"18\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"19\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"20\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"21\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"22\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"23\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"24\", \"role_data\", \"config_settings\"]}]}, \"role_data, docker_config\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"1\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"2\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"3\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"4\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"5\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"6\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"7\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"8\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"9\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"10\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"11\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"12\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"13\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"14\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"15\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"16\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"17\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"18\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"19\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"20\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"21\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"22\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"23\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"24\", \"role_data\", \"docker_config\"]}]}, \"role_data\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\"]}, {\"get_attr\": [\"1\", \"role_data\"]}, {\"get_attr\": [\"2\", \"role_data\"]}, {\"get_attr\": [\"3\", \"role_data\"]}, {\"get_attr\": [\"4\", \"role_data\"]}, {\"get_attr\": [\"5\", \"role_data\"]}, {\"get_attr\": [\"6\", \"role_data\"]}, {\"get_attr\": [\"7\", \"role_data\"]}, {\"get_attr\": [\"8\", \"role_data\"]}, {\"get_attr\": [\"9\", \"role_data\"]}, {\"get_attr\": [\"10\", \"role_data\"]}, {\"get_attr\": [\"11\", \"role_data\"]}, {\"get_attr\": [\"12\", \"role_data\"]}, {\"get_attr\": [\"13\", \"role_data\"]}, {\"get_attr\": [\"14\", \"role_data\"]}, {\"get_attr\": [\"15\", \"role_data\"]}, {\"get_attr\": [\"16\", \"role_data\"]}, {\"get_attr\": [\"17\", \"role_data\"]}, {\"get_attr\": [\"18\", \"role_data\"]}, {\"get_attr\": [\"19\", \"role_data\"]}, {\"get_attr\": [\"20\", \"role_data\"]}, {\"get_attr\": [\"21\", \"role_data\"]}, {\"get_attr\": [\"22\", \"role_data\"]}, {\"get_attr\": [\"23\", \"role_data\"]}, {\"get_attr\": [\"24\", \"role_data\"]}]}, \"role_data, service_names\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"1\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"2\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"3\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"4\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"5\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"6\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"7\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"8\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"9\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"10\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"11\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"12\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"13\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"14\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"15\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"16\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"17\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"18\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"19\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"20\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"21\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"22\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"23\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"24\", \"role_data\", \"service_names\"]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (37,'2026-06-12 08:25:51',NULL,'{\"heat_template_version\": \"2015-04-30\", \"resources\": {\"0\": {\"type\": \"OS::TripleO::Services::BootParams\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}}, \"1\": {\"type\": \"OS::TripleO::Services::CACerts\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}}, \"2\": {\"type\": \"OS::TripleO::Services::Clustercheck\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}}, \"3\": {\"type\": \"OS::TripleO::Services::Collectd\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}}, \"4\": {\"type\": \"OS::TripleO::Services::ContainerImagePrepare\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"0\"]}, \"5\": {\"type\": \"OS::TripleO::Services::ContainersLogrotateCrond\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"1\"]}, \"6\": {\"type\": \"OS::TripleO::Services::HAproxy\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"2\"]}, \"7\": {\"type\": \"OS::TripleO::Services::Iscsid\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"3\"]}, \"8\": {\"type\": \"OS::TripleO::Services::Kernel\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"4\"]}, \"9\": {\"type\": \"OS::TripleO::Services::MetricsQdr\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"5\"]}, \"10\": {\"type\": \"OS::TripleO::Services::MySQL\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"6\"]}, \"11\": {\"type\": \"OS::TripleO::Services::MySQLClient\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"7\"]}, \"12\": {\"type\": \"OS::TripleO::Services::NovaConductor\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"8\"]}, \"13\": {\"type\": \"OS::TripleO::Services::NovaMetadata\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"9\"]}, \"14\": {\"type\": \"OS::TripleO::Services::NovaVncProxy\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"10\"]}, \"15\": {\"type\": \"OS::TripleO::Services::OsloMessagingRpc\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"11\"]}, \"16\": {\"type\": \"OS::TripleO::Services::Pacemaker\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"12\"]}, \"17\": {\"type\": \"OS::TripleO::Services::Podman\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"13\"]}, \"18\": {\"type\": \"OS::TripleO::Services::Rsyslog\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"14\"]}, \"19\": {\"type\": \"OS::TripleO::Services::Snmp\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"15\"]}, \"20\": {\"type\": \"OS::TripleO::Services::Sshd\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"16\"]}, \"21\": {\"type\": \"OS::TripleO::Services::Timesync\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"17\"]}, \"22\": {\"type\": \"OS::TripleO::Services::Timezone\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"18\"]}, \"23\": {\"type\": \"OS::TripleO::Services::TripleoFirewall\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"19\"]}, \"24\": {\"type\": \"OS::TripleO::Services::TripleoPackages\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"20\"]}, \"25\": {\"type\": \"OS::TripleO::Services::Tuned\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"21\"]}}, \"outputs\": {\"role_data, container_config_scripts\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"1\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"2\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"3\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"4\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"5\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"6\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"7\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"8\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"9\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"10\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"11\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"12\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"13\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"14\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"15\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"16\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"17\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"18\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"19\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"20\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"21\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"22\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"23\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"24\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"25\", \"role_data\", \"container_config_scripts\"]}]}, \"role_data, step_config\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"1\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"2\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"3\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"4\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"5\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"6\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"7\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"8\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"9\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"10\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"11\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"12\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"13\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"14\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"15\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"16\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"17\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"18\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"19\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"20\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"21\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"22\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"23\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"24\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"25\", \"role_data\", \"step_config\"]}]}, \"role_data, service_name\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"1\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"2\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"3\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"4\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"5\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"6\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"7\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"8\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"9\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"10\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"11\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"12\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"13\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"14\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"15\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"16\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"17\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"18\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"19\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"20\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"21\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"22\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"23\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"24\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"25\", \"role_data\", \"service_name\"]}]}, \"role_data, config_settings\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"1\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"2\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"3\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"4\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"5\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"6\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"7\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"8\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"9\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"10\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"11\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"12\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"13\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"14\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"15\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"16\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"17\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"18\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"19\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"20\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"21\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"22\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"23\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"24\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"25\", \"role_data\", \"config_settings\"]}]}, \"role_data, docker_config\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"1\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"2\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"3\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"4\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"5\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"6\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"7\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"8\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"9\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"10\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"11\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"12\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"13\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"14\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"15\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"16\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"17\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"18\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"19\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"20\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"21\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"22\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"23\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"24\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"25\", \"role_data\", \"docker_config\"]}]}, \"role_data\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\"]}, {\"get_attr\": [\"1\", \"role_data\"]}, {\"get_attr\": [\"2\", \"role_data\"]}, {\"get_attr\": [\"3\", \"role_data\"]}, {\"get_attr\": [\"4\", \"role_data\"]}, {\"get_attr\": [\"5\", \"role_data\"]}, {\"get_attr\": [\"6\", \"role_data\"]}, {\"get_attr\": [\"7\", \"role_data\"]}, {\"get_attr\": [\"8\", \"role_data\"]}, {\"get_attr\": [\"9\", \"role_data\"]}, {\"get_attr\": [\"10\", \"role_data\"]}, {\"get_attr\": [\"11\", \"role_data\"]}, {\"get_attr\": [\"12\", \"role_data\"]}, {\"get_attr\": [\"13\", \"role_data\"]}, {\"get_attr\": [\"14\", \"role_data\"]}, {\"get_attr\": [\"15\", \"role_data\"]}, {\"get_attr\": [\"16\", \"role_data\"]}, {\"get_attr\": [\"17\", \"role_data\"]}, {\"get_attr\": [\"18\", \"role_data\"]}, {\"get_attr\": [\"19\", \"role_data\"]}, {\"get_attr\": [\"20\", \"role_data\"]}, {\"get_attr\": [\"21\", \"role_data\"]}, {\"get_attr\": [\"22\", \"role_data\"]}, {\"get_attr\": [\"23\", \"role_data\"]}, {\"get_attr\": [\"24\", \"role_data\"]}, {\"get_attr\": [\"25\", \"role_data\"]}]}, \"role_data, service_names\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"1\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"2\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"3\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"4\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"5\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"6\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"7\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"8\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"9\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"10\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"11\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"12\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"13\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"14\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"15\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"16\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"17\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"18\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"19\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"20\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"21\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"22\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"23\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"24\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"25\", \"role_data\", \"service_names\"]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(38,'2026-06-12 08:25:54',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"MySQL HA clustercheck service deployment using puppet This service is used by HAProxy in a HA scenario to report whether the local galera node is synced\\n\", \"parameters\": {\"ContainerClustercheckImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\"}, \"ContainerClustercheckConfigImage\": {\"description\": \"The container image to use for the clustercheck config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ClustercheckListener\": {\"default\": \"socat\", \"description\": \"How to expose the clustercheck service over TCP\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"socat\", \"xinetd\"]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MysqlPuppetBase\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerClustercheckImage\": \"ContainerClustercheckImage\", \"ContainerClustercheckConfigImage\": \"ContainerClustercheckConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerClustercheckImage\": {\"get_param\": \"ContainerClustercheckImage\"}, \"ContainerClustercheckConfigImage\": {\"get_param\": \"ContainerClustercheckConfigImage\"}}}]}}}}, \"conditions\": {\"socat_listener\": {\"equals\": [{\"get_param\": \"ClustercheckListener\"}, \"socat\"]}}, \"outputs\": {\"role_data\": {\"description\": \"Containerized service clustercheck using composable services.\", \"value\": {\"service_name\": \"clustercheck\", \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"MysqlPuppetBase\", \"role_data\", \"config_settings\"]}, {\"tripleo::profile::pacemaker::clustercheck::bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$FQDN$NETWORK\')}\", \"params\": {\"$FQDN\": {\"if\": [\"socat_listener\", \"\", \"fqdn_\"]}, \"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}}]}, \"puppet_config\": {\"config_volume\": \"clustercheck\", \"puppet_tags\": \"file\", \"step_config\": \"include tripleo::profile::pacemaker::clustercheck\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerClustercheckConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/clustercheck.json\": {\"command\": {\"if\": [\"socat_listener\", \"bash -c $* -- eval source /etc/sysconfig/clustercheck; exec socat -T\\\"${TRIPLEO_HEALTHCHECK_TIMEOUT:-2}\\\" \\\"$TRIPLEO_SOCAT_BIND\\\" system:\\\"grep -qPe \\\\\\\"^\\\\\\\\r\\\\$\\\\\\\" && /usr/bin/clustercheck\\\"\", \"/usr/sbin/xinetd -dontfork\"]}, \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_2\": {\"clustercheck\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerClustercheckImage\"]}, \"restart\": \"always\", \"net\": \"host\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/clustercheck.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/clustercheck:/var/lib/kolla/config_files/src:ro\", \"/var/lib/mysql:/var/lib/mysql\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": null, \"upgrade_tasks\": null, \"update_tasks\": null, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop clustercheck container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"clustercheck\"], \"tripleo_delegate_to\": \"{{ groups[\'clustercheck\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(39,'2026-06-12 08:25:54',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"MySQL service deployment with pacemaker bundle\\n\", \"parameters\": {\"ContainerMysqlImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\"}, \"ContainerMysqlConfigImage\": {\"description\": \"The container image to use for the mysql config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\"}, \"ClusterCommonTag\": {\"default\": false, \"description\": \"When set to false, a pacemaker service is configured to use a floating tag for its container image name, e.g. \'REGISTRY/NAMESPACE/IMAGENAME:pcmklatest\'. When set to true, the service uses a floating prefix as well, e.g. \'cluster.common.tag/IMAGENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"ClusterFullTag\": {\"default\": true, \"description\": \"When set to true, the pacemaker service uses a fully constant tag for its container image name, e.g. \'cluster.common.tag/SERVICENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"MysqlRootPassword\": {\"type\": \"string\", \"hidden\": true, \"default\": \"lewodgEGks\"}, \"MysqlClustercheckPassword\": {\"type\": \"string\", \"hidden\": true, \"default\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\"}, \"MysqlUpgradePersist\": {\"type\": \"boolean\", \"default\": false}, \"MysqlUpgradeTransfer\": {\"type\": \"boolean\", \"default\": true}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"ConfigDebug\": {\"default\": false, \"description\": \"Whether to run config management (e.g. Puppet) in debug mode.\", \"type\": \"boolean\"}, \"DeployIdentifier\": {\"default\": 1781252715, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"MysqlGaleraSSTMethod\": {\"type\": \"string\", \"default\": \"rsync\", \"description\": \"Method used by galera to perform State Snapshot Transfers\", \"constraints\": [{\"allowed_values\": [\"rsync\", \"mariabackup\"]}]}, \"MysqlMariabackupUser\": {\"type\": \"string\", \"default\": \"mariabackup\", \"description\": \"When MysqlGaleraSSTMethod is set to mariabackup, the name of the database user that executes the SST.\"}, \"MysqlMariabackupPassword\": {\"type\": \"string\", \"hidden\": true, \"description\": \"When MysqlGaleraSSTMethod is set to mariabackup, the password of the database user that executes the SST.\", \"default\": \"zgFej84GkeJYRMxOd5txIKJHX\"}, \"MysqlGaleraSSLCipher\": {\"type\": \"string\", \"default\": \"AES128-SHA256\", \"description\": \"Symmetric cipher to use.\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MysqlBase\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerMysqlImage\": \"ContainerMysqlImage\", \"ContainerMysqlConfigImage\": \"ContainerMysqlConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerMysqlImage\": {\"get_param\": \"ContainerMysqlImage\"}, \"ContainerMysqlConfigImage\": {\"get_param\": \"ContainerMysqlConfigImage\"}}}]}}}}, \"conditions\": {\"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"role_data\": {\"description\": \"Containerized service MySQL using composable services.\", \"value\": {\"service_name\": {\"get_attr\": [\"MysqlBase\", \"role_data\", \"service_name\"]}, \"firewall_rules\": {\"104 mysql galera-bundle\": {\"dport\": [873, 3123, 3306, 4444, 4567, 4568, 9200]}}, \"firewall_frontend_rules\": {\"100 mysql_haproxy\": {\"dport\": [3306]}}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"MysqlBase\", \"role_data\", \"config_settings\"]}, {\"tripleo::profile::pacemaker::database::mysql::bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::pacemaker::database::mysql::gmcast_listen_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::pacemaker::database::mysql::ca_file\": {\"get_param\": \"InternalTLSCAFile\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::mysql_docker_image\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"tripleo::profile::pacemaker::database::mysql_bundle::control_port\": 3123, \"tripleo::profile::pacemaker::database::mysql_bundle::container_backend\": {\"get_param\": \"ContainerCli\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::pacemaker::database::mysql_bundle::ca_file\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"InternalTLSCAFile\"}]}, \"tripleo::profile::pacemaker::database::mysql_bundle::sst_method\": {\"get_param\": \"MysqlGaleraSSTMethod\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::mariabackup_user\": {\"get_param\": \"MysqlMariabackupUser\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::mariabackup_password\": {\"get_param\": \"MysqlMariabackupPassword\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::force_ocf\": true, \"tripleo::profile::pacemaker::database::mysql_bundle::gcomm_cipher\": {\"get_param\": \"MysqlGaleraSSLCipher\"}}]}, \"puppet_config\": {\"config_volume\": \"mysql\", \"puppet_tags\": \"file\", \"step_config\": {\"list_join\": [\"\\n\", [\"[\'Mysql_datadir\', \'Mysql_user\', \'Mysql_database\', \'Mysql_grant\', \'Mysql_plugin\'].each |String $val| { noop_resource($val) }\", \"exec {\'wait-for-settle\': command => \'/bin/true\' }\", \"include tripleo::profile::pacemaker::database::mysql_bundle\"]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/mysql.json\": {\"command\": \"/usr/sbin/pacemaker_remoted\", \"config_files\": [{\"dest\": \"/etc/libqb/force-filesystem-sockets\", \"source\": \"/dev/null\", \"owner\": \"root\", \"perm\": \"0644\"}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"optional\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/mysql\", \"owner\": \"mysql:mysql\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/mysql.crt\", \"owner\": \"mysql:mysql\", \"perm\": \"0600\", \"optional\": true}, {\"path\": \"/etc/pki/tls/private/mysql.key\", \"owner\": \"mysql:mysql\", \"perm\": \"0600\", \"optional\": true}]}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"docker_config\": {\"step_1\": {\"mysql_data_ownership\": {\"start_order\": 0, \"detach\": false, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"net\": \"host\", \"user\": \"root\", \"command\": [\"chown\", \"-R\", \"mysql:\", \"/var/lib/mysql\"], \"volumes\": [\"/var/lib/mysql:/var/lib/mysql:z\"]}, \"mysql_bootstrap\": {\"start_order\": 1, \"detach\": false, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"net\": \"host\", \"user\": \"root\", \"command\": [\"bash\", \"-ec\", {\"list_join\": [\"\\n\", [\"if [ -e /var/lib/mysql/mysql ]; then exit 0; fi\", \"echo -e \\\"\\\\n[mysqld]\\\\nwsrep_provider=none\\\" >> /etc/my.cnf\", \"export DB_ROOT_PASSWORD=$(hiera \'mysql::server::root_password\')\", \"kolla_set_configs\", \"sudo -u mysql -E kolla_extend_start\", \"timeout ${DB_MAX_TIMEOUT} /bin/bash -c \'while pgrep -af /usr/bin/mysqld_safe | grep -q -v grep; do sleep 1; done\'\", \"mysqld_safe --skip-networking --wsrep-on=OFF &\", \"timeout ${DB_MAX_TIMEOUT} /bin/bash -c \'until mysqladmin -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" ping 2>/dev/null; do sleep 1; done\'\"], {\"if\": [{\"equals\": [{\"get_param\": \"MysqlGaleraSSTMethod\"}, \"mariabackup\"]}, [\"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"CREATE USER \'${DB_MARIABACKUP_USER}\'@\'localhost\' IDENTIFIED BY \'${DB_MARIABACKUP_PASSWORD}\';\\\"\", \"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"GRANT RELOAD, PROCESS, LOCK TABLES, REPLICATION CLIENT ON *.* TO \'${DB_MARIABACKUP_USER}\'@\'localhost\';\\\"\"]]}, [\"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"CREATE USER \'clustercheck\'@\'localhost\' IDENTIFIED BY \'$(hiera mysql_clustercheck_password)\';\\\"\", \"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"GRANT PROCESS ON *.* TO \'clustercheck\'@\'localhost\' WITH GRANT OPTION;\\\"\", \"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"DELETE FROM mysql.user WHERE user = \'root\' AND host NOT IN (\'%\',\'localhost\');\\\"\", \"timeout ${DB_MAX_TIMEOUT} mysqladmin -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" shutdown\"]]}], \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/mysql.json:/var/lib/kolla/config_files/config.json:rw,z\", \"/var/lib/config-data/puppet-generated/mysql:/var/lib/kolla/config_files/src:ro,z\", \"/var/lib/mysql:/var/lib/mysql:rw,z\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/mysql.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/mysql.crt:ro\", \"/etc/pki/tls/private/mysql.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/mysql.key:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"KOLLA_BOOTSTRAP\": true, \"DB_MAX_TIMEOUT\": 60, \"DB_MARIABACKUP_USER\": {\"get_param\": \"MysqlMariabackupUser\"}, \"DB_MARIABACKUP_PASSWORD\": {\"get_param\": \"MysqlMariabackupPassword\"}}}}, \"step_2\": {\"mysql_wait_bundle\": {\"start_order\": 0, \"detach\": false, \"net\": \"host\", \"ipc\": \"host\", \"user\": \"root\", \"command\": {\"list_concat\": [[\"/container_puppet_apply.sh\", \"2\", \"file,file_line,concat,augeas,galera_ready,mysql_database,mysql_grant,mysql_user\", \"include tripleo::profile::pacemaker::database::mysql_bundle\"], {\"if\": [{\"get_param\": \"ConfigDebug\"}, [\"--debug\"]]}]}, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"container_puppet_apply_volumes\"]}, [\"/var/lib/mysql:/var/lib/mysql:rw,z\", \"/var/lib/config-data/puppet-generated/mysql/root:/root:rw\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"]]}]}, \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/mysql\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/mysql\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/log/mariadb\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}], \"metadata_settings\": {\"get_attr\": [\"MysqlBase\", \"role_data\", \"metadata_settings\"]}, \"deploy_steps_tasks\": {\"list_concat\": [{\"get_attr\": [\"MysqlBase\", \"role_data\", \"deploy_steps_tasks\"]}, [{\"name\": \"MySQL tag container image for pacemaker\", \"when\": \"step|int == 1\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"container_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}}}, {\"name\": \"MySQL HA Wrappers Step\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Mysql puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"mysql\", \"tripleo_ha_wrapper_resource_name\": \"galera\", \"tripleo_ha_wrapper_bundle_name\": \"galera-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Master\", \"tripleo_ha_wrapper_puppet_config_volume\": \"mysql\", \"tripleo_ha_wrapper_puppet_execute\": \"[\\\"Mysql_datadir\\\", \\\"Mysql_user\\\", \\\"Mysql_database\\\", \\\"Mysql_grant\\\", \\\"Mysql_plugin\\\"].each |String $val| { noop_resource($val) }; include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::database::mysql_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}]}]]}, \"external_update_tasks\": [{\"when\": \"step|int == 1\", \"tags\": \"ha_image_update\", \"block\": [{\"block\": [{\"name\": \"Get galera image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_galera_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'galera-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container galera image\", \"set_fact\": {\"galera_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"galera_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_galera_image\": \"{{xmllint_pcmk_galera_image.stdout}}\"}}], \"delegate_to\": \"{{ (groups[\\\"mysql\\\"] | difference(groups[\\\"excluded_overcloud\\\"]))[0] }}\"}, {\"name\": \"MySQL temporary pacemaker container tag in case of image switch\", \"become\": true, \"import_role\": {\"name\": \"tripleo_ha_image_update\"}, \"vars\": {\"tripleo_ha_image_update_node_names\": \"{{ groups[\\\"mysql\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) }}\", \"tripleo_ha_image_update_bundle\": \"galera-bundle\", \"tripleo_ha_image_update_new_image\": \"{{galera_image_latest}}\", \"tripleo_ha_image_update_old_image\": \"{{pcmk_galera_image}}\"}, \"when\": [\"(pcmk_galera_image != \\\"\\\")\", \"(pcmk_galera_image != galera_image_latest)\"]}]}], \"update_tasks\": [{\"block\": [{\"name\": \"Get galera image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_galera_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'galera-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container galera image\", \"set_fact\": {\"galera_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"galera_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_galera_image\": \"{{xmllint_pcmk_galera_image.stdout}}\"}}], \"when\": \"(step|int == 0 or step|int == 2)\"}, {\"name\": \"Check for update of galera container image name\", \"when\": \"step|int == 0\", \"assert\": {\"that\": \"pcmk_galera_image == galera_image_latest\", \"fail_msg\": \"galera image change detected, run overcloud external-update --tags ha_image_update first\"}}, {\"name\": \"Tear-down non-HA mysql container\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"stat mysql container\", \"command\": \"podman container exists mysql\", \"failed_when\": false, \"changed_when\": false, \"register\": \"stat_mysql_container\"}, {\"name\": \"Create clustercheck user and permissions\", \"command\": {\"argv\": \"{{ mysql_exec_data | container_exec_cmd }}\"}, \"changed_when\": true, \"when\": [\"stat_mysql_container.rc == 0\"], \"vars\": {\"mysql_exec_data\": {\"environment\": {\"CLUSTERCHECK_PASSWORD\": {\"get_param\": \"MysqlClustercheckPassword\"}}, \"command\": [\"mysql\", \"/bin/sh\", \"-c\", \"mysql -e \\\"CREATE USER IF NOT EXISTS \'clustercheck\'@\'localhost\' IDENTIFIED BY \'${CLUSTERCHECK_PASSWORD}\'; GRANT PROCESS ON *.* TO \'clustercheck\'@\'localhost\' WITH GRANT OPTION;\\\"\"]}}}, {\"name\": \"Remove non-HA mysql container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"mysql\"]}}]}, {\"name\": \"Mariadb fetch and retag container image for pacemaker\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Retag pcmklatest to latest galera image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{galera_image}}\", \"container_image_latest\": \"{{galera_image_latest}}\"}}]}, {\"name\": \"Ensure mariadb-server is not installed on the host\", \"when\": \"step|int == 2\", \"yum\": {\"name\": \"mariadb-server*\", \"state\": \"absent\"}}], \"post_update_tasks\": [{\"name\": \"Mysql bundle post update\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Mysql puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"mysql\", \"tripleo_ha_wrapper_resource_name\": \"galera\", \"tripleo_ha_wrapper_bundle_name\": \"galera-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Master\", \"tripleo_ha_wrapper_puppet_config_volume\": \"mysql\", \"tripleo_ha_wrapper_puppet_execute\": \"[\\\"Mysql_datadir\\\", \\\"Mysql_user\\\", \\\"Mysql_database\\\", \\\"Mysql_grant\\\", \\\"Mysql_plugin\\\"].each |String $val| { noop_resource($val) }; include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::database::mysql_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}], \"vars\": {\"tripleo_ha_wrapper_minor_update\": true}}], \"upgrade_tasks\": {\"list_concat\": [[{\"name\": \"Tear-down non-HA mysql container\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"stat mysql container\", \"command\": \"podman container exists mysql\", \"failed_when\": false, \"changed_when\": false, \"register\": \"stat_mysql_container\"}, {\"name\": \"Create clustercheck user and permissions\", \"command\": {\"argv\": \"{{ mysql_exec_data | container_exec_cmd }}\"}, \"changed_when\": true, \"when\": [\"stat_mysql_container.rc == 0\"], \"vars\": {\"mysql_exec_data\": {\"environment\": {\"CLUSTERCHECK_PASSWORD\": {\"get_param\": \"MysqlClustercheckPassword\"}}, \"command\": [\"mysql\", \"/bin/sh\", \"-c\", \"mysql -e \\\"CREATE USER IF NOT EXISTS \'clustercheck\'@\'localhost\' IDENTIFIED BY \'${CLUSTERCHECK_PASSWORD}\'; GRANT PROCESS ON *.* TO \'clustercheck\'@\'localhost\' WITH GRANT OPTION;\\\"\"]}}}, {\"name\": \"Remove non-HA mysql container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"mysql\"]}}]}], [{\"name\": \"set mysql container name fact\", \"when\": [\"step|int == 1\"], \"set_fact\": {\"mysql_container_name\": \"galera-bundle\"}}], {\"get_attr\": [\"MysqlBase\", \"mysql_drop_unused_users\"]}, [{\"vars\": {\"mysql_upgrade_persist\": {\"get_param\": \"MysqlUpgradePersist\"}}, \"when\": [\"step|int == 3\", \"mysql_upgrade_persist\"], \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"block\": [{\"name\": \"Persist mysql data\", \"include_role\": {\"name\": \"tripleo_persist\", \"tasks_from\": \"persist.yml\"}, \"vars\": {\"tripleo_persist_dir\": \"/var/lib/mysql\"}}]}, {\"vars\": {\"mysql_upgrade_persist\": {\"get_param\": \"MysqlUpgradePersist\"}}, \"when\": [\"step|int == 5\", \"mysql_upgrade_persist\"], \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\"], \"block\": [{\"name\": \"Restore mysql data\", \"include_role\": {\"name\": \"tripleo_persist\", \"tasks_from\": \"restore.yml\"}, \"vars\": {\"tripleo_persist_dir\": \"/var/lib/mysql\"}}]}, {\"name\": \"Prepare switch of galera image name\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Get galera image id currently used by pacemaker\", \"shell\": \"pcs resource config galera-bundle | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\", \"register\": \"galera_image_current_res\", \"failed_when\": false}, {\"name\": \"Image facts for galera\", \"set_fact\": {\"galera_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"galera_image_current\": \"{{galera_image_current_res.stdout}}\"}}, {\"name\": \"Temporarily tag the current galera image id with the upgraded image name\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{galera_image_current}}\", \"container_image_latest\": \"{{galera_image_latest}}\", \"pull_image\": false}, \"when\": [\"galera_image_current != \'\'\", \"galera_image_current != galera_image_latest\"]}, {\"name\": \"Create galera retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/galera_needs_retag\", \"state\": \"touch\"}, \"when\": [\"galera_image_current != \'\'\", \"galera_image_current != galera_image_latest\"]}]}, {\"name\": \"Update galera pcs resource bundle for new container image - check\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"set is_mysql_bootstrap_node fact\", \"tags\": \"common\", \"set_fact\": \"is_mysql_bootstrap_node={{mysql_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\"}, {\"name\": \"Check for galera retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/galera_needs_retag\"}, \"register\": \"galera_retag_state_file\"}]}, {\"name\": \"Update galera pcs resource bundle for new container image\", \"when\": [\"step|int == 1\", \"is_mysql_bootstrap_node|bool\", \"galera_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the galera cluster resource before container upgrade\", \"pacemaker_resource\": {\"resource\": \"galera-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Move Mysql logging to /var/log/containers\", \"block\": [{\"name\": \"Check Mysql logging configuration in pacemaker\", \"command\": \"cibadmin --query --xpath \\\"//storage-mapping[@id=\'mysql-log\']\\\"\", \"failed_when\": false, \"register\": \"mysql_logs_moved\"}, {\"name\": \"Change Mysql logging configuration in pacemaker\", \"when\": \"mysql_logs_moved.rc == 6\", \"block\": [{\"name\": \"Add a bind mount for logging in the galera bundle\", \"command\": \"pcs resource bundle update galera-bundle storage-map add id=mysql-log source-dir=/var/log/containers/mysql target-dir=/var/log/mysql options=rw\"}, {\"name\": \"Reconfigure Mysql log file in the galera resource agent\", \"command\": \"pcs resource update galera log=/var/log/mysql/mysqld.log\"}]}]}, {\"name\": \"Update the galera bundle to use the new container image name\", \"command\": \"pcs resource bundle update galera-bundle container image={{galera_image_latest}}\"}, {\"name\": \"Enable the galera cluster resource\", \"pacemaker_resource\": {\"resource\": \"galera-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}]}, {\"name\": \"Upgrade galera in step3\", \"when\": [\"step|int == 3\"], \"block\": [{\"name\": \"Bind mounts for temporary container\", \"set_fact\": {\"mysql_upgrade_db_bind_mounts\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/mysql.json:/var/lib/kolla/config_files/config.json:rw,z\", \"/var/lib/config-data/puppet-generated/mysql:/var/lib/kolla/config_files/src:ro,z\", \"/var/lib/mysql:/var/lib/mysql:rw,z\"], [\"/var/log/containers/mysql:/var/log/mysql:rw,z\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/mysql.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/mysql.crt:ro\", \"/etc/pki/tls/private/mysql.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/mysql.key:ro\"]]}]}}}, {\"name\": \"Check if Galera needs upgrade\", \"shell\": {\"str_replace\": {\"template\": \"CONTAINER_CLI run --rm --log-driver=k8s-file --log-opt path=LOG_DIR/db-upgrade.log \\\\ -u root --net=host UPGRADE_ENV UPGRADE_VOLUMES \\\"UPGRADE_IMAGE\\\" /bin/bash -ecx \\\"$UPGRADE_SCRIPT\\\"\", \"params\": {\"UPGRADE_ENV\": \"-e \\\"KOLLA_CONFIG_STRATEGY=COPY_ALWAYS\\\"\", \"UPGRADE_IMAGE\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"UPGRADE_VOLUMES\": \"-v {{ mysql_upgrade_db_bind_mounts | join(\' -v \')}}\", \"CONTAINER_CLI\": \"{{ container_cli }}\", \"LOG_DIR\": \"/var/log/containers/mysql\"}}}, \"environment\": {\"UPGRADE_SCRIPT\": \"kolla_set_configs\\nupgraded_ver=$(cat /var/lib/mysql/mysql_upgrade_info 2>/dev/null || true)\\nmysql_ver=$(mysql --version | awk -F\'[ ,]*\' \'{print $5}\')\\nif [ \\\"${upgraded_ver}\\\" = \\\"${mysql_ver}\\\" ]; then\\n    echo \\\"mysql already upgraded\\\"\\nelse\\n    echo \\\"${upgraded_ver} VS ${mysql_ver}\\\"\\nfi\\n\"}, \"register\": \"mysql_upgrade_needed\"}, {\"name\": \"Set fact upgrade_mysql\", \"set_fact\": {\"upgrade_mysql\": \"{{ (mysql_upgrade_needed.stdout != \\\"mysql already upgraded\\\") | bool }}\"}}, {\"debug\": {\"msg\": \"MYSQL check - {{ mysql_upgrade_needed.stdout }} - Upgrade needed: {{ upgrade_mysql }}\"}}, {\"name\": \"Disable the galera cluster resource before container upgrade\", \"when\": [\"upgrade_mysql|bool\"], \"pacemaker_resource\": {\"resource\": \"galera-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"block\": [{\"name\": \"Get galera image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_galera_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'galera-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container galera image\", \"set_fact\": {\"galera_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"galera_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_galera_image\": \"{{xmllint_pcmk_galera_image.stdout}}\"}}]}, {\"name\": \"Check for galera retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/galera_needs_retag\"}, \"register\": \"galera_retag_state_file\"}, {\"name\": \"Retag the pacemaker image if containerized\", \"when\": [\"galera_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Retag pcmklatest to latest galera image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{galera_image}}\", \"container_image_latest\": \"{{galera_image_latest}}\"}}]}, {\"name\": \"Remove galera retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/galera_needs_retag\", \"state\": \"absent\"}}, {\"name\": \"Mysql upgrade script\", \"when\": [\"upgrade_mysql|bool\"], \"set_fact\": {\"mysql_upgrade_script\": {\"list_join\": [\"\\n\", [\"kolla_set_configs\\nif mysqladmin ping --silent; then exit 0; fi\\nupgraded_ver=$(cat /var/lib/mysql/mysql_upgrade_info 2>/dev/null || true)\\nmysql_ver=$(mysql --version | awk -F\'[ ,]*\' \'{print $5}\')\\nif [ \\\"${upgraded_ver}\\\" = \\\"${mysql_ver}\\\" ]; then\\n    echo \\\"mysql already upgraded\\\"\\n    exit 0\\nfi\\nchown -R mysql:mysql /var/lib/mysql\\nchown -R mysql:mysql /var/log/mysql\\nmysqld_safe --user=mysql --wsrep-provider=none --skip-networking --wsrep-on=off --log-error=/var/log/mysql/mysqld-upgrade.log &\\n\", {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/mysql_upgrade_db.sh\"}, \"mysqladmin shutdown\"]]}}}, {\"name\": \"Upgrade Mysql database from a temporary container\", \"when\": [\"upgrade_mysql|bool\"], \"shell\": {\"str_replace\": {\"template\": \"CONTAINER_CLI run --rm --log-driver=k8s-file --log-opt path=LOG_DIR/db-upgrade.log \\\\ -u root --net=host UPGRADE_ENV UPGRADE_VOLUMES \\\"UPGRADE_IMAGE\\\" /bin/bash -ecx \\\"$UPGRADE_SCRIPT\\\"\", \"params\": {\"UPGRADE_ENV\": \"-e \\\"KOLLA_CONFIG_STRATEGY=COPY_ALWAYS\\\"\", \"UPGRADE_IMAGE\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"UPGRADE_VOLUMES\": \"-v {{ mysql_upgrade_db_bind_mounts | join(\' -v \')}}\", \"CONTAINER_CLI\": \"{{ container_cli }}\", \"LOG_DIR\": \"/var/log/containers/mysql\"}}}, \"environment\": {\"UPGRADE_SCRIPT\": \"{{ mysql_upgrade_script }}\"}}, {\"name\": \"Enable the galera cluster resource\", \"when\": [\"upgrade_mysql|bool\"], \"pacemaker_resource\": {\"resource\": \"galera-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}]}]]}, \"external_upgrade_tasks\": [{\"vars\": {\"mysql_upgrade_transfer\": {\"get_param\": \"MysqlUpgradeTransfer\"}}, \"when\": [\"step|int == 2\", \"mysql_upgrade_transfer\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\"], \"block\": [{\"name\": \"Transfer mysql data\", \"include_role\": {\"name\": \"tripleo_transfer\"}, \"vars\": {\"tripleo_transfer_src_dir\": \"/var/lib/mysql\", \"tripleo_transfer_src_host\": \"{{hostvars[groups[\'overcloud\'][0]][\'mysql_short_node_names\'][1]}}\", \"tripleo_transfer_dest_dir\": \"/var/lib/mysql\", \"tripleo_transfer_dest_host\": \"{{hostvars[groups[\'overcloud\'][0]][\'mysql_short_bootstrap_node_name\']}}\", \"tripleo_transfer_flag_file\": \"/var/lib/tripleo/transfer-flags/var-lib-mysql\", \"tripleo_transfer_sync_options\": \"--whole-file --ignore-times --inplace --archive --delete\", \"tripleo_transfer_include\": [\"/ibdata*\", \"/ib_lru_dump\", \"/ib_logfile[0-9]*\", \"/undo*\", \"/*/\"], \"tripleo_transfer_exclude\": \"/*\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (40,'2026-06-12 08:25:55',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"MySQL service deployment using puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"MysqlMaxConnections\": {\"description\": \"Configures MySQL max_connections config setting\", \"type\": \"number\", \"default\": 4096}, \"MysqlIncreaseFileLimit\": {\"description\": \"Flag to increase MySQL open-files-limit to 16384\", \"type\": \"boolean\", \"default\": true}, \"MysqlRootPassword\": {\"type\": \"string\", \"hidden\": true, \"default\": \"lewodgEGks\"}, \"MysqlClustercheckPassword\": {\"type\": \"string\", \"hidden\": true, \"default\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\"}, \"EnableGalera\": {\"default\": true, \"description\": \"Whether to use Galera instead of regular MariaDB.\", \"type\": \"boolean\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"EnableMysqlAuthEd25519\": {\"type\": \"boolean\", \"description\": \"Whether to configure MySQL users to connect to the server using the Ed25519-based client authentication.\", \"default\": false}, \"MysqlIPv6\": {\"default\": false, \"description\": \"Enable IPv6 in MySQL\", \"type\": \"boolean\"}, \"MysqlInnodbBufferPoolSize\": {\"type\": \"string\", \"description\": \"Buffer pool size for MySQL database; this needs to be larger for at-scale deployments\", \"default\": \"128M\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"MysqlCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"MysqlIPv6\"]}], \"conditions\": {\"is_ipv6\": {\"equals\": [{\"get_param\": [\"ServiceData\", \"net_ip_version_map\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}, 6]}, \"innodb_buffer_pool_set\": {\"not\": {\"equals\": [{\"get_param\": \"MysqlInnodbBufferPoolSize\"}, \"\"]}}, \"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"MysqlCertificateKeySize\"}, \"\"]}}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared docker config scripts\", \"value\": {\"mysql_upgrade_db.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/mysql_upgrade_db.sh\"}}}}, \"mysql_drop_unused_users\": {\"description\": \"Ansible block to clean up unusued Openstack DB users\", \"value\": [{\"name\": \"Drop unused OpenStack DB users\", \"when\": [\"step|int == 1\", \"mysql_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower\"], \"block\": [{\"name\": \"mysql container id\", \"command\": \"podman ps -q --filter name={{ mysql_container_name }} --filter status=running\", \"register\": \"mysql_container_id\"}, {\"name\": \"set mysql container id fact\", \"set_fact\": {\"mysql_container\": \"{{ mysql_container_id.stdout }}\"}}, {\"name\": \"Mysql script to drop unused DB users\", \"when\": \"( mysql_container | length ) > 0\", \"block\": [{\"name\": \"Get the list of all OpenStack DB users\", \"shell\": \"jq -r \'to_entries[] | select(.key|endswith(\\\"::db::mysql::user\\\")) | .value\' /etc/puppet/hieradata/service_configs.json\", \"register\": \"openstack_db_users\"}, {\"name\": \"List all DB users that match the DB users to be dropped\", \"shell\": \"for u in {{ openstack_db_users.stdout_lines | join(\' \') }}; do podman exec -u root -it \\\"{{ mysql_container }}\\\" mysql -sNe \\\"select concat(\'\\\\`\',user,\'\\\\`@\\\\`\',host,\'\\\\`\') from mysql.user where user = \'$u\' and host != \'%\';\\\"; done\", \"register\": \"mysql_db_users\"}, {\"name\": \"resulting DB users to be dropped\", \"debug\": {\"msg\": \"{{ mysql_db_users.stdout_lines }}\"}}, {\"name\": \"Drop all unneeded Openstack DB users\", \"shell\": \"podman exec -u root -it \\\"{{ mysql_container }}\\\" mysql -sNe \'drop user {{ item }};\'\", \"loop\": \"{{ mysql_db_users.stdout_lines }}\"}]}]}]}, \"role_data\": {\"description\": \"Service MySQL using composable services.\", \"value\": {\"service_name\": \"mysql\", \"config_settings\": {\"mysql::server::package_name\": \"mariadb-galera-server\", \"mysql::server::manage_config_file\": true, \"mysql_ipv6\": {\"if\": [\"is_ipv6\", true, false]}, \"mysql_max_connections\": {\"get_param\": \"MysqlMaxConnections\"}, \"mysql::server::root_password\": {\"get_param\": \"MysqlRootPassword\"}, \"mysql_clustercheck_password\": {\"get_param\": \"MysqlClustercheckPassword\"}, \"enable_galera\": {\"get_param\": \"EnableGalera\"}, \"mysql_auth_ed25519\": {\"get_param\": \"EnableMysqlAuthEd25519\"}, \"mysql_bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::generate_dropin_file_limit\": {\"get_param\": \"MysqlIncreaseFileLimit\"}, \"tripleo::profile::base::database::mysql::certificate_specs\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"service_certificate\": \"/etc/pki/tls/certs/mysql.crt\", \"service_key\": \"/etc/pki/tls/private/mysql.key\"}]}, \"innodb_buffer_pool_size\": {\"if\": [\"innodb_buffer_pool_set\", {\"get_param\": \"MysqlInnodbBufferPoolSize\"}]}}, \"step_config\": \"include tripleo::profile::base::database::mysql\\n\", \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [{\"service\": \"mysql\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}, \"type\": \"vip\"}, {\"service\": \"mysql\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}, \"type\": \"node\"}]]}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"mysql\", \"dns\": [{\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, {\"str_replace\": {\"template\": \"{{cloud_names.cloud_name_NETWORK}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}], \"principal\": {\"str_replace\": {\"template\": \"mysql/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"MysqlCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(41,'2026-06-12 08:25:55',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Host config and reboot service which configures Kernel Args and reboot\", \"parameters\": {\"RoleNetIpMap\": {\"default\": {}, \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KernelArgs\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Kernel Args to apply to the host\", \"tags\": [\"role_specific\"]}, \"KernelArgsDeferReboot\": {\"default\": false, \"type\": \"boolean\", \"description\": \"When enabled, nodes will not get rebooted automatically by tripleo-kernel if KernelArgs have been changed. Operators will have to manually reboot nodes after the deployment or update process is completed.\\nLeaving this enabled during a scale-up operation will prevent reboot on new nodes. This might cause deployment errors as the KernelArgs will not be applied.\\n\", \"tags\": [\"role_specific\"]}, \"TunedProfileName\": {\"default\": \"throughput-performance\", \"type\": \"string\", \"description\": \"Tuned Profile to apply to the host\", \"tags\": [\"role_specific\"]}, \"IsolCpusList\": {\"default\": \"\", \"type\": \"string\", \"description\": \"List of logical CPU ids whic need to be isolated from the host processes. This input is provided to the tuned profile cpu-partitioning to configure systemd and repin interrupts (IRQ repinning).\\n\", \"tags\": [\"role_specific\"]}, \"NodeRebootWaitTimeout\": {\"default\": 900, \"type\": \"number\", \"description\": \"Timeout in seconds to specify the wait time for ansible node reboot\"}, \"Hugepages\": {\"default\": {}, \"type\": \"json\", \"description\": \"Hash for hugepage configuration Example:\\n  Hugepages:\\n    2048:\\n      count: 100\\n      default: false\\n    1048576:\\n      count: 100\\n      default: true\\n\", \"tags\": [\"role_specific\"]}, \"ReconfigureHugepages\": {\"default\": false, \"type\": \"boolean\", \"description\": \"By default, tripleo-kernel will configure the provided Hugepages as specified by operators but it won\'t try to remove Hugepages configured on the host that are not part of the TripleO paramater. Enabling this setting will make sure everything is reconfigured exactly like the TripleO parameter, otherwise we just add the content of the Hugepages parameter to what\'s already in place.\\n\", \"tags\": [\"role_specific\"]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"tuned_profile\": \"TunedProfileName\", \"isolated_cores\": \"IsolCpusList\", \"kernel_args\": \"KernelArgs\", \"kernel_args_defer_reboot\": \"KernelArgsDeferReboot\", \"hugepages\": \"Hugepages\", \"reconfigure_hugepages\": \"ReconfigureHugepages\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"TunedProfileName\": {\"get_param\": \"TunedProfileName\"}, \"IsolCpusList\": {\"get_param\": \"IsolCpusList\"}, \"KernelArgs\": {\"get_param\": \"KernelArgs\"}, \"KernelArgsDeferReboot\": {\"get_param\": \"KernelArgsDeferReboot\"}, \"Hugepages\": {\"get_param\": \"Hugepages\"}, \"ReconfigureHugepages\": {\"get_param\": \"ReconfigureHugepages\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Host Config Service\", \"value\": {\"service_name\": \"boot_params_service\", \"deploy_steps_tasks\": [{\"name\": \"Configure tuned before reboot\", \"when\": \"step|int == 0\", \"include_role\": {\"name\": \"tuned\"}, \"vars\": {\"tuned_profile\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"tuned_profile\"]}, \"tuned_isolated_cores\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"isolated_cores\"]}}}, {\"name\": \"Configure kernel args and reboot\", \"when\": \"step|int == 0\", \"include_role\": {\"name\": \"tripleo_kernel\", \"tasks_from\": \"kernelargs.yml\"}, \"vars\": {\"tripleo_kernel_args\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"kernel_args\"]}, \"tripleo_kernel_hugepages\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"hugepages\"]}, \"tripleo_kernel_hugepages_remove\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"reconfigure_hugepages\"]}, \"tripleo_kernel_defer_reboot\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"kernel_args_defer_reboot\"]}, \"tripleo_kernel_reboot_timeout\": {\"get_param\": \"NodeRebootWaitTimeout\"}}}], \"upgrade_tasks\": [{\"name\": \"upgrade prepare for leapp to align kernel arg shortcommings in leapp\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"fix grub entries to have name start with GRUB_\", \"replace\": {\"path\": \"/etc/default/grub\", \"regexp\": \"^(TRIPLEO_HEAT_TEMPLATE_KERNEL_ARGS)(.*)\", \"replace\": \"GRUB_\\\\1\\\\2\"}}, {\"name\": \"fix grub entries in append statement\", \"replace\": {\"path\": \"/etc/default/grub\", \"regexp\": \"(.*){(TRIPLEO_HEAT_TEMPLATE_KERNEL_ARGS)}(.*)\", \"replace\": \"\\\\1{GRUB_\\\\2}\\\\3\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(42,'2026-06-12 08:25:55',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(43,'2026-06-12 08:25:56',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(44,'2026-06-12 08:25:56',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Containerized collectd service\\n\", \"parameters\": {\"ContainerCollectdImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\"}, \"ContainerCollectdConfigImage\": {\"description\": \"The container image to use for the collectd config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"description\": \"Keystone region for endpoint\", \"default\": \"regionOne\"}, \"MetricsQdrPort\": {\"default\": 5666, \"description\": \"Service name or port number on which the qdrouterd will accept connections.\", \"type\": \"number\"}, \"MetricsQdrUsername\": {\"default\": \"guest\", \"description\": \"Username which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\"}, \"MetricsQdrPassword\": {\"default\": \"guest\", \"description\": \"Password which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\", \"hidden\": true}, \"MonitoringSubscriptionCollectd\": {\"default\": \"overcloud-collectd\", \"type\": \"string\"}, \"CollectdConnectionType\": {\"default\": \"amqp1\", \"description\": \"Define which write plugin should collectd use. Currently supported are \'amqp1\' and \'network\'.\", \"type\": \"string\"}, \"CollectdDefaultPollingInterval\": {\"default\": 120, \"type\": \"number\", \"description\": \"Controls how often registered read functions are called and with that the resolution of the collected data. This value can be overridden per plugin(per role) by setting \\\"::collectd::plugin::<plugin_name>::interval\\\" key in ExtraConfig(<role_name>ExtraConfig) if using puppet, and by setting \\\"collectd_plugin_<plugin_name>_interval\\\" in <role_name>ExtraConfig/CollectdVars if using ansible.\\n\"}, \"CollectdDefaultPlugins\": {\"default\": [\"cpu\", \"df\", \"disk\", \"hugepages\", \"interface\", \"load\", \"memory\", \"unixsock\", \"uptime\"], \"type\": \"comma_delimited_list\", \"description\": \"List of collectd plugins to activate on all overcloud hosts.  See the documentation for the puppet-collectd module for a list plugins supported by the module (https://github.com/voxpupuli/puppet-collectd). Set this key to override the default list of plugins.  Use CollectdExtraPlugins if you want to load additional plugins without overriding the defaults.\\n\"}, \"CollectdExtraPlugins\": {\"default\": [], \"type\": \"comma_delimited_list\", \"description\": \"List of collectd plugins to activate on all overcloud hosts.  See the documentation for the puppet-collectd module for a list plugins supported by the module (https://github.com/voxpupuli/puppet-collectd). Set this key to load plugins in addition to those in CollectdDefaultPlugins.\\n\"}, \"CollectdServer\": {\"type\": \"string\", \"description\": \"Address of remote collectd server to which we will send metrics.\\n\", \"default\": \"\"}, \"CollectdServerPort\": {\"type\": \"number\", \"default\": 25826, \"description\": \"Port on remote collectd server to which we will send metrics.\\n\"}, \"CollectdUsername\": {\"type\": \"string\", \"description\": \"Username for authenticating to the remote collectd server. The default is to not configure any authentication.\\n\", \"default\": \"\"}, \"CollectdPassword\": {\"type\": \"string\", \"hidden\": true, \"description\": \"Password for authenticating to the remote collectd server. The default is to not configure any authentication.\\n\", \"default\": \"\"}, \"CollectdSecurityLevel\": {\"type\": \"string\", \"description\": \"Security level setting for remote collectd connection. If it is set to Sign or Encrypt the CollectdPassword and CollectdUsername parameters need to be set.\\n\", \"default\": \"None\", \"constraints\": [{\"allowed_values\": [\"None\", \"Sign\", \"Encrypt\"]}]}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"CollectdSQLAlchemyLogMessages\": {\"type\": \"string\", \"description\": \"set to \\\"debug\\\" to enable message logging.\", \"default\": \"info\"}, \"CollectdSQLAlchemyBindHost\": {\"type\": \"string\", \"description\": \"hostname for SQLAlchemy-collectd plugin to bind on.  defaults to localhost.\\n\", \"default\": \"localhost\"}, \"CollectdAmqpHost\": {\"type\": \"string\", \"description\": \"Hostname or IP address of the AMQP 1.0 intermediary.\", \"default\": \"nil\"}, \"CollectdAmqpPort\": {\"type\": \"number\", \"description\": \"Service name or port number on which the AMQP 1.0 intermediary accepts connections. This argument must be a string, even if the numeric form is used.\\n\", \"default\": 5666}, \"CollectdAmqpUser\": {\"type\": \"string\", \"description\": \"User part of credentials used to authenticate to the AMQP 1.0 intermediary.\\n\", \"default\": \"guest\"}, \"CollectdAmqpPassword\": {\"type\": \"string\", \"description\": \"Password part of credentials used to authenticate to the AMQP 1.0 intermediary.\\n\", \"default\": \"guest\", \"hidden\": true}, \"CollectdAmqpTransportName\": {\"type\": \"string\", \"description\": \"Name of the AMQP 1.0 transport.\", \"default\": \"metrics\"}, \"CollectdAmqpAddress\": {\"type\": \"string\", \"description\": \"This option specifies the prefix for the send-to value in the message.\\n\", \"default\": \"collectd\"}, \"CollectdAmqpInstances\": {\"type\": \"json\", \"description\": \"Hash of hashes. Each inner hash represent Instance block in plugin configuration file. Key of outter hash represents instance name. The \'address\' value concatenated with the \'name\' given will be used as the send-to address for communications over the messaging link.\\n\", \"default\": {}}, \"CollectdAmqpRetryDelay\": {\"type\": \"number\", \"description\": \"When the AMQP 1.0 connection is lost, defines the time in seconds to wait before attempting to reconnect.\\n\", \"default\": 1}, \"CollectdAmqpInterval\": {\"type\": \"number\", \"description\": \"Interval on which metrics should be sent to AMQP intermediary. If not set the default for all collectd plugins is used.\\n\", \"default\": -666}, \"CollectdAmqpSendQueueLimit\": {\"type\": \"number\", \"description\": \"Number of data sets to be kept in memory, older sets will be discarded, if set to -1, this feature is disabled.\\n\", \"default\": -1}, \"CollectdEnableSensubility\": {\"type\": \"boolean\", \"description\": \"Set to true if sensubility should be executed by exec plugin.\", \"default\": false}, \"CollectdSensubilityExecSudoRule\": {\"type\": \"string\", \"description\": \"Given rule will be created in /etc/sudoers.d for sensubility to enable it calling restricted commands via sensubility executor.\\n\", \"default\": \"\"}, \"CollectdSensubilityLogLevel\": {\"type\": \"string\", \"description\": \"Use for override the default logging level (WARNING).\", \"default\": \"WARNING\"}, \"CollectdSensubilityConnection\": {\"type\": \"string\", \"description\": \"URL to Sensu sever side\", \"default\": \"amqp://sensu:sensu@localhost:5672//sensu\"}, \"CollectdSensubilityKeepaliveInterval\": {\"type\": \"number\", \"description\": \"Interval in seconds for sending keepalive messages to Sensu server side.\", \"default\": 20}, \"CollectdSensubilityTmpDir\": {\"type\": \"string\", \"description\": \"Path to temporary directory which is used for creation of check scripts.\", \"default\": \"/var/tmp/collectd-sensubility-checks\"}, \"CollectdSensubilityShellPath\": {\"type\": \"string\", \"description\": \"Path to shell used for executing check scripts.\", \"default\": \"/usr/bin/sh\"}, \"CollectdSensubilityWorkerCount\": {\"type\": \"number\", \"description\": \"Number of goroutines spawned for executing check scripts.\", \"default\": 2}, \"CollectdSensubilityChecks\": {\"type\": \"json\", \"description\": \"JSON formated definition of standalone checks to be scheduled on client side.\", \"default\": {}}, \"CollectdSensubilityTransport\": {\"type\": \"string\", \"description\": \"Bus type for sent data. Options are \'sensu\' (rabbitmq) and \'amqp1\'\", \"default\": \"sensu\"}, \"CollectdSensubilityResultsChannel\": {\"type\": \"string\", \"description\": \"AMQP1 channel address\", \"default\": \"collectd/notify\"}, \"CollectdSensubilityScripts\": {\"type\": \"json\", \"description\": \"List of hashes of scripts for download for sensubility usage. Value has to be in following format:\\n[{\\\"name\\\": \\\"<script name>\\\", \\\"source\\\": \\\"<http URI to download script>\\\", \\\"checksum\\\": \\\"<alogithm:sum>\\\"}]\\n\", \"default\": []}, \"CollectdEnableContainerHealthCheck\": {\"type\": \"boolean\", \"description\": \"Set to false if container health check should not be defined and attached to CollectdEnableContainerHealthCheck.\\n\", \"default\": true}, \"CollectdContainerHealthCheckCommand\": {\"type\": \"string\", \"default\": \"/config-scripts/collectd_check_health.py\"}, \"CollectdContainerHealthCheckInterval\": {\"type\": \"number\", \"description\": \"The frequency in seconds the docker health check is executed.\", \"default\": 10}, \"CollectdContainerHealthCheckHandlers\": {\"default\": [], \"description\": \"The Sensu event handler to use for events created by the docker health check.\", \"type\": \"comma_delimited_list\"}, \"CollectdContainerHealthCheckOccurrences\": {\"type\": \"number\", \"description\": \"The number of event occurrences before sensu-plugin-aware handler should take action.\", \"default\": 3}, \"CollectdContainerHealthCheckRefresh\": {\"type\": \"number\", \"description\": \"The number of seconds sensu-plugin-aware handlers should wait before taking second action.\", \"default\": 90}, \"EnableSTF\": {\"type\": \"boolean\", \"description\": \"Set to true to enable configuration for STF client.\", \"default\": false}, \"CollectdEnableMcelog\": {\"type\": \"boolean\", \"description\": \"Set to true to enable mcelog\", \"default\": false}, \"CollectdEnableLibpodstats\": {\"type\": \"boolean\", \"description\": \"Set to true if collectd should run the libpodstats plugin\", \"default\": false}, \"CollectdContainerAdditionalCapAdd\": {\"type\": \"comma_delimited_list\", \"description\": \"Additional container capabilities to add to the collectd container. By default is appended to IPC_LOCK.\", \"default\": []}, \"CollectdLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"collectd\", \"file\": \"/var/log/containers/collectd/collectd.log\"}}, \"DeployedCeph\": {\"default\": false, \"type\": \"boolean\", \"description\": \"If the Ceph cluster has already been deployed but needs to be configured\\nso that the overcloud can use it (create cephx keys, pools, configure RGW\\nwith haproxy, etc), then this parameter should be set to true. Set this\\nparameter to false to have cephadm deploy the ceph cluster during overcloud\\ndeployment. DeployedCeph and CephDynamicSpec are mutually exclusive.\\n\"}, \"CephClusterFSID\": {\"type\": \"string\", \"description\": \"The Ceph cluster FSID. Must be a UUID.\", \"default\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\"}}, \"conditions\": {\"amqp_connection\": {\"equals\": [{\"get_param\": \"CollectdConnectionType\"}, \"amqp1\"]}, \"amqp_default_connection\": {\"equals\": [{\"get_param\": \"CollectdAmqpHost\"}, \"nil\"]}, \"amqp_default_interval\": {\"equals\": [{\"get_param\": \"CollectdAmqpInterval\"}, -666]}, \"amqp_default_send_queue_limit\": {\"equals\": [{\"get_param\": \"CollectdAmqpSendQueueLimit\"}, -1]}, \"collectd_connection\": {\"equals\": [{\"get_param\": \"CollectdConnectionType\"}, \"network\"]}, \"enable_sensubility\": {\"equals\": [{\"get_param\": \"CollectdEnableSensubility\"}, true]}, \"enable_stf\": {\"equals\": [{\"get_param\": \"EnableSTF\"}, true]}, \"enable_sqlalchemy_collectd\": {\"equals\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, true]}, \"sensubility_needs_sudo\": {\"not\": {\"equals\": [{\"get_param\": \"CollectdSensubilityExecSudoRule\"}, \"\"]}}, \"enable_libpodstats\": {\"equals\": [{\"get_param\": \"CollectdEnableLibpodstats\"}, true]}, \"ipmi_monitor\": {\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"IpmiMonitor\"]}, \"\"]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCollectdImage\": \"ContainerCollectdImage\", \"ContainerCollectdConfigImage\": \"ContainerCollectdConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCollectdImage\": {\"get_param\": \"ContainerCollectdImage\"}, \"ContainerCollectdConfigImage\": {\"get_param\": \"ContainerCollectdConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the collectd role.\", \"value\": {\"service_name\": \"collectd\", \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::enable_file_logging\": true, \"collectd::plugin::logfile::log_file\": \"/var/log/collectd/collectd.log\"}, {\"collectd::manage_repo\": false, \"collectd::purge\": true, \"collectd::recurse\": true, \"collectd::purge_config\": true, \"collectd::minimum_version\": \"5.7\", \"collectd::interval\": {\"get_param\": \"CollectdDefaultPollingInterval\"}, \"collectd::plugin::unixsock::socketgroup\": \"root\", \"collectd::plugin::unixsock::socketfile\": \"/run/collectd-socket\", \"collectd::plugin::unixsock::deletesocket\": true, \"collectd::plugin::cpu::reportbycpu\": true, \"collectd::plugin::cpu::reportbystate\": true, \"collectd::plugin::cpu::reportnumcpu\": false, \"collectd::plugin::cpu::valuespercentage\": true, \"collectd::plugin::df::ignoreselected\": true, \"collectd::plugin::df::reportbydevice\": true, \"collectd::plugin::df::fstypes\": [\"xfs\"], \"collectd::plugin::load::reportrelative\": true, \"collectd::plugin::virt::connection\": \"qemu:///system\", \"collectd::plugin::virt::extra_stats\": {\"list_join\": [\" \", [\"pcpu\", \"cpu_util\", \"vcpu\", \"memory\", \"disk\", \"disk_err\", \"disk_allocation\", \"disk_capacity\", \"disk_physical\", \"domain_state\", \"job_stats_background\", \"perf\"]]}, \"collectd::plugin::virt::hostname_format\": \"hostname\", \"tripleo.collectd.plugins.collectd\": {\"yaql\": {\"data\": {\"default_plugins\": {\"get_param\": \"CollectdDefaultPlugins\"}, \"stf_plugins\": {\"if\": [\"enable_stf\", [\"cpu\", \"df\", \"load\", \"connectivity\", \"intel_rdt\", \"procevent\"], []]}, \"extra_plugins\": {\"get_param\": \"CollectdExtraPlugins\"}}, \"expression\": \"($.data.default_plugins + $.data.stf_plugins + $.data.extra_plugins) .flatten().distinct()\\n\"}}}, {\"if\": [\"amqp_connection\", {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::amqp_transport_name\": {\"get_param\": \"CollectdAmqpTransportName\"}, \"tripleo::profile::base::metrics::collectd::amqp_address\": {\"get_param\": \"CollectdAmqpAddress\"}, \"tripleo::profile::base::metrics::collectd::amqp_instances\": {\"get_param\": \"CollectdAmqpInstances\"}, \"tripleo::profile::base::metrics::collectd::amqp_retry_delay\": {\"get_param\": \"CollectdAmqpRetryDelay\"}}, {\"if\": [\"amqp_default_interval\", {}, {\"tripleo::profile::base::metrics::collectd::amqp_interval\": {\"get_param\": \"CollectdAmqpInterval\"}}]}, {\"if\": [\"amqp_default_send_queue_limit\", {}, {\"tripleo::profile::base::metrics::collectd::amqp_send_queue_limit\": {\"get_param\": \"CollectdAmqpSendQueueLimit\"}}]}, {\"if\": [\"amqp_default_connection\", {\"tripleo::profile::base::metrics::collectd::amqp_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::metrics::collectd::amqp_port\": {\"get_param\": \"MetricsQdrPort\"}, \"tripleo::profile::base::metrics::collectd::amqp_user\": {\"get_param\": \"MetricsQdrUsername\"}, \"tripleo::profile::base::metrics::collectd::amqp_password\": {\"get_param\": \"MetricsQdrPassword\"}}, {\"tripleo::profile::base::metrics::collectd::amqp_host\": {\"get_param\": \"CollectdAmqpHost\"}, \"tripleo::profile::base::metrics::collectd::amqp_port\": {\"get_param\": \"CollectdAmqpPort\"}, \"tripleo::profile::base::metrics::collectd::amqp_user\": {\"get_param\": \"CollectdAmqpUser\"}, \"tripleo::profile::base::metrics::collectd::amqp_password\": {\"get_param\": \"CollectdAmqpPassword\"}}]}]}, {}]}, {\"if\": [\"collectd_connection\", {\"tripleo::profile::base::metrics::collectd::collectd_server\": {\"get_param\": \"CollectdServer\"}, \"tripleo::profile::base::metrics::collectd::collectd_port\": {\"get_param\": \"CollectdServerPort\"}, \"tripleo::profile::base::metrics::collectd::collectd_username\": {\"get_param\": \"CollectdUsername\"}, \"tripleo::profile::base::metrics::collectd::collectd_password\": {\"get_param\": \"CollectdPassword\"}, \"tripleo::profile::base::metrics::collectd::collectd_securitylevel\": {\"get_param\": \"CollectdSecurityLevel\"}}, {}]}, {\"if\": [\"enable_sqlalchemy_collectd\", {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::enable_sqlalchemy_collectd\": true}, {\"tripleo::profile::base::metrics::collectd::sqlalchemy_collectd_bind_host\": {\"get_param\": \"CollectdSQLAlchemyBindHost\"}}, {\"tripleo::profile::base::metrics::collectd::sqlalchemy_collectd_log_messages\": {\"get_param\": \"CollectdSQLAlchemyLogMessages\"}}]}, {}]}, {\"if\": [\"enable_sensubility\", {\"map_merge\": [{\"if\": [\"sensubility_needs_sudo\", {\"tripleo::profile::base::metrics::collectd::sensubility::exec_sudo_rule\": {\"get_param\": \"CollectdSensubilityExecSudoRule\"}}, {}]}, {\"tripleo::profile::base::metrics::collectd::enable_sensubility\": {\"get_param\": \"CollectdEnableSensubility\"}, \"tripleo::profile::base::metrics::collectd::sensubility::connection\": {\"get_param\": \"CollectdSensubilityConnection\"}, \"tripleo::profile::base::metrics::collectd::sensubility::log_level\": {\"get_param\": \"CollectdSensubilityLogLevel\"}, \"tripleo::profile::base::metrics::collectd::sensubility::client_name\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_NETWORK\')}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::metrics::collectd::sensubility::client_address\": {\"str_replace\": {\"template\": \"%{hiera(\'NETWORK\')}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::metrics::collectd::sensubility::keepalive_interval\": {\"get_param\": \"CollectdSensubilityKeepaliveInterval\"}, \"tripleo::profile::base::metrics::collectd::sensubility::tmp_base_dir\": {\"get_param\": \"CollectdSensubilityTmpDir\"}, \"tripleo::profile::base::metrics::collectd::sensubility::shell_path\": {\"get_param\": \"CollectdSensubilityShellPath\"}, \"tripleo::profile::base::metrics::collectd::sensubility::worker_count\": {\"get_param\": \"CollectdSensubilityWorkerCount\"}, \"tripleo::profile::base::metrics::collectd::sensubility::checks\": {\"map_merge\": [{\"get_param\": \"CollectdSensubilityChecks\"}, {\"if\": [{\"get_param\": \"CollectdEnableContainerHealthCheck\"}, {\"check-container-health\": {\"standalone\": true, \"command\": {\"get_param\": \"CollectdContainerHealthCheckCommand\"}, \"interval\": {\"get_param\": \"CollectdContainerHealthCheckInterval\"}, \"handlers\": {\"get_param\": \"CollectdContainerHealthCheckHandlers\"}, \"occurrences\": {\"get_param\": \"CollectdContainerHealthCheckOccurrences\"}, \"refresh\": {\"get_param\": \"CollectdContainerHealthCheckRefresh\"}}}, {}]}]}, \"tripleo::profile::base::metrics::collectd::sensubility::results_channel\": {\"get_param\": \"CollectdSensubilityResultsChannel\"}, \"tripleo::profile::base::metrics::collectd::sensubility::transport\": {\"get_param\": \"CollectdSensubilityTransport\"}, \"tripleo::profile::base::metrics::collectd::sensubility::amqp_port\": {\"get_param\": \"CollectdAmqpPort\"}}]}, {}]}, {\"if\": [\"enable_libpodstats\", {\"tripleo::profile::base::metrics::collectd::enable_libpodstats\": {\"get_param\": \"CollectdEnableLibpodstats\"}}, {}]}, {\"if\": [{\"get_param\": \"DeployedCeph\"}, {\"collectd::plugin::ceph::ceph_fsid\": {\"get_param\": \"CephClusterFSID\"}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_collectd\": [{\"get_param\": \"CollectdLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"collectd\", \"puppet_tags\": \"collectd_client_config,exec\", \"step_config\": \"include tripleo::profile::base::metrics::collectd\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCollectdConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/collectd.json\": {\"command\": \"/usr/sbin/collectd -f\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/collectd.d\", \"dest\": \"/etc/\", \"merge\": false, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/collectd\", \"owner\": \"collectd:collectd\", \"recurse\": true}, {\"path\": \"/scripts\", \"owner\": \"collectd:collectd\", \"recurse\": true}, {\"path\": \"/config-scripts\", \"owner\": \"collectd:collectd\", \"recurse\": true}]}}, \"container_config_scripts\": {\"map_merge\": [{\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, {\"collectd_check_health.py\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/monitoring/collectd_check_health.py\"}}}]}, \"docker_config\": {\"step_2\": {\"if\": [{\"get_param\": \"CollectdEnableSensubility\"}, {\"collectd_init_perm\": {\"image\": {\"get_param\": \"ContainerCollectdImage\"}, \"net\": \"none\", \"user\": \"root\", \"volumes\": [\"/var/lib/tripleo-podman/collectd:/tmp/run:rw,z\"], \"command\": [\"setfacl\", \"-R\", \"-m\", \"u:collectd:rwx\", \"/tmp/run\"]}}]}, \"step_3\": {\"collectd\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCollectdImage\"]}, \"net\": \"host\", \"pid\": \"host\", \"user\": \"root\", \"restart\": \"always\", \"memory\": \"512m\", \"device\": {\"if\": [\"ipmi_monitor\", {\"get_param\": [\"RoleParameters\", \"IpmiMonitor\"]}]}, \"cap_add\": {\"list_concat\": [{\"get_param\": \"CollectdContainerAdditionalCapAdd\"}, [\"IPC_LOCK\"]]}, \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/collectd.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/containers/storage/overlay-containers:/var/lib/containers/storage/overlay-containers:ro\", \"/var/lib/config-data/puppet-generated/collectd:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/collectd:/var/log/collectd:rw,z\", \"/var/lib/container-config-scripts:/config-scripts:ro\", \"/var/lib/container-user-scripts:/scripts:z\", \"/run:/run:rw\", \"/sys/fs/cgroup:/sys/fs/cgroup:ro\"], {\"if\": [{\"get_param\": \"CollectdEnableSensubility\"}, [\"/var/lib/tripleo-podman/collectd:/run/podman:z\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/collectd\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/container-user-scripts/\", \"setype\": \"container_file_t\", \"mode\": \"0755\"}]}, {\"name\": \"import provision_mcelog\", \"include_role\": {\"name\": \"tripleo_provision_mcelog\"}, \"when\": {\"get_param\": \"CollectdEnableMcelog\"}}], \"deploy_steps_tasks\": [{\"name\": \"set enable_sensubility fact\", \"set_fact\": {\"enable_sensubility\": {\"get_param\": \"CollectdEnableSensubility\"}}}, {\"name\": \"create podman socket for sensubility purposes\", \"block\": [{\"name\": \"create podman socket and appropriate systemd service\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_service\"}, \"vars\": {\"tripleo_podman_socket_path\": \"/var/lib/tripleo-podman/collectd/podman.sock\"}}, {\"name\": \"create systemd service for ensuring socket file ACL contains collectd\", \"become\": true, \"ansible.builtin.copy\": {\"content\": \"[Unit]\\nDescription=ACL setting for /var/lib/tripleo-podman/collectd/podman.sock\\nRequires=tripleo_collectd.service\\nAfter=tripleo_podman.service\\nAfter=tripleo_collectd.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/usr/bin/podman exec -it collectd setfacl -m m:rwx /run/podman/podman.sock\\nExecStart=/usr/bin/podman exec -it collectd setfacl -R -m u:collectd:rwx /run/podman\\nExecStart=/usr/bin/podman exec -it collectd setfacl -d -m u:collectd:rwx /run/podman\\n\\n[Install]\\nWantedBy=multi-user.target\\n\", \"dest\": \"/etc/systemd/system/tripleo_podman_collectd_acl.service\", \"mode\": 420}}, {\"name\": \"enable podman.sock ACL service\", \"ansible.builtin.service\": {\"name\": \"tripleo_podman_collectd_acl.service\", \"enabled\": true}}, {\"name\": \"create directory for downloads of users\' scripts\", \"file\": {\"path\": \"/var/lib/container-user-scripts\", \"state\": \"directory\", \"setype\": \"container_file_t\", \"mode\": \"0755\"}}, {\"name\": \"download exec scripts\", \"ansible.builtin.get_url\": {\"url\": \"{{ item.source }}\", \"checksum\": \"{{ item.checksum }}\", \"dest\": \"/var/lib/container-user-scripts/{{ item.name }}\", \"mode\": \"0755\"}, \"with_items\": {\"get_param\": \"CollectdSensubilityScripts\"}}], \"when\": [\"enable_sensubility|bool\", \"step|int == 1\"]}], \"update_tasks\": [{\"name\": \"remove rsyslog configuration for podman healthcheck log\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_rsyslog_cleanup\"}}], \"upgrade_tasks\": [{\"name\": \"remove rsyslog configuration for podman healthcheck log\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_rsyslog_cleanup\"}}, {\"name\": \"Force pull image collectd\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 3\"], \"containers.podman.podman_image\": {\"name\": {\"get_param\": \"ContainerCollectdImage\"}, \"force\": true}}, {\"name\": \"UBI8 to UBI9 switch of collectd\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 5\"], \"block\": [{\"name\": \"Update collectd to UBI9\", \"tripleo_container_manage\": {\"config_dir\": \"/var/lib/tripleo-config/container-startup-config/step_3\", \"config_patterns\": \"collectd.json\", \"config_id\": [\"tripleo_step3\"], \"log_base_path\": \"{{ container_log_stdout_path }}\", \"debug\": \"{{ enable_debug | bool }}\", \"config_overrides\": {\"collectd\": {\"image\": {\"get_param\": \"ContainerCollectdImage\"}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(45,'2026-06-12 08:25:56',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(46,'2026-06-12 08:25:56',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"HAproxy service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CAMap\": {\"description\": \"Map containing the CA certs and information needed for deploying them.\\n\", \"default\": {}, \"type\": \"json\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for injecting CA certificates.\", \"value\": {\"service_name\": \"ca_certs\", \"config_settings\": {\"tripleo::trusted_cas::ca_map\": {\"get_param\": \"CAMap\"}}, \"step_config\": \"include tripleo::trusted_cas\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(47,'2026-06-12 08:25:56',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"storage_mgmt_ip_address\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"storage_ip_address\": {\"value\": []}, \"blacklist_ip_address\": {\"value\": []}, \"internal_api_ip_address\": {\"value\": []}, \"blacklist_hostname\": {\"value\": []}, \"hostname_map\": {\"value\": []}, \"ip_address\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"hostname\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"ansible_host_vars_map\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (48,'2026-06-12 08:25:56',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Prepare container images\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerImagePrepare\": {\"default\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images.\", \"type\": \"json\"}, \"ContainerImagePrepareLogFile\": {\"default\": \"/var/log/tripleo-container-image-prepare.log\", \"type\": \"string\", \"description\": \"Used to store outputs of \\\"openstack tripleo container image prepare\\\".\"}, \"DockerInsecureRegistryAddress\": {\"description\": \"Optional. The IP Address and Port of an insecure docker namespace that will be configured in /etc/sysconfig/docker. The value can be multiple addresses separated by commas.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"NeutronMechanismDrivers\": {\"default\": \"ovn\", \"description\": \"The mechanism drivers for the Neutron tenant network.\\n\", \"type\": \"comma_delimited_list\"}, \"DockerRegistryMirror\": {\"description\": \"Optional. Mirror to use for registry docker.io\", \"default\": \"\", \"type\": \"string\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"ContainerImagePrepareDebug\": {\"default\": false, \"description\": \"Whether or not we want to activate --debug in tripleo container image prepare.\", \"type\": \"boolean\"}, \"ContainerImageRegistryCredentials\": {\"type\": \"json\", \"hidden\": true, \"default\": {}, \"description\": \"Mapping of image registry hosts to login credentials. Must be in the following example format\\n\\n  docker.io:\\n    username: pa55word\\n  \'192.0.2.1:8787\':\\n    registry_username: password\\n\"}, \"AdditionalArchitectures\": {\"default\": [], \"description\": \"List of additional architectures to enable.\", \"type\": \"comma_delimited_list\"}, \"ControllerContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"ControllerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Controller role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"ControllerCount\": {\"description\": \"Number of Controller nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"CellControllerContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"CellControllerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CellController role.\", \"type\": \"comma_delimited_list\", \"default\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}, \"CellControllerCount\": {\"description\": \"Number of CellController nodes to deploy\", \"type\": \"number\", \"default\": 1}, \"CellControllerComputeContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"CellControllerComputeServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CellControllerCompute role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"CellControllerComputeCount\": {\"description\": \"Number of CellControllerCompute nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"ComputeContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"ComputeServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Compute role.\", \"type\": \"comma_delimited_list\", \"default\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"]}, \"ComputeCount\": {\"description\": \"Number of Compute nodes to deploy\", \"type\": \"number\", \"default\": 1}, \"BlockStorageContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"BlockStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the BlockStorage role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"BlockStorageCount\": {\"description\": \"Number of BlockStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"ObjectStorageContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"ObjectStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the ObjectStorage role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"ObjectStorageCount\": {\"description\": \"Number of ObjectStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"CephStorageContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"CephStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CephStorage role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"CephStorageCount\": {\"description\": \"Number of CephStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"NetworkerContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"NetworkerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Networker role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"NetworkerCount\": {\"description\": \"Number of Networker nodes to deploy\", \"type\": \"number\", \"default\": 0}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for container image prepare\", \"value\": {\"service_name\": \"container_image_prepare\", \"external_deploy_tasks\": [{\"name\": \"Run tripleo-container-image-prepare role\", \"import_role\": {\"name\": \"tripleo_container_image_prepare\"}, \"vars\": {\"tripleo_container_image_prepare_log_file\": {\"get_param\": \"ContainerImagePrepareLogFile\"}, \"tripleo_container_image_prepare_debug\": {\"if\": [{\"get_param\": \"ContainerImagePrepareDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"tripleo_container_image_prepare_roles\": [{\"name\": \"Controller\", \"description\": \"Controller role that has all the controler services loaded and handles\\\\nDatabase, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\", \"external_bridge\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BarbicanApi\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\", \"OS::TripleO::Services::BarbicanBackendDogtag\", \"OS::TripleO::Services::BarbicanBackendKmip\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::CephGrafana\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CephNfs\", \"OS::TripleO::Services::CephRbdMirror\", \"OS::TripleO::Services::CephRgw\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackendDellSc\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\", \"OS::TripleO::Services::CinderBackendDellEMCSc\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\", \"OS::TripleO::Services::CinderBackendNetApp\", \"OS::TripleO::Services::CinderBackendPure\", \"OS::TripleO::Services::CinderBackendScaleIO\", \"OS::TripleO::Services::CinderBackendNVMeOF\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::DesignateApi\", \"OS::TripleO::Services::DesignateCentral\", \"OS::TripleO::Services::DesignateProducer\", \"OS::TripleO::Services::DesignateWorker\", \"OS::TripleO::Services::DesignateMDNS\", \"OS::TripleO::Services::DesignateSink\", \"OS::TripleO::Services::DesignateBind\", \"OS::TripleO::Services::Etcd\", \"OS::TripleO::Services::ExternalSwiftProxy\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::IronicApi\", \"OS::TripleO::Services::IronicConductor\", \"OS::TripleO::Services::IronicInspector\", \"OS::TripleO::Services::IronicPxe\", \"OS::TripleO::Services::IronicNeutronAgent\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaBackendFlashBlade\", \"OS::TripleO::Services::ManilaBackendIsilon\", \"OS::TripleO::Services::ManilaBackendNetapp\", \"OS::TripleO::Services::ManilaBackendPowerMax\", \"OS::TripleO::Services::ManilaBackendUnity\", \"OS::TripleO::Services::ManilaBackendVNX\", \"OS::TripleO::Services::ManilaBackendVMAX\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronBgpVpnApi\", \"OS::TripleO::Services::NeutronSfcApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NeutronDhcpAgent\", \"OS::TripleO::Services::NeutronL2gwAgent\", \"OS::TripleO::Services::NeutronL2gwApi\", \"OS::TripleO::Services::NeutronL3Agent\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NeutronOvsAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NeutronAgentsIBConfig\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaIronic\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OctaviaApi\", \"OS::TripleO::Services::OctaviaDeploymentConfig\", \"OS::TripleO::Services::OctaviaHealthManager\", \"OS::TripleO::Services::OctaviaHousekeeping\", \"OS::TripleO::Services::OctaviaWorker\", \"OS::TripleO::Services::OpenStackClients\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftDispersion\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Unbound\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"CellController\", \"description\": \"Controller role that has the cell controler specific\\\\nservices and handles Database, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Ptp\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"CellControllerCompute\", \"description\": \"Controller and Compute AIO role that has compute and cell controler specific\\\\nservices loaded and handles Database, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\", \"external_bridge\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-compute-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\", \"OS::TripleO::Services::ComputeNeutronL3Agent\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NovaAZConfig\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Ptp\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"Compute\", \"description\": \"Basic Compute Node role\\\\n\", \"CountDefault\": 1, \"tags\": [\"compute\", \"external_bridge\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-novacompute-%index%\", \"RoleParametersDefault\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"uses_deprecated_params\": true, \"deprecated_param_image\": \"NovaImage\", \"deprecated_param_extraconfig\": \"NovaComputeExtraConfig\", \"deprecated_param_metadata\": \"NovaComputeServerMetadata\", \"deprecated_param_scheduler_hints\": \"NovaComputeSchedulerHints\", \"deprecated_param_ips\": \"NovaComputeIPs\", \"deprecated_server_resource_name\": \"NovaCompute\", \"deprecated_nic_config_name\": \"compute.yaml\", \"update_serial\": 25, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\", \"OS::TripleO::Services::ComputeNeutronL3Agent\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NovaAZConfig\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"]}, {\"name\": \"BlockStorage\", \"description\": \"Cinder Block Storage node role\\\\n\", \"tags\": [\"storage\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": false, \"deprecated_nic_config_name\": \"cinder-storage.yaml\", \"update_serial\": 25, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BlockStorageCinderVolume\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}, {\"name\": \"ObjectStorage\", \"description\": \"Swift Object Storage node role\\\\n\", \"tags\": [\"storage\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": true, \"deprecated_param_metadata\": \"SwiftStorageServerMetadata\", \"deprecated_param_ips\": \"SwiftStorageIPs\", \"deprecated_param_image\": \"SwiftStorageImage\", \"deprecated_param_flavor\": \"OvercloudSwiftStorageFlavor\", \"deprecated_nic_config_name\": \"swift-storage.yaml\", \"deprecated_server_resource_name\": \"SwiftStorage\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Ptp\"]}, {\"name\": \"CephStorage\", \"description\": \"Ceph OSD Storage node role\\\\n\", \"tags\": [\"ceph\", \"storage\"], \"networks\": {\"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": false, \"HostnameFormatDefault\": \"%stackname%-cephstorage-%index%\", \"deprecated_nic_config_name\": \"ceph-storage.yaml\", \"update_serial\": 1, \"rhsm_enforce\": false, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}, {\"name\": \"Networker\", \"description\": \"Standalone networking role to run Neutron agents on their own.\\\\n\", \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"tags\": [\"external_bridge\"], \"HostnameFormatDefault\": \"%stackname%-networker-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::IronicNeutronAgent\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronDhcpAgent\", \"OS::TripleO::Services::NeutronL2gwAgent\", \"OS::TripleO::Services::NeutronL3Agent\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NeutronOvsAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OctaviaDeploymentConfig\", \"OS::TripleO::Services::OctaviaHealthManager\", \"OS::TripleO::Services::OctaviaHousekeeping\", \"OS::TripleO::Services::OctaviaWorker\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}], \"tripleo_container_image_prepare_content\": {\"parameter_defaults\": {\"ContainerImagePrepare\": {\"get_param\": \"ContainerImagePrepare\"}, \"DockerInsecureRegistryAddress\": {\"get_param\": \"DockerInsecureRegistryAddress\"}, \"NeutronMechanismDrivers\": {\"get_param\": \"NeutronMechanismDrivers\"}, \"DockerRegistryMirror\": {\"get_param\": \"DockerRegistryMirror\"}, \"ContainerImageRegistryCredentials\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"AdditionalArchitectures\": {\"get_param\": \"AdditionalArchitectures\"}, \"ControllerContainerImagePrepare\": {\"get_param\": \"ControllerContainerImagePrepare\"}, \"ControllerServices\": {\"get_param\": \"ControllerServices\"}, \"ControllerCount\": {\"get_param\": \"ControllerCount\"}, \"CellControllerContainerImagePrepare\": {\"get_param\": \"CellControllerContainerImagePrepare\"}, \"CellControllerServices\": {\"get_param\": \"CellControllerServices\"}, \"CellControllerCount\": {\"get_param\": \"CellControllerCount\"}, \"CellControllerComputeContainerImagePrepare\": {\"get_param\": \"CellControllerComputeContainerImagePrepare\"}, \"CellControllerComputeServices\": {\"get_param\": \"CellControllerComputeServices\"}, \"CellControllerComputeCount\": {\"get_param\": \"CellControllerComputeCount\"}, \"ComputeContainerImagePrepare\": {\"get_param\": \"ComputeContainerImagePrepare\"}, \"ComputeServices\": {\"get_param\": \"ComputeServices\"}, \"ComputeCount\": {\"get_param\": \"ComputeCount\"}, \"BlockStorageContainerImagePrepare\": {\"get_param\": \"BlockStorageContainerImagePrepare\"}, \"BlockStorageServices\": {\"get_param\": \"BlockStorageServices\"}, \"BlockStorageCount\": {\"get_param\": \"BlockStorageCount\"}, \"ObjectStorageContainerImagePrepare\": {\"get_param\": \"ObjectStorageContainerImagePrepare\"}, \"ObjectStorageServices\": {\"get_param\": \"ObjectStorageServices\"}, \"ObjectStorageCount\": {\"get_param\": \"ObjectStorageCount\"}, \"CephStorageContainerImagePrepare\": {\"get_param\": \"CephStorageContainerImagePrepare\"}, \"CephStorageServices\": {\"get_param\": \"CephStorageServices\"}, \"CephStorageCount\": {\"get_param\": \"CephStorageCount\"}, \"NetworkerContainerImagePrepare\": {\"get_param\": \"NetworkerContainerImagePrepare\"}, \"NetworkerServices\": {\"get_param\": \"NetworkerServices\"}, \"NetworkerCount\": {\"get_param\": \"NetworkerCount\"}}}}, \"when\": [\"(step | int) == 1\"]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(49,'2026-06-12 08:25:57',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"attributes, nova_server_resource\": {\"value\": {}}, \"blacklist_ip_address\": {\"value\": []}, \"internal_api_ip_address\": {\"value\": []}, \"blacklist_hostname\": {\"value\": []}, \"hostname_map\": {\"value\": []}, \"tenant_ip_address\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"ip_address\": {\"value\": []}, \"hostname\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"ansible_host_vars_map\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(50,'2026-06-12 08:25:57',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"storage_mgmt_ip_address\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"storage_ip_address\": {\"value\": []}, \"blacklist_ip_address\": {\"value\": []}, \"blacklist_hostname\": {\"value\": []}, \"hostname_map\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"ip_address\": {\"value\": []}, \"hostname\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"ansible_host_vars_map\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(51,'2026-06-12 08:25:57',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Host config and reboot service which configures Kernel Args and reboot\", \"parameters\": {\"RoleNetIpMap\": {\"default\": {}, \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KernelArgs\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Kernel Args to apply to the host\", \"tags\": [\"role_specific\"]}, \"KernelArgsDeferReboot\": {\"default\": false, \"type\": \"boolean\", \"description\": \"When enabled, nodes will not get rebooted automatically by tripleo-kernel if KernelArgs have been changed. Operators will have to manually reboot nodes after the deployment or update process is completed.\\nLeaving this enabled during a scale-up operation will prevent reboot on new nodes. This might cause deployment errors as the KernelArgs will not be applied.\\n\", \"tags\": [\"role_specific\"]}, \"TunedProfileName\": {\"default\": \"throughput-performance\", \"type\": \"string\", \"description\": \"Tuned Profile to apply to the host\", \"tags\": [\"role_specific\"]}, \"IsolCpusList\": {\"default\": \"\", \"type\": \"string\", \"description\": \"List of logical CPU ids whic need to be isolated from the host processes. This input is provided to the tuned profile cpu-partitioning to configure systemd and repin interrupts (IRQ repinning).\\n\", \"tags\": [\"role_specific\"]}, \"NodeRebootWaitTimeout\": {\"default\": 900, \"type\": \"number\", \"description\": \"Timeout in seconds to specify the wait time for ansible node reboot\"}, \"Hugepages\": {\"default\": {}, \"type\": \"json\", \"description\": \"Hash for hugepage configuration Example:\\n  Hugepages:\\n    2048:\\n      count: 100\\n      default: false\\n    1048576:\\n      count: 100\\n      default: true\\n\", \"tags\": [\"role_specific\"]}, \"ReconfigureHugepages\": {\"default\": false, \"type\": \"boolean\", \"description\": \"By default, tripleo-kernel will configure the provided Hugepages as specified by operators but it won\'t try to remove Hugepages configured on the host that are not part of the TripleO paramater. Enabling this setting will make sure everything is reconfigured exactly like the TripleO parameter, otherwise we just add the content of the Hugepages parameter to what\'s already in place.\\n\", \"tags\": [\"role_specific\"]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"tuned_profile\": \"TunedProfileName\", \"isolated_cores\": \"IsolCpusList\", \"kernel_args\": \"KernelArgs\", \"kernel_args_defer_reboot\": \"KernelArgsDeferReboot\", \"hugepages\": \"Hugepages\", \"reconfigure_hugepages\": \"ReconfigureHugepages\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"TunedProfileName\": {\"get_param\": \"TunedProfileName\"}, \"IsolCpusList\": {\"get_param\": \"IsolCpusList\"}, \"KernelArgs\": {\"get_param\": \"KernelArgs\"}, \"KernelArgsDeferReboot\": {\"get_param\": \"KernelArgsDeferReboot\"}, \"Hugepages\": {\"get_param\": \"Hugepages\"}, \"ReconfigureHugepages\": {\"get_param\": \"ReconfigureHugepages\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Host Config Service\", \"value\": {\"service_name\": \"boot_params_service\", \"deploy_steps_tasks\": [{\"name\": \"Configure tuned before reboot\", \"when\": \"step|int == 0\", \"include_role\": {\"name\": \"tuned\"}, \"vars\": {\"tuned_profile\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"tuned_profile\"]}, \"tuned_isolated_cores\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"isolated_cores\"]}}}, {\"name\": \"Configure kernel args and reboot\", \"when\": \"step|int == 0\", \"include_role\": {\"name\": \"tripleo_kernel\", \"tasks_from\": \"kernelargs.yml\"}, \"vars\": {\"tripleo_kernel_args\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"kernel_args\"]}, \"tripleo_kernel_hugepages\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"hugepages\"]}, \"tripleo_kernel_hugepages_remove\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"reconfigure_hugepages\"]}, \"tripleo_kernel_defer_reboot\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"kernel_args_defer_reboot\"]}, \"tripleo_kernel_reboot_timeout\": {\"get_param\": \"NodeRebootWaitTimeout\"}}}], \"upgrade_tasks\": [{\"name\": \"upgrade prepare for leapp to align kernel arg shortcommings in leapp\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"fix grub entries to have name start with GRUB_\", \"replace\": {\"path\": \"/etc/default/grub\", \"regexp\": \"^(TRIPLEO_HEAT_TEMPLATE_KERNEL_ARGS)(.*)\", \"replace\": \"GRUB_\\\\1\\\\2\"}}, {\"name\": \"fix grub entries in append statement\", \"replace\": {\"path\": \"/etc/default/grub\", \"regexp\": \"(.*){(TRIPLEO_HEAT_TEMPLATE_KERNEL_ARGS)}(.*)\", \"replace\": \"\\\\1{GRUB_\\\\2}\\\\3\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(52,'2026-06-12 08:25:57',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Containerized logrotate with crond for containerized service logs rotation\\n\", \"parameters\": {\"ContainerCrondImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\"}, \"ContainerCrondConfigImage\": {\"description\": \"The container image to use for the crond config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"LogrotateMaxsize\": {\"description\": \"Configures the maxsize param for containerized logrotate.\", \"type\": \"string\", \"default\": \"10M\"}, \"LogrotateRotationInterval\": {\"description\": \"Configures rotation interval for containerized logrotate.\", \"type\": \"string\", \"default\": \"daily\", \"constraints\": [{\"allowed_values\": [\"hourly\", \"daily\", \"weekly\", \"monthly\"]}]}, \"LogrotateRotate\": {\"description\": \"Configures the rotate param for containerized logrotate.\", \"type\": \"string\", \"default\": \"14\"}, \"LogrotatePurgeAfterDays\": {\"description\": \"Enforces life time (days) of rotated and compressed files.\", \"type\": \"string\", \"default\": \"14\"}, \"LogrotateDateExt\": {\"description\": \"Enable/disable dateext parameter.\", \"type\": \"boolean\", \"default\": false}, \"LogrotateDateFormat\": {\"description\": \"Configures dateformat strings for containerized logrotate. This is valid when LogrotateDateExt is true. The allowed specifiers are only %Y %m %d %H %M %S %V and %s.\", \"type\": \"string\", \"default\": \"-%Y%m%d\", \"constraints\": [{\"allowed_pattern\": \"-(%[YmdHMSVs])+$\"}]}, \"LogrotateDateYesterday\": {\"description\": \"Configures dateyesterday paramter for containerized logrotate. This is valid when LogrotateDateExt is true.\", \"type\": \"boolean\", \"default\": false}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCrondImage\": \"ContainerCrondImage\", \"ContainerCrondConfigImage\": \"ContainerCrondConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCrondImage\": {\"get_param\": \"ContainerCrondImage\"}, \"ContainerCrondConfigImage\": {\"get_param\": \"ContainerCrondConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the crond role.\", \"value\": {\"service_name\": \"logrotate_crond\", \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::logging::logrotate::maxsize\": {\"get_param\": \"LogrotateMaxsize\"}, \"tripleo::profile::base::logging::logrotate::rotation\": {\"get_param\": \"LogrotateRotationInterval\"}, \"tripleo::profile::base::logging::logrotate::rotate\": {\"get_param\": \"LogrotateRotate\"}, \"tripleo::profile::base::logging::logrotate::purge_after_days\": {\"get_param\": \"LogrotatePurgeAfterDays\"}, \"tripleo::profile::base::logging::logrotate::dateext\": {\"get_param\": \"LogrotateDateExt\"}}, {\"if\": [{\"get_param\": \"LogrotateDateExt\"}, {\"tripleo::profile::base::logging::logrotate::dateformat\": {\"get_param\": \"LogrotateDateFormat\"}, \"tripleo::profile::base::logging::logrotate::dateyesterday\": {\"get_param\": \"LogrotateDateYesterday\"}}]}]}, \"host_prep_tasks\": [{\"name\": \"allow logrotate to read inside containers\", \"seboolean\": {\"name\": \"logrotate_read_inside_containers\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}], \"deploy_steps_tasks\": [{\"name\": \"configure tmpwatch on the host\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Push script\", \"copy\": {\"dest\": \"/usr/local/sbin/containers-tmpwatch\", \"owner\": \"root\", \"group\": \"root\", \"mode\": 493, \"content\": \"#!/bin/sh\\ntmpwatch --nodirs \\\\\\n  -X \\\"/var/log/containers/*/*log\\\" \\\\\\n  -X \\\"/var/log/containers/*/*/*log\\\" \\\\\\n  -X \\\"/var/log/containers/*/*err\\\" \\\\\\n  {{ LogrotatePurgeAfterDays|int +1 }}d \\\\\\n  /var/log/containers/ 2>&1 | logger -t container-tmpwatch\\n\"}, \"vars\": {\"LogrotatePurgeAfterDays\": {\"get_param\": \"LogrotatePurgeAfterDays\"}}}, {\"name\": \"Insert cronjob in root crontab\", \"cron\": {\"name\": \"Remove old logs\", \"special_time\": \"daily\", \"user\": \"root\", \"job\": \"/usr/local/sbin/containers-tmpwatch\"}}]}], \"update_tasks\": [{\"name\": \"Ensure old cron.daily is absent\", \"when\": \"step|int == 1\", \"file\": {\"path\": \"/etc/cron.daily/containers-tmpwatch\", \"state\": \"absent\"}}], \"upgrade_tasks\": [{\"name\": \"Ensure old cron.daily is absent\", \"when\": \"step|int == 1\", \"file\": {\"path\": \"/etc/cron.daily/containers-tmpwatch\", \"state\": \"absent\"}}], \"puppet_config\": {\"config_volume\": \"crond\", \"step_config\": \"include tripleo::profile::base::logging::logrotate\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCrondConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/logrotate-crond.json\": {\"command\": \"/usr/sbin/crond -s -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_4\": {\"logrotate_crond\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCrondImage\"]}, \"net\": \"none\", \"pid\": \"host\", \"privileged\": true, \"user\": \"root\", \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/logrotate-crond.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/crond:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers:/var/log/containers:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop logrotate container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"logrotate_crond\"], \"tripleo_delegate_to\": \"{{ groups[\'logrotate_crond\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(53,'2026-06-12 08:25:57',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(54,'2026-06-12 08:25:57',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"storage_mgmt_ip_address\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"storage_ip_address\": {\"value\": []}, \"blacklist_ip_address\": {\"value\": []}, \"internal_api_ip_address\": {\"value\": []}, \"blacklist_hostname\": {\"value\": []}, \"hostname_map\": {\"value\": []}, \"tenant_ip_address\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"ip_address\": {\"value\": []}, \"hostname\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"ansible_host_vars_map\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(55,'2026-06-12 08:25:57',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Containerized collectd service\\n\", \"parameters\": {\"ContainerCollectdImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\"}, \"ContainerCollectdConfigImage\": {\"description\": \"The container image to use for the collectd config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"description\": \"Keystone region for endpoint\", \"default\": \"regionOne\"}, \"MetricsQdrPort\": {\"default\": 5666, \"description\": \"Service name or port number on which the qdrouterd will accept connections.\", \"type\": \"number\"}, \"MetricsQdrUsername\": {\"default\": \"guest\", \"description\": \"Username which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\"}, \"MetricsQdrPassword\": {\"default\": \"guest\", \"description\": \"Password which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\", \"hidden\": true}, \"MonitoringSubscriptionCollectd\": {\"default\": \"overcloud-collectd\", \"type\": \"string\"}, \"CollectdConnectionType\": {\"default\": \"amqp1\", \"description\": \"Define which write plugin should collectd use. Currently supported are \'amqp1\' and \'network\'.\", \"type\": \"string\"}, \"CollectdDefaultPollingInterval\": {\"default\": 120, \"type\": \"number\", \"description\": \"Controls how often registered read functions are called and with that the resolution of the collected data. This value can be overridden per plugin(per role) by setting \\\"::collectd::plugin::<plugin_name>::interval\\\" key in ExtraConfig(<role_name>ExtraConfig) if using puppet, and by setting \\\"collectd_plugin_<plugin_name>_interval\\\" in <role_name>ExtraConfig/CollectdVars if using ansible.\\n\"}, \"CollectdDefaultPlugins\": {\"default\": [\"cpu\", \"df\", \"disk\", \"hugepages\", \"interface\", \"load\", \"memory\", \"unixsock\", \"uptime\"], \"type\": \"comma_delimited_list\", \"description\": \"List of collectd plugins to activate on all overcloud hosts.  See the documentation for the puppet-collectd module for a list plugins supported by the module (https://github.com/voxpupuli/puppet-collectd). Set this key to override the default list of plugins.  Use CollectdExtraPlugins if you want to load additional plugins without overriding the defaults.\\n\"}, \"CollectdExtraPlugins\": {\"default\": [], \"type\": \"comma_delimited_list\", \"description\": \"List of collectd plugins to activate on all overcloud hosts.  See the documentation for the puppet-collectd module for a list plugins supported by the module (https://github.com/voxpupuli/puppet-collectd). Set this key to load plugins in addition to those in CollectdDefaultPlugins.\\n\"}, \"CollectdServer\": {\"type\": \"string\", \"description\": \"Address of remote collectd server to which we will send metrics.\\n\", \"default\": \"\"}, \"CollectdServerPort\": {\"type\": \"number\", \"default\": 25826, \"description\": \"Port on remote collectd server to which we will send metrics.\\n\"}, \"CollectdUsername\": {\"type\": \"string\", \"description\": \"Username for authenticating to the remote collectd server. The default is to not configure any authentication.\\n\", \"default\": \"\"}, \"CollectdPassword\": {\"type\": \"string\", \"hidden\": true, \"description\": \"Password for authenticating to the remote collectd server. The default is to not configure any authentication.\\n\", \"default\": \"\"}, \"CollectdSecurityLevel\": {\"type\": \"string\", \"description\": \"Security level setting for remote collectd connection. If it is set to Sign or Encrypt the CollectdPassword and CollectdUsername parameters need to be set.\\n\", \"default\": \"None\", \"constraints\": [{\"allowed_values\": [\"None\", \"Sign\", \"Encrypt\"]}]}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"CollectdSQLAlchemyLogMessages\": {\"type\": \"string\", \"description\": \"set to \\\"debug\\\" to enable message logging.\", \"default\": \"info\"}, \"CollectdSQLAlchemyBindHost\": {\"type\": \"string\", \"description\": \"hostname for SQLAlchemy-collectd plugin to bind on.  defaults to localhost.\\n\", \"default\": \"localhost\"}, \"CollectdAmqpHost\": {\"type\": \"string\", \"description\": \"Hostname or IP address of the AMQP 1.0 intermediary.\", \"default\": \"nil\"}, \"CollectdAmqpPort\": {\"type\": \"number\", \"description\": \"Service name or port number on which the AMQP 1.0 intermediary accepts connections. This argument must be a string, even if the numeric form is used.\\n\", \"default\": 5666}, \"CollectdAmqpUser\": {\"type\": \"string\", \"description\": \"User part of credentials used to authenticate to the AMQP 1.0 intermediary.\\n\", \"default\": \"guest\"}, \"CollectdAmqpPassword\": {\"type\": \"string\", \"description\": \"Password part of credentials used to authenticate to the AMQP 1.0 intermediary.\\n\", \"default\": \"guest\", \"hidden\": true}, \"CollectdAmqpTransportName\": {\"type\": \"string\", \"description\": \"Name of the AMQP 1.0 transport.\", \"default\": \"metrics\"}, \"CollectdAmqpAddress\": {\"type\": \"string\", \"description\": \"This option specifies the prefix for the send-to value in the message.\\n\", \"default\": \"collectd\"}, \"CollectdAmqpInstances\": {\"type\": \"json\", \"description\": \"Hash of hashes. Each inner hash represent Instance block in plugin configuration file. Key of outter hash represents instance name. The \'address\' value concatenated with the \'name\' given will be used as the send-to address for communications over the messaging link.\\n\", \"default\": {}}, \"CollectdAmqpRetryDelay\": {\"type\": \"number\", \"description\": \"When the AMQP 1.0 connection is lost, defines the time in seconds to wait before attempting to reconnect.\\n\", \"default\": 1}, \"CollectdAmqpInterval\": {\"type\": \"number\", \"description\": \"Interval on which metrics should be sent to AMQP intermediary. If not set the default for all collectd plugins is used.\\n\", \"default\": -666}, \"CollectdAmqpSendQueueLimit\": {\"type\": \"number\", \"description\": \"Number of data sets to be kept in memory, older sets will be discarded, if set to -1, this feature is disabled.\\n\", \"default\": -1}, \"CollectdEnableSensubility\": {\"type\": \"boolean\", \"description\": \"Set to true if sensubility should be executed by exec plugin.\", \"default\": false}, \"CollectdSensubilityExecSudoRule\": {\"type\": \"string\", \"description\": \"Given rule will be created in /etc/sudoers.d for sensubility to enable it calling restricted commands via sensubility executor.\\n\", \"default\": \"\"}, \"CollectdSensubilityLogLevel\": {\"type\": \"string\", \"description\": \"Use for override the default logging level (WARNING).\", \"default\": \"WARNING\"}, \"CollectdSensubilityConnection\": {\"type\": \"string\", \"description\": \"URL to Sensu sever side\", \"default\": \"amqp://sensu:sensu@localhost:5672//sensu\"}, \"CollectdSensubilityKeepaliveInterval\": {\"type\": \"number\", \"description\": \"Interval in seconds for sending keepalive messages to Sensu server side.\", \"default\": 20}, \"CollectdSensubilityTmpDir\": {\"type\": \"string\", \"description\": \"Path to temporary directory which is used for creation of check scripts.\", \"default\": \"/var/tmp/collectd-sensubility-checks\"}, \"CollectdSensubilityShellPath\": {\"type\": \"string\", \"description\": \"Path to shell used for executing check scripts.\", \"default\": \"/usr/bin/sh\"}, \"CollectdSensubilityWorkerCount\": {\"type\": \"number\", \"description\": \"Number of goroutines spawned for executing check scripts.\", \"default\": 2}, \"CollectdSensubilityChecks\": {\"type\": \"json\", \"description\": \"JSON formated definition of standalone checks to be scheduled on client side.\", \"default\": {}}, \"CollectdSensubilityTransport\": {\"type\": \"string\", \"description\": \"Bus type for sent data. Options are \'sensu\' (rabbitmq) and \'amqp1\'\", \"default\": \"sensu\"}, \"CollectdSensubilityResultsChannel\": {\"type\": \"string\", \"description\": \"AMQP1 channel address\", \"default\": \"collectd/notify\"}, \"CollectdSensubilityScripts\": {\"type\": \"json\", \"description\": \"List of hashes of scripts for download for sensubility usage. Value has to be in following format:\\n[{\\\"name\\\": \\\"<script name>\\\", \\\"source\\\": \\\"<http URI to download script>\\\", \\\"checksum\\\": \\\"<alogithm:sum>\\\"}]\\n\", \"default\": []}, \"CollectdEnableContainerHealthCheck\": {\"type\": \"boolean\", \"description\": \"Set to false if container health check should not be defined and attached to CollectdEnableContainerHealthCheck.\\n\", \"default\": true}, \"CollectdContainerHealthCheckCommand\": {\"type\": \"string\", \"default\": \"/config-scripts/collectd_check_health.py\"}, \"CollectdContainerHealthCheckInterval\": {\"type\": \"number\", \"description\": \"The frequency in seconds the docker health check is executed.\", \"default\": 10}, \"CollectdContainerHealthCheckHandlers\": {\"default\": [], \"description\": \"The Sensu event handler to use for events created by the docker health check.\", \"type\": \"comma_delimited_list\"}, \"CollectdContainerHealthCheckOccurrences\": {\"type\": \"number\", \"description\": \"The number of event occurrences before sensu-plugin-aware handler should take action.\", \"default\": 3}, \"CollectdContainerHealthCheckRefresh\": {\"type\": \"number\", \"description\": \"The number of seconds sensu-plugin-aware handlers should wait before taking second action.\", \"default\": 90}, \"EnableSTF\": {\"type\": \"boolean\", \"description\": \"Set to true to enable configuration for STF client.\", \"default\": false}, \"CollectdEnableMcelog\": {\"type\": \"boolean\", \"description\": \"Set to true to enable mcelog\", \"default\": false}, \"CollectdEnableLibpodstats\": {\"type\": \"boolean\", \"description\": \"Set to true if collectd should run the libpodstats plugin\", \"default\": false}, \"CollectdContainerAdditionalCapAdd\": {\"type\": \"comma_delimited_list\", \"description\": \"Additional container capabilities to add to the collectd container. By default is appended to IPC_LOCK.\", \"default\": []}, \"CollectdLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"collectd\", \"file\": \"/var/log/containers/collectd/collectd.log\"}}, \"DeployedCeph\": {\"default\": false, \"type\": \"boolean\", \"description\": \"If the Ceph cluster has already been deployed but needs to be configured\\nso that the overcloud can use it (create cephx keys, pools, configure RGW\\nwith haproxy, etc), then this parameter should be set to true. Set this\\nparameter to false to have cephadm deploy the ceph cluster during overcloud\\ndeployment. DeployedCeph and CephDynamicSpec are mutually exclusive.\\n\"}, \"CephClusterFSID\": {\"type\": \"string\", \"description\": \"The Ceph cluster FSID. Must be a UUID.\", \"default\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\"}}, \"conditions\": {\"amqp_connection\": {\"equals\": [{\"get_param\": \"CollectdConnectionType\"}, \"amqp1\"]}, \"amqp_default_connection\": {\"equals\": [{\"get_param\": \"CollectdAmqpHost\"}, \"nil\"]}, \"amqp_default_interval\": {\"equals\": [{\"get_param\": \"CollectdAmqpInterval\"}, -666]}, \"amqp_default_send_queue_limit\": {\"equals\": [{\"get_param\": \"CollectdAmqpSendQueueLimit\"}, -1]}, \"collectd_connection\": {\"equals\": [{\"get_param\": \"CollectdConnectionType\"}, \"network\"]}, \"enable_sensubility\": {\"equals\": [{\"get_param\": \"CollectdEnableSensubility\"}, true]}, \"enable_stf\": {\"equals\": [{\"get_param\": \"EnableSTF\"}, true]}, \"enable_sqlalchemy_collectd\": {\"equals\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, true]}, \"sensubility_needs_sudo\": {\"not\": {\"equals\": [{\"get_param\": \"CollectdSensubilityExecSudoRule\"}, \"\"]}}, \"enable_libpodstats\": {\"equals\": [{\"get_param\": \"CollectdEnableLibpodstats\"}, true]}, \"ipmi_monitor\": {\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"IpmiMonitor\"]}, \"\"]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCollectdImage\": \"ContainerCollectdImage\", \"ContainerCollectdConfigImage\": \"ContainerCollectdConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCollectdImage\": {\"get_param\": \"ContainerCollectdImage\"}, \"ContainerCollectdConfigImage\": {\"get_param\": \"ContainerCollectdConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the collectd role.\", \"value\": {\"service_name\": \"collectd\", \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::enable_file_logging\": true, \"collectd::plugin::logfile::log_file\": \"/var/log/collectd/collectd.log\"}, {\"collectd::manage_repo\": false, \"collectd::purge\": true, \"collectd::recurse\": true, \"collectd::purge_config\": true, \"collectd::minimum_version\": \"5.7\", \"collectd::interval\": {\"get_param\": \"CollectdDefaultPollingInterval\"}, \"collectd::plugin::unixsock::socketgroup\": \"root\", \"collectd::plugin::unixsock::socketfile\": \"/run/collectd-socket\", \"collectd::plugin::unixsock::deletesocket\": true, \"collectd::plugin::cpu::reportbycpu\": true, \"collectd::plugin::cpu::reportbystate\": true, \"collectd::plugin::cpu::reportnumcpu\": false, \"collectd::plugin::cpu::valuespercentage\": true, \"collectd::plugin::df::ignoreselected\": true, \"collectd::plugin::df::reportbydevice\": true, \"collectd::plugin::df::fstypes\": [\"xfs\"], \"collectd::plugin::load::reportrelative\": true, \"collectd::plugin::virt::connection\": \"qemu:///system\", \"collectd::plugin::virt::extra_stats\": {\"list_join\": [\" \", [\"pcpu\", \"cpu_util\", \"vcpu\", \"memory\", \"disk\", \"disk_err\", \"disk_allocation\", \"disk_capacity\", \"disk_physical\", \"domain_state\", \"job_stats_background\", \"perf\"]]}, \"collectd::plugin::virt::hostname_format\": \"hostname\", \"tripleo.collectd.plugins.collectd\": {\"yaql\": {\"data\": {\"default_plugins\": {\"get_param\": \"CollectdDefaultPlugins\"}, \"stf_plugins\": {\"if\": [\"enable_stf\", [\"cpu\", \"df\", \"load\", \"connectivity\", \"intel_rdt\", \"procevent\"], []]}, \"extra_plugins\": {\"get_param\": \"CollectdExtraPlugins\"}}, \"expression\": \"($.data.default_plugins + $.data.stf_plugins + $.data.extra_plugins) .flatten().distinct()\\n\"}}}, {\"if\": [\"amqp_connection\", {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::amqp_transport_name\": {\"get_param\": \"CollectdAmqpTransportName\"}, \"tripleo::profile::base::metrics::collectd::amqp_address\": {\"get_param\": \"CollectdAmqpAddress\"}, \"tripleo::profile::base::metrics::collectd::amqp_instances\": {\"get_param\": \"CollectdAmqpInstances\"}, \"tripleo::profile::base::metrics::collectd::amqp_retry_delay\": {\"get_param\": \"CollectdAmqpRetryDelay\"}}, {\"if\": [\"amqp_default_interval\", {}, {\"tripleo::profile::base::metrics::collectd::amqp_interval\": {\"get_param\": \"CollectdAmqpInterval\"}}]}, {\"if\": [\"amqp_default_send_queue_limit\", {}, {\"tripleo::profile::base::metrics::collectd::amqp_send_queue_limit\": {\"get_param\": \"CollectdAmqpSendQueueLimit\"}}]}, {\"if\": [\"amqp_default_connection\", {\"tripleo::profile::base::metrics::collectd::amqp_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::metrics::collectd::amqp_port\": {\"get_param\": \"MetricsQdrPort\"}, \"tripleo::profile::base::metrics::collectd::amqp_user\": {\"get_param\": \"MetricsQdrUsername\"}, \"tripleo::profile::base::metrics::collectd::amqp_password\": {\"get_param\": \"MetricsQdrPassword\"}}, {\"tripleo::profile::base::metrics::collectd::amqp_host\": {\"get_param\": \"CollectdAmqpHost\"}, \"tripleo::profile::base::metrics::collectd::amqp_port\": {\"get_param\": \"CollectdAmqpPort\"}, \"tripleo::profile::base::metrics::collectd::amqp_user\": {\"get_param\": \"CollectdAmqpUser\"}, \"tripleo::profile::base::metrics::collectd::amqp_password\": {\"get_param\": \"CollectdAmqpPassword\"}}]}]}, {}]}, {\"if\": [\"collectd_connection\", {\"tripleo::profile::base::metrics::collectd::collectd_server\": {\"get_param\": \"CollectdServer\"}, \"tripleo::profile::base::metrics::collectd::collectd_port\": {\"get_param\": \"CollectdServerPort\"}, \"tripleo::profile::base::metrics::collectd::collectd_username\": {\"get_param\": \"CollectdUsername\"}, \"tripleo::profile::base::metrics::collectd::collectd_password\": {\"get_param\": \"CollectdPassword\"}, \"tripleo::profile::base::metrics::collectd::collectd_securitylevel\": {\"get_param\": \"CollectdSecurityLevel\"}}, {}]}, {\"if\": [\"enable_sqlalchemy_collectd\", {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::enable_sqlalchemy_collectd\": true}, {\"tripleo::profile::base::metrics::collectd::sqlalchemy_collectd_bind_host\": {\"get_param\": \"CollectdSQLAlchemyBindHost\"}}, {\"tripleo::profile::base::metrics::collectd::sqlalchemy_collectd_log_messages\": {\"get_param\": \"CollectdSQLAlchemyLogMessages\"}}]}, {}]}, {\"if\": [\"enable_sensubility\", {\"map_merge\": [{\"if\": [\"sensubility_needs_sudo\", {\"tripleo::profile::base::metrics::collectd::sensubility::exec_sudo_rule\": {\"get_param\": \"CollectdSensubilityExecSudoRule\"}}, {}]}, {\"tripleo::profile::base::metrics::collectd::enable_sensubility\": {\"get_param\": \"CollectdEnableSensubility\"}, \"tripleo::profile::base::metrics::collectd::sensubility::connection\": {\"get_param\": \"CollectdSensubilityConnection\"}, \"tripleo::profile::base::metrics::collectd::sensubility::log_level\": {\"get_param\": \"CollectdSensubilityLogLevel\"}, \"tripleo::profile::base::metrics::collectd::sensubility::client_name\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_NETWORK\')}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::metrics::collectd::sensubility::client_address\": {\"str_replace\": {\"template\": \"%{hiera(\'NETWORK\')}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::metrics::collectd::sensubility::keepalive_interval\": {\"get_param\": \"CollectdSensubilityKeepaliveInterval\"}, \"tripleo::profile::base::metrics::collectd::sensubility::tmp_base_dir\": {\"get_param\": \"CollectdSensubilityTmpDir\"}, \"tripleo::profile::base::metrics::collectd::sensubility::shell_path\": {\"get_param\": \"CollectdSensubilityShellPath\"}, \"tripleo::profile::base::metrics::collectd::sensubility::worker_count\": {\"get_param\": \"CollectdSensubilityWorkerCount\"}, \"tripleo::profile::base::metrics::collectd::sensubility::checks\": {\"map_merge\": [{\"get_param\": \"CollectdSensubilityChecks\"}, {\"if\": [{\"get_param\": \"CollectdEnableContainerHealthCheck\"}, {\"check-container-health\": {\"standalone\": true, \"command\": {\"get_param\": \"CollectdContainerHealthCheckCommand\"}, \"interval\": {\"get_param\": \"CollectdContainerHealthCheckInterval\"}, \"handlers\": {\"get_param\": \"CollectdContainerHealthCheckHandlers\"}, \"occurrences\": {\"get_param\": \"CollectdContainerHealthCheckOccurrences\"}, \"refresh\": {\"get_param\": \"CollectdContainerHealthCheckRefresh\"}}}, {}]}]}, \"tripleo::profile::base::metrics::collectd::sensubility::results_channel\": {\"get_param\": \"CollectdSensubilityResultsChannel\"}, \"tripleo::profile::base::metrics::collectd::sensubility::transport\": {\"get_param\": \"CollectdSensubilityTransport\"}, \"tripleo::profile::base::metrics::collectd::sensubility::amqp_port\": {\"get_param\": \"CollectdAmqpPort\"}}]}, {}]}, {\"if\": [\"enable_libpodstats\", {\"tripleo::profile::base::metrics::collectd::enable_libpodstats\": {\"get_param\": \"CollectdEnableLibpodstats\"}}, {}]}, {\"if\": [{\"get_param\": \"DeployedCeph\"}, {\"collectd::plugin::ceph::ceph_fsid\": {\"get_param\": \"CephClusterFSID\"}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_collectd\": [{\"get_param\": \"CollectdLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"collectd\", \"puppet_tags\": \"collectd_client_config,exec\", \"step_config\": \"include tripleo::profile::base::metrics::collectd\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCollectdConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/collectd.json\": {\"command\": \"/usr/sbin/collectd -f\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/collectd.d\", \"dest\": \"/etc/\", \"merge\": false, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/collectd\", \"owner\": \"collectd:collectd\", \"recurse\": true}, {\"path\": \"/scripts\", \"owner\": \"collectd:collectd\", \"recurse\": true}, {\"path\": \"/config-scripts\", \"owner\": \"collectd:collectd\", \"recurse\": true}]}}, \"container_config_scripts\": {\"map_merge\": [{\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, {\"collectd_check_health.py\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/monitoring/collectd_check_health.py\"}}}]}, \"docker_config\": {\"step_2\": {\"if\": [{\"get_param\": \"CollectdEnableSensubility\"}, {\"collectd_init_perm\": {\"image\": {\"get_param\": \"ContainerCollectdImage\"}, \"net\": \"none\", \"user\": \"root\", \"volumes\": [\"/var/lib/tripleo-podman/collectd:/tmp/run:rw,z\"], \"command\": [\"setfacl\", \"-R\", \"-m\", \"u:collectd:rwx\", \"/tmp/run\"]}}]}, \"step_3\": {\"collectd\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCollectdImage\"]}, \"net\": \"host\", \"pid\": \"host\", \"user\": \"root\", \"restart\": \"always\", \"memory\": \"512m\", \"device\": {\"if\": [\"ipmi_monitor\", {\"get_param\": [\"RoleParameters\", \"IpmiMonitor\"]}]}, \"cap_add\": {\"list_concat\": [{\"get_param\": \"CollectdContainerAdditionalCapAdd\"}, [\"IPC_LOCK\"]]}, \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/collectd.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/containers/storage/overlay-containers:/var/lib/containers/storage/overlay-containers:ro\", \"/var/lib/config-data/puppet-generated/collectd:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/collectd:/var/log/collectd:rw,z\", \"/var/lib/container-config-scripts:/config-scripts:ro\", \"/var/lib/container-user-scripts:/scripts:z\", \"/run:/run:rw\", \"/sys/fs/cgroup:/sys/fs/cgroup:ro\"], {\"if\": [{\"get_param\": \"CollectdEnableSensubility\"}, [\"/var/lib/tripleo-podman/collectd:/run/podman:z\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/collectd\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/container-user-scripts/\", \"setype\": \"container_file_t\", \"mode\": \"0755\"}]}, {\"name\": \"import provision_mcelog\", \"include_role\": {\"name\": \"tripleo_provision_mcelog\"}, \"when\": {\"get_param\": \"CollectdEnableMcelog\"}}], \"deploy_steps_tasks\": [{\"name\": \"set enable_sensubility fact\", \"set_fact\": {\"enable_sensubility\": {\"get_param\": \"CollectdEnableSensubility\"}}}, {\"name\": \"create podman socket for sensubility purposes\", \"block\": [{\"name\": \"create podman socket and appropriate systemd service\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_service\"}, \"vars\": {\"tripleo_podman_socket_path\": \"/var/lib/tripleo-podman/collectd/podman.sock\"}}, {\"name\": \"create systemd service for ensuring socket file ACL contains collectd\", \"become\": true, \"ansible.builtin.copy\": {\"content\": \"[Unit]\\nDescription=ACL setting for /var/lib/tripleo-podman/collectd/podman.sock\\nRequires=tripleo_collectd.service\\nAfter=tripleo_podman.service\\nAfter=tripleo_collectd.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/usr/bin/podman exec -it collectd setfacl -m m:rwx /run/podman/podman.sock\\nExecStart=/usr/bin/podman exec -it collectd setfacl -R -m u:collectd:rwx /run/podman\\nExecStart=/usr/bin/podman exec -it collectd setfacl -d -m u:collectd:rwx /run/podman\\n\\n[Install]\\nWantedBy=multi-user.target\\n\", \"dest\": \"/etc/systemd/system/tripleo_podman_collectd_acl.service\", \"mode\": 420}}, {\"name\": \"enable podman.sock ACL service\", \"ansible.builtin.service\": {\"name\": \"tripleo_podman_collectd_acl.service\", \"enabled\": true}}, {\"name\": \"create directory for downloads of users\' scripts\", \"file\": {\"path\": \"/var/lib/container-user-scripts\", \"state\": \"directory\", \"setype\": \"container_file_t\", \"mode\": \"0755\"}}, {\"name\": \"download exec scripts\", \"ansible.builtin.get_url\": {\"url\": \"{{ item.source }}\", \"checksum\": \"{{ item.checksum }}\", \"dest\": \"/var/lib/container-user-scripts/{{ item.name }}\", \"mode\": \"0755\"}, \"with_items\": {\"get_param\": \"CollectdSensubilityScripts\"}}], \"when\": [\"enable_sensubility|bool\", \"step|int == 1\"]}], \"update_tasks\": [{\"name\": \"remove rsyslog configuration for podman healthcheck log\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_rsyslog_cleanup\"}}], \"upgrade_tasks\": [{\"name\": \"remove rsyslog configuration for podman healthcheck log\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_rsyslog_cleanup\"}}, {\"name\": \"Force pull image collectd\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 3\"], \"containers.podman.podman_image\": {\"name\": {\"get_param\": \"ContainerCollectdImage\"}, \"force\": true}}, {\"name\": \"UBI8 to UBI9 switch of collectd\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 5\"], \"block\": [{\"name\": \"Update collectd to UBI9\", \"tripleo_container_manage\": {\"config_dir\": \"/var/lib/tripleo-config/container-startup-config/step_3\", \"config_patterns\": \"collectd.json\", \"config_id\": [\"tripleo_step3\"], \"log_base_path\": \"{{ container_log_stdout_path }}\", \"debug\": \"{{ enable_debug | bool }}\", \"config_overrides\": {\"collectd\": {\"image\": {\"get_param\": \"ContainerCollectdImage\"}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (56,'2026-06-12 08:25:57',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"storage_mgmt_ip_address\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"storage_ip_address\": {\"value\": []}, \"blacklist_ip_address\": {\"value\": []}, \"internal_api_ip_address\": {\"value\": []}, \"blacklist_hostname\": {\"value\": []}, \"hostname_map\": {\"value\": []}, \"tenant_ip_address\": {\"value\": []}, \"ip_address\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"hostname\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"ansible_host_vars_map\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(57,'2026-06-12 08:25:57',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(58,'2026-06-12 08:25:58',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"HAproxy service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CAMap\": {\"description\": \"Map containing the CA certs and information needed for deploying them.\\n\", \"default\": {}, \"type\": \"json\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for injecting CA certificates.\", \"value\": {\"service_name\": \"ca_certs\", \"config_settings\": {\"tripleo::trusted_cas::ca_map\": {\"get_param\": \"CAMap\"}}, \"step_config\": \"include tripleo::trusted_cas\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(59,'2026-06-12 08:25:58',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": true, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"StorageIpList\": \"\", \"StorageMgmtIpList\": \"\", \"InternalApiIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,storage,storage_mgmt,internal_api\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(60,'2026-06-12 08:25:58',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Load kernel modules with kmod and configure kernel options with sysctl.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KernelPidMax\": {\"default\": 1048576, \"description\": \"Configures sysctl kernel.pid_max key\", \"type\": \"number\"}, \"KernelDisableIPv6\": {\"default\": 0, \"description\": \"Configures sysctl net.ipv6.{default/all}.disable_ipv6 keys\", \"type\": \"number\"}, \"KernelIpForward\": {\"default\": 1, \"description\": \"Configures net.ipv4.ip_forward key\", \"type\": \"number\"}, \"KernelIpv6ConfAllForwarding\": {\"default\": 0, \"description\": \"Configures the net.ipv6.conf.all.forwarding key\", \"type\": \"number\"}, \"KernelIpv4ConfAllRpFilter\": {\"default\": 1, \"description\": \"Configures the net.ipv4.conf.all.rp_filter key\", \"type\": \"number\"}, \"KernelIpNonLocalBind\": {\"default\": 1, \"description\": \"Configures net.ipv{4,6}.ip_nonlocal_bind key\", \"type\": \"number\"}, \"NeighbourGcThreshold1\": {\"default\": 1024, \"description\": \"Configures sysctl net.ipv4.neigh.default.gc_thresh1 value. This is the minimum number of entries to keep in the ARP cache. The garbage collector will not run if there are fewer than this number of entries in the cache.\", \"type\": \"number\"}, \"NeighbourGcThreshold2\": {\"default\": 2048, \"description\": \"Configures sysctl net.ipv4.neigh.default.gc_thresh2 value. This is the soft maximum number of entries to keep in the ARP cache. The garbage collector will  allow the number of entries to exceed this for 5 seconds before collection will be performed.\", \"type\": \"number\"}, \"NeighbourGcThreshold3\": {\"default\": 4096, \"description\": \"Configures sysctl net.ipv4.neigh.default.gc_thresh3 value. This is the hard maximum number of entries to keep in the ARP cache. The garbage collector will always run if there are more than this number of entries in the cache.\", \"type\": \"number\"}, \"InotifyInstancesMax\": {\"default\": 1024, \"description\": \"Configures sysctl fs.inotify.max_user_instances key\", \"type\": \"number\"}, \"BridgeNfCallArpTables\": {\"default\": 1, \"description\": \"Configures sysctl net.bridge.bridge-nf-call-arptables key\", \"type\": \"number\"}, \"BridgeNfCallIpTables\": {\"default\": 1, \"description\": \"Configures sysctl net.bridge.bridge-nf-call-iptables key\", \"type\": \"number\"}, \"BridgeNfCallIp6Tables\": {\"default\": 1, \"description\": \"Configures sysctl net.bridge.bridge-nf-call-ip6tables key\", \"type\": \"number\"}, \"ExtraKernelModules\": {\"default\": {}, \"description\": \"Hash of extra Kernel modules to load.\", \"type\": \"json\", \"tags\": [\"role_specific\"]}, \"ExtraKernelPackages\": {\"default\": {}, \"description\": \"List of extra kernel related packages to install.\", \"type\": \"json\", \"tags\": [\"role_specific\"]}, \"ExtraSysctlSettings\": {\"default\": {}, \"description\": \"Hash of extra sysctl settings to apply.\", \"type\": \"json\", \"tags\": [\"role_specific\"]}, \"FsAioMaxNumber\": {\"default\": 0, \"description\": \"The kernel allocates aio memory on demand, and this number limits the number of parallel aio requests; the only drawback of a larger limit is that a malicious guest could issue parallel requests to cause the kernel to set aside memory.  Set this number at least as large as\\n  128 * (number of virtual disks on the host)\\nLibvirt uses a default of 1M requests to allow 8k disks, with at most 64M of kernel memory if all disks hit an aio request at the same time.\\n\", \"type\": \"number\", \"tags\": [\"role_specific\"]}, \"InotifyIntancesMax\": {\"default\": 1024, \"description\": \"Configures sysctl fs.inotify.max_user_instances key\", \"type\": \"number\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"Do not use deprecated params, they will be removed.\", \"parameters\": [\"InotifyIntancesMax\"]}], \"conditions\": {\"ipv6_disabled\": {\"equals\": [{\"get_param\": \"KernelDisableIPv6\"}, 1]}, \"is_inotify_intances_max_default\": {\"equals\": [{\"get_param\": \"InotifyIntancesMax\"}, 1024]}, \"fs_aio_max_number_set\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"FsAioMaxNumber\"]}, 0]}}, {\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"FsAioMaxNumber\"]}, \"\"]}}]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"extra_kernel_modules\": \"ExtraKernelModules\", \"extra_kernel_packages\": \"ExtraKernelPackages\", \"extra_sysctl_settings\": \"ExtraSysctlSettings\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ExtraKernelModules\": {\"get_param\": \"ExtraKernelModules\"}, \"ExtraKernelPackages\": {\"get_param\": \"ExtraKernelPackages\"}, \"ExtraSysctlSettings\": {\"get_param\": \"ExtraSysctlSettings\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Kernel modules\", \"value\": {\"service_name\": \"kernel\", \"host_prep_tasks\": [{\"include_role\": {\"name\": \"tripleo_kernel\"}}], \"ansible_group_vars\": {\"hieradata_localhost_address\": {\"if\": [\"ipv6_disabled\", \"127.0.0.1\", \"localhost\"]}, \"tripleo_kernel_extra_modules\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"extra_kernel_modules\"]}, \"tripleo_kernel_extra_packages\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"extra_kernel_packages\"]}, \"tripleo_kernel_sysctl_extra_settings\": {\"map_merge\": [{\"net.ipv6.conf.default.disable_ipv6\": {\"value\": {\"get_param\": \"KernelDisableIPv6\"}}, \"net.ipv4.ip_local_reserved_ports\": {\"value\": \"35357,49000-49001\"}, \"net.ipv6.conf.all.disable_ipv6\": {\"value\": {\"get_param\": \"KernelDisableIPv6\"}}, \"net.ipv6.conf.lo.disable_ipv6\": {\"value\": 0}, \"net.ipv4.ip_forward\": {\"value\": {\"get_param\": \"KernelIpForward\"}}, \"net.ipv4.conf.all.rp_filter\": {\"value\": {\"get_param\": \"KernelIpv4ConfAllRpFilter\"}}, \"net.ipv6.conf.all.forwarding\": {\"value\": {\"get_param\": \"KernelIpv6ConfAllForwarding\"}}, \"net.ipv4.ip_nonlocal_bind\": {\"value\": {\"get_param\": \"KernelIpNonLocalBind\"}}, \"net.ipv6.ip_nonlocal_bind\": {\"value\": {\"get_param\": \"KernelIpNonLocalBind\"}}, \"kernel.pid_max\": {\"value\": {\"get_param\": \"KernelPidMax\"}}, \"net.ipv4.neigh.default.gc_thresh1\": {\"value\": {\"get_param\": \"NeighbourGcThreshold1\"}}, \"net.ipv4.neigh.default.gc_thresh2\": {\"value\": {\"get_param\": \"NeighbourGcThreshold2\"}}, \"net.ipv4.neigh.default.gc_thresh3\": {\"value\": {\"get_param\": \"NeighbourGcThreshold3\"}}, \"net.bridge.bridge-nf-call-arptables\": {\"value\": {\"get_param\": \"BridgeNfCallArpTables\"}}, \"net.bridge.bridge-nf-call-iptables\": {\"value\": {\"get_param\": \"BridgeNfCallIpTables\"}}, \"net.bridge.bridge-nf-call-ip6tables\": {\"value\": {\"get_param\": \"BridgeNfCallIp6Tables\"}}, \"fs.inotify.max_user_instances\": {\"value\": {\"if\": [\"is_inotify_intances_max_default\", {\"get_param\": \"InotifyInstancesMax\"}, {\"get_param\": \"InotifyIntancesMax\"}]}}}, {\"if\": [\"fs_aio_max_number_set\", {\"fs.aio-max-nr\": {\"value\": {\"get_param\": [\"RoleParameters\", \"FsAioMaxNumber\"]}}}]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"extra_sysctl_settings\"]}]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(61,'2026-06-12 08:25:58',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": true, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"InternalApiIpList\": \"\", \"TenantIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,internal_api,tenant\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(62,'2026-06-12 08:25:58',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Ceilometer Agent Ipmi service\\n\", \"parameters\": {\"ContainerCeilometerIpmiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\"}, \"ContainerCeilometerConfigImage\": {\"description\": \"The container image to use for the ceilometer config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"CeilometerAgentIpmiLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.ceilometer.agent.ipmi\", \"file\": \"/var/log/containers/ceilometer/ipmi.log\"}}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"RedisPassword\": {\"description\": \"The password for the redis service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"zTfbzAZoNB6iKueE7EslkZpK7\"}, \"MonitoringSubscriptionCeilometerIpmi\": {\"default\": \"overcloud-ceilometer-agent-ipmi\", \"type\": \"string\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CeilometerServiceBase\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"CeilometerAgentCentralBase\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCeilometerIpmiImage\": \"ContainerCeilometerIpmiImage\", \"ContainerCeilometerConfigImage\": \"ContainerCeilometerConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCeilometerIpmiImage\": {\"get_param\": \"ContainerCeilometerIpmiImage\"}, \"ContainerCeilometerConfigImage\": {\"get_param\": \"ContainerCeilometerConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer Agent Ipmi role.\", \"value\": {\"service_name\": \"ceilometer_agent_ipmi\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCeilometerIpmi\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"config_settings\"]}, {\"ceilometer_redis_password\": {\"get_param\": \"RedisPassword\"}, \"ipmi_namespace\": true}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_ceilometer_agent_ipmi\": [{\"get_param\": \"CeilometerAgentIpmiLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"ceilometer\", \"puppet_tags\": \"ceilometer_config\", \"step_config\": \"include tripleo::profile::base::ceilometer::agent::polling\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/ceilometer-agent-ipmi.json\": {\"command\": \"/usr/bin/ceilometer-polling --polling-namespaces ipmi --logfile /var/log/ceilometer/ipmi.log\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_3\": {\"ceilometer_init_log\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerIpmiImage\"]}, \"net\": \"none\", \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"chown -R ceilometer:ceilometer /var/log/ceilometer\"], \"volumes\": [\"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]}}, \"step_4\": {\"ceilometer_agent_ipmi\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerIpmiImage\"]}, \"net\": \"host\", \"privileged\": true, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer-agent-ipmi.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/ceilometer\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(63,'2026-06-12 08:25:58',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"storage_mgmt_ip_address\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"storage_ip_address\": {\"value\": []}, \"blacklist_ip_address\": {\"value\": []}, \"internal_api_ip_address\": {\"value\": []}, \"blacklist_hostname\": {\"value\": []}, \"hostname_map\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"ip_address\": {\"value\": []}, \"hostname\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"ansible_host_vars_map\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(64,'2026-06-12 08:25:59',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Load kernel modules with kmod and configure kernel options with sysctl.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KernelPidMax\": {\"default\": 1048576, \"description\": \"Configures sysctl kernel.pid_max key\", \"type\": \"number\"}, \"KernelDisableIPv6\": {\"default\": 0, \"description\": \"Configures sysctl net.ipv6.{default/all}.disable_ipv6 keys\", \"type\": \"number\"}, \"KernelIpForward\": {\"default\": 1, \"description\": \"Configures net.ipv4.ip_forward key\", \"type\": \"number\"}, \"KernelIpv6ConfAllForwarding\": {\"default\": 0, \"description\": \"Configures the net.ipv6.conf.all.forwarding key\", \"type\": \"number\"}, \"KernelIpv4ConfAllRpFilter\": {\"default\": 1, \"description\": \"Configures the net.ipv4.conf.all.rp_filter key\", \"type\": \"number\"}, \"KernelIpNonLocalBind\": {\"default\": 1, \"description\": \"Configures net.ipv{4,6}.ip_nonlocal_bind key\", \"type\": \"number\"}, \"NeighbourGcThreshold1\": {\"default\": 1024, \"description\": \"Configures sysctl net.ipv4.neigh.default.gc_thresh1 value. This is the minimum number of entries to keep in the ARP cache. The garbage collector will not run if there are fewer than this number of entries in the cache.\", \"type\": \"number\"}, \"NeighbourGcThreshold2\": {\"default\": 2048, \"description\": \"Configures sysctl net.ipv4.neigh.default.gc_thresh2 value. This is the soft maximum number of entries to keep in the ARP cache. The garbage collector will  allow the number of entries to exceed this for 5 seconds before collection will be performed.\", \"type\": \"number\"}, \"NeighbourGcThreshold3\": {\"default\": 4096, \"description\": \"Configures sysctl net.ipv4.neigh.default.gc_thresh3 value. This is the hard maximum number of entries to keep in the ARP cache. The garbage collector will always run if there are more than this number of entries in the cache.\", \"type\": \"number\"}, \"InotifyInstancesMax\": {\"default\": 1024, \"description\": \"Configures sysctl fs.inotify.max_user_instances key\", \"type\": \"number\"}, \"BridgeNfCallArpTables\": {\"default\": 1, \"description\": \"Configures sysctl net.bridge.bridge-nf-call-arptables key\", \"type\": \"number\"}, \"BridgeNfCallIpTables\": {\"default\": 1, \"description\": \"Configures sysctl net.bridge.bridge-nf-call-iptables key\", \"type\": \"number\"}, \"BridgeNfCallIp6Tables\": {\"default\": 1, \"description\": \"Configures sysctl net.bridge.bridge-nf-call-ip6tables key\", \"type\": \"number\"}, \"ExtraKernelModules\": {\"default\": {}, \"description\": \"Hash of extra Kernel modules to load.\", \"type\": \"json\", \"tags\": [\"role_specific\"]}, \"ExtraKernelPackages\": {\"default\": {}, \"description\": \"List of extra kernel related packages to install.\", \"type\": \"json\", \"tags\": [\"role_specific\"]}, \"ExtraSysctlSettings\": {\"default\": {}, \"description\": \"Hash of extra sysctl settings to apply.\", \"type\": \"json\", \"tags\": [\"role_specific\"]}, \"FsAioMaxNumber\": {\"default\": 0, \"description\": \"The kernel allocates aio memory on demand, and this number limits the number of parallel aio requests; the only drawback of a larger limit is that a malicious guest could issue parallel requests to cause the kernel to set aside memory.  Set this number at least as large as\\n  128 * (number of virtual disks on the host)\\nLibvirt uses a default of 1M requests to allow 8k disks, with at most 64M of kernel memory if all disks hit an aio request at the same time.\\n\", \"type\": \"number\", \"tags\": [\"role_specific\"]}, \"InotifyIntancesMax\": {\"default\": 1024, \"description\": \"Configures sysctl fs.inotify.max_user_instances key\", \"type\": \"number\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"Do not use deprecated params, they will be removed.\", \"parameters\": [\"InotifyIntancesMax\"]}], \"conditions\": {\"ipv6_disabled\": {\"equals\": [{\"get_param\": \"KernelDisableIPv6\"}, 1]}, \"is_inotify_intances_max_default\": {\"equals\": [{\"get_param\": \"InotifyIntancesMax\"}, 1024]}, \"fs_aio_max_number_set\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"FsAioMaxNumber\"]}, 0]}}, {\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"FsAioMaxNumber\"]}, \"\"]}}]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"extra_kernel_modules\": \"ExtraKernelModules\", \"extra_kernel_packages\": \"ExtraKernelPackages\", \"extra_sysctl_settings\": \"ExtraSysctlSettings\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ExtraKernelModules\": {\"get_param\": \"ExtraKernelModules\"}, \"ExtraKernelPackages\": {\"get_param\": \"ExtraKernelPackages\"}, \"ExtraSysctlSettings\": {\"get_param\": \"ExtraSysctlSettings\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Kernel modules\", \"value\": {\"service_name\": \"kernel\", \"host_prep_tasks\": [{\"include_role\": {\"name\": \"tripleo_kernel\"}}], \"ansible_group_vars\": {\"hieradata_localhost_address\": {\"if\": [\"ipv6_disabled\", \"127.0.0.1\", \"localhost\"]}, \"tripleo_kernel_extra_modules\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"extra_kernel_modules\"]}, \"tripleo_kernel_extra_packages\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"extra_kernel_packages\"]}, \"tripleo_kernel_sysctl_extra_settings\": {\"map_merge\": [{\"net.ipv6.conf.default.disable_ipv6\": {\"value\": {\"get_param\": \"KernelDisableIPv6\"}}, \"net.ipv4.ip_local_reserved_ports\": {\"value\": \"35357,49000-49001\"}, \"net.ipv6.conf.all.disable_ipv6\": {\"value\": {\"get_param\": \"KernelDisableIPv6\"}}, \"net.ipv6.conf.lo.disable_ipv6\": {\"value\": 0}, \"net.ipv4.ip_forward\": {\"value\": {\"get_param\": \"KernelIpForward\"}}, \"net.ipv4.conf.all.rp_filter\": {\"value\": {\"get_param\": \"KernelIpv4ConfAllRpFilter\"}}, \"net.ipv6.conf.all.forwarding\": {\"value\": {\"get_param\": \"KernelIpv6ConfAllForwarding\"}}, \"net.ipv4.ip_nonlocal_bind\": {\"value\": {\"get_param\": \"KernelIpNonLocalBind\"}}, \"net.ipv6.ip_nonlocal_bind\": {\"value\": {\"get_param\": \"KernelIpNonLocalBind\"}}, \"kernel.pid_max\": {\"value\": {\"get_param\": \"KernelPidMax\"}}, \"net.ipv4.neigh.default.gc_thresh1\": {\"value\": {\"get_param\": \"NeighbourGcThreshold1\"}}, \"net.ipv4.neigh.default.gc_thresh2\": {\"value\": {\"get_param\": \"NeighbourGcThreshold2\"}}, \"net.ipv4.neigh.default.gc_thresh3\": {\"value\": {\"get_param\": \"NeighbourGcThreshold3\"}}, \"net.bridge.bridge-nf-call-arptables\": {\"value\": {\"get_param\": \"BridgeNfCallArpTables\"}}, \"net.bridge.bridge-nf-call-iptables\": {\"value\": {\"get_param\": \"BridgeNfCallIpTables\"}}, \"net.bridge.bridge-nf-call-ip6tables\": {\"value\": {\"get_param\": \"BridgeNfCallIp6Tables\"}}, \"fs.inotify.max_user_instances\": {\"value\": {\"if\": [\"is_inotify_intances_max_default\", {\"get_param\": \"InotifyInstancesMax\"}, {\"get_param\": \"InotifyIntancesMax\"}]}}}, {\"if\": [\"fs_aio_max_number_set\", {\"fs.aio-max-nr\": {\"value\": {\"get_param\": [\"RoleParameters\", \"FsAioMaxNumber\"]}}}]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"extra_sysctl_settings\"]}]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (65,'2026-06-12 08:25:59',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": true, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"StorageIpList\": \"\", \"StorageMgmtIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,storage,storage_mgmt\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(66,'2026-06-12 08:25:59',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Ceilometer Agent Compute service\\n\", \"parameters\": {\"ContainerCeilometerComputeImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\"}, \"ContainerCeilometerConfigImage\": {\"description\": \"The container image to use for the ceilometer config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"MonitoringSubscriptionCeilometerCompute\": {\"default\": \"overcloud-ceilometer-agent-compute\", \"type\": \"string\"}, \"InstanceDiscoveryMethod\": {\"default\": \"libvirt_metadata\", \"description\": \"Method used to discover instances running on compute node\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"naive\", \"libvirt_metadata\", \"workload_partitioning\"]}]}, \"RedisPassword\": {\"description\": \"The password for the redis service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"zTfbzAZoNB6iKueE7EslkZpK7\"}, \"CeilometerEnableTenantDiscovery\": {\"default\": false, \"description\": \"Identify user and project names from polled metrics.\", \"type\": \"boolean\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CeilometerServiceBase\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCeilometerComputeImage\": \"ContainerCeilometerComputeImage\", \"ContainerCeilometerConfigImage\": \"ContainerCeilometerConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCeilometerComputeImage\": {\"get_param\": \"ContainerCeilometerComputeImage\"}, \"ContainerCeilometerConfigImage\": {\"get_param\": \"ContainerCeilometerConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer Agent Compute role.\", \"value\": {\"service_name\": \"ceilometer_agent_compute\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCeilometerCompute\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"config_settings\"]}, {\"ceilometer::agent::polling::instance_discovery_method\": {\"get_param\": \"InstanceDiscoveryMethod\"}}, {\"ceilometer_redis_password\": {\"get_param\": \"RedisPassword\"}, \"compute_namespace\": true, \"ceilometer::agent::polling::tenant_name_discovery\": {\"get_param\": \"CeilometerEnableTenantDiscovery\"}}]}, \"service_config_settings\": {\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"service_config_settings\"]}, \"puppet_config\": {\"config_volume\": \"ceilometer\", \"puppet_tags\": \"ceilometer_config\", \"step_config\": \"include tripleo::profile::base::ceilometer::agent::polling\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/ceilometer_agent_compute.json\": {\"command\": \"/usr/bin/ceilometer-polling --polling-namespaces compute --logfile /var/log/ceilometer/compute.log\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_4\": {\"ceilometer_agent_compute\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerComputeImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"depends_on\": [\"tripleo_nova_libvirt.target\"], \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer_agent_compute.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/run/libvirt:/run/libvirt:shared,z\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/ceilometer\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}, {\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(67,'2026-06-12 08:25:59',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized HAproxy service for pacemaker\\n\", \"parameters\": {\"ContainerHAProxyImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\"}, \"ContainerHAProxyConfigImage\": {\"description\": \"The container image to use for the haproxy config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\"}, \"ClusterCommonTag\": {\"default\": false, \"description\": \"When set to false, a pacemaker service is configured to use a floating tag for its container image name, e.g. \'REGISTRY/NAMESPACE/IMAGENAME:pcmklatest\'. When set to true, the service uses a floating prefix as well, e.g. \'cluster.common.tag/IMAGENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"ClusterFullTag\": {\"default\": true, \"description\": \"When set to true, the pacemaker service uses a fully constant tag for its container image name, e.g. \'cluster.common.tag/SERVICENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"SSLCertificate\": {\"default\": \"\", \"description\": \"The content of the SSL certificate (without Key) in PEM format.\\n\", \"type\": \"string\"}, \"PublicSSLCertificateAutogenerated\": {\"default\": false, \"description\": \"Whether the public SSL certificate was autogenerated or not.\\n\", \"type\": \"boolean\"}, \"EnablePublicTLS\": {\"default\": true, \"description\": \"Whether to enable TLS on the public interface or not.\\n\", \"type\": \"boolean\"}, \"DeployedSSLCertificatePath\": {\"default\": \"/etc/pki/tls/private/overcloud_endpoint.pem\", \"description\": \"The filepath of the certificate as it will be stored in the controller.\\n\", \"type\": \"string\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"HAProxyInternalTLSCertsDirectory\": {\"default\": \"/etc/pki/tls/certs/haproxy\", \"type\": \"string\"}, \"HAProxyInternalTLSKeysDirectory\": {\"default\": \"/etc/pki/tls/private/haproxy\", \"type\": \"string\"}, \"HAProxyLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.haproxy\", \"file\": \"/var/log/containers/haproxy/haproxy.log\", \"startmsg.regex\": \"^[a-zA-Z]{3} [ 123][0-9] [:0-9]{8}\"}}, \"HAProxySyslogAddress\": {\"default\": \"/dev/log\", \"description\": \"Syslog address where HAproxy will send its log\", \"type\": \"string\"}, \"HAProxySyslogFacility\": {\"default\": \"local0\", \"description\": \"Syslog facility HAProxy will use for its logs\", \"type\": \"string\"}, \"ConfigDebug\": {\"default\": false, \"description\": \"Whether to run config management (e.g. Puppet) in debug mode.\", \"type\": \"boolean\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"DeployIdentifier\": {\"default\": 1781252715, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}}, \"conditions\": {\"public_tls_enabled\": {\"and\": [{\"get_param\": \"EnablePublicTLS\"}, {\"or\": [{\"not\": {\"equals\": [{\"get_param\": \"SSLCertificate\"}, \"\"]}}, {\"get_param\": \"PublicSSLCertificateAutogenerated\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\"}, \"HAProxyBase\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"HAProxyPublicTLS\": {\"type\": \"OS::TripleO::Services::HAProxyPublicTLS\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"HAProxyInternalTLS\": {\"type\": \"OS::TripleO::Services::HAProxyInternalTLS\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerHAProxyImage\": \"ContainerHAProxyImage\", \"ContainerHAProxyConfigImage\": \"ContainerHAProxyConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerHAProxyImage\": {\"get_param\": \"ContainerHAProxyImage\"}, \"ContainerHAProxyConfigImage\": {\"get_param\": \"ContainerHAProxyConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the HAproxy role.\", \"value\": {\"service_name\": \"haproxy\", \"firewall_rules\": {\"get_attr\": [\"HAProxyBase\", \"role_data\", \"firewall_rules\"]}, \"monitoring_subscription\": {\"get_attr\": [\"HAProxyBase\", \"role_data\", \"monitoring_subscription\"]}, \"ansible_group_vars\": {\"get_attr\": [\"HAProxyBase\", \"role_data\", \"ansible_group_vars\"]}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"HAProxyBase\", \"role_data\", \"config_settings\"]}, {\"tripleo::haproxy::haproxy_service_manage\": false, \"tripleo::haproxy::mysql_clustercheck\": true, \"tripleo::haproxy::haproxy_log_address\": {\"get_param\": \"HAProxySyslogAddress\"}, \"tripleo::haproxy::haproxy_log_facility\": {\"get_param\": \"HAProxySyslogFacility\"}}, {\"haproxy_docker\": true, \"tripleo::profile::pacemaker::haproxy_bundle::container_backend\": {\"get_param\": \"ContainerCli\"}, \"tripleo::profile::pacemaker::haproxy_bundle::tls_mapping\": {\"list_concat\": [{\"if\": [\"public_tls_enabled\", [{\"get_param\": \"DeployedSSLCertificatePath\"}]]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}, {\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}]]}]}, \"tripleo::profile::pacemaker::haproxy_bundle::tls_mapping_init_bundle\": {\"list_concat\": [{\"if\": [\"public_tls_enabled\", [{\"get_param\": \"DeployedSSLCertificatePath\"}]]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [{\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}, {\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}]]}]}, \"tripleo::profile::pacemaker::haproxy_bundle::internal_certs_directory\": {\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, \"tripleo::profile::pacemaker::haproxy_bundle::internal_keys_directory\": {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}, \"tripleo::profile::pacemaker::haproxy_bundle::haproxy_docker_image\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/haproxy:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_haproxy\": [{\"get_param\": \"HAProxyLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"haproxy\", \"puppet_tags\": \"haproxy_config\", \"step_config\": {\"list_join\": [\"\\n\", [\"exec {\'wait-for-settle\': command => \'/bin/true\' }\", \"class tripleo::firewall(){}; define tripleo::firewall::rule( $port = undef, $dport = undef, $sport = undef, $proto = undef, $action = undef, $state = undef, $source = undef, $iniface = undef, $chain = undef, $destination = undef, $extras = undef){}\", \"[\'pcmk_bundle\', \'pcmk_resource\', \'pcmk_property\', \'pcmk_constraint\', \'pcmk_resource_default\'].each |String $val| { noop_resource($val) }\", \"include tripleo::profile::pacemaker::haproxy_bundle\"]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyConfigImage\"]}, \"volumes\": {\"yaql\": {\"expression\": \"$.data.select($+\\\":\\\"+$+\\\":ro\\\")\", \"data\": {\"list_concat\": [{\"if\": [\"public_tls_enabled\", [{\"get_param\": \"DeployedSSLCertificatePath\"}]]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}, {\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}]]}]}}}}, \"kolla_config\": {\"/var/lib/kolla/config_files/haproxy.json\": {\"command\": \"bash -c $* -- eval if [ -f /usr/sbin/haproxy-systemd-wrapper ]; then exec /usr/sbin/haproxy-systemd-wrapper -f /etc/haproxy/haproxy.cfg; else exec /usr/sbin/haproxy -f /etc/haproxy/haproxy.cfg -Ws; fi\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"optional\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/lib/haproxy\", \"owner\": \"haproxy:haproxy\", \"recurse\": true}, {\"path\": {\"list_join\": [\"\", [{\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, \"/*\"]]}, \"owner\": \"haproxy:haproxy\", \"perm\": \"0600\", \"optional\": true}, {\"path\": {\"list_join\": [\"\", [{\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}, \"/*\"]]}, \"owner\": \"haproxy:haproxy\", \"perm\": \"0600\", \"optional\": true}]}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HAProxyBase\", \"role_data\", \"host_prep_tasks\"]}, [{\"name\": \"Run puppet on the host to apply IPtables rules\", \"no_log\": true, \"shell\": \"puppet apply {{ (puppet_debug|bool) | ternary(\'--debug --verbose\', \'\') }} --detailed-exitcodes --summarize --color=false \\\\\\n    --modulepath \'{{ puppet_modulepath }}\' --tags \'{{ puppet_tags }}\' -e \'{{ puppet_execute }}\'\\n\", \"register\": \"puppet_host_outputs\", \"changed_when\": \"puppet_host_outputs.rc == 2\", \"failed_when\": false, \"vars\": {\"puppet_execute\": \"if hiera(\'enable_load_balancer\', true) { class {\'::tripleo::haproxy\': use_internal_certificates => false, manage_firewall => hiera(\'tripleo::firewall::manage_firewall\', true), }}\", \"puppet_tags\": \"tripleo::firewall::rule\", \"puppet_modulepath\": \"/etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules\", \"puppet_debug\": {\"get_param\": \"ConfigDebug\"}}}, {\"name\": \"Debug output for task: Run puppet on the host to apply IPtables rules\", \"debug\": {\"var\": \"puppet_host_outputs.stdout_lines | default([]) | union(puppet_host_outputs.stderr_lines | default([]))\"}, \"when\": [\"not (ansible_check_mode | bool)\", \"puppet_host_outputs.rc is defined\"], \"failed_when\": \"puppet_host_outputs.rc not in [0, 2]\"}]]}, \"metadata_settings\": {\"get_attr\": [\"HAProxyBase\", \"role_data\", \"metadata_settings\"]}, \"deploy_steps_tasks\": {\"list_concat\": [[{\"name\": \"Configure rsyslog for HAproxy container managed by Pacemaker\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Check if rsyslog exists\", \"shell\": \"systemctl is-active rsyslog\", \"register\": \"rsyslog_config\"}, {\"when\": [\"rsyslog_config is changed\", \"rsyslog_config.rc == 0\"], \"block\": [{\"name\": \"Forward logging to haproxy.log file\", \"blockinfile\": {\"content\": \"if $syslogfacility-text == \'{{facility}}\' and $programname == \'haproxy\' then -/var/log/containers/haproxy/haproxy.log\\n& stop\\n\", \"create\": true, \"path\": \"/etc/rsyslog.d/openstack-haproxy.conf\"}, \"vars\": {\"facility\": {\"get_param\": \"HAProxySyslogFacility\"}}, \"register\": \"logconfig\"}, {\"name\": \"restart rsyslog service after logging conf change\", \"service\": {\"name\": \"rsyslog\", \"state\": \"restarted\"}, \"when\": \"logconfig is changed\"}]}]}, {\"name\": \"HAproxy tag container image for pacemaker\", \"when\": \"step|int == 1\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"container_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/haproxy:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}}}, {\"name\": \"HAproxy HA Wrappers Step\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"HAproxy puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"haproxy\", \"tripleo_ha_wrapper_resource_name\": \"haproxy-bundle\", \"tripleo_ha_wrapper_bundle_name\": \"haproxy-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"haproxy\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::haproxy_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}]}], {\"if\": [\"public_tls_enabled\", {\"get_attr\": [\"HAProxyPublicTLS\", \"role_data\", \"deploy_steps_tasks\"]}, []]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_attr\": [\"HAProxyInternalTLS\", \"role_data\", \"deploy_steps_tasks\"]}]}]}, \"external_update_tasks\": [{\"when\": \"step|int == 1\", \"tags\": \"ha_image_update\", \"block\": [{\"block\": [{\"name\": \"Get haproxy image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_haproxy_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'haproxy-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container haproxy image\", \"set_fact\": {\"haproxy_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"haproxy_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/haproxy:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_haproxy_image\": \"{{xmllint_pcmk_haproxy_image.stdout}}\"}}], \"delegate_to\": \"{{ (groups[\\\"haproxy\\\"] | difference(groups[\\\"excluded_overcloud\\\"]))[0] }}\"}, {\"name\": \"haproxy temporary pacemaker container tag in case of image switch\", \"become\": true, \"import_role\": {\"name\": \"tripleo_ha_image_update\"}, \"vars\": {\"tripleo_ha_image_update_node_names\": \"{{ groups[\\\"haproxy\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) }}\", \"tripleo_ha_image_update_bundle\": \"haproxy-bundle\", \"tripleo_ha_image_update_new_image\": \"{{haproxy_image_latest}}\", \"tripleo_ha_image_update_old_image\": \"{{pcmk_haproxy_image}}\"}, \"when\": [\"(pcmk_haproxy_image != \\\"\\\")\", \"(pcmk_haproxy_image != haproxy_image_latest)\"]}]}], \"update_tasks\": [{\"block\": [{\"name\": \"Get haproxy image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_haproxy_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'haproxy-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container haproxy image\", \"set_fact\": {\"haproxy_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"haproxy_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/haproxy:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_haproxy_image\": \"{{xmllint_pcmk_haproxy_image.stdout}}\"}}], \"when\": \"(step|int == 0 or step|int == 2)\"}, {\"name\": \"Check for update of haproxy container image name\", \"when\": \"step|int == 0\", \"assert\": {\"that\": \"pcmk_haproxy_image == haproxy_image_latest\", \"fail_msg\": \"haproxy image change detected, run overcloud external-update --tags ha_image_update first\"}}, {\"name\": \"Tear-down non-HA haproxy container\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Remove non-HA haproxy container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"haproxy\"]}}]}, {\"name\": \"Set HAProxy upgrade facts\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"set is_haproxy_bootstrap_node fact\", \"tags\": \"common\", \"set_fact\": \"is_haproxy_bootstrap_node={{haproxy_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\", \"when\": [\"haproxy_short_bootstrap_node_name|default(false)\"]}]}, {\"name\": \"Mount TLS cert if needed\", \"when\": [\"step|int == 1\", \"is_haproxy_bootstrap_node\"], \"block\": [{\"name\": \"Check haproxy public certificate configuration in pacemaker\", \"command\": \"cibadmin --query --xpath \\\"//storage-mapping[@id=\'haproxy-cert\']\\\"\", \"failed_when\": false, \"register\": \"haproxy_cert_mounted\"}, {\"name\": \"Disable the haproxy cluster resource\", \"pacemaker_resource\": {\"resource\": \"haproxy-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\", \"when\": \"haproxy_cert_mounted.rc == 6\"}, {\"name\": \"Set HAProxy public cert volume mount fact\", \"set_fact\": {\"haproxy_public_cert_path\": {\"get_param\": \"DeployedSSLCertificatePath\"}, \"haproxy_public_tls_enabled\": {\"if\": [\"public_tls_enabled\", true, false]}}}, {\"name\": \"Add a bind mount for public certificate in the haproxy bundle\", \"command\": \"pcs resource bundle update haproxy-bundle storage-map add id=haproxy-cert source-dir={{ haproxy_public_cert_path }} target-dir=/var/lib/kolla/config_files/src-tls/{{ haproxy_public_cert_path }} options=ro\", \"when\": \"haproxy_cert_mounted.rc == 6 and haproxy_public_tls_enabled|bool\"}, {\"name\": \"Enable the haproxy cluster resource\", \"pacemaker_resource\": {\"resource\": \"haproxy-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\", \"when\": \"haproxy_cert_mounted.rc == 6\"}]}, {\"name\": \"Haproxy fetch and retag container image for pacemaker\", \"tags\": \"haproxy_syn_block\", \"when\": [\"step|int == 2\"], \"block\": [{\"name\": \"Retag pcmklatest to latest haproxy image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{haproxy_image}}\", \"container_image_latest\": \"{{haproxy_image_latest}}\"}}]}, {\"name\": \"Move virtual IPs to another node before stopping pacemaker\", \"when\": [\"step|int == 1\", \"hostvars[inventory_hostname][\\\"haproxy_node_names\\\"]|default([])|length > 1\"], \"shell\": \"CLUSTER_NODE=$(crm_node -n)\\necho \\\"Retrieving all the VIPs which are hosted on this node\\\"\\nVIPS_TO_MOVE=$(crm_mon --as-xml | xmllint --xpath \'//resource[@resource_agent=\\\"ocf:heartbeat:IPaddr2\\\" and @role = \\\"Started\\\" and @managed = \\\"true\\\" and ./node[@name = \\\"\'${CLUSTER_NODE}\'\\\"]]/@id\' - | sed -e \'s/id=//g\' -e \'s/\\\"//g\')\\nfor v in ${VIPS_TO_MOVE}; do\\n    echo \\\"Moving VIP $v on another node\\\"\\n    pcs resource ban $v ${CLUSTER_NODE} --wait=300\\ndone\\necho \\\"Removing the location constraints that were created to move the VIPs\\\"\\nfor v in ${VIPS_TO_MOVE}; do\\n    echo \\\"Removing location ban for VIP $v\\\"\\n    ban_id=$(cibadmin --query | xmllint --xpath \'string(//rsc_location[@rsc=\\\"\'${v}\'\\\" and @node=\\\"\'${CLUSTER_NODE}\'\\\" and @score=\\\"-INFINITY\\\"]/@id)\' -)\\n    if [ -n \\\"$ban_id\\\" ]; then\\n        pcs constraint remove ${ban_id}\\n    else\\n        echo \\\"Could not retrieve and clear location constraint for VIP $v\\\" 2>&1\\n    fi\\ndone\\n\"}, {\"name\": \"Wait for 10s to settle connections on new VIPs\", \"wait_for\": {\"timeout\": 10}, \"when\": [\"step|int == 1\", \"hostvars[inventory_hostname][\\\"haproxy_node_names\\\"]|default([])|length > 1\"]}, {\"name\": \"Block local INPUT SYN packets on the backends except mysql\", \"tags\": \"haproxy_syn_block\", \"when\": [\"step|int == 1\"], \"shell\": \"# server controller-0.storage.redhat.local 172.17.3.93:8080 check fall 5 inter 2000 rise 2\\n# server controller-0.internalapi.redhat.local fd00:fd00:fd00:2000::176:9292 check fall 5 inter 2000 rise 2\\nset -o pipefail\\nsource /etc/os-release; test  \\\"${VERSION_ID%*}\\\" = \\\"9.0\\\" && exit 0\\ngrep {{ ansible_facts[\\\"hostname\\\"]|lower }} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg  | grep -v \\\":3306 \\\" | \\\\\\nawk \'{print $3}\' | \\\\\\nwhile read BACKEND; do\\n    IP=${BACKEND%:*}\\n    PORT=${BACKEND#\\\"$IP:\\\"}\\n    if [[ $IP =~ .*:.* ]]\\n      then PROTOCOL=\\\"ip6\\\"\\n      else PROTOCOL=\\\"ip\\\"\\n    fi\\necho \\\"insert rule $PROTOCOL filter INPUT $PROTOCOL daddr $IP tcp dport $PORT tcp flags syn / fin,syn,rst,ack meta time\\\"\\ndone | xargs -i nft {} $(date +%s)-$(date -d\'+20 minutes\' +%s) counter drop comment \\\"{{ ansible_facts[\\\"hostname\\\"]|lower }}_haproxy_drop\\\"\\n\"}, {\"name\": \"Generate block for other nodes OUTPUT SYN packets on the backends except mysql\", \"tags\": \"haproxy_syn_block\", \"when\": [\"step|int == 1\"], \"shell\": \"set -o pipefail\\nsource /etc/os-release; test  \\\"${VERSION_ID%*}\\\" = \\\"9.0\\\" && exit 0\\ngrep {{ ansible_facts[\\\"hostname\\\"]|lower }} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg  | grep -v \\\":3306 \\\" | \\\\\\nawk \'{print $3}\' | \\\\\\nwhile read BACKEND; do\\n    IP=${BACKEND%:*}\\n    PORT=${BACKEND#\\\"$IP:\\\"}\\n    if [[ $IP =~ .*:.* ]]\\n      then PROTOCOL=\\\"ip6\\\"\\n      else PROTOCOL=\\\"ip\\\"\\n    fi\\n echo \\\"nft insert rule $PROTOCOL \\\\$TABLE OUTPUT $PROTOCOL daddr $IP tcp dport $PORT tcp flags syn / fin,syn,rst,ack meta time $(date +%s)-$(date -d\'+20 minutes\' +%s) counter drop comment \\\\\\\"{{ ansible_facts[\\\"hostname\\\"]|lower }}_haproxy_drop\\\\\\\" \\\"\\ndone\\n\", \"register\": \"haproxy_iptables_block\"}, {\"name\": \"Block OUTPUT SYN packets to this node on other haproxy nodes\", \"tags\": \"haproxy_syn_block\", \"delegate_to\": \"{{ item }}\", \"when\": [\"step|int == 1\"], \"shell\": \"set -o pipefail\\ngrep {{ ansible_facts[\\\"hostname\\\"]|lower }} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg | head -n 1 \\\\\\nawk \'{print $3}\' | while read BACKEND; do\\n    IP=${BACKEND%:*}\\n    if [[ $IP =~ .*:.* ]]\\n      then PROTOCOL=\\\"ip6\\\"\\n      else PROTOCOL=\\\"ip\\\"\\n    fi\\ndone\\nTABLE=$(nft list tables | grep -q \\\"$PROTOCOL raw\\\" && echo raw || echo filter )\\necho \\\"{{ haproxy_iptables_block.stdout}}\\\" | while read i; do bash -c \\\"$i\\\"; done\\n\", \"loop\": \"{{ groups[\\\"haproxy\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) | difference(ansible_facts[\\\"hostname\\\"]|lower) }}\"}], \"post_update_tasks\": [{\"name\": \"HAProxy bundle post update\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"HAproxy puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"haproxy\", \"tripleo_ha_wrapper_resource_name\": \"haproxy-bundle\", \"tripleo_ha_wrapper_bundle_name\": \"haproxy-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"haproxy\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::haproxy_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}], \"vars\": {\"tripleo_ha_wrapper_minor_update\": true}}, {\"name\": \"Cleanup local SYN DROP rules\", \"tags\": \"haproxy_syn_block\", \"when\": \"step|int == 1\", \"shell\": \"nft -a list chain filter INPUT | grep {{ ansible_facts[\\\"hostname\\\"]|lower }} | grep haproxy_drop | \\\\\\nawk -F# \'{print \\\"nft delete rule filter INPUT \\\"$2}\' | \\\\\\nwhile read i; do bash -c \\\"$i\\\"; done\\n\"}, {\"name\": \"Cleanup SYN DROP rules from other haproxy nodes\", \"tags\": \"haproxy_syn_block\", \"when\": \"step|int == 1\", \"delegate_to\": \"{{ item }}\", \"loop\": \"{{ groups[\\\"haproxy\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) | difference(ansible_facts[\\\"hostname\\\"]|lower) }}\", \"shell\": \"nft -a list chain raw OUTPUT | grep {{ ansible_facts[\\\"hostname\\\"]|lower }} | grep haproxy_drop | \\\\\\nawk -F# \'{print \\\"nft delete rule raw OUTPUT \\\"$2}\' | \\\\\\nwhile read i; do bash -c \\\"$i\\\"; done\\n\"}], \"upgrade_tasks\": [{\"name\": \"Tear-down non-HA haproxy container\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Remove non-HA haproxy container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"haproxy\"]}}]}, {\"name\": \"Prepare switch of haproxy image name\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Get haproxy image id currently used by pacemaker\", \"shell\": \"pcs resource config haproxy-bundle | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\", \"register\": \"haproxy_image_current_res\", \"failed_when\": false}, {\"name\": \"Image facts for haproxy\", \"set_fact\": {\"haproxy_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/haproxy:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"haproxy_image_current\": \"{{haproxy_image_current_res.stdout}}\"}}, {\"name\": \"Temporarily tag the current haproxy image id with the upgraded image name\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{haproxy_image_current}}\", \"container_image_latest\": \"{{haproxy_image_latest}}\", \"pull_image\": false}, \"when\": [\"haproxy_image_current != \'\'\", \"haproxy_image_current != haproxy_image_latest\"]}, {\"name\": \"Create haproxy retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/haproxy_needs_retag\", \"state\": \"touch\"}, \"when\": [\"haproxy_image_current != \'\'\", \"haproxy_image_current != haproxy_image_latest\"]}]}, {\"name\": \"Update haproxy pcs resource bundle for new container image\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Set upgrade haproxy facts\", \"set_fact\": {\"is_haproxy_bootstrap_node\": \"{{haproxy_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\"}}, {\"name\": \"Check for haproxy retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/haproxy_needs_retag\"}, \"register\": \"haproxy_retag_state_file\"}]}, {\"name\": \"Update haproxy pcs resource bundle for new container image\", \"when\": [\"step|int == 1\", \"is_haproxy_bootstrap_node|bool\", \"haproxy_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the haproxy cluster resource before container upgrade\", \"pacemaker_resource\": {\"resource\": \"haproxy-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Expose HAProxy stats socket on the host and mount TLS cert if needed\", \"block\": [{\"name\": \"Check haproxy stats socket configuration in pacemaker\", \"command\": \"cibadmin --query --xpath \\\"//storage-mapping[@id=\'haproxy-var-lib\']\\\"\", \"failed_when\": false, \"register\": \"haproxy_stats_exposed\"}, {\"name\": \"Check haproxy public certificate configuration in pacemaker\", \"command\": \"cibadmin --query --xpath \\\"//storage-mapping[@id=\'haproxy-cert\']\\\"\", \"failed_when\": false, \"register\": \"haproxy_cert_mounted\"}, {\"name\": \"Add a bind mount for stats socket in the haproxy bundle\", \"command\": \"pcs resource bundle update haproxy-bundle storage-map add id=haproxy-var-lib source-dir=/var/lib/haproxy target-dir=/var/lib/haproxy options=rw\", \"when\": \"haproxy_stats_exposed.rc == 6\"}, {\"name\": \"Set HAProxy public cert volume mount fact\", \"set_fact\": {\"haproxy_public_cert_path\": {\"get_param\": \"DeployedSSLCertificatePath\"}, \"haproxy_public_tls_enabled\": {\"if\": [\"public_tls_enabled\", true, false]}}}, {\"name\": \"Add a bind mount for public certificate in the haproxy bundle\", \"command\": \"pcs resource bundle update haproxy-bundle storage-map add id=haproxy-cert source-dir={{ haproxy_public_cert_path }} target-dir=/var/lib/kolla/config_files/src-tls/{{ haproxy_public_cert_path }} options=ro\", \"when\": [\"haproxy_cert_mounted.rc == 6\", \"haproxy_public_tls_enabled|bool\"]}]}, {\"name\": \"Update the haproxy bundle to use the new container image name\", \"command\": \"pcs resource bundle update haproxy-bundle container image={{haproxy_image_latest}}\"}, {\"name\": \"Enable the haproxy cluster resource\", \"pacemaker_resource\": {\"resource\": \"haproxy-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Remove haproxy retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/haproxy_needs_retag\", \"state\": \"absent\"}}]}, {\"name\": \"Retag the pacemaker image if containerized\", \"when\": [\"step|int == 3\"], \"block\": [{\"block\": [{\"name\": \"Get haproxy image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_haproxy_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'haproxy-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container haproxy image\", \"set_fact\": {\"haproxy_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"haproxy_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/haproxy:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_haproxy_image\": \"{{xmllint_pcmk_haproxy_image.stdout}}\"}}]}, {\"block\": [{\"name\": \"Retag pcmklatest to latest haproxy image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{haproxy_image}}\", \"container_image_latest\": \"{{haproxy_image_latest}}\"}}]}, {\"name\": \"Ensure config works for the new config\", \"shell\": \"set -o pipefail\\nawk -i inplace -v INPLACE_SUFFIX=.bak \'/  rsprep/ {print \\\"  http-response replace-header Location \\\" $3\\\" \\\"$5; next;}; {print} \' /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg\"}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(68,'2026-06-12 08:25:59',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Ceilometer Agent Central service\\n\", \"parameters\": {\"ContainerCeilometerCentralImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"ContainerCeilometerConfigImage\": {\"description\": \"The container image to use for the ceilometer config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"CeilometerAgentCentralLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.ceilometer.agent.central\", \"file\": \"/var/log/containers/ceilometer/central.log\"}}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"RedisPassword\": {\"description\": \"The password for the redis service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"zTfbzAZoNB6iKueE7EslkZpK7\"}, \"MonitoringSubscriptionCeilometerCentral\": {\"default\": \"overcloud-ceilometer-agent-central\", \"type\": \"string\"}, \"CeilometerEnableGnocchi\": {\"default\": false, \"description\": \"Whether to enable gnocchi usage.\", \"type\": \"boolean\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\"}, \"CeilometerEnableTenantDiscovery\": {\"default\": false, \"description\": \"Identify user and project names from polled metrics.\", \"type\": \"boolean\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CeilometerServiceBase\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCeilometerCentralImage\": \"ContainerCeilometerCentralImage\", \"ContainerCeilometerConfigImage\": \"ContainerCeilometerConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCeilometerCentralImage\": {\"get_param\": \"ContainerCeilometerCentralImage\"}, \"ContainerCeilometerConfigImage\": {\"get_param\": \"ContainerCeilometerConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer Agent Central role.\", \"value\": {\"service_name\": \"ceilometer_agent_central\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCeilometerCentral\"}, \"keystone_resources\": {\"ceilometer\": {\"users\": {\"ceilometer\": {\"password\": {\"get_param\": \"CeilometerPassword\"}, \"roles\": [\"admin\", \"ResellerAdmin\"]}}, \"roles\": [\"ResellerAdmin\"]}}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"config_settings\"]}, {\"ceilometer_redis_password\": {\"get_param\": \"RedisPassword\"}, \"central_namespace\": true, \"ceilometer::agent::polling::tenant_name_discovery\": {\"get_param\": \"CeilometerEnableTenantDiscovery\"}}]}, \"service_config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"service_config_settings\"]}, {\"rsyslog\": {\"tripleo_logging_sources_ceilometer_agent_central\": [{\"get_param\": \"CeilometerAgentCentralLoggingSource\"}]}}]}, \"puppet_config\": {\"config_volume\": \"ceilometer\", \"puppet_tags\": \"ceilometer_config\", \"step_config\": \"include tripleo::profile::base::ceilometer::agent::polling\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/ceilometer_agent_central.json\": {\"command\": \"/usr/bin/ceilometer-polling --polling-namespaces central --logfile /var/log/ceilometer/central.log\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/ceilometer_agent_gnocchi_upgrade.json\": {\"command\": \"/usr/bin/bootstrap_host_exec ceilometer_agent_central su ceilometer -s /bin/bash -c \'for n in {1..10}; do /usr/bin/ceilometer-upgrade && exit 0 || sleep 30; done; exit 1\'\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_3\": {\"ceilometer_init_log\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerCentralImage\"]}, \"net\": \"none\", \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"chown -R ceilometer:ceilometer /var/log/ceilometer\"], \"volumes\": [\"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]}}, \"step_4\": {\"ceilometer_agent_central\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerCentralImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer_agent_central.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}, \"step_5\": {\"if\": [{\"get_param\": \"CeilometerEnableGnocchi\"}, {\"ceilometer_gnocchi_upgrade\": {\"start_order\": 99, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerCentralImage\"]}, \"net\": \"host\", \"detach\": false, \"privileged\": false, \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer_agent_gnocchi_upgrade.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}]}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/ceilometer\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop ceilometer agent central container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"ceilometer_agent_central\"], \"tripleo_delegate_to\": \"{{ groups[\'ceilometer_agent_central\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(69,'2026-06-12 08:25:59',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": true, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"StorageIpList\": \"\", \"StorageMgmtIpList\": \"\", \"InternalApiIpList\": \"\", \"TenantIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,storage,storage_mgmt,internal_api,tenant\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(70,'2026-06-12 08:25:59',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Iscsid service\\n\", \"parameters\": {\"ContainerIscsidImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\"}, \"ContainerIscsidConfigImage\": {\"description\": \"The container image to use for the iscsid config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"LVMFilterEnabled\": {\"default\": false, \"description\": \"Enables configuration of LVM2 with a filter so that devices not in use on the host or explicitly allowed are ignored by LVM2. Can be configured per-role. When disabled, the proposed lvm.conf file will be created regardless and left in /tmp/tripleo_lvmfilter.conf for debugging purposes.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"LVMFilterAllowlist\": {\"default\": [], \"description\": \"A list of block devices which should be allowed in the LVM2 `global_filter`. Supports regular expressions, like `/dev/sd.*` and can be configured per-role. Any block device in use at boot time will be automatically allowed.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"LVMFilterDenylist\": {\"default\": [\".*\"], \"description\": \"A list of block devices which should be disallowed in the LVM2 `global_filter`. Supports regular expressions, like `/dev/sd.*` and can be configured per-role.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"IscsidCHAPAlgorithms\": {\"default\": \"SHA3-256,SHA256,SHA1,MD5\", \"description\": \"A comma separated list of algorithms to be used for the CHAP algorithm.\", \"type\": \"string\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"tripleo_tripleo_lvmfilter_enabled\": \"LVMFilterEnabled\", \"tripleo_tripleo_lvmfilter_devices_allowlist\": \"LVMFilterAllowlist\", \"tripleo_tripleo_lvmfilter_devices_denylist\": \"LVMFilterDenylist\", \"ContainerIscsidImage\": \"ContainerIscsidImage\", \"ContainerIscsidConfigImage\": \"ContainerIscsidConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"LVMFilterEnabled\": {\"get_param\": \"LVMFilterEnabled\"}, \"LVMFilterAllowlist\": {\"get_param\": \"LVMFilterAllowlist\"}, \"LVMFilterDenylist\": {\"get_param\": \"LVMFilterDenylist\"}, \"ContainerIscsidImage\": {\"get_param\": \"ContainerIscsidImage\"}, \"ContainerIscsidConfigImage\": {\"get_param\": \"ContainerIscsidConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Iscsid role.\", \"value\": {\"service_name\": \"iscsid\", \"config_settings\": {\"tripleo::profile::base::iscsid::chap_algs\": {\"get_param\": \"IscsidCHAPAlgorithms\"}}, \"service_config_settings\": {}, \"deploy_steps_tasks\": [{\"name\": \"Run lvmfilter role\", \"include_role\": {\"name\": \"tripleo_lvmfilter\"}, \"when\": [\"step|int == 1\"]}], \"ansible_group_vars\": {\"get_attr\": [\"RoleParametersValue\", \"value\"]}, \"puppet_config\": {\"config_volume\": \"iscsid\", \"puppet_tags\": \"iscsid_config\", \"step_config\": \"include tripleo::profile::base::iscsid\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerIscsidConfigImage\"]}, \"volumes\": [\"/etc/iscsi:/tmp/iscsi.host:z\"]}, \"kolla_config\": {\"/var/lib/kolla/config_files/iscsid.json\": {\"command\": \"/usr/sbin/iscsid -f\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src-iscsid/\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_3\": {\"iscsid\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerIscsidImage\"]}, \"net\": \"host\", \"privileged\": true, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/iscsid.json:/var/lib/kolla/config_files/config.json:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", \"/etc/target:/etc/target:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create fcontext entry for iscsi\", \"community.general.sefcontext\": {\"target\": \"{{ item.path }}(/.*)?\", \"setype\": \"{{ item.setype }}\", \"state\": \"present\"}, \"with_items\": [{\"path\": \"/etc/iscsi\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/target\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/iscsi\", \"setype\": \"container_file_t\"}]}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\"}, \"with_items\": [{\"path\": \"/etc/iscsi\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/target\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/iscsi\", \"setype\": \"container_file_t\"}]}, {\"name\": \"stat /lib/systemd/system/iscsid.socket\", \"stat\": \"path=/lib/systemd/system/iscsid.socket\", \"register\": \"stat_iscsid_socket\"}, {\"name\": \"Stop and disable iscsid.socket service\", \"service\": \"name=iscsid.socket state=stopped enabled=no\", \"when\": \"stat_iscsid_socket.stat.exists\"}, {\"name\": \"Check if iscsi.service is enabled\", \"command\": \"systemctl is-enabled --quiet iscsi.service\", \"failed_when\": false, \"register\": \"iscsi_service_enabled_result\"}, {\"name\": \"Stop iscsi.service\", \"service\": \"name=iscsi.service state=stopped enabled=no\", \"when\": [\"iscsi_service_enabled_result is changed\", \"iscsi_service_enabled_result.rc == 0\"]}], \"upgrade_tasks\": []}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(71,'2026-06-12 08:25:59',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": true, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"StorageIpList\": \"\", \"StorageMgmtIpList\": \"\", \"InternalApiIpList\": \"\", \"TenantIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,storage,storage_mgmt,internal_api,tenant\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(72,'2026-06-12 08:25:59',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized HAproxy service\\n\", \"parameters\": {\"ContainerHAProxyImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\"}, \"ContainerHAProxyConfigImage\": {\"description\": \"The container image to use for the haproxy config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"HAProxyStatsPassword\": {\"description\": \"Password for HAProxy stats endpoint\", \"hidden\": true, \"type\": \"string\", \"default\": \"MUfjd43QRvJhihQtc3FyU3ZcN\"}, \"HAProxyStatsUser\": {\"description\": \"User for HAProxy stats endpoint\", \"default\": \"admin\", \"type\": \"string\"}, \"HAProxyLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.haproxy\", \"file\": \"/var/log/containers/haproxy/haproxy.log\", \"startmsg.regex\": \"^[a-zA-Z]{3} [ 123][0-9] [:0-9]{8}\"}}, \"HAProxySyslogAddress\": {\"default\": \"/dev/log\", \"description\": \"Syslog address where HAproxy will send its log\", \"type\": \"string\"}, \"HAProxySyslogFacility\": {\"default\": \"local0\", \"description\": \"Syslog facility HAProxy will use for its logs\", \"type\": \"string\"}, \"SSLCertificate\": {\"default\": \"\", \"description\": \"The content of the SSL certificate (without Key) in PEM format.\\n\", \"type\": \"string\"}, \"PublicSSLCertificateAutogenerated\": {\"default\": false, \"description\": \"Whether the public SSL certificate was autogenerated or not.\\n\", \"type\": \"boolean\"}, \"EnablePublicTLS\": {\"default\": true, \"description\": \"Whether to enable TLS on the public interface or not.\\n\", \"type\": \"boolean\"}, \"DeployedSSLCertificatePath\": {\"default\": \"/etc/pki/tls/private/overcloud_endpoint.pem\", \"description\": \"The filepath of the certificate as it will be stored in the controller.\\n\", \"type\": \"string\"}, \"RedisPassword\": {\"description\": \"The password for the redis service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"zTfbzAZoNB6iKueE7EslkZpK7\"}, \"MonitoringSubscriptionHaproxy\": {\"default\": \"overcloud-haproxy\", \"type\": \"string\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"ConfigDebug\": {\"default\": false, \"description\": \"Whether to run config management (e.g. Puppet) in debug mode.\", \"type\": \"boolean\"}, \"EnableLoadBalancer\": {\"default\": true, \"description\": \"Whether to deploy a LoadBalancer, set to false when an external load balancer is used.\", \"type\": \"boolean\"}, \"HAProxyStatsEnabled\": {\"default\": true, \"description\": \"Whether or not to enable the HAProxy stats interface.\", \"type\": \"boolean\"}, \"InternalTLSCRLPEMFile\": {\"default\": \"/etc/pki/CA/crl/overcloud-crl.pem\", \"type\": \"string\", \"description\": \"Specifies the default CRL PEM file to use for revocation if TLS is used for services in the internal network.\"}, \"InternalTLSCRLPEMDir\": {\"default\": \"/etc/pki/CA/crl/\", \"type\": \"string\", \"description\": \"The directory of the CRL PEM file to be mounted.\"}}, \"conditions\": {\"public_tls_enabled\": {\"and\": [{\"get_param\": \"EnablePublicTLS\"}, {\"or\": [{\"not\": {\"equals\": [{\"get_param\": \"SSLCertificate\"}, \"\"]}}, {\"get_param\": \"PublicSSLCertificateAutogenerated\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\"}, \"HAProxyLogging\": {\"type\": \"OS::TripleO::Services::Logging::HAProxy\"}, \"HAProxyPublicTLS\": {\"type\": \"OS::TripleO::Services::HAProxyPublicTLS\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"HAProxyInternalTLS\": {\"type\": \"OS::TripleO::Services::HAProxyInternalTLS\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerHAProxyImage\": \"ContainerHAProxyImage\", \"ContainerHAProxyConfigImage\": \"ContainerHAProxyConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerHAProxyImage\": {\"get_param\": \"ContainerHAProxyImage\"}, \"ContainerHAProxyConfigImage\": {\"get_param\": \"ContainerHAProxyConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the HAproxy role.\", \"value\": {\"service_name\": \"haproxy\", \"firewall_rules\": {\"107 haproxy stats\": {\"dport\": 1993}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionHaproxy\"}, \"ansible_group_vars\": {\"tripleo_firewall_frontend_enabled\": true, \"tripleo_firewall_ssl_frontend_enabled\": {\"if\": [\"public_tls_enabled\", true]}}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"HAProxyLogging\", \"config_settings\"]}, {\"tripleo::haproxy::haproxy_service_manage\": false, \"tripleo::haproxy::haproxy_log_address\": {\"get_param\": \"HAProxySyslogAddress\"}, \"tripleo::haproxy::haproxy_log_facility\": {\"get_param\": \"HAProxySyslogFacility\"}, \"tripleo::haproxy::haproxy_stats_user\": {\"get_param\": \"HAProxyStatsUser\"}, \"tripleo::haproxy::haproxy_stats_password\": {\"get_param\": \"HAProxyStatsPassword\"}, \"tripleo::haproxy::haproxy_stats_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HaproxyNetwork\"]}}}}, \"tripleo::haproxy::redis_password\": {\"get_param\": \"RedisPassword\"}, \"tripleo::haproxy::crl_file\": null, \"tripleo::haproxy::haproxy_stats\": {\"get_param\": \"HAProxyStatsEnabled\"}, \"enable_load_balancer\": {\"get_param\": \"EnableLoadBalancer\"}, \"tripleo::profile::base::haproxy::certificates_specs\": {\"map_merge\": [{\"get_attr\": [\"HAProxyPublicTLS\", \"role_data\", \"certificates_specs\"]}, {\"get_attr\": [\"HAProxyInternalTLS\", \"role_data\", \"certificates_specs\"]}]}, \"tripleo::haproxy::service_certificate\": {\"if\": [\"public_tls_enabled\", {\"get_param\": \"DeployedSSLCertificatePath\"}]}, \"tripleo::haproxy::ca_bundle\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"InternalTLSCAFile\"}]}}, {\"get_attr\": [\"HAProxyPublicTLS\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"HAProxyInternalTLS\", \"role_data\", \"config_settings\"]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_haproxy\": [{\"get_param\": \"HAProxyLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"haproxy\", \"puppet_tags\": \"haproxy_config\", \"step_config\": \"class {\'tripleo::profile::base::haproxy\': manage_firewall => false}\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyConfigImage\"]}, \"volumes\": {\"list_concat\": [{\"if\": [\"public_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"DeployedSSLCertificatePath\"}, {\"get_param\": \"DeployedSSLCertificatePath\"}, \"ro,shared\"]]}]]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/haproxy:/etc/pki/tls/certs/haproxy:ro,shared\", \"/etc/pki/tls/private/haproxy:/etc/pki/tls/private/haproxy:ro,shared\", {\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro,shared\"]]}, {\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCRLPEMDir\"}, {\"get_param\": \"InternalTLSCRLPEMDir\"}, \"ro,shared\"]]}]]}]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/haproxy.json\": {\"command\": \"bash -c $* -- eval if [ -f /usr/sbin/haproxy-systemd-wrapper ]; then exec /usr/sbin/haproxy-systemd-wrapper -f /etc/haproxy/haproxy.cfg; else exec /usr/sbin/haproxy -f /etc/haproxy/haproxy.cfg -Ws; fi\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/lib/haproxy\", \"owner\": \"haproxy:haproxy\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/haproxy\", \"owner\": \"haproxy:haproxy\", \"recurse\": true, \"optional\": true}]}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"docker_config\": {\"step_1\": {\"map_merge\": [{\"get_attr\": [\"HAProxyLogging\", \"docker_config\", \"step_1\"]}, {\"haproxy\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"net\": \"host\", \"restart\": \"always\", \"security_opt\": [\"label=disable\"], \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"HAProxyLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/haproxy.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/haproxy:/var/lib/kolla/config_files/src:ro\", \"/var/lib/haproxy:/var/lib/haproxy:rw,z\"], {\"if\": [\"public_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"DeployedSSLCertificatePath\"}, {\"list_join\": [\"\", [\"/var/lib/kolla/config_files/src-tls\", {\"get_param\": \"DeployedSSLCertificatePath\"}]]}, \"ro,shared\"]]}]]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/haproxy:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/haproxy:ro,shared\", \"/etc/pki/tls/private/haproxy:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/haproxy:ro,shared\", {\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCRLPEMDir\"}, {\"get_param\": \"InternalTLSCRLPEMDir\"}, \"ro\"]]}]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}]}}, \"deploy_steps_tasks\": {\"list_concat\": [[{\"name\": \"Configure rsyslog for HAproxy container\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Check if rsyslog exists\", \"shell\": \"systemctl is-active rsyslog\", \"register\": \"rsyslog_config\"}, {\"when\": [\"rsyslog_config is changed\", \"rsyslog_config.rc == 0\"], \"block\": [{\"name\": \"Forward logging to haproxy.log file\", \"blockinfile\": {\"content\": \"if $syslogfacility-text == \'{{facility}}\' and $programname == \'haproxy\' then -/var/log/containers/haproxy/haproxy.log\\n& stop\\n\", \"create\": true, \"path\": \"/etc/rsyslog.d/openstack-haproxy.conf\"}, \"vars\": {\"facility\": {\"get_param\": \"HAProxySyslogFacility\"}}, \"register\": \"logconfig\"}, {\"name\": \"restart rsyslog service after logging conf change\", \"service\": {\"name\": \"rsyslog\", \"state\": \"restarted\"}, \"when\": \"logconfig is changed\"}]}]}, {\"name\": \"Run puppet on the host to apply IPtables rules\", \"no_log\": true, \"when\": \"step|int == 1\", \"register\": \"puppet_host_outputs\", \"shell\": \"puppet apply {{ (puppet_debug|bool) | ternary(\'--debug --verbose\', \'\') }} --detailed-exitcodes --summarize --color=false \\\\\\n    --modulepath \'{{ puppet_modulepath }}\' --tags \'{{ puppet_tags }}\' -e \'{{ puppet_execute }}\'\\n\", \"changed_when\": \"puppet_host_outputs.rc == 2\", \"failed_when\": false, \"vars\": {\"puppet_execute\": \"include tripleo::profile::base::haproxy\", \"puppet_tags\": \"tripleo::firewall::rule\", \"puppet_modulepath\": \"/etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules\", \"puppet_debug\": {\"get_param\": \"ConfigDebug\"}}}, {\"name\": \"Debug output for task: Run puppet on the host to apply IPtables rules\", \"debug\": {\"var\": \"puppet_host_outputs.stdout_lines | default([]) | union(puppet_host_outputs.stderr_lines | default([]))\"}, \"when\": [\"not (ansible_check_mode | bool)\", \"puppet_host_outputs.rc is defined\"], \"failed_when\": \"puppet_host_outputs.rc not in [0, 2]\"}], {\"if\": [\"public_tls_enabled\", {\"get_attr\": [\"HAProxyPublicTLS\", \"role_data\", \"deploy_steps_tasks\"]}]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_attr\": [\"HAProxyInternalTLS\", \"role_data\", \"deploy_steps_tasks\"]}]}]}, \"upgrade_tasks\": [{\"name\": \"ensure we have haproxy log dir with the correct setype\", \"file\": {\"path\": \"/var/log/containers/haproxy\", \"state\": \"directory\", \"setype\": \"var_log_t\", \"recurse\": true}, \"when\": \"step|int == 1\"}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop haproxy container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"haproxy\"], \"tripleo_delegate_to\": \"{{ groups[\'haproxy\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}], \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HAProxyPublicTLS\", \"role_data\", \"host_prep_tasks\"]}, [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/haproxy\", \"setype\": \"var_log_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/haproxy\", \"setype\": \"container_file_t\"}]}]]}, \"metadata_settings\": {\"list_concat\": [{\"get_attr\": [\"HAProxyPublicTLS\", \"role_data\", \"metadata_settings\"]}, {\"get_attr\": [\"HAProxyInternalTLS\", \"role_data\", \"metadata_settings\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (73,'2026-06-12 08:25:59',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Qpid dispatch router service for metrics and monitoring purposes\\n\", \"parameters\": {\"ContainerMetricsQdrImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\"}, \"ContainerMetricsQdrConfigImage\": {\"description\": \"The container image to use for the qdrouterd config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"MonitoringSubscriptionQdr\": {\"default\": \"overcloud-qdr\", \"type\": \"string\"}, \"MetricsQdrLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.nova.consoleauth\", \"file\": \"/var/log/containers/metrics_qdr/metrics_qdr.log\", \"startmsg.regex\": \"^[0-9]{4}-[0-9]{2}-[0-9]{2} [0-9]{2}:[0-9]{2}:[0-9]{2}(.[0-9]+ \\\\\\\\+[0-9]+)? [A-Z]+ \\\\\\\\([a-z]+\\\\\\\\) \"}}, \"MetricsQdrPort\": {\"default\": 5666, \"description\": \"Service name or port number on which the qdrouterd will accept connections.\", \"type\": \"number\"}, \"MetricsQdrUsername\": {\"default\": \"guest\", \"description\": \"Username which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\"}, \"MetricsQdrPassword\": {\"default\": \"guest\", \"description\": \"Password which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\", \"hidden\": true}, \"MetricsQdrConnectors\": {\"default\": [], \"description\": \"Connectors configuration (array of hashes).\", \"type\": \"json\"}, \"MetricsQdrSSLProfiles\": {\"default\": [{\"name\": \"sslProfile\"}], \"description\": \"SSL Profiles for the connectors (array of hashes).\", \"type\": \"json\"}, \"MetricsQdrAddresses\": {\"default\": [{\"prefix\": \"collectd\", \"distribution\": \"multicast\"}, {\"prefix\": \"ceilometer/metering.sample\", \"distribution\": \"multicast\"}, {\"prefix\": \"ceilometer/event.sample\", \"distribution\": \"multicast\"}], \"description\": \"Addresses configuration (array of hashes).\", \"type\": \"json\"}, \"MetricsQdrAutoLinks\": {\"default\": [], \"description\": \"AutoLinks for the Configured Addresses\", \"type\": \"json\"}, \"MetricsQdrUseSSL\": {\"default\": false, \"description\": \"Set to true if it is required to use SSL or TLS on the connection for the local listener. !WARNING! Currently breaks connections from collectd and ceilometer.\", \"type\": \"boolean\"}, \"MetricsQdrUseEncryption\": {\"default\": false, \"description\": \"Set to true if it is required to encrypt connection to the peer for listener. Not currently implemented, use EnableInternalTLS instead. This option can be ignored.\", \"type\": \"boolean\"}, \"MetricsQdrSaslMechanisms\": {\"default\": \"ANONYMOUS\", \"description\": \"List of accepted SASL auth mechanisms for listener in format of comma separated list.\", \"type\": \"string\"}, \"MetricsQdrSslCertDb\": {\"default\": \"/etc/ipa/ca.crt\", \"description\": \"Path to SSL certificate db for listener.\", \"type\": \"string\"}, \"MetricsQdrSslCertFile\": {\"default\": \"/etc/pki/tls/certs/metrics_qdr.crt\", \"description\": \"Path to SSL certificate file for listener.\", \"type\": \"string\"}, \"MetricsQdrSslKeyFile\": {\"default\": \"/etc/pki/tls/private/metrics_qdr.key\", \"description\": \"Path to SSL private key file for listener.\", \"type\": \"string\"}, \"MetricsQdrSslPwFile\": {\"default\": \"\", \"description\": \"Path to SSL password file for certificate key for listener.\", \"type\": \"string\"}, \"MetricsQdrSslPassword\": {\"default\": \"\", \"description\": \"SSL password to be supplied for listener.\", \"type\": \"string\"}, \"MetricsQdrTrustedCerts\": {\"default\": \"\", \"description\": \"Path to file containing trusted certificates for listener.\", \"type\": \"string\"}, \"MetricsQdrAuthenticateClient\": {\"default\": false, \"description\": \"Authenticate the client using SSL/TLS\", \"type\": \"boolean\"}, \"MetricsQdrExternalEndpoint\": {\"default\": false, \"description\": \"Whether QDR should listen on external network interface. To enable listening on external network one must deploy QDRs in mesh mode.\", \"type\": \"boolean\"}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"EnableSTF\": {\"default\": false, \"description\": \"Set to true to enable configuration for STF client.\", \"type\": \"boolean\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"QdrCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"listener_ssl_enabled\": {\"equals\": [{\"get_param\": \"MetricsQdrUseSSL\"}, true]}, \"enable_stf\": {\"equals\": [{\"get_param\": \"EnableSTF\"}, true]}, \"key_size_override_unset\": {\"equals\": [{\"get_param\": \"QdrCertificateKeySize\"}, \"\"]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerMetricsQdrImage\": \"ContainerMetricsQdrImage\", \"ContainerMetricsQdrConfigImage\": \"ContainerMetricsQdrConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerMetricsQdrImage\": {\"get_param\": \"ContainerMetricsQdrImage\"}, \"ContainerMetricsQdrConfigImage\": {\"get_param\": \"ContainerMetricsQdrConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the metrics Qdr role.\", \"value\": {\"service_name\": \"metrics_qdr\", \"firewall_rules\": {\"map_merge\": [{\"109 metrics qdr\": {\"dport\": [{\"get_param\": \"MetricsQdrPort\"}]}}, {\"map_merge\": {\"repeat\": {\"for_each\": {\"<%net_cidr%>\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", \"ctlplane\"]}}, \"template\": {\"109 accept internal metrics qdr ctlplane subnet <%net_cidr%>\": {\"dport\": [5667, 5668]}}}}}]}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionQdr\"}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_metrics_qdr\": [{\"get_param\": \"MetricsQdrLoggingSource\"}]}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::metrics::qdr::listener_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::haproxy::metrics_qdr\": {\"get_param\": \"MetricsQdrExternalEndpoint\"}, \"tripleo::profile::base::metrics::qdr::listener_port\": {\"get_param\": \"MetricsQdrPort\"}, \"tripleo::profile::base::metrics::qdr::username\": {\"get_param\": \"MetricsQdrUsername\"}, \"tripleo::profile::base::metrics::qdr::password\": {\"get_param\": \"MetricsQdrPassword\"}, \"tripleo::profile::base::metrics::qdr::connectors\": {\"get_param\": \"MetricsQdrConnectors\"}, \"tripleo::profile::base::metrics::qdr::addresses\": {\"get_param\": \"MetricsQdrAddresses\"}, \"tripleo::profile::base::metrics::qdr::autolink_addresses\": {\"get_param\": \"MetricsQdrAutoLinks\"}, \"tripleo::profile::base::metrics::qdr::listener_require_ssl\": {\"if\": [\"listener_ssl_enabled\", true, false]}, \"tripleo::profile::base::metrics::qdr::listener_require_encrypt\": {\"get_param\": \"MetricsQdrUseEncryption\"}, \"tripleo::profile::base::metrics::qdr::listener_sasl_mech\": {\"get_param\": \"MetricsQdrSaslMechanisms\"}, \"tripleo::profile::base::metrics::qdr::listener_ssl_cert_db\": {\"get_param\": \"MetricsQdrSslCertDb\"}, \"tripleo::profile::base::metrics::qdr::listener_ssl_cert_file\": {\"get_param\": \"MetricsQdrSslCertFile\"}, \"tripleo::profile::base::metrics::qdr::listener_ssl_key_file\": {\"get_param\": \"MetricsQdrSslKeyFile\"}, \"tripleo::profile::base::metrics::qdr::listener_ssl_pw_file\": {\"get_param\": \"MetricsQdrSslPwFile\"}, \"tripleo::profile::base::metrics::qdr::listener_ssl_password\": {\"get_param\": \"MetricsQdrSslPassword\"}, \"tripleo::profile::base::metrics::qdr::listener_trusted_certs\": {\"get_param\": \"MetricsQdrTrustedCerts\"}, \"qdr::log_enable\": \"info+\", \"qdr::log_output\": \"/var/log/qdrouterd/metrics_qdr.log\", \"qdr::listener_auth_peer\": {\"get_param\": \"MetricsQdrAuthenticateClient\"}}, {\"if\": [\"internal_tls_enabled\", {\"tripleo::profile::base::metrics::qdr::ssl_profiles\": {\"list_concat\": [{\"get_param\": \"MetricsQdrSSLProfiles\"}, [{\"name\": \"tlsProfile\", \"certFile\": \"/etc/pki/tls/certs/metrics_qdr.crt\", \"keyFile\": \"/etc/pki/tls/private/metrics_qdr.key\", \"caCertFile\": {\"get_param\": \"InternalTLSCAFile\"}}]]}}, {\"tripleo::profile::base::metrics::qdr::ssl_profiles\": {\"get_param\": \"MetricsQdrSSLProfiles\"}}]}, {\"if\": [\"enable_stf\", {\"tripleo::profile::base::metrics::qdr::interior_mesh_nodes\": \"\", \"tripleo::profile::base::metrics::qdr::router_mode\": \"edge\"}, null]}]}, \"metadata_settings\": {\"if\": [\"internal_tls_enabled\", [{\"service\": \"metrics_qdr\", \"network\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}, \"type\": \"node\"}], null]}, \"puppet_config\": {\"config_volume\": \"metrics_qdr\", \"step_config\": \"include tripleo::profile::base::metrics::qdr\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMetricsQdrConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/metrics_qdr.json\": {\"command\": \"/usr/sbin/qdrouterd -c /etc/qpid-dispatch/qdrouterd.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/lib/qdrouterd\", \"owner\": \"qdrouterd:qdrouterd\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/metrics_qdr.crt\", \"owner\": \"qdrouterd:qdrouterd\", \"optional\": true}, {\"path\": \"/etc/pki/tls/private/metrics_qdr.key\", \"owner\": \"qdrouterd:qdrouterd\", \"optional\": true}]}}, \"docker_config\": {\"step_1\": {\"metrics_qdr_init_logs\": {\"start_order\": 0, \"detach\": false, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMetricsQdrImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/metrics_qdr:/var/log/qdrouterd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R qdrouterd:qdrouterd /var/log/qdrouterd\"]}, \"metrics_qdr\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMetricsQdrImage\"]}, \"net\": \"host\", \"user\": \"qdrouterd\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/metrics_qdr.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/metrics_qdr:/var/lib/kolla/config_files/src:ro\", \"/var/lib/metrics_qdr:/var/lib/qdrouterd:z\", \"/var/log/containers/metrics_qdr:/var/log/qdrouterd:z\"], {\"if\": [\"internal_tls_enabled\", [\"/etc/pki/tls/certs/metrics_qdr.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/metrics_qdr.crt:ro\", \"/etc/pki/tls/private/metrics_qdr.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/metrics_qdr.key:ro\"], null]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"metrics_qdr\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_NETWORK}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"principal\": {\"str_replace\": {\"template\": \"metrics_qdr/{{fqdn_NETWORK}}@{{idm_realm}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"run_after\": \"container_name=$({{container_cli}} ps --format=\\\\{\\\\{.Names\\\\}\\\\} | grep metrics_qdr)\\nservice_crt=\\\"/etc/pki/tls/certs/metrics_qdr.crt\\\"\\nservice_key=\\\"/etc/pki/tls/private/metrics_qdr.key\\n# Copy the new cert from the mount-point to the real path\\n{{container_cli}} exec \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_crt\\\" \\\"$service_crt\\\"\\n# Copy the new key from the mount-point to the real path\\n{{container_cli}} exec \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_key\\\" \\\"$service_key\\\"\\n# Set appropriate permissions\\n{{container_cli}} exec \\\"$container_name\\\" chown qdrouterd:qdrouterd \\\"$service_crt\\\"\\n{{container_cli}} exec \\\"$container_name\\\" chown qdrouterd:qdrouterd \\\"$service_key\\\"\\n# Trigger a container restart to read the new certificate\\n{{container_cli}} restart \\\"$container_name\\\"\\n\", \"key_size\": {\"if\": [\"key_size_override_unset\", {\"get_param\": \"CertificateKeySize\"}, {\"get_param\": \"QdrCertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}], \"host_prep_tasks\": [{\"name\": \"create persistent logs directory\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/metrics_qdr\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/metrics_qdr\", \"setype\": \"container_file_t\"}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(74,'2026-06-12 08:26:00',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Iscsid service\\n\", \"parameters\": {\"ContainerIscsidImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\"}, \"ContainerIscsidConfigImage\": {\"description\": \"The container image to use for the iscsid config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"LVMFilterEnabled\": {\"default\": false, \"description\": \"Enables configuration of LVM2 with a filter so that devices not in use on the host or explicitly allowed are ignored by LVM2. Can be configured per-role. When disabled, the proposed lvm.conf file will be created regardless and left in /tmp/tripleo_lvmfilter.conf for debugging purposes.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"LVMFilterAllowlist\": {\"default\": [], \"description\": \"A list of block devices which should be allowed in the LVM2 `global_filter`. Supports regular expressions, like `/dev/sd.*` and can be configured per-role. Any block device in use at boot time will be automatically allowed.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"LVMFilterDenylist\": {\"default\": [\".*\"], \"description\": \"A list of block devices which should be disallowed in the LVM2 `global_filter`. Supports regular expressions, like `/dev/sd.*` and can be configured per-role.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"IscsidCHAPAlgorithms\": {\"default\": \"SHA3-256,SHA256,SHA1,MD5\", \"description\": \"A comma separated list of algorithms to be used for the CHAP algorithm.\", \"type\": \"string\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"tripleo_tripleo_lvmfilter_enabled\": \"LVMFilterEnabled\", \"tripleo_tripleo_lvmfilter_devices_allowlist\": \"LVMFilterAllowlist\", \"tripleo_tripleo_lvmfilter_devices_denylist\": \"LVMFilterDenylist\", \"ContainerIscsidImage\": \"ContainerIscsidImage\", \"ContainerIscsidConfigImage\": \"ContainerIscsidConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"LVMFilterEnabled\": {\"get_param\": \"LVMFilterEnabled\"}, \"LVMFilterAllowlist\": {\"get_param\": \"LVMFilterAllowlist\"}, \"LVMFilterDenylist\": {\"get_param\": \"LVMFilterDenylist\"}, \"ContainerIscsidImage\": {\"get_param\": \"ContainerIscsidImage\"}, \"ContainerIscsidConfigImage\": {\"get_param\": \"ContainerIscsidConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Iscsid role.\", \"value\": {\"service_name\": \"iscsid\", \"config_settings\": {\"tripleo::profile::base::iscsid::chap_algs\": {\"get_param\": \"IscsidCHAPAlgorithms\"}}, \"service_config_settings\": {}, \"deploy_steps_tasks\": [{\"name\": \"Run lvmfilter role\", \"include_role\": {\"name\": \"tripleo_lvmfilter\"}, \"when\": [\"step|int == 1\"]}], \"ansible_group_vars\": {\"get_attr\": [\"RoleParametersValue\", \"value\"]}, \"puppet_config\": {\"config_volume\": \"iscsid\", \"puppet_tags\": \"iscsid_config\", \"step_config\": \"include tripleo::profile::base::iscsid\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerIscsidConfigImage\"]}, \"volumes\": [\"/etc/iscsi:/tmp/iscsi.host:z\"]}, \"kolla_config\": {\"/var/lib/kolla/config_files/iscsid.json\": {\"command\": \"/usr/sbin/iscsid -f\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src-iscsid/\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_3\": {\"iscsid\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerIscsidImage\"]}, \"net\": \"host\", \"privileged\": true, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/iscsid.json:/var/lib/kolla/config_files/config.json:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", \"/etc/target:/etc/target:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create fcontext entry for iscsi\", \"community.general.sefcontext\": {\"target\": \"{{ item.path }}(/.*)?\", \"setype\": \"{{ item.setype }}\", \"state\": \"present\"}, \"with_items\": [{\"path\": \"/etc/iscsi\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/target\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/iscsi\", \"setype\": \"container_file_t\"}]}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\"}, \"with_items\": [{\"path\": \"/etc/iscsi\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/target\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/iscsi\", \"setype\": \"container_file_t\"}]}, {\"name\": \"stat /lib/systemd/system/iscsid.socket\", \"stat\": \"path=/lib/systemd/system/iscsid.socket\", \"register\": \"stat_iscsid_socket\"}, {\"name\": \"Stop and disable iscsid.socket service\", \"service\": \"name=iscsid.socket state=stopped enabled=no\", \"when\": \"stat_iscsid_socket.stat.exists\"}, {\"name\": \"Check if iscsi.service is enabled\", \"command\": \"systemctl is-enabled --quiet iscsi.service\", \"failed_when\": false, \"register\": \"iscsi_service_enabled_result\"}, {\"name\": \"Stop iscsi.service\", \"service\": \"name=iscsi.service state=stopped enabled=no\", \"when\": [\"iscsi_service_enabled_result is changed\", \"iscsi_service_enabled_result.rc == 0\"]}], \"upgrade_tasks\": []}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(75,'2026-06-12 08:26:00',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(76,'2026-06-12 08:26:00',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized HAProxy API service\\n\", \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": null}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_1\": {}}}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": null}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(77,'2026-06-12 08:26:00',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(78,'2026-06-12 08:26:00',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Nova Conductor service\\n\", \"parameters\": {\"ContainerNovaConductorImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\"}, \"ContainerNovaConfigImage\": {\"description\": \"The container image to use for the nova config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\"}, \"NovaConductorLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.nova.conductor\", \"file\": \"/var/log/containers/nova/nova-conductor.log\"}}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1781252715, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"NovaWorkers\": {\"default\": 1, \"description\": \"Number of workers for Nova services.\", \"type\": \"number\"}, \"MonitoringSubscriptionNovaConductor\": {\"default\": \"overcloud-nova-conductor\", \"type\": \"string\"}, \"NovaPassword\": {\"description\": \"The password for the nova service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"1Ii49H1EfmLUfEWsgfy9vla3q\"}, \"NovaAdditionalCell\": {\"default\": true, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}}, \"conditions\": {\"nova_workers_set\": {\"not\": {\"equals\": [{\"get_param\": \"NovaWorkers\"}, 0]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"NovaLogging\": {\"type\": \"OS::TripleO::Services::Logging::NovaCommon\", \"properties\": {\"ContainerNovaImage\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaConductorImage\"]}, \"NovaServiceName\": \"conductor\"}}, \"NovaBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"NovaApiDBClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"NovaDBClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerNovaConductorImage\": \"ContainerNovaConductorImage\", \"ContainerNovaConfigImage\": \"ContainerNovaConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerNovaConductorImage\": {\"get_param\": \"ContainerNovaConductorImage\"}, \"ContainerNovaConfigImage\": {\"get_param\": \"ContainerNovaConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova Conductor service.\", \"value\": {\"service_name\": \"nova_conductor\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionNovaConductor\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"NovaBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"NovaApiDBClient\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"NovaDBClient\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"NovaLogging\", \"config_settings\"]}, {\"if\": [\"nova_workers_set\", {\"nova::conductor::workers\": {\"get_param\": \"NovaWorkers\"}}]}]}, \"service_config_settings\": {\"rabbitmq\": {\"get_attr\": [\"NovaBase\", \"role_data\", \"service_config_settings\"], \"rabbitmq\": null}, \"mysql\": {\"map_merge\": [{\"get_attr\": [\"NovaApiDBClient\", \"role_data\", \"service_config_settings\", \"mysql\"]}, {\"get_attr\": [\"NovaDBClient\", \"role_data\", \"service_config_settings\", \"mysql\"]}]}, \"rsyslog\": {\"tripleo_logging_sources_nova_conductor\": [{\"get_param\": \"NovaConductorLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"nova\", \"puppet_tags\": \"nova_config\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::nova::conductor\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/nova_conductor.json\": {\"command\": {\"list_join\": [\" \", [\"/usr/bin/nova-conductor\", {\"get_attr\": [\"NovaLogging\", \"cmd_extra_args\"]}]]}, \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/nova\", \"owner\": \"nova:nova\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/nova_conductor_db_sync.json\": {\"command\": {\"str_replace\": {\"template\": \"/usr/bin/bootstrap_host_exec nova_conductor su nova -s /bin/bash -c \'/usr/bin/nova-manage db sync DB_SYNC_ARGS\'\", \"params\": {\"if\": [{\"get_param\": \"NovaAdditionalCell\"}, {\"DB_SYNC_ARGS\": \"--local_cell\"}, {\"DB_SYNC_ARGS\": \"\"}]}}}, \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/nova\", \"owner\": \"nova:nova\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"NovaLogging\", \"docker_config\", \"step_2\"]}, \"step_3\": {\"nova_db_sync\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaConductorImage\"]}, \"cap_add\": [\"AUDIT_WRITE\"], \"start_order\": 3, \"net\": \"host\", \"detach\": false, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/nova_conductor_db_sync.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/nova:/var/lib/kolla/config_files/src:ro\"]]}, \"user\": \"root\", \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}, \"step_4\": {\"nova_conductor\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaConductorImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"get_attr\": [\"ContainersCommon\", \"healthcheck_rpc_port\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/nova_conductor.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/nova:/var/lib/kolla/config_files/src:ro\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"deploy_steps_tasks\": [{\"name\": \"validate nova-conductor container state\", \"containers.podman.podman_container_info\": {\"name\": \"nova_conductor\"}, \"register\": \"nova_conductor_infos\", \"failed_when\": [\"nova_conductor_infos.containers.0.Healthcheck.Status is defined\", \"\'healthy\' not in nova_conductor_infos.containers.0.Healthcheck.Status\"], \"retries\": 10, \"delay\": 30, \"tags\": [\"opendev-validation\", \"opendev-validation-nova\"], \"when\": [\"container_cli == \'podman\'\", \"not container_healthcheck_disabled\", \"step|int == 5\"]}], \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"NovaLogging\", \"host_prep_tasks\"]}, [{\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}]]}, \"external_upgrade_tasks\": [{\"when\": \"step|int == 1\", \"block\": [{\"name\": \"Set facts for running online DB migrations\", \"set_fact\": {\"is_additional_cell\": {\"get_param\": \"NovaAdditionalCell\"}}, \"tags\": [\"online_upgrade\", \"online_upgrade_nova\"]}, {\"name\": \"Online data migration for Nova\", \"when\": \"not is_additional_cell|bool\", \"command\": \"{{ container_cli }} exec nova_conductor nova-manage db online_data_migrations\", \"delegate_to\": \"{{ (groups[\'nova_conductor\'] | difference(groups[\'excluded_overcloud\']))[0] }}\", \"become\": true, \"tags\": [\"online_upgrade\", \"online_upgrade_nova\"]}]}, {\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop nova conductor container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"nova_conductor\"], \"tripleo_delegate_to\": \"{{ groups[\'nova_conductor\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}], \"external_update_tasks\": [{\"when\": \"step|int == 1\", \"block\": [{\"name\": \"Set facts for running online DB migrations\", \"set_fact\": {\"is_additional_cell\": {\"get_param\": \"NovaAdditionalCell\"}}, \"tags\": [\"online_upgrade\", \"online_upgrade_nova\"]}, {\"name\": \"Online data migration for Nova\", \"when\": \"not is_additional_cell|bool\", \"command\": \"{{ container_cli }} exec nova_conductor nova-manage db online_data_migrations\", \"delegate_to\": \"{{ (groups[\'nova_conductor\'] | difference(groups[\'excluded_overcloud\']))[0] }}\", \"become\": true, \"tags\": [\"online_upgrade\", \"online_upgrade_nova\"]}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(79,'2026-06-12 08:26:00',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Modular Libvirt Service\\n\", \"parameters\": {\"ContainerNovaLibvirtImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\"}, \"ContainerNovaLibvirtConfigImage\": {\"description\": \"The container image to use for the nova_libvirt config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\"}, \"ContainerNovaLibvirtUlimit\": {\"default\": [\"nofile=131072\", \"nproc=126960\"], \"description\": \"ulimit for Nova Libvirt Container\", \"type\": \"comma_delimited_list\"}, \"ContainerNovaLibvirtPidsLimit\": {\"default\": 65536, \"description\": \"Tune nova_libvirt container PID limit (set to 0 for unlimited) (defaults to 65536)\", \"type\": \"number\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"UseCustomGnuTlsQemuCryptoPolicy\": {\"type\": \"boolean\", \"default\": false, \"description\": \"If set to true, will use CustomGnuTlsQemuCryptoPolicy in crypto policy.\"}, \"CustomGnuTlsQemuCryptoPolicy\": {\"default\": \"QEMU=NONE:+ECDHE-RSA:+ECDHE-ECDSA:+RSA:+DHE-RSA:+GROUP-X25519:+GROUP-X448:+GROUP-SECP256R1:+GROUP-SECP384R1:+GROUP-SECP521R1:+GROUP-FFDHE2048:+GROUP-FFDHE3072:+GROUP-FFDHE4096:+GROUP-FFDHE6144:+GROUP-FFDHE8192:+CHACHA20-POLY1305:+AEAD:+SHA1:+SHA512:+SIGN-ECDSA-SHA256:+SIGN-ECDSA-SECP256R1-SHA256:+SIGN-ECDSA-SHA384:+SIGN-ECDSA-SECP384R1-SHA384:+SIGN-ECDSA-SHA512:+SIGN-ECDSA-SECP521R1-SHA512:+SIGN-EdDSA-Ed25519:+SIGN-EdDSA-Ed448:+SIGN-RSA-PSS-SHA256:+SIGN-RSA-PSS-SHA384:+SIGN-RSA-PSS-SHA512:+SIGN-RSA-PSS-RSAE-SHA256:+SIGN-RSA-PSS-RSAE-SHA384:+SIGN-RSA-PSS-RSAE-SHA512:+SIGN-RSA-SHA256:+SIGN-RSA-SHA384:+SIGN-RSA-SHA512:+VERS-TLS1.3:+VERS-TLS1.2:+VERS-DTLS1.2\", \"description\": \"Custom GnuTls Crypto Policy for QEMU\", \"type\": \"string\"}, \"UseTLSTransportForLiveMigration\": {\"type\": \"boolean\", \"default\": true, \"description\": \"If set to true and if EnableInternalTLS is enabled, it will set the libvirt URI\'s transport to tls and configure the relevant keys for libvirt.\"}, \"NovaEnableRbdBackend\": {\"default\": false, \"description\": \"Whether to enable the Rbd backend for Nova ephemeral storage.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"CinderEnableRbdBackend\": {\"default\": false, \"description\": \"Whether to enable or not the Rbd backend for Cinder\", \"type\": \"boolean\"}, \"CephClientKey\": {\"description\": \"The Ceph client key. Can be created with ceph-authtool --gen-print-key.\", \"type\": \"string\", \"hidden\": true, \"constraints\": [{\"allowed_pattern\": \"^[a-zA-Z0-9+/]{38}==$\"}], \"default\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\"}, \"CephClusterFSID\": {\"type\": \"string\", \"description\": \"The Ceph cluster FSID. Must be a UUID.\", \"default\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CinderRbdMultiConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring multiple RBD backends. The\\nhash key is the backend name, and the value is a dictionary of parameter\\nvalues unique to that backend. The following parameters are required,\\nand must match the corresponding value defined in CephExternalMultiConfig.\\n  CephClusterName (must match the CephExternalMultiConfig entry\'s \'cluster\')\\n  CephClusterFSID (must match the CephExternalMultiConfig entry\'s \'fsid\')\\nThe following parameters are optional, and override the corresponding\\nparameter\'s default value.\\n  CephClientUserName\\n  CinderRbdPoolName\\n  CinderRbdExtraPools\\n  CinderRbdAvailabilityZone\\n  CinderRbdFlattenVolumeFromSnapshot\\n\"}, \"UseTLSTransportForVnc\": {\"type\": \"boolean\", \"default\": true, \"description\": \"If set to true and if EnableInternalTLS is enabled, it will enable TLS transaport for libvirt VNC and configure the relevant keys for libvirt.\"}, \"UseTLSTransportForNbd\": {\"type\": \"boolean\", \"default\": true, \"description\": \"If set to true and if EnableInternalTLS is enabled, it will enable TLS transaport for libvirt NBD and configure the relevant keys for libvirt.\"}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"LibvirtCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"QemuServerCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"QemuClientCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"LibvirtCACert\": {\"type\": \"string\", \"default\": \"\", \"description\": \"This specifies the CA certificate to use for TLS in libvirt. This file will be symlinked to the default CA path in libvirt, which is /etc/pki/CA/cacert.pem. Note that due to limitations GNU TLS, which is the TLS backend for libvirt, the file must be less than 65K (so we can\'t use the system\'s CA bundle). This parameter should be used if the default (which comes from the InternalTLSCAFile parameter) is not desired. The current default reflects TripleO\'s default CA, which is FreeIPA. It will only be used if internal TLS is enabled.\"}, \"QemuCACert\": {\"type\": \"string\", \"default\": \"\", \"description\": \"This specifies the CA certificate to use for qemu. This file will be symlinked to the default CA path, which is /etc/pki/qemu/ca-cert.pem. This parameter should be used if the default (which comes from the InternalTLSCAFile parameter) is not desired. The current default reflects TripleO\'s default CA, which is FreeIPA. It will only be used if internal TLS is enabled.\"}, \"VhostuserSocketGroup\": {\"default\": \"qemu\", \"description\": \"The vhost-user socket directory group name. Defaults to \'qemu\'. When vhostuser mode is \'dpdkvhostuserclient\' (which is the default mode), the vhost socket is created by qemu.\\n\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"QemuMemoryBackingDir\": {\"type\": \"string\", \"description\": \"Directory used for memoryBacking source if configured as file. NOTE: big files will be stored here\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaComputeLibvirtType\": {\"type\": \"string\", \"default\": \"qemu\"}, \"LibvirtEnabledPerfEvents\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"This is a performance event list which could be used as monitor. For example - ``enabled_perf_events = cmt, mbml, mbmt`` The supported events list can be found in https://libvirt.org/html/libvirt-libvirt-domain.html , which you may need to search key words ``VIR_PERF_PARAM_*``\"}, \"MonitoringSubscriptionNovaLibvirt\": {\"default\": \"overcloud-nova-libvirt\", \"type\": \"string\"}, \"MigrationSshKey\": {\"type\": \"json\", \"description\": \"SSH key for migration. Expects a dictionary with keys \'public_key\' and \'private_key\'. Values should be identical to SSH public/private key files.\\n\", \"default\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}}, \"MigrationSshPort\": {\"default\": 2022, \"description\": \"Target port for migration over ssh\", \"type\": \"number\"}, \"LibvirtTLSPassword\": {\"description\": \"The password for the libvirt service when TLS is enabled\", \"type\": \"string\", \"hidden\": true, \"default\": \"2CigqEmSelPTodxLFsXPpqGIh\"}, \"QemuDefaultTLSVerify\": {\"description\": \"Whether to enable or disable TLS client certificate verification. Enabling this option will reject any client who does not have a certificate signed by the CA in /etc/pki/qemu/ca-cert.pem\\n\", \"default\": true, \"type\": \"boolean\"}, \"LibvirtLogFilters\": {\"description\": \"Defines a filter in libvirt daemon to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:libvirt 1:qemu 1:conf 1:security 3:event 3:json 3:file 3:object 1:util\"}, \"LibvirtVirtlogdLogFilters\": {\"description\": \"Defines a filter in virtlogd to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:logging 4:object 4:json 4:event 1:util\"}, \"LibvirtVirtsecretdLogFilters\": {\"description\": \"Defines a filter in virtsecretd to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\"}, \"LibvirtVirtnodedevdLogFilters\": {\"description\": \"Defines a filter in virtnodedevd to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\"}, \"LibvirtVirtstoragedLogFilters\": {\"description\": \"Defines a filter in virtstoraged to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\"}, \"LibvirtVirtqemudLogFilters\": {\"description\": \"Defines a filter in virtqemud to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\"}, \"LibvirtVirtproxydLogFilters\": {\"description\": \"Defines a filter in virtproxyd to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\"}, \"LibvirtTLSPriority\": {\"description\": \"Override the compile time default TLS priority string.\\n\", \"type\": \"string\", \"default\": \"NORMAL:-VERS-SSL3.0:-VERS-TLS-ALL:+VERS-TLS1.2\"}, \"NovaLibvirtOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"NovaEnableVirtlogdContainerWrapper\": {\"description\": \"Generate a virtlogd wrapper script so that virtlogd launches in a separate container and won\'t get restarted e.g. on minor updates.\", \"type\": \"boolean\", \"default\": true}, \"VirtlogdWrapperDebug\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Controls debugging for the wrapper scripts.\"}, \"DeployIdentifier\": {\"default\": 1781252715, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"RbdDiskCachemodes\": {\"type\": \"comma_delimited_list\", \"default\": [\"network=writeback\"], \"description\": \"Disk cachemodes for RBD backend.\\n\"}}, \"conditions\": {\"use_tls_for_live_migration\": {\"and\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"UseTLSTransportForLiveMigration\"}]}, \"libvirt_specific_ca_set\": {\"not\": {\"equals\": [{\"get_param\": \"LibvirtCACert\"}, \"\"]}}, \"need_libvirt_secret\": {\"or\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaEnableRbdBackend\"]}, true]}, {\"and\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaEnableRbdBackend\"]}, \"\"]}, {\"equals\": [{\"get_param\": \"NovaEnableRbdBackend\"}, true]}]}, {\"get_param\": \"CinderEnableRbdBackend\"}]}, \"use_tls_for_vnc\": {\"and\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"UseTLSTransportForVnc\"}]}, \"libvirt_vnc_specific_ca_set\": {\"not\": {\"equals\": [{\"get_param\": \"LibvirtVncCACert\"}, \"\"]}}, \"use_tls_for_nbd\": {\"and\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"UseTLSTransportForNbd\"}]}, \"qemu_specific_ca_set\": {\"not\": {\"equals\": [{\"get_param\": \"QemuCACert\"}, \"\"]}}, \"key_size_libvirt_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"LibvirtCertificateKeySize\"}, \"\"]}}, \"key_size_qemu_client_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"QemuClientCertificateKeySize\"}, \"\"]}}, \"key_size_qemu_server_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"QemuServerCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"vhostuser_socket_group\": \"VhostuserSocketGroup\", \"nova_libvirt_opt_volumes\": \"NovaLibvirtOptVolumes\", \"ContainerNovaLibvirtImage\": \"ContainerNovaLibvirtImage\", \"ContainerNovaLibvirtConfigImage\": \"ContainerNovaLibvirtConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"VhostuserSocketGroup\": {\"get_param\": \"VhostuserSocketGroup\"}, \"NovaLibvirtOptVolumes\": {\"get_param\": \"NovaLibvirtOptVolumes\"}, \"ContainerNovaLibvirtImage\": {\"get_param\": \"ContainerNovaLibvirtImage\"}, \"ContainerNovaLibvirtConfigImage\": {\"get_param\": \"ContainerNovaLibvirtConfigImage\"}}}]}}}, \"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"NovaLibvirtLogging\": {\"type\": \"OS::TripleO::Services::Logging::NovaLibvirt\"}, \"NovaBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"NovaLibvirtCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-common.yaml\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Libvirt service.\", \"value\": {\"service_name\": \"nova_libvirt\", \"firewall_rules\": {\"200 nova_libvirt\": {\"dport\": [16514, \"61152-61215\", \"5900-6923\"]}}, \"ansible_group_vars\": {\"tripleo_nova_libvirt_virsh_container\": \"nova_virtproxyd\"}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionNovaLibvirt\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"NovaBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"config_settings\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"config_settings\"]}, {\"nova::compute::libvirt::manage_libvirt_services\": false, \"tripleo::profile::base::nova::virtlogd_wrapper::enable_wrapper\": {\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"tripleo::profile::base::nova::virtlogd_wrapper::virtlogd_process_wrapper\": \"/var/lib/container-config-scripts/virtlogd_wrapper\", \"tripleo::profile::base::nova::virtlogd_wrapper::virtlogd_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"tripleo::profile::base::nova::virtlogd_wrapper::debug\": {\"if\": [{\"get_param\": \"VirtlogdWrapperDebug\"}, true, {\"get_attr\": [\"NovaBase\", \"role_data\", \"config_settings\", \"nova::logging::debug\"]}]}, \"nova::compute::libvirt::migration_support\": false, \"nova::compute::rbd::libvirt_images_rbd_ceph_conf\": {\"list_join\": [\"\", [\"/etc/ceph/\", {\"get_param\": \"CephClusterName\"}, \".conf\"]]}, \"nova::compute::rbd::libvirt_rbd_user\": {\"get_param\": \"CephClientUserName\"}, \"tripleo::profile::base::nova::compute_libvirt_shared::nova_rbd_ceph_conf_path\": {\"get_param\": \"CephConfigPath\"}, \"nova::compute::rbd::rbd_keyring\": {\"list_join\": [\".\", [\"client\", {\"get_param\": \"CephClientUserName\"}]]}, \"nova::compute::rbd::libvirt_rbd_secret_key\": {\"get_param\": \"CephClientKey\"}, \"nova::compute::rbd::libvirt_rbd_secret_uuid\": {\"get_param\": \"CephClusterFSID\"}, \"tripleo::profile::base::nova::migration::client::libvirt_enabled\": true, \"tripleo::profile::base::nova::migration::client::ssh_private_key\": {\"get_param\": [\"MigrationSshKey\", \"private_key\"]}, \"tripleo::profile::base::nova::migration::client::ssh_port\": {\"get_param\": \"MigrationSshPort\"}, \"nova::compute::libvirt::services::libvirt_virt_type\": {\"get_param\": \"NovaComputeLibvirtType\"}, \"nova::compute::libvirt::virt_type\": {\"get_param\": \"NovaComputeLibvirtType\"}, \"nova::compute::libvirt::enabled_perf_events\": {\"get_param\": \"LibvirtEnabledPerfEvents\"}, \"nova::compute::libvirt::qemu::configure_qemu\": true, \"nova::compute::libvirt::qemu::max_files\": 32768, \"nova::compute::libvirt::qemu::max_processes\": 131072, \"nova::migration::qemu::configure_qemu\": true, \"nova::migration::qemu::migration_port_min\": 61152, \"nova::migration::qemu::migration_port_max\": 61215, \"nova::compute::libvirt::vncserver_listen\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"nova::compute::libvirt::log_filters\": {\"get_param\": \"LibvirtLogFilters\"}, \"nova::compute::libvirt::virtlogd::log_filters\": {\"get_param\": \"LibvirtVirtlogdLogFilters\"}, \"rbd_persistent_storage\": {\"get_param\": \"CinderEnableRbdBackend\"}, \"rbd_disk_cachemodes\": {\"get_param\": \"RbdDiskCachemodes\"}, \"nova::compute::libvirt::virtsecretd::log_filters\": {\"get_param\": \"LibvirtVirtsecretdLogFilters\"}, \"nova::compute::libvirt::virtnodedevd::log_filters\": {\"get_param\": \"LibvirtVirtnodedevdLogFilters\"}, \"nova::compute::libvirt::virtstoraged::log_filters\": {\"get_param\": \"LibvirtVirtstoragedLogFilters\"}, \"nova::compute::libvirt::virtqemud::log_filters\": {\"get_param\": \"LibvirtVirtqemudLogFilters\"}, \"nova::compute::libvirt::virtproxyd::log_filters\": {\"get_param\": \"LibvirtVirtproxydLogFilters\"}, \"tripleo::profile::base::nova::libvirt::modular_libvirt\": true, \"nova::compute::libvirt::services::modular_libvirt\": true, \"nova::compute::libvirt::modular_libvirt\": true, \"nova::migration::libvirt::modular_libvirt\": true}, {\"if\": [\"use_tls_for_live_migration\", {\"tripleo::profile::base::nova::migration::client::libvirt_tls\": true, \"tripleo::profile::base::nova::libvirt::tls_password\": {\"get_param\": [\"LibvirtTLSPassword\"]}, \"nova::compute::libvirt::qemu::default_tls_verify\": {\"get_param\": \"QemuDefaultTLSVerify\"}, \"nova::compute::libvirt::tls_priority\": {\"get_param\": \"LibvirtTLSPriority\"}, \"nova::migration::libvirt::listen_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"nova::migration::libvirt::live_migration_inbound_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}}, {\"nova::migration::libvirt::live_migration_inbound_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}}]}, {\"if\": [\"use_tls_for_vnc\", {\"nova::compute::libvirt::qemu::vnc_tls\": true, \"nova::compute::libvirt::qemu::vnc_tls_verify\": true}]}, {\"if\": [\"use_tls_for_nbd\", {\"nova::compute::libvirt::qemu::nbd_tls\": true, \"nova::migration::libvirt::live_migration_with_native_tls\": true}]}]}, \"puppet_config\": {\"config_volume\": \"nova_libvirt\", \"puppet_tags\": \"libvirtd_config,virtlogd_config,virtproxyd_config,virtqemud_config,virtnodedevd_config,virtsecretd_config,virtstoraged_config,nova_config,file,libvirt_tls_password\", \"step_config\": \"include tripleo::profile::base::nova::libvirt\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/nova_virtlogd.json\": {\"command\": {\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"/usr/local/bin/virtlogd_wrapper\", \"/usr/sbin/virtlogd --config /etc/libvirt/virtlogd.conf\"]}, \"config_files\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_permissions\"]}}, \"/var/lib/kolla/config_files/nova_virtsecretd.json\": {\"command\": \"/usr/sbin/virtsecretd --config /etc/libvirt/virtsecretd.conf\", \"config_files\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_permissions\"]}}, \"/var/lib/kolla/config_files/nova_virtnodedevd.json\": {\"command\": \"/usr/sbin/virtnodedevd --config /etc/libvirt/virtnodedevd.conf\", \"config_files\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_permissions\"]}}, \"/var/lib/kolla/config_files/nova_virtstoraged.json\": {\"command\": \"/usr/sbin/virtstoraged --config /etc/libvirt/virtstoraged.conf\", \"config_files\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_permissions\"]}}, \"/var/lib/kolla/config_files/nova_virtqemud.json\": {\"command\": \"/usr/sbin/virtqemud --config /etc/libvirt/virtqemud.conf\", \"config_files\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_permissions\"]}}, \"/var/lib/kolla/config_files/nova_virtproxyd.json\": {\"command\": \"/usr/sbin/virtproxyd --config /etc/libvirt/virtproxyd.conf\", \"config_files\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_permissions\"]}}}, \"container_config_scripts\": {\"nova_libvirt_init_secret.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/nova_libvirt_init_secret.sh\"}}}, \"docker_config\": {\"step_2\": {\"nova_virtqemud_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"net\": \"none\", \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"user\": \"root\", \"volumes\": [\"/var/log/containers/libvirt/swtpm:/var/log/swtpm:shared,z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R tss:tss /var/log/swtpm\"], \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}, \"create_virtlogd_wrapper\": {\"start_order\": 1, \"detach\": false, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"user\": \"root\", \"command\": {\"list_concat\": [[\"/container_puppet_apply.sh\", \"4\", \"file\", \"include ::tripleo::profile::base::nova::virtlogd_wrapper\"]]}, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"container_puppet_apply_volumes\"]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:shared,z\"]]}, \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}, \"step_3\": {\"map_merge\": [{\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, {\"nova_virtlogd_wrapper\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtlogd.json:/var/lib/kolla/config_files/config.json:ro\"], {\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, [\"/var/lib/container-config-scripts/virtlogd_wrapper:/usr/local/bin/virtlogd_wrapper:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}, {\"nova_virtlogd\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtlogd.json:/var/lib/kolla/config_files/config.json:ro\"], {\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, [\"/var/lib/container-config-scripts/virtlogd_wrapper:/usr/local/bin/virtlogd_wrapper:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}]}, {\"nova_virtsecretd\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"pids_limit\": {\"get_param\": \"ContainerNovaLibvirtPidsLimit\"}, \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"depends_on\": [{\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"tripleo_nova_virtlogd_wrapper.service\", \"tripleo_nova_virtlogd.service\"]}], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_libvirt_opt_volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtsecretd.json:/var/lib/kolla/config_files/config.json:ro\"]]}}}, {\"nova_virtnodedevd\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"pids_limit\": {\"get_param\": \"ContainerNovaLibvirtPidsLimit\"}, \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"depends_on\": [{\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"tripleo_nova_virtlogd_wrapper.service\", \"tripleo_nova_virtlogd.service\"]}], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_libvirt_opt_volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtnodedevd.json:/var/lib/kolla/config_files/config.json:ro\"]]}}}, {\"nova_virtstoraged\": {\"start_order\": 3, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"pids_limit\": {\"get_param\": \"ContainerNovaLibvirtPidsLimit\"}, \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"depends_on\": [{\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"tripleo_nova_virtlogd_wrapper.service\", \"tripleo_nova_virtlogd.service\"]}], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_libvirt_opt_volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtstoraged.json:/var/lib/kolla/config_files/config.json:ro\"]]}}}, {\"nova_virtqemud\": {\"start_order\": 4, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"pids_limit\": {\"get_param\": \"ContainerNovaLibvirtPidsLimit\"}, \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"depends_on\": [{\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"tripleo_nova_virtlogd_wrapper.service\", \"tripleo_nova_virtlogd.service\"]}], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_libvirt_opt_volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtqemud.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/log/containers/libvirt/swtpm:/var/log/swtpm:z\", {\"if\": [{\"get_param\": \"UseCustomGnuTlsQemuCryptoPolicy\"}, \"/etc/crypto-policies:/etc/crypto-policies:ro\"]}]]}}}, {\"nova_virtproxyd\": {\"start_order\": 5, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"pids_limit\": {\"get_param\": \"ContainerNovaLibvirtPidsLimit\"}, \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"depends_on\": [{\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"tripleo_nova_virtlogd_wrapper.service\", \"tripleo_nova_virtlogd.service\"]}], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_libvirt_opt_volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtproxyd.json:/var/lib/kolla/config_files/config.json:ro\"]]}}}]}, \"step_4\": {\"if\": [\"need_libvirt_secret\", {\"nova_libvirt_init_secret\": {\"detach\": false, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"security_opt\": [\"label=disable\"], \"privileged\": false, \"user\": \"root\", \"cgroupns\": \"host\", \"net\": \"host\", \"environment\": {\"LIBVIRT_DEFAULT_URI\": \"qemu:///system\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/nova_libvirt/etc/nova:/etc/nova\", \"/etc/libvirt:/etc/libvirt\", \"/run/libvirt:/run/libvirt:shared,z\", \"/var/lib/libvirt:/var/lib/libvirt:shared\", \"/var/lib/container-config-scripts/nova_libvirt_init_secret.sh:/nova_libvirt_init_secret.sh:ro\", {\"str_replace\": {\"template\": \"HOST_CEPH:/etc/ceph:ro\", \"params\": {\"HOST_CEPH\": {\"get_param\": \"CephConfigPath\"}}}}]]}, \"command\": {\"list_join\": [\" \", [{\"str_replace\": {\"template\": \"/nova_libvirt_init_secret.sh CLUSTER:USER\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}], {\"repeat\": {\"template\": \"<%ceph_info%>\", \"for_each\": {\"<%ceph_info%>\": {\"yaql\": {\"expression\": \"let(u => $.data.default_user) -> $.data.multiconfig.values().select($.CephClusterName + \\\":\\\" + $.get(\\\"CephClientUserName\\\", $u))\", \"data\": {\"default_user\": {\"get_param\": \"CephClientUserName\"}, \"multiconfig\": {\"get_param\": \"CinderRbdMultiConfig\"}}}}}}}]}}}]}}, \"deploy_steps_tasks\": {\"list_concat\": [[{\"name\": \"Ensure recovery of containerized virtqemud\", \"when\": \"step|int == 4\", \"become\": true, \"block\": [{\"name\": \"Create virtqemud recovery script\", \"copy\": {\"dest\": \"/usr/libexec/recover_tripleo_nova_virtqemud.sh\", \"mode\": \"0755\", \"content\": \"#!/bin/bash\\npgrep -f /sbin/virtqemud\\n[ $? -eq 0 ] && exit 0\\nkill -9 $(cat /run/nova_virtqemud.pid)\\n\"}}, {\"name\": \"Create virtqemud recovery trigger service\", \"copy\": {\"dest\": \"/etc/systemd/system/tripleo_nova_virtqemud_recover.service\", \"mode\": \"0644\", \"content\": \"[Unit]\\nDescription=Check and recover tripleo_nova_virtqemud\\nAfter=tripleo_nova_virtqemud.service\\nRequisite=tripleo_nova_virtqemud.service\\n[Service]\\nType=oneshot\\nExecStart=bash /usr/libexec/recover_tripleo_nova_virtqemud.sh\\nSyslogIdentifier=recover_tripleo_nova_virtqemud\\n[Install]\\nWantedBy=multi-user.target\\n\"}}, {\"name\": \"Create virtqemud recovery trigger timer\", \"copy\": {\"dest\": \"/etc/systemd/system/tripleo_nova_virtqemud_recover.timer\", \"mode\": \"0644\", \"content\": \"[Unit]\\nDescription=Check and recover tripleo_nova_virtqemud every 10m\\nPartOf=tripleo_nova_virtqemud.service\\n[Timer]\\nOnCalendar=*:5/10\\nOnActiveSec=120\\nOnUnitActiveSec=60\\nRandomizedDelaySec=1m\\n[Install]\\nWantedBy=timers.target\\n\"}}, {\"name\": \"Enable virtqemud recovery trigger service\", \"systemd\": {\"name\": \"tripleo_nova_virtqemud_recover.service\", \"enabled\": true, \"daemon_reload\": true}}, {\"name\": \"Enable virtqemud recovery trigger timer\", \"systemd\": {\"name\": \"tripleo_nova_virtqemud_recover.timer\", \"enabled\": true, \"state\": \"restarted\", \"daemon_reload\": true}, \"register\": \"virtqemud_recover_timer_result\"}, {\"name\": \"Really enable virtqemud recovery trigger timer\", \"shell\": {\"cmd\": \"systemctl enable --now tripleo_nova_virtqemud_recover.timer\"}, \"when\": \"virtqemud_recover_timer_result.status.UnitFileState != \\\"enabled\\\"\"}]}], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [{\"name\": \"Certificate generation\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/libvirt\", \"/etc/pki/libvirt/private\", \"/etc/pki/qemu\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"libvirt-server-cert\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"libvirt/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"run_after\": {\"str_replace\": {\"template\": \"# Copy cert and key to libvirt dirs\\ncp CACERT /etc/pki/CA/cacert.pem\\nchown root:root /etc/pki/CA/cacert.pem\\nchmod 644 /etc/pki/CA/cacert.pem\\ncp /etc/pki/tls/certs/libvirt-server-cert.crt /etc/pki/libvirt/servercert.pem\\ncp /etc/pki/tls/private/libvirt-server-cert.key /etc/pki/libvirt/private/serverkey.pem\\npodman exec nova_virtproxyd virt-admin server-update-tls virtproxyd || systemctl reload tripleo_nova_virtproxyd\\n\", \"params\": {\"CACERT\": {\"if\": [\"libvirt_specific_ca_set\", {\"get_param\": \"LibvirtCACert\"}, {\"get_param\": \"InternalTLSCAFile\"}]}}}}, \"key_size\": {\"if\": [\"key_size_libvirt_override_set\", {\"get_param\": \"LibvirtCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, {\"name\": \"libvirt-client-cert\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"libvirt/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"run_after\": \"# Copy cert and key to libvirt dirs\\ncp /etc/pki/tls/certs/libvirt-client-cert.crt /etc/pki/libvirt/clientcert.pem\\ncp /etc/pki/tls/private/libvirt-client-cert.key /etc/pki/libvirt/private/clientkey.pem\\npodman exec nova_virtproxyd virt-admin server-update-tls virtproxyd || systemctl reload tripleo_nova_virtproxyd\\n\", \"key_size\": {\"if\": [\"key_size_libvirt_override_set\", {\"get_param\": \"LibvirtCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, {\"name\": \"qemu-server-cert\", \"owner\": \"root\", \"group\": \"qemu\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"qemu/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"run_after\": {\"str_replace\": {\"template\": \"# Copy cert and key to qemu dir\\ncp CACERT /etc/pki/qemu/ca-cert.pem\\nchown root:root /etc/pki/qemu/ca-cert.pem\\nchmod 644 /etc/pki/qemu/ca-cert.pem\\ncp -a /etc/pki/tls/certs/qemu-server-cert.crt /etc/pki/qemu/server-cert.pem\\ncp -a /etc/pki/tls/private/qemu-server-cert.key /etc/pki/qemu/server-key.pem\\nchgrp qemu /etc/pki/qemu/server-*\\nchmod 0640 /etc/pki/qemu/server-cert.pem\\nchmod 0640 /etc/pki/qemu/server-key.pem\\n\", \"params\": {\"CACERT\": {\"if\": [\"qemu_specific_ca_set\", {\"get_param\": \"QemuCACert\"}, {\"get_param\": \"InternalTLSCAFile\"}]}}}}, \"key_size\": {\"if\": [\"key_size_qemu_server_override_set\", {\"get_param\": \"QemuServerCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, {\"name\": \"qemu-client-cert\", \"owner\": \"root\", \"group\": \"qemu\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"qemu/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"run_after\": \"# Copy cert and key to qemu dir\\ncp -a /etc/pki/tls/certs/qemu-client-cert.crt /etc/pki/qemu/client-cert.pem\\ncp -a /etc/pki/tls/private/qemu-client-cert.key /etc/pki/qemu/client-key.pem\\nchgrp qemu /etc/pki/qemu/client-*\\nchmod 0640 /etc/pki/qemu/client-cert.pem\\nchmod 0640 /etc/pki/qemu/client-key.pem\\n\", \"key_size\": {\"if\": [\"key_size_qemu_client_override_set\", {\"get_param\": \"QemuClientCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}]]}, [{\"name\": \"Set up systemd target for libvirt services\", \"when\": \"step|int == 4\", \"block\": [{\"name\": \"Create systemd file\", \"copy\": {\"dest\": \"/etc/systemd/system/tripleo_nova_libvirt.target\", \"mode\": \"0644\", \"owner\": \"root\", \"group\": \"root\", \"content\": \"[Unit]\\nWants=tripleo_nova_virtsecretd.service\\nWants=tripleo_nova_virtnodedevd.service\\nWants=tripleo_nova_virtstoraged.service\\nWants=tripleo_nova_virtproxyd.service\\nWants=tripleo_nova_virtqemud.service\\nAfter=tripleo_nova_virtsecretd.service\\nAfter=tripleo_nova_virtnodedevd.service\\nAfter=tripleo_nova_virtstoraged.service\\nAfter=tripleo_nova_virtproxyd.service\\nAfter=tripleo_nova_virtqemud.service\\n\"}, \"become\": true, \"register\": \"libvirt_target_result\"}, {\"name\": \"Reload systemd\", \"systemd\": {\"name\": \"tripleo_nova_libvirt.target\", \"enabled\": true, \"state\": \"restarted\", \"daemon_reload\": true}, \"become\": true, \"when\": \"libvirt_target_result.changed\"}]}]]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"NovaLibvirtLogging\", \"host_prep_tasks\"]}, [{\"name\": \"create libvirt persistent data directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype | default(omit) }}\", \"mode\": \"{{ item.mode | default(omit) }}\"}, \"with_items\": [{\"path\": \"/etc/libvirt\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/libvirt/secrets\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/libvirt/qemu\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/libvirt\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/cache/libvirt\"}, {\"path\": \"/var/lib/nova\", \"setype\": \"container_file_t\"}, {\"path\": \"/run/libvirt\"}, {\"path\": \"/var/log/containers/libvirt/swtpm\", \"setype\": \"container_file_t\", \"mode\": \"0770\"}]}, {\"name\": \"ensure qemu group is present on the host\", \"group\": {\"name\": \"qemu\", \"gid\": 107, \"state\": \"present\"}}, {\"name\": \"ensure qemu user is present on the host\", \"user\": {\"name\": \"qemu\", \"uid\": 107, \"group\": \"qemu\", \"state\": \"present\", \"shell\": \"/sbin/nologin\", \"comment\": \"qemu user\"}}, {\"name\": \"create directory for vhost-user sockets with qemu ownership\", \"file\": {\"path\": \"/var/lib/vhost_sockets\", \"state\": \"directory\", \"owner\": \"qemu\", \"group\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"vhostuser_socket_group\"]}, \"setype\": \"virt_cache_t\", \"seuser\": \"system_u\"}}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}, {\"name\": \"check if libvirt is installed\", \"command\": \"/usr/bin/rpm -q libvirt-daemon\", \"failed_when\": false, \"register\": \"libvirt_installed\", \"check_mode\": false}, {\"name\": \"make sure libvirt services are disabled and masked\", \"service\": {\"name\": \"{{ item }}\", \"state\": \"stopped\", \"enabled\": false, \"masked\": true, \"daemon_reload\": true}, \"with_items\": [\"libvirtd.service\", \"virtlogd.socket\"], \"when\": \"libvirt_installed.rc == 0\"}, {\"name\": \"ensure /run/libvirt is present upon reboot\", \"copy\": {\"dest\": \"/etc/tmpfiles.d/run-libvirt.conf\", \"content\": \"d /run/libvirt 0755 root root - -\\n\"}}, {\"name\": \"Enable os_enable_vtpm SELinux boolean for vTPM\", \"seboolean\": {\"name\": \"os_enable_vtpm\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}, {\"if\": [{\"get_param\": \"UseCustomGnuTlsQemuCryptoPolicy\"}, [{\"name\": \"set gnutls_qemu_config_crypto_policy fact\", \"set_fact\": {\"gnutls_qemu_config_crypto_policy\": {\"get_param\": \"CustomGnuTlsQemuCryptoPolicy\"}}}, {\"name\": \"create gnutls-qemu.config\", \"copy\": {\"dest\": \"/etc/crypto-policies/local.d/gnutls-qemu.config\", \"mode\": \"0644\", \"owner\": \"root\", \"group\": \"root\", \"content\": \"{{ gnutls_qemu_config_crypto_policy }}\\n\"}, \"register\": \"update_gnutls_config\"}], [{\"name\": \"remove gnutls-qemu.config\", \"file\": {\"path\": \"/etc/crypto-policies/local.d/gnutls-qemu.config\", \"state\": \"absent\"}, \"register\": \"update_gnutls_config\"}]]}, {\"name\": \"update crypto policies\", \"command\": \"update-crypto-policies\", \"when\": \"update_gnutls_config.changed\"}]]}, \"metadata_settings\": {\"list_concat\": [{\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [{\"service\": \"libvirt\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}, \"type\": \"node\"}, {\"service\": \"qemu\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}, \"type\": \"node\"}, {\"service\": \"libvirt-vnc\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}, \"type\": \"node\"}]]}]}, \"upgrade_tasks\": {\"list_concat\": [[{\"name\": \"Fail if we are on RHEL8 as this is monolithic libvirt deployment\", \"when\": [\"step|int == 0\", \"\'system_upgrade\' not in ansible_run_tags\", \"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\"], \"fail\": {\"msg\": \"Use of the Modular Libvirt deployment on RHEL8 results in loss of workloads. Use NovaLibvirtLegacy in roles data.\"}}, {\"name\": \"nova_libvirt_container_tmpfile_cleanup\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Remove old tmpfiles.d config\", \"file\": {\"path\": \"/etc/tmpfiles.d/var-run-libvirt.conf\", \"state\": \"absent\"}}]}, {\"name\": \"Get container virtlogd image\", \"when\": \"step|int == 1\", \"tags\": \"always\", \"set_fact\": {\"virtlogd_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}}}, {\"name\": \"Force pull image novalibvirt\", \"when\": [\"step|int == 1\"], \"containers.podman.podman_image\": {\"name\": \"{{ virtlogd_image }}\", \"force\": true}}, {\"name\": \"Diff OS release in container image and baremetal\", \"when\": \"step|int == 1\", \"shell\": \"diff /etc/redhat-release <(podman run {{ virtlogd_image }} cat /etc/redhat-release)\\n\", \"args\": {\"executable\": \"/bin/bash\"}, \"failed_when\": false, \"register\": \"libvirt_ubi_diff\"}, {\"name\": \"Fail if UBI of the container does not match RHEL of running host\", \"when\": [\"\'system_upgrade\' not in ansible_run_tags\", \"step|int == 1\", \"libvirt_ubi_diff.rc == 1\"], \"fail\": {\"msg\": \"The host operating system versus container UBI does not match.\\n{{ libvirt_ubi_diff.stdout }}\\nMost likely container passed to NovaLibvirt was EL8 one.\\nYou have to pass the correct container for container-image-prepare.\\nIf you would continue all running workloads would get destroyed.\\n\"}}], {\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, [{\"name\": \"Switch virtlogd image before system upgrade\", \"when\": \"step|int == 1\", \"tags\": [\"never\", \"system_upgrade\"], \"block\": [{\"name\": \"Get running image version\", \"shell\": \"podman ps --filter name=^nova_virtlogd$ --format \\\"{% raw %}{{ .Image }}{% endraw %}\\\"\\n\", \"register\": \"old_virtlogd_image\"}, {\"name\": \"Switch running image to new image in wrapper script\", \"shell\": \"set -o pipefail\\nsed -i -e \'s|{{ old_virtlogd_image.stdout }}|{{ virtlogd_image }}|\' /var/lib/container-config-scripts/virtlogd_wrapper\\n\", \"when\": [\"old_virtlogd_image.stdout != virtlogd_image\", \"old_virtlogd_image.stdout != \'\'\"]}]}]]}]}, \"update_tasks\": {\"list_concat\": [{\"get_attr\": [\"NovaLibvirtCommon\", \"update_tasks\"]}, [{\"name\": \"nova_libvirt_container_tmpfile_cleanup\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Remove old tmpfiles.d config\", \"file\": {\"path\": \"/etc/tmpfiles.d/var-run-libvirt.conf\", \"state\": \"absent\"}}]}]]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(80,'2026-06-12 08:26:00',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": true, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"StorageIpList\": \"\", \"StorageMgmtIpList\": \"\", \"InternalApiIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,storage,storage_mgmt,internal_api\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (81,'2026-06-12 08:26:00',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Nova base service. Shared for all Nova services.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"NovaPassword\": {\"description\": \"The password for the nova service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"1Ii49H1EfmLUfEWsgfy9vla3q\"}, \"NeutronPassword\": {\"description\": \"The password for the neutron service and db account, used by neutron agents.\", \"type\": \"string\", \"hidden\": true, \"default\": \"qnvMdngIoyiS9ntQpzmg868ob\"}, \"PlacementPassword\": {\"description\": \"The password for the Placement service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\"}, \"PlacementAPIInterface\": {\"type\": \"string\", \"description\": \"Endpoint interface to be used for the placement API.\\n\", \"default\": \"internal\"}, \"NovaOVSBridge\": {\"default\": \"br-int\", \"description\": \"Name of integration bridge used by Open vSwitch\", \"type\": \"string\"}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"NovaDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Nova services.\", \"type\": \"boolean\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"EnableConfigPurge\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Remove configuration that is not generated by TripleO. Used to avoid configuration remnants after upgrades.\\n\"}, \"UpgradeLevelNovaCompute\": {\"type\": \"string\", \"description\": \"Nova Compute upgrade level\", \"default\": \"\"}, \"NovaOVSDBConnection\": {\"type\": \"string\", \"description\": \"OVS DB connection string to used by Nova\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaSyncPowerStateInterval\": {\"type\": \"number\", \"description\": \"Interval to sync power states between the database and the hypervisor. Set to -1 to disable. Setting this to 0 will run at the default rate(60) defined in oslo.service.\", \"default\": 600}, \"RpcUseSSL\": {\"default\": false, \"description\": \"Messaging client subscriber parameter to specify an SSL connection to the messaging host.\\n\", \"type\": \"string\"}, \"NovaAdditionalCell\": {\"default\": true, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"NovaCrossAZAttach\": {\"default\": true, \"description\": \"Whether instances can attach cinder volumes from a different availability zone.\", \"type\": \"boolean\"}, \"MemcachedTLS\": {\"default\": false, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"conditions\": {\"compute_upgrade_level_set\": {\"not\": {\"equals\": [{\"get_param\": \"UpgradeLevelNovaCompute\"}, \"\"]}}, \"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"nova::ovsdb_connection\": \"NovaOVSDBConnection\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NovaOVSDBConnection\": {\"get_param\": \"NovaOVSDBConnection\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova base service.\", \"value\": {\"service_name\": \"nova_base\", \"config_settings\": {\"map_merge\": [{\"nova::my_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}}}, \"nova::rabbit_use_ssl\": {\"get_param\": \"RpcUseSSL\"}, \"nova::keystone::service_user::send_service_user_token\": true, \"nova::keystone::service_user::project_name\": \"service\", \"nova::keystone::service_user::password\": {\"get_param\": \"NovaPassword\"}, \"nova::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::placement::project_name\": \"service\", \"nova::placement::password\": {\"get_param\": \"PlacementPassword\"}, \"nova::placement::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::placement::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::placement::valid_interfaces\": {\"get_param\": \"PlacementAPIInterface\"}, \"nova::os_region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::logging::debug\": {\"if\": [{\"get_param\": \"NovaDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"nova::purge_config\": {\"get_param\": \"EnableConfigPurge\"}, \"nova::network::neutron::project_name\": \"service\", \"nova::network::neutron::username\": \"neutron\", \"nova::network::neutron::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::dhcp_domain\": \"\", \"nova::network::neutron::password\": {\"get_param\": \"NeutronPassword\"}, \"nova::network::neutron::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"nova::network::neutron::valid_interfaces\": \"internal\", \"nova::glance::valid_interfaces\": \"internal\", \"nova::rabbit_heartbeat_timeout_threshold\": 60, \"nova::cinder_catalog_info\": \"volumev3:cinderv3:internalURL\", \"nova::host\": \"%{hiera(\'fqdn_canonical\')}\", \"nova::notify_on_state_change\": \"vm_and_task_state\", \"nova::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"nova::notification_format\": \"unversioned\", \"nova::network::neutron::auth_type\": \"v3password\", \"nova::db::database_db_max_retries\": -1, \"nova::db::database_max_retries\": -1, \"nova::network::neutron::ovs_bridge\": {\"get_param\": \"NovaOVSBridge\"}, \"nova::compute::sync_power_state_interval\": {\"get_param\": \"NovaSyncPowerStateInterval\"}, \"nova_is_additional_cell\": {\"get_param\": \"NovaAdditionalCell\"}, \"nova::cross_az_attach\": {\"get_param\": \"NovaCrossAZAttach\"}, \"nova::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"nova::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}, \"nova::cache::backend\": {\"if\": [\"tls_cache_enabled\", \"dogpile.cache.pymemcache\", \"dogpile.cache.memcached\"]}, \"nova::rabbit_heartbeat_in_pthread\": false, \"nova::upgrade_level_compute\": {\"if\": [\"compute_upgrade_level_set\", {\"get_param\": \"UpgradeLevelNovaCompute\"}]}}, {\"get_attr\": [\"RoleParametersValue\", \"value\"]}]}, \"service_config_settings\": {\"rabbitmq\": {\"nova::rabbit_use_ssl\": {\"get_param\": \"RpcUseSSL\"}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(82,'2026-06-12 08:26:00',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(83,'2026-06-12 08:26:01',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Ceilometer service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CeilometerMeteringSecret\": {\"description\": \"Secret shared by the ceilometer services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"EPgaQlmbDVmqQsiNdVrRly1ai\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\"}, \"AmqpRpcAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for RPC addresses\", \"type\": \"string\"}, \"AmqpNotifyAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for Notification addresses\", \"type\": \"string\"}, \"ManagePolling\": {\"default\": false, \"description\": \"Whether to manage polling.yaml.\", \"type\": \"boolean\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CeilometerDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Ceilometer services.\", \"type\": \"boolean\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"SnmpdReadonlyUserName\": {\"default\": \"ro_snmp_user\", \"description\": \"The user name for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\"}, \"SnmpdReadonlyUserPassword\": {\"description\": \"The user password for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\", \"hidden\": true, \"default\": \"KjPkLxPsqu3qjdbO0SJ0shPX\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"GnocchiArchivePolicy\": {\"default\": \"ceilometer-low-rate\", \"type\": \"string\", \"description\": \"(DEPRECATED) archive policy to use with gnocchi backend\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"MemcachedTLS\": {\"default\": false, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"GnocchiArchivePolicy\"]}], \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer role.\", \"value\": {\"service_name\": \"ceilometer_base\", \"config_settings\": {\"map_merge\": [{\"ceilometer::logging::debug\": {\"if\": [{\"get_param\": \"CeilometerDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"ceilometer::agent::polling::manage_polling\": {\"get_param\": \"ManagePolling\"}, \"ceilometer::agent::service_credentials::password\": {\"get_param\": \"CeilometerPassword\"}, \"ceilometer::agent::service_credentials::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"ceilometer::agent::service_credentials::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"ceilometer::agent::service_credentials::project_name\": \"service\", \"ceilometer::agent::service_credentials::user_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::auth_project_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::interface\": \"internalURL\", \"ceilometer::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"ceilometer::amqp_rpc_address_prefix\": {\"get_param\": \"AmqpRpcAddressPrefix\"}, \"ceilometer::amqp_notify_address_prefix\": {\"get_param\": \"AmqpNotifyAddressPrefix\"}, \"ceilometer::telemetry_secret\": {\"get_param\": \"CeilometerMeteringSecret\"}, \"ceilometer::snmpd_readonly_username\": {\"get_param\": \"SnmpdReadonlyUserName\"}, \"ceilometer::snmpd_readonly_user_password\": {\"get_param\": \"SnmpdReadonlyUserPassword\"}, \"ceilometer::host\": \"%{hiera(\'fqdn_canonical\')}\", \"ceilometer::rabbit_heartbeat_in_pthread\": false, \"ceilometer::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"ceilometer::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}}, {\"if\": [\"tls_cache_enabled\", {\"ceilometer::cache::backend\": \"dogpile.cache.pymemcache\", \"ceilometer::cache::enable_socket_keepalive\": true}, {\"ceilometer::cache::backend\": \"dogpile.cache.memcached\"}]}]}, \"service_config_settings\": {\"keystone\": {\"tripleo::profile::base::keystone::ceilometer_notification_topics\": [\"notifications\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(84,'2026-06-12 08:26:01',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"HAProxy deployment with TLS enabled, with an injected certificate\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"SSLCertificate\": {\"default\": \"\", \"description\": \"The content of the SSL certificate (without Key) in PEM format.\\n\", \"type\": \"string\"}, \"SSLIntermediateCertificate\": {\"default\": \"\", \"description\": \"The content of an SSL intermediate CA certificate in PEM format.\\n\", \"type\": \"string\"}, \"SSLKey\": {\"default\": \"\", \"description\": \"The content of the SSL Key in PEM format.\\n\", \"type\": \"string\", \"hidden\": true}, \"DeployedSSLCertificatePath\": {\"default\": \"/etc/pki/tls/private/overcloud_endpoint.pem\", \"description\": \"The filepath of the certificate as it will be stored in the controller.\\n\", \"type\": \"string\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the HAProxy public TLS injection.\", \"value\": {\"service_name\": \"haproxy_public_tls_inject\", \"config_settings\": {}, \"certificates_specs\": {}, \"metadata_settings\": null, \"host_prep_tasks\": [{\"name\": \"get parameters\", \"set_fact\": {\"cert_path\": {\"get_param\": \"DeployedSSLCertificatePath\"}, \"cert_content\": {\"get_param\": \"SSLCertificate\"}, \"chain_content\": {\"get_param\": \"SSLIntermediateCertificate\"}, \"key_content\": {\"get_param\": \"SSLKey\"}}, \"no_log\": \"{{ hide_sensitive_logs | bool }}\"}, {\"name\": \"manage certificate\", \"when\": [\"cert_content is defined\", \"cert_content != \'\'\"], \"block\": [{\"name\": \"get DeployedSSLCertificatePath attributes\", \"register\": \"attr_cert_path\", \"stat\": {\"path\": \"{{cert_path}}\"}}, {\"name\": \"set is_haproxy_bootstrap_node fact\", \"set_fact\": \"is_haproxy_bootstrap_node={{haproxy_short_bootstrap_node_name | lower == ansible_facts[\'hostname\'] | lower}}\", \"when\": [\"haproxy_short_bootstrap_node_name|default(false)\"]}, {\"name\": \"get haproxy status\", \"register\": \"haproxy_state\", \"systemd\": {\"name\": \"haproxy\"}}, {\"name\": \"get pacemaker status\", \"register\": \"pacemaker_state\", \"systemd\": {\"name\": \"pacemaker\"}}, {\"name\": \"get docker status\", \"register\": \"docker_state\", \"systemd\": {\"name\": \"docker\"}}, {\"name\": \"get container_id\", \"when\": [\"docker_state.status.ActiveState == \'active\' or container_cli == \'podman\'\", \"attr_cert_path.stat.exists\", \"attr_cert_path.stat.isdir == False\"], \"command\": \"{{ container_cli }} ps -q -f name=\'^haproxy(-bundle)?\'\", \"register\": \"container_id\"}, {\"name\": \"get pcs resource name for haproxy container\", \"when\": [\"bootstrap_node is defined\", \"is_haproxy_bootstrap_node\", \"pacemaker_state.status.ActiveState == \'active\'\", \"attr_cert_path.stat.exists\", \"attr_cert_path.stat.isdir\"], \"shell\": \"pcs status resources | sed -n \'s/^.*container.*: \\\\(haproxy.*\\\\) .*/\\\\1/p\'\\n\", \"register\": \"pacemaker_resource\"}, {\"name\": \"remove DeployedSSLCertificatePath if is dir\", \"when\": \"attr_cert_path.stat.isdir is defined and attr_cert_path.stat.isdir\", \"file\": {\"path\": \"{{cert_path}}\", \"state\": \"absent\"}}, {\"name\": \"push certificate content\", \"no_log\": \"{{ hide_sensitive_logs | bool }}\", \"copy\": {\"dest\": \"{{cert_path}}\", \"mode\": 288, \"owner\": \"root\", \"content\": \"{{cert_content}}\\n{{chain_content}}\\n{{key_content}}\\n\"}}, {\"name\": \"BM haproxy non-pacemaker context\", \"when\": \"haproxy_state.status.ActiveState == \'active\'\", \"block\": [{\"name\": \"set certificate ownership\", \"file\": {\"path\": \"{{cert_path}}\", \"group\": \"haproxy\"}}, {\"name\": \"reload haproxy if enabled\", \"service\": {\"name\": \"haproxy\", \"state\": \"reloaded\"}}]}, {\"name\": \"restart pacemaker resource for haproxy\", \"when\": [\"pacemaker_resource is defined\", \"pacemaker_resource.stdout is defined\", \"pacemaker_resource.stdout != \'\'\"], \"command\": \"pcs resource restart \\\"{{pacemaker_resource.stdout}}\\\"\"}, {\"name\": \"dedicated part for containers\", \"when\": [\"container_id is defined\", \"container_id.stdout is defined\", \"container_id.stdout != \'\'\"], \"block\": [{\"name\": \"copy certificate, chgrp, restart haproxy\", \"shell\": \"set -e\\nif {{ container_cli }} ps -f \\\"id={{ item }}\\\" --format \\\"{{ \'{{\' }}.Names{{ \'}}\' }}\\\" | grep -q \\\"^haproxy-bundle\\\"; then\\n  tar -c {{ cert_path }} | {{container_cli}} exec -i {{ item }} tar -C / -xv\\nelse\\n  {{ container_cli }} cp {{ cert_path }} {{ item }}:{{ cert_path }}\\nfi\\n{{ container_cli }} exec --user root {{ item }} chgrp haproxy {{ cert_path }}\\n{{ container_cli }} kill --signal=HUP {{ item }}\\n\", \"register\": \"container_kill_result\", \"failed_when\": [\"container_kill_result.rc != 0\", \"(\\\"no such container\\\" not in container_kill_result.stderr)\", \"(\\\"container state improper\\\" not in container_kill_result.stderr)\"], \"with_items\": \"{{ container_id.stdout.split(\'\\n\') }}\"}]}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(85,'2026-06-12 08:26:01',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(86,'2026-06-12 08:26:01',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(87,'2026-06-12 08:26:01',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(88,'2026-06-12 08:26:01',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (89,'2026-06-12 08:26:01',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"HAProxy deployment with TLS enabled, with an injected certificate\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"SSLCertificate\": {\"default\": \"\", \"description\": \"The content of the SSL certificate (without Key) in PEM format.\\n\", \"type\": \"string\"}, \"SSLIntermediateCertificate\": {\"default\": \"\", \"description\": \"The content of an SSL intermediate CA certificate in PEM format.\\n\", \"type\": \"string\"}, \"SSLKey\": {\"default\": \"\", \"description\": \"The content of the SSL Key in PEM format.\\n\", \"type\": \"string\", \"hidden\": true}, \"DeployedSSLCertificatePath\": {\"default\": \"/etc/pki/tls/private/overcloud_endpoint.pem\", \"description\": \"The filepath of the certificate as it will be stored in the controller.\\n\", \"type\": \"string\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the HAProxy public TLS injection.\", \"value\": {\"service_name\": \"haproxy_public_tls_inject\", \"config_settings\": {}, \"certificates_specs\": {}, \"metadata_settings\": null, \"host_prep_tasks\": [{\"name\": \"get parameters\", \"set_fact\": {\"cert_path\": {\"get_param\": \"DeployedSSLCertificatePath\"}, \"cert_content\": {\"get_param\": \"SSLCertificate\"}, \"chain_content\": {\"get_param\": \"SSLIntermediateCertificate\"}, \"key_content\": {\"get_param\": \"SSLKey\"}}, \"no_log\": \"{{ hide_sensitive_logs | bool }}\"}, {\"name\": \"manage certificate\", \"when\": [\"cert_content is defined\", \"cert_content != \'\'\"], \"block\": [{\"name\": \"get DeployedSSLCertificatePath attributes\", \"register\": \"attr_cert_path\", \"stat\": {\"path\": \"{{cert_path}}\"}}, {\"name\": \"set is_haproxy_bootstrap_node fact\", \"set_fact\": \"is_haproxy_bootstrap_node={{haproxy_short_bootstrap_node_name | lower == ansible_facts[\'hostname\'] | lower}}\", \"when\": [\"haproxy_short_bootstrap_node_name|default(false)\"]}, {\"name\": \"get haproxy status\", \"register\": \"haproxy_state\", \"systemd\": {\"name\": \"haproxy\"}}, {\"name\": \"get pacemaker status\", \"register\": \"pacemaker_state\", \"systemd\": {\"name\": \"pacemaker\"}}, {\"name\": \"get docker status\", \"register\": \"docker_state\", \"systemd\": {\"name\": \"docker\"}}, {\"name\": \"get container_id\", \"when\": [\"docker_state.status.ActiveState == \'active\' or container_cli == \'podman\'\", \"attr_cert_path.stat.exists\", \"attr_cert_path.stat.isdir == False\"], \"command\": \"{{ container_cli }} ps -q -f name=\'^haproxy(-bundle)?\'\", \"register\": \"container_id\"}, {\"name\": \"get pcs resource name for haproxy container\", \"when\": [\"bootstrap_node is defined\", \"is_haproxy_bootstrap_node\", \"pacemaker_state.status.ActiveState == \'active\'\", \"attr_cert_path.stat.exists\", \"attr_cert_path.stat.isdir\"], \"shell\": \"pcs status resources | sed -n \'s/^.*container.*: \\\\(haproxy.*\\\\) .*/\\\\1/p\'\\n\", \"register\": \"pacemaker_resource\"}, {\"name\": \"remove DeployedSSLCertificatePath if is dir\", \"when\": \"attr_cert_path.stat.isdir is defined and attr_cert_path.stat.isdir\", \"file\": {\"path\": \"{{cert_path}}\", \"state\": \"absent\"}}, {\"name\": \"push certificate content\", \"no_log\": \"{{ hide_sensitive_logs | bool }}\", \"copy\": {\"dest\": \"{{cert_path}}\", \"mode\": 288, \"owner\": \"root\", \"content\": \"{{cert_content}}\\n{{chain_content}}\\n{{key_content}}\\n\"}}, {\"name\": \"BM haproxy non-pacemaker context\", \"when\": \"haproxy_state.status.ActiveState == \'active\'\", \"block\": [{\"name\": \"set certificate ownership\", \"file\": {\"path\": \"{{cert_path}}\", \"group\": \"haproxy\"}}, {\"name\": \"reload haproxy if enabled\", \"service\": {\"name\": \"haproxy\", \"state\": \"reloaded\"}}]}, {\"name\": \"restart pacemaker resource for haproxy\", \"when\": [\"pacemaker_resource is defined\", \"pacemaker_resource.stdout is defined\", \"pacemaker_resource.stdout != \'\'\"], \"command\": \"pcs resource restart \\\"{{pacemaker_resource.stdout}}\\\"\"}, {\"name\": \"dedicated part for containers\", \"when\": [\"container_id is defined\", \"container_id.stdout is defined\", \"container_id.stdout != \'\'\"], \"block\": [{\"name\": \"copy certificate, chgrp, restart haproxy\", \"shell\": \"set -e\\nif {{ container_cli }} ps -f \\\"id={{ item }}\\\" --format \\\"{{ \'{{\' }}.Names{{ \'}}\' }}\\\" | grep -q \\\"^haproxy-bundle\\\"; then\\n  tar -c {{ cert_path }} | {{container_cli}} exec -i {{ item }} tar -C / -xv\\nelse\\n  {{ container_cli }} cp {{ cert_path }} {{ item }}:{{ cert_path }}\\nfi\\n{{ container_cli }} exec --user root {{ item }} chgrp haproxy {{ cert_path }}\\n{{ container_cli }} kill --signal=HUP {{ item }}\\n\", \"register\": \"container_kill_result\", \"failed_when\": [\"container_kill_result.rc != 0\", \"(\\\"no such container\\\" not in container_kill_result.stderr)\", \"(\\\"container state improper\\\" not in container_kill_result.stderr)\"], \"with_items\": \"{{ container_id.stdout.split(\'\\n\') }}\"}]}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(90,'2026-06-12 08:26:02',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(91,'2026-06-12 08:26:02',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Ceilometer service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CeilometerMeteringSecret\": {\"description\": \"Secret shared by the ceilometer services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"EPgaQlmbDVmqQsiNdVrRly1ai\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\"}, \"AmqpRpcAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for RPC addresses\", \"type\": \"string\"}, \"AmqpNotifyAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for Notification addresses\", \"type\": \"string\"}, \"ManagePolling\": {\"default\": false, \"description\": \"Whether to manage polling.yaml.\", \"type\": \"boolean\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CeilometerDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Ceilometer services.\", \"type\": \"boolean\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"SnmpdReadonlyUserName\": {\"default\": \"ro_snmp_user\", \"description\": \"The user name for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\"}, \"SnmpdReadonlyUserPassword\": {\"description\": \"The user password for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\", \"hidden\": true, \"default\": \"KjPkLxPsqu3qjdbO0SJ0shPX\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"GnocchiArchivePolicy\": {\"default\": \"ceilometer-low-rate\", \"type\": \"string\", \"description\": \"(DEPRECATED) archive policy to use with gnocchi backend\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"MemcachedTLS\": {\"default\": false, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"GnocchiArchivePolicy\"]}], \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer role.\", \"value\": {\"service_name\": \"ceilometer_base\", \"config_settings\": {\"map_merge\": [{\"ceilometer::logging::debug\": {\"if\": [{\"get_param\": \"CeilometerDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"ceilometer::agent::polling::manage_polling\": {\"get_param\": \"ManagePolling\"}, \"ceilometer::agent::service_credentials::password\": {\"get_param\": \"CeilometerPassword\"}, \"ceilometer::agent::service_credentials::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"ceilometer::agent::service_credentials::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"ceilometer::agent::service_credentials::project_name\": \"service\", \"ceilometer::agent::service_credentials::user_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::auth_project_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::interface\": \"internalURL\", \"ceilometer::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"ceilometer::amqp_rpc_address_prefix\": {\"get_param\": \"AmqpRpcAddressPrefix\"}, \"ceilometer::amqp_notify_address_prefix\": {\"get_param\": \"AmqpNotifyAddressPrefix\"}, \"ceilometer::telemetry_secret\": {\"get_param\": \"CeilometerMeteringSecret\"}, \"ceilometer::snmpd_readonly_username\": {\"get_param\": \"SnmpdReadonlyUserName\"}, \"ceilometer::snmpd_readonly_user_password\": {\"get_param\": \"SnmpdReadonlyUserPassword\"}, \"ceilometer::host\": \"%{hiera(\'fqdn_canonical\')}\", \"ceilometer::rabbit_heartbeat_in_pthread\": false, \"ceilometer::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"ceilometer::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}}, {\"if\": [\"tls_cache_enabled\", {\"ceilometer::cache::backend\": \"dogpile.cache.pymemcache\", \"ceilometer::cache::enable_socket_keepalive\": true}, {\"ceilometer::cache::backend\": \"dogpile.cache.memcached\"}]}]}, \"service_config_settings\": {\"keystone\": {\"tripleo::profile::base::keystone::ceilometer_notification_topics\": [\"notifications\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(92,'2026-06-12 08:26:02',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Nova Metadata service\\n\", \"parameters\": {\"ContainerNovaMetadataImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\"}, \"ContainerNovaMetadataConfigImage\": {\"description\": \"The container image to use for the nova config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\"}, \"NovaMetadataLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.nova.api.metadata\", \"file\": \"/var/log/containers/nova/nova-metadata-api.log\"}}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"NovaWorkers\": {\"default\": 1, \"description\": \"Number of workers for Nova services.\", \"type\": \"number\"}, \"NovaPassword\": {\"description\": \"The password for the nova service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"1Ii49H1EfmLUfEWsgfy9vla3q\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"NeutronMetadataProxySharedSecret\": {\"description\": \"Shared secret to prevent spoofing\", \"type\": \"string\", \"hidden\": true, \"default\": \"8w93bMk7ykp2VXaxsdJErpmNY\"}, \"MonitoringSubscriptionNovaMetadata\": {\"default\": \"overcloud-nova-metadata\", \"type\": \"string\"}, \"NovaLocalMetadataPerCell\": {\"default\": true, \"description\": \"Indicates that the nova-metadata API service has been deployed per-cell, so that we can have better performance and data isolation in a multi-cell deployment. Users should consider the use of this configuration depending on how neutron is setup. If networks span cells, you might need to run nova-metadata API service globally. If your networks are segmented along cell boundaries, then you can run nova-metadata API service per cell. When running nova-metadata API service per cell, you should also configure each Neutron metadata-agent to point to the corresponding nova-metadata API service.\\n\", \"type\": \"boolean\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}}, \"conditions\": {\"nova_workers_set\": {\"not\": {\"equals\": [{\"get_param\": \"NovaWorkers\"}, 0]}}, \"is_neutron_shared_metadata_notempty\": {\"not\": {\"equals\": [{\"get_param\": \"NeutronMetadataProxySharedSecret\"}, \"\"]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"NovaMetadataLogging\": {\"type\": \"OS::TripleO::Services::Logging::NovaMetadata\"}, \"ApacheServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"NovaBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"NovaApiDBClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"NovaDBClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerNovaMetadataImage\": \"ContainerNovaMetadataImage\", \"ContainerNovaMetadataConfigImage\": \"ContainerNovaMetadataConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerNovaMetadataImage\": {\"get_param\": \"ContainerNovaMetadataImage\"}, \"ContainerNovaMetadataConfigImage\": {\"get_param\": \"ContainerNovaMetadataConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova Metadata service.\", \"value\": {\"service_name\": \"nova_metadata\", \"firewall_rules\": {\"139 nova_metadata\": {\"dport\": [8775]}}, \"firewall_frontend_rules\": {\"100 nova_metadatahaproxy_frontend\": {\"dport\": [8775]}}, \"firewall_ssl_frontend_rules\": {\"100 nova_metadatahaproxy_frontend_ssl\": {\"dport\": [13775]}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionNovaMetadata\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"NovaBase\", \"role_data\", \"config_settings\"]}, {\"if\": [{\"not\": {\"get_param\": \"NovaLocalMetadataPerCell\"}}, {\"get_attr\": [\"NovaApiDBClient\", \"role_data\", \"config_settings\"]}]}, {\"get_attr\": [\"NovaDBClient\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"NovaMetadataLogging\", \"config_settings\"]}, {\"apache::default_vhost\": false}, {\"nova::keystone::authtoken::project_name\": \"service\", \"nova::keystone::authtoken::password\": {\"get_param\": \"NovaPassword\"}, \"nova::keystone::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"nova::keystone::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::keystone::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::keystone::authtoken::interface\": \"internal\", \"nova::keystone::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"nova::wsgi::apache_metadata::api_port\": \"8775\", \"nova::wsgi::apache_metadata::ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"nova::metadata::local_metadata_per_cell\": {\"get_param\": \"NovaLocalMetadataPerCell\"}, \"nova::wsgi::apache_metadata::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}}}}, \"nova::wsgi::apache_metadata::servername\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}}}}, \"nova::wsgi::apache_metadata::workers\": {\"if\": [\"nova_workers_set\", {\"get_param\": \"NovaWorkers\"}]}, \"nova::metadata::neutron_metadata_proxy_shared_secret\": {\"if\": [\"is_neutron_shared_metadata_notempty\", {\"get_param\": \"NeutronMetadataProxySharedSecret\"}]}}]}, \"service_config_settings\": {\"rabbitmq\": {\"get_attr\": [\"NovaBase\", \"role_data\", \"service_config_settings\"], \"rabbitmq\": null}, \"mysql\": {\"map_merge\": [{\"if\": [{\"not\": {\"get_param\": \"NovaLocalMetadataPerCell\"}}, {\"get_attr\": [\"NovaApiDBClient\", \"role_data\", \"service_config_settings\", \"mysql\"]}]}, {\"get_attr\": [\"NovaDBClient\", \"role_data\", \"service_config_settings\", \"mysql\"]}]}, \"rsyslog\": {\"tripleo_logging_sources_nova_metadata\": [{\"get_param\": \"NovaMetadataLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"nova_metadata\", \"puppet_tags\": \"nova_config,nova_api_paste_ini\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::nova::metadata\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaMetadataConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/nova_metadata.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/nova\", \"owner\": \"nova:nova\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"NovaMetadataLogging\", \"docker_config\", \"step_2\"]}, \"step_4\": {\"nova_metadata\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaMetadataImage\"]}, \"net\": \"host\", \"user\": \"root\", \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaMetadataLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/nova_metadata.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/nova_metadata:/var/lib/kolla/config_files/src:ro\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"deploy_steps_tasks\": {\"list_concat\": [{\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"deploy_steps_tasks\"]}, [{\"name\": \"validate nova-metadata container state\", \"containers.podman.podman_container_info\": {\"name\": \"nova_metadata\"}, \"register\": \"nova_metadata_infos\", \"failed_when\": [\"nova_metadata_infos.containers.0.Healthcheck.Status is defined\", \"\'healthy\' not in nova_metadata_infos.containers.0.Healthcheck.Status\"], \"retries\": 10, \"delay\": 30, \"tags\": [\"opendev-validation\", \"opendev-validation-nova\"], \"when\": [\"container_cli == \'podman\'\", \"not container_healthcheck_disabled\", \"step|int == 5\"]}]]}, \"host_prep_tasks\": {\"get_attr\": [\"NovaMetadataLogging\", \"host_prep_tasks\"]}, \"metadata_settings\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"metadata_settings\"]}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop nova metadata container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"nova_metadata\"], \"tripleo_delegate_to\": \"{{ groups[\'nova_metadata\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(93,'2026-06-12 08:26:02',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Ceilometer service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CeilometerMeteringSecret\": {\"description\": \"Secret shared by the ceilometer services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"EPgaQlmbDVmqQsiNdVrRly1ai\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\"}, \"AmqpRpcAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for RPC addresses\", \"type\": \"string\"}, \"AmqpNotifyAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for Notification addresses\", \"type\": \"string\"}, \"ManagePolling\": {\"default\": false, \"description\": \"Whether to manage polling.yaml.\", \"type\": \"boolean\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CeilometerDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Ceilometer services.\", \"type\": \"boolean\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"SnmpdReadonlyUserName\": {\"default\": \"ro_snmp_user\", \"description\": \"The user name for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\"}, \"SnmpdReadonlyUserPassword\": {\"description\": \"The user password for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\", \"hidden\": true, \"default\": \"KjPkLxPsqu3qjdbO0SJ0shPX\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"GnocchiArchivePolicy\": {\"default\": \"ceilometer-low-rate\", \"type\": \"string\", \"description\": \"(DEPRECATED) archive policy to use with gnocchi backend\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"MemcachedTLS\": {\"default\": false, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"GnocchiArchivePolicy\"]}], \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer role.\", \"value\": {\"service_name\": \"ceilometer_base\", \"config_settings\": {\"map_merge\": [{\"ceilometer::logging::debug\": {\"if\": [{\"get_param\": \"CeilometerDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"ceilometer::agent::polling::manage_polling\": {\"get_param\": \"ManagePolling\"}, \"ceilometer::agent::service_credentials::password\": {\"get_param\": \"CeilometerPassword\"}, \"ceilometer::agent::service_credentials::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"ceilometer::agent::service_credentials::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"ceilometer::agent::service_credentials::project_name\": \"service\", \"ceilometer::agent::service_credentials::user_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::auth_project_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::interface\": \"internalURL\", \"ceilometer::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"ceilometer::amqp_rpc_address_prefix\": {\"get_param\": \"AmqpRpcAddressPrefix\"}, \"ceilometer::amqp_notify_address_prefix\": {\"get_param\": \"AmqpNotifyAddressPrefix\"}, \"ceilometer::telemetry_secret\": {\"get_param\": \"CeilometerMeteringSecret\"}, \"ceilometer::snmpd_readonly_username\": {\"get_param\": \"SnmpdReadonlyUserName\"}, \"ceilometer::snmpd_readonly_user_password\": {\"get_param\": \"SnmpdReadonlyUserPassword\"}, \"ceilometer::host\": \"%{hiera(\'fqdn_canonical\')}\", \"ceilometer::rabbit_heartbeat_in_pthread\": false, \"ceilometer::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"ceilometer::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}}, {\"if\": [\"tls_cache_enabled\", {\"ceilometer::cache::backend\": \"dogpile.cache.pymemcache\", \"ceilometer::cache::enable_socket_keepalive\": true}, {\"ceilometer::cache::backend\": \"dogpile.cache.memcached\"}]}]}, \"service_config_settings\": {\"keystone\": {\"tripleo::profile::base::keystone::ceilometer_notification_topics\": [\"notifications\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(94,'2026-06-12 08:26:02',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(95,'2026-06-12 08:26:02',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Qpid dispatch router service for metrics and monitoring purposes\\n\", \"parameters\": {\"ContainerMetricsQdrImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\"}, \"ContainerMetricsQdrConfigImage\": {\"description\": \"The container image to use for the qdrouterd config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"MonitoringSubscriptionQdr\": {\"default\": \"overcloud-qdr\", \"type\": \"string\"}, \"MetricsQdrLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.nova.consoleauth\", \"file\": \"/var/log/containers/metrics_qdr/metrics_qdr.log\", \"startmsg.regex\": \"^[0-9]{4}-[0-9]{2}-[0-9]{2} [0-9]{2}:[0-9]{2}:[0-9]{2}(.[0-9]+ \\\\\\\\+[0-9]+)? [A-Z]+ \\\\\\\\([a-z]+\\\\\\\\) \"}}, \"MetricsQdrPort\": {\"default\": 5666, \"description\": \"Service name or port number on which the qdrouterd will accept connections.\", \"type\": \"number\"}, \"MetricsQdrUsername\": {\"default\": \"guest\", \"description\": \"Username which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\"}, \"MetricsQdrPassword\": {\"default\": \"guest\", \"description\": \"Password which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\", \"hidden\": true}, \"MetricsQdrConnectors\": {\"default\": [], \"description\": \"Connectors configuration (array of hashes).\", \"type\": \"json\"}, \"MetricsQdrSSLProfiles\": {\"default\": [{\"name\": \"sslProfile\"}], \"description\": \"SSL Profiles for the connectors (array of hashes).\", \"type\": \"json\"}, \"MetricsQdrAddresses\": {\"default\": [{\"prefix\": \"collectd\", \"distribution\": \"multicast\"}, {\"prefix\": \"ceilometer/metering.sample\", \"distribution\": \"multicast\"}, {\"prefix\": \"ceilometer/event.sample\", \"distribution\": \"multicast\"}], \"description\": \"Addresses configuration (array of hashes).\", \"type\": \"json\"}, \"MetricsQdrAutoLinks\": {\"default\": [], \"description\": \"AutoLinks for the Configured Addresses\", \"type\": \"json\"}, \"MetricsQdrUseSSL\": {\"default\": false, \"description\": \"Set to true if it is required to use SSL or TLS on the connection for the local listener. !WARNING! Currently breaks connections from collectd and ceilometer.\", \"type\": \"boolean\"}, \"MetricsQdrUseEncryption\": {\"default\": false, \"description\": \"Set to true if it is required to encrypt connection to the peer for listener. Not currently implemented, use EnableInternalTLS instead. This option can be ignored.\", \"type\": \"boolean\"}, \"MetricsQdrSaslMechanisms\": {\"default\": \"ANONYMOUS\", \"description\": \"List of accepted SASL auth mechanisms for listener in format of comma separated list.\", \"type\": \"string\"}, \"MetricsQdrSslCertDb\": {\"default\": \"/etc/ipa/ca.crt\", \"description\": \"Path to SSL certificate db for listener.\", \"type\": \"string\"}, \"MetricsQdrSslCertFile\": {\"default\": \"/etc/pki/tls/certs/metrics_qdr.crt\", \"description\": \"Path to SSL certificate file for listener.\", \"type\": \"string\"}, \"MetricsQdrSslKeyFile\": {\"default\": \"/etc/pki/tls/private/metrics_qdr.key\", \"description\": \"Path to SSL private key file for listener.\", \"type\": \"string\"}, \"MetricsQdrSslPwFile\": {\"default\": \"\", \"description\": \"Path to SSL password file for certificate key for listener.\", \"type\": \"string\"}, \"MetricsQdrSslPassword\": {\"default\": \"\", \"description\": \"SSL password to be supplied for listener.\", \"type\": \"string\"}, \"MetricsQdrTrustedCerts\": {\"default\": \"\", \"description\": \"Path to file containing trusted certificates for listener.\", \"type\": \"string\"}, \"MetricsQdrAuthenticateClient\": {\"default\": false, \"description\": \"Authenticate the client using SSL/TLS\", \"type\": \"boolean\"}, \"MetricsQdrExternalEndpoint\": {\"default\": false, \"description\": \"Whether QDR should listen on external network interface. To enable listening on external network one must deploy QDRs in mesh mode.\", \"type\": \"boolean\"}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"EnableSTF\": {\"default\": false, \"description\": \"Set to true to enable configuration for STF client.\", \"type\": \"boolean\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"QdrCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"listener_ssl_enabled\": {\"equals\": [{\"get_param\": \"MetricsQdrUseSSL\"}, true]}, \"enable_stf\": {\"equals\": [{\"get_param\": \"EnableSTF\"}, true]}, \"key_size_override_unset\": {\"equals\": [{\"get_param\": \"QdrCertificateKeySize\"}, \"\"]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerMetricsQdrImage\": \"ContainerMetricsQdrImage\", \"ContainerMetricsQdrConfigImage\": \"ContainerMetricsQdrConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerMetricsQdrImage\": {\"get_param\": \"ContainerMetricsQdrImage\"}, \"ContainerMetricsQdrConfigImage\": {\"get_param\": \"ContainerMetricsQdrConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the metrics Qdr role.\", \"value\": {\"service_name\": \"metrics_qdr\", \"firewall_rules\": {\"map_merge\": [{\"109 metrics qdr\": {\"dport\": [{\"get_param\": \"MetricsQdrPort\"}]}}, {\"map_merge\": {\"repeat\": {\"for_each\": {\"<%net_cidr%>\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", \"ctlplane\"]}}, \"template\": {\"109 accept internal metrics qdr ctlplane subnet <%net_cidr%>\": {\"dport\": [5667, 5668]}}}}}]}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionQdr\"}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_metrics_qdr\": [{\"get_param\": \"MetricsQdrLoggingSource\"}]}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::metrics::qdr::listener_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::haproxy::metrics_qdr\": {\"get_param\": \"MetricsQdrExternalEndpoint\"}, \"tripleo::profile::base::metrics::qdr::listener_port\": {\"get_param\": \"MetricsQdrPort\"}, \"tripleo::profile::base::metrics::qdr::username\": {\"get_param\": \"MetricsQdrUsername\"}, \"tripleo::profile::base::metrics::qdr::password\": {\"get_param\": \"MetricsQdrPassword\"}, \"tripleo::profile::base::metrics::qdr::connectors\": {\"get_param\": \"MetricsQdrConnectors\"}, \"tripleo::profile::base::metrics::qdr::addresses\": {\"get_param\": \"MetricsQdrAddresses\"}, \"tripleo::profile::base::metrics::qdr::autolink_addresses\": {\"get_param\": \"MetricsQdrAutoLinks\"}, \"tripleo::profile::base::metrics::qdr::listener_require_ssl\": {\"if\": [\"listener_ssl_enabled\", true, false]}, \"tripleo::profile::base::metrics::qdr::listener_require_encrypt\": {\"get_param\": \"MetricsQdrUseEncryption\"}, \"tripleo::profile::base::metrics::qdr::listener_sasl_mech\": {\"get_param\": \"MetricsQdrSaslMechanisms\"}, \"tripleo::profile::base::metrics::qdr::listener_ssl_cert_db\": {\"get_param\": \"MetricsQdrSslCertDb\"}, \"tripleo::profile::base::metrics::qdr::listener_ssl_cert_file\": {\"get_param\": \"MetricsQdrSslCertFile\"}, \"tripleo::profile::base::metrics::qdr::listener_ssl_key_file\": {\"get_param\": \"MetricsQdrSslKeyFile\"}, \"tripleo::profile::base::metrics::qdr::listener_ssl_pw_file\": {\"get_param\": \"MetricsQdrSslPwFile\"}, \"tripleo::profile::base::metrics::qdr::listener_ssl_password\": {\"get_param\": \"MetricsQdrSslPassword\"}, \"tripleo::profile::base::metrics::qdr::listener_trusted_certs\": {\"get_param\": \"MetricsQdrTrustedCerts\"}, \"qdr::log_enable\": \"info+\", \"qdr::log_output\": \"/var/log/qdrouterd/metrics_qdr.log\", \"qdr::listener_auth_peer\": {\"get_param\": \"MetricsQdrAuthenticateClient\"}}, {\"if\": [\"internal_tls_enabled\", {\"tripleo::profile::base::metrics::qdr::ssl_profiles\": {\"list_concat\": [{\"get_param\": \"MetricsQdrSSLProfiles\"}, [{\"name\": \"tlsProfile\", \"certFile\": \"/etc/pki/tls/certs/metrics_qdr.crt\", \"keyFile\": \"/etc/pki/tls/private/metrics_qdr.key\", \"caCertFile\": {\"get_param\": \"InternalTLSCAFile\"}}]]}}, {\"tripleo::profile::base::metrics::qdr::ssl_profiles\": {\"get_param\": \"MetricsQdrSSLProfiles\"}}]}, {\"if\": [\"enable_stf\", {\"tripleo::profile::base::metrics::qdr::interior_mesh_nodes\": \"\", \"tripleo::profile::base::metrics::qdr::router_mode\": \"edge\"}, null]}]}, \"metadata_settings\": {\"if\": [\"internal_tls_enabled\", [{\"service\": \"metrics_qdr\", \"network\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}, \"type\": \"node\"}], null]}, \"puppet_config\": {\"config_volume\": \"metrics_qdr\", \"step_config\": \"include tripleo::profile::base::metrics::qdr\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMetricsQdrConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/metrics_qdr.json\": {\"command\": \"/usr/sbin/qdrouterd -c /etc/qpid-dispatch/qdrouterd.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/lib/qdrouterd\", \"owner\": \"qdrouterd:qdrouterd\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/metrics_qdr.crt\", \"owner\": \"qdrouterd:qdrouterd\", \"optional\": true}, {\"path\": \"/etc/pki/tls/private/metrics_qdr.key\", \"owner\": \"qdrouterd:qdrouterd\", \"optional\": true}]}}, \"docker_config\": {\"step_1\": {\"metrics_qdr_init_logs\": {\"start_order\": 0, \"detach\": false, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMetricsQdrImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/metrics_qdr:/var/log/qdrouterd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R qdrouterd:qdrouterd /var/log/qdrouterd\"]}, \"metrics_qdr\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMetricsQdrImage\"]}, \"net\": \"host\", \"user\": \"qdrouterd\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/metrics_qdr.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/metrics_qdr:/var/lib/kolla/config_files/src:ro\", \"/var/lib/metrics_qdr:/var/lib/qdrouterd:z\", \"/var/log/containers/metrics_qdr:/var/log/qdrouterd:z\"], {\"if\": [\"internal_tls_enabled\", [\"/etc/pki/tls/certs/metrics_qdr.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/metrics_qdr.crt:ro\", \"/etc/pki/tls/private/metrics_qdr.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/metrics_qdr.key:ro\"], null]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"metrics_qdr\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_NETWORK}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"principal\": {\"str_replace\": {\"template\": \"metrics_qdr/{{fqdn_NETWORK}}@{{idm_realm}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"run_after\": \"container_name=$({{container_cli}} ps --format=\\\\{\\\\{.Names\\\\}\\\\} | grep metrics_qdr)\\nservice_crt=\\\"/etc/pki/tls/certs/metrics_qdr.crt\\\"\\nservice_key=\\\"/etc/pki/tls/private/metrics_qdr.key\\n# Copy the new cert from the mount-point to the real path\\n{{container_cli}} exec \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_crt\\\" \\\"$service_crt\\\"\\n# Copy the new key from the mount-point to the real path\\n{{container_cli}} exec \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_key\\\" \\\"$service_key\\\"\\n# Set appropriate permissions\\n{{container_cli}} exec \\\"$container_name\\\" chown qdrouterd:qdrouterd \\\"$service_crt\\\"\\n{{container_cli}} exec \\\"$container_name\\\" chown qdrouterd:qdrouterd \\\"$service_key\\\"\\n# Trigger a container restart to read the new certificate\\n{{container_cli}} restart \\\"$container_name\\\"\\n\", \"key_size\": {\"if\": [\"key_size_override_unset\", {\"get_param\": \"CertificateKeySize\"}, {\"get_param\": \"QdrCertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}], \"host_prep_tasks\": [{\"name\": \"create persistent logs directory\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/metrics_qdr\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/metrics_qdr\", \"setype\": \"container_file_t\"}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(96,'2026-06-12 08:26:03',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Nova base service. Shared for all Nova services.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"NovaPassword\": {\"description\": \"The password for the nova service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"1Ii49H1EfmLUfEWsgfy9vla3q\"}, \"NeutronPassword\": {\"description\": \"The password for the neutron service and db account, used by neutron agents.\", \"type\": \"string\", \"hidden\": true, \"default\": \"qnvMdngIoyiS9ntQpzmg868ob\"}, \"PlacementPassword\": {\"description\": \"The password for the Placement service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\"}, \"PlacementAPIInterface\": {\"type\": \"string\", \"description\": \"Endpoint interface to be used for the placement API.\\n\", \"default\": \"internal\"}, \"NovaOVSBridge\": {\"default\": \"br-int\", \"description\": \"Name of integration bridge used by Open vSwitch\", \"type\": \"string\"}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"NovaDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Nova services.\", \"type\": \"boolean\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"EnableConfigPurge\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Remove configuration that is not generated by TripleO. Used to avoid configuration remnants after upgrades.\\n\"}, \"UpgradeLevelNovaCompute\": {\"type\": \"string\", \"description\": \"Nova Compute upgrade level\", \"default\": \"\"}, \"NovaOVSDBConnection\": {\"type\": \"string\", \"description\": \"OVS DB connection string to used by Nova\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaSyncPowerStateInterval\": {\"type\": \"number\", \"description\": \"Interval to sync power states between the database and the hypervisor. Set to -1 to disable. Setting this to 0 will run at the default rate(60) defined in oslo.service.\", \"default\": 600}, \"RpcUseSSL\": {\"default\": false, \"description\": \"Messaging client subscriber parameter to specify an SSL connection to the messaging host.\\n\", \"type\": \"string\"}, \"NovaAdditionalCell\": {\"default\": true, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"NovaCrossAZAttach\": {\"default\": true, \"description\": \"Whether instances can attach cinder volumes from a different availability zone.\", \"type\": \"boolean\"}, \"MemcachedTLS\": {\"default\": false, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"conditions\": {\"compute_upgrade_level_set\": {\"not\": {\"equals\": [{\"get_param\": \"UpgradeLevelNovaCompute\"}, \"\"]}}, \"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"nova::ovsdb_connection\": \"NovaOVSDBConnection\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NovaOVSDBConnection\": {\"get_param\": \"NovaOVSDBConnection\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova base service.\", \"value\": {\"service_name\": \"nova_base\", \"config_settings\": {\"map_merge\": [{\"nova::my_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}}}, \"nova::rabbit_use_ssl\": {\"get_param\": \"RpcUseSSL\"}, \"nova::keystone::service_user::send_service_user_token\": true, \"nova::keystone::service_user::project_name\": \"service\", \"nova::keystone::service_user::password\": {\"get_param\": \"NovaPassword\"}, \"nova::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::placement::project_name\": \"service\", \"nova::placement::password\": {\"get_param\": \"PlacementPassword\"}, \"nova::placement::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::placement::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::placement::valid_interfaces\": {\"get_param\": \"PlacementAPIInterface\"}, \"nova::os_region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::logging::debug\": {\"if\": [{\"get_param\": \"NovaDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"nova::purge_config\": {\"get_param\": \"EnableConfigPurge\"}, \"nova::network::neutron::project_name\": \"service\", \"nova::network::neutron::username\": \"neutron\", \"nova::network::neutron::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::dhcp_domain\": \"\", \"nova::network::neutron::password\": {\"get_param\": \"NeutronPassword\"}, \"nova::network::neutron::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"nova::network::neutron::valid_interfaces\": \"internal\", \"nova::glance::valid_interfaces\": \"internal\", \"nova::rabbit_heartbeat_timeout_threshold\": 60, \"nova::cinder_catalog_info\": \"volumev3:cinderv3:internalURL\", \"nova::host\": \"%{hiera(\'fqdn_canonical\')}\", \"nova::notify_on_state_change\": \"vm_and_task_state\", \"nova::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"nova::notification_format\": \"unversioned\", \"nova::network::neutron::auth_type\": \"v3password\", \"nova::db::database_db_max_retries\": -1, \"nova::db::database_max_retries\": -1, \"nova::network::neutron::ovs_bridge\": {\"get_param\": \"NovaOVSBridge\"}, \"nova::compute::sync_power_state_interval\": {\"get_param\": \"NovaSyncPowerStateInterval\"}, \"nova_is_additional_cell\": {\"get_param\": \"NovaAdditionalCell\"}, \"nova::cross_az_attach\": {\"get_param\": \"NovaCrossAZAttach\"}, \"nova::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"nova::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}, \"nova::cache::backend\": {\"if\": [\"tls_cache_enabled\", \"dogpile.cache.pymemcache\", \"dogpile.cache.memcached\"]}, \"nova::rabbit_heartbeat_in_pthread\": false, \"nova::upgrade_level_compute\": {\"if\": [\"compute_upgrade_level_set\", {\"get_param\": \"UpgradeLevelNovaCompute\"}]}}, {\"get_attr\": [\"RoleParametersValue\", \"value\"]}]}, \"service_config_settings\": {\"rabbitmq\": {\"nova::rabbit_use_ssl\": {\"get_param\": \"RpcUseSSL\"}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (97,'2026-06-12 08:26:03',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(98,'2026-06-12 08:26:03',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Nova Compute service\\n\", \"parameters\": {\"ContainerNovaComputeImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\"}, \"ContainerNovaLibvirtConfigImage\": {\"description\": \"The container image to use for the nova_libvirt config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\"}, \"DockerNovaComputeUlimit\": {\"default\": [\"nofile=131072\", \"memlock=67108864\"], \"description\": \"ulimit for Nova Compute Container\", \"type\": \"comma_delimited_list\"}, \"NovaComputeLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.nova.compute\", \"file\": \"/var/log/containers/nova/nova-compute.log\"}}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CinderRbdMultiConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring multiple RBD backends. The\\nhash key is the backend name, and the value is a dictionary of parameter\\nvalues unique to that backend. The following parameters are required,\\nand must match the corresponding value defined in CephExternalMultiConfig.\\n  CephClusterName (must match the CephExternalMultiConfig entry\'s \'cluster\')\\n  CephClusterFSID (must match the CephExternalMultiConfig entry\'s \'fsid\')\\nThe following parameters are optional, and override the corresponding\\nparameter\'s default value.\\n  CephClientUserName\\n  CinderRbdPoolName\\n  CinderRbdExtraPools\\n  CinderRbdAvailabilityZone\\n  CinderRbdFlattenVolumeFromSnapshot\\n\"}, \"NovaComputeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"NovaComputeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\", \"tags\": [\"role_specific\"]}, \"NovaComputeStartupDelay\": {\"default\": 0, \"description\": \"Delays the startup of nova-compute service after compute node is booted. This is to give a chance to ceph to get back healthy before booting instances after and overcloud reboot.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 0, \"max\": 600}}], \"tags\": [\"role_specific\"]}, \"EnableInstanceHA\": {\"default\": false, \"description\": \"Whether to enable an Instance Ha configurarion or not. This setup requires the Compute role to have the PacemakerRemote service added to it.\", \"type\": \"boolean\"}, \"NovaRbdPoolName\": {\"default\": \"vms\", \"type\": \"string\", \"description\": \"The pool name for RBD backend ephemeral storage.\", \"tags\": [\"role_specific\"]}, \"CephClientKey\": {\"description\": \"The Ceph client key. Can be created with ceph-authtool --gen-print-key.\", \"type\": \"string\", \"hidden\": true, \"constraints\": [{\"allowed_pattern\": \"^[a-zA-Z0-9+/]{38}==$\"}], \"default\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\"}, \"CephClusterFSID\": {\"type\": \"string\", \"description\": \"The Ceph cluster FSID. Must be a UUID.\", \"default\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\"}, \"CinderEnableNfsBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NFS backend for Cinder\", \"type\": \"boolean\"}, \"NovaMkisofsCmd\": {\"default\": \"mkisofs\", \"description\": \"Name or path of the tool used for ISO image creation.\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"NovaNfsEnabled\": {\"default\": false, \"description\": \"Whether to enable or not the NFS backend for Nova\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaNfsShare\": {\"default\": \"\", \"description\": \"NFS share to mount for nova storage (when NovaNfsEnabled is true)\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"NovaNfsOptions\": {\"default\": \"context=system_u:object_r:nfs_t:s0\", \"description\": \"NFS mount options for nova storage (when NovaNfsEnabled is true)\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"NovaNfsVersion\": {\"default\": \"4.2\", \"description\": \"NFS version used for nova storage (when NovaNfsEnabled is true). Since NFSv3 does not support full locking a NFSv4 version need to be used.\\n\", \"type\": \"string\", \"constraints\": [{\"allowed_pattern\": \"^4.?[0-9]?\"}], \"tags\": [\"role_specific\"]}, \"CinderEnableRbdBackend\": {\"default\": false, \"description\": \"Whether to enable or not the Rbd backend for Cinder\", \"type\": \"boolean\"}, \"NovaEnableRbdBackend\": {\"default\": false, \"description\": \"Whether to enable the Rbd backend for Nova ephemeral storage.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaComputeForceRawImages\": {\"default\": true, \"description\": \"Set to \\\"True\\\" to convert non-raw cached base images to raw format.\\nSet to \\\"False\\\" if you have a system with slow I/O or low available space,\\ntrading the higher CPU requirements of compression for that of minimized input\\nbandwidth.\\nNotes::\\n- The Compute service removes any compression from the base image during\\n  compression, to avoid CPU bottlenecks. Converted images cannot have backing\\n  files, which might be a security issue.\\n- The raw image format uses more space than other image formats, for example,\\n  qcow2.\\n  Raw base images are always used with libvirt_images_type=lvm.\\n\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaComputeUseCowImages\": {\"default\": true, \"description\": \"Set to \\\"True\\\" to use CoW (Copy on Write) images in cqow2 format for libvirt\\ninstance disks. With CoW, depending on the backing store and host caching,\\nthere might be better concurrency achieved by having each instance operate\\non its own copy.\\nSet to \\\"False\\\" to use the raw format. Raw format uses more space for common\\nparts of the disk image.\\n\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaComputeLibvirtPreAllocateImages\": {\"default\": \"none\", \"description\": \"Specifies the preallocation mode for libvirt instance disks.\\nSet to one of the following valid values::\\n- none - No storage is provisioned at instance start.\\n- space - Storage is fully allocated at instance start using fallocate,\\n          which can help with both space guarantees and I/O performance.\\n\\nEven when not using CoW instance disks, the copy each instance gets is sparse\\nand so the instance might fail unexpectedly at run time with ENOSPC. By\\nrunning fallocate(1) on the instance disk images, the Compute service\\nimmediately and efficiently allocates the space for them in the file system,\\nif supported. Run time performance should also be improved because the file\\nsystem does not have to dynamically allocate blocks at run time, which reduces\\nCPU overhead and file fragmentation.\\n\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"none\", \"space\"]}], \"tags\": [\"role_specific\"]}, \"NovaComputeImageCacheManagerInterval\": {\"default\": 2400, \"description\": \"Specifies the number of seconds to wait between runs of the image cache\\nmanager, which impacts base image caching on Compute nodes. This period\\nis used in the auto removal of unused cached images configured with\\nremove_unused_base_images and remove_unused_original_minimum_age_seconds.\\n\\nSet to \\\"0\\\" to run at the default interval of 60 seconds (not recommended)\\n\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": -1}}], \"tags\": [\"role_specific\"]}, \"NovaComputeImageCacheRemoveUnusedBaseImages\": {\"default\": true, \"description\": \"Set to \\\"True\\\" to automatically remove unused base images from the cache\\nat intervals configured by using image_cache_manager_interval. Images\\nare defined as unused if they have not been accessed during the time\\nspecified by using remove_unused_original_minimum_age_seconds.\\n\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaComputeImageCacheRemoveUnusedResizedMinimumAge\": {\"default\": 3600, \"description\": \"Specifies the minimum age that an unused resized base image must be to\\nbe removed from the cache, in seconds. Unused unresized base images\\nyounger than this will not be removed.\\n\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1}}], \"tags\": [\"role_specific\"]}, \"NovaComputeImageCachePrecacheConcurrency\": {\"default\": 1, \"description\": \"Maximum number of Compute nodes to trigger image precaching in parallel.\\nWhen an image precache request is made, Compute nodes are contacted {by\\nwho/which service} to initiate the download.\\n\\nHigher numbers will cause more computes to work in parallel and may result\\nin reduced time to complete the operation, but may also DDoS the image\\nservice. Lower numbers will result in more sequential operation, lower\\nimage service load, but likely longer runtime to completion.\\n\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1}}], \"tags\": [\"role_specific\"]}, \"NovaPCIPassthrough\": {\"description\": \"List of PCI Passthrough whitelist parameters. Example - NovaPCIPassthrough:\\n  - vendor_id: \\\"8086\\\"\\n    product_id: \\\"154c\\\"\\n    address: \\\"0000:05:00.0\\\"\\n    physical_network: \\\"datacentre\\\"\\nFor different formats, refer to the nova.conf documentation for pci_passthrough_whitelist configuration\\n\", \"type\": \"json\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaComputeCpuSharedSet\": {\"description\": \"The behavior of this option depends on the deprecated `NovaVcpuPinSet` option:\\n\\n* `NovaVcpuPinSet` is not set: `NovaComputeCpuSharedSet` is set to a\\n  comma-separated list or range of physical host CPU numbers used to:\\n\\n  - provide vCPU inventory\\n  - determine the host CPUs that unpinned instances can be scheduled to\\n  - determine the host CPUS that instance emulator threads should be\\n    offloaded to for instances configured with the share emulator thread\\n    policy, `hw:emulator_threads_policy=share`\\n\\n* `NovaVcpuPinSet` is set: `NovaComputeCpuSharedSet` is set to a list or\\n  range of host CPU cores used to determine the host CPUs that instance\\n  emulator threads should be offloaded to for instances configured with\\n  the share emulator thread policy (`hw:emulator_threads_policy=share`).\\n  In this case, `NovaVcpuPinSet` is used to provide vCPU inventory and to\\n  determine the host CPUs that both pinned and unpinned instances can be\\n  scheduled to.\\n\\nEx. NovaComputeCpuSharedSet: [4-12,^8,15] will reserve cores from 4-12\\nand 15, excluding 8.\\n\", \"type\": \"comma_delimited_list\", \"default\": [], \"tags\": [\"role_specific\"]}, \"NovaComputeCpuDedicatedSet\": {\"description\": \"A list or range of host CPU cores to which processes for pinned instance CPUs (PCPUs) can be scheduled. Ex. NovaComputeCpuDedicatedSet: [4-12,^8,15] will reserve cores from 4-12 and 15, excluding 8.\\n\", \"type\": \"comma_delimited_list\", \"default\": [], \"tags\": [\"role_specific\"]}, \"NovaReservedHostMemory\": {\"description\": \"Reserved RAM for host processes.\\n\", \"type\": \"number\", \"default\": 512, \"constraints\": [{\"range\": {\"min\": 512}}], \"tags\": [\"role_specific\"]}, \"NovaReservedHugePages\": {\"description\": \"A list of valid key=value which reflect NUMA node ID, page size (Default unit is KiB) and number of pages to be reserved. Example - NovaReservedHugePages: [\\\"node:0,size:2048,count:64\\\",\\\"node:1,size:1GB,count:1\\\"] will reserve on NUMA node 0 64 pages of 2MiB and on NUMA node 1 1 page of 1GiB\\n\", \"type\": \"comma_delimited_list\", \"default\": [], \"tags\": [\"role_specific\"]}, \"KernelArgs\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Kernel Args to apply to the host\", \"tags\": [\"role_specific\"]}, \"OvsDpdkSocketMemory\": {\"default\": \"\", \"description\": \"Sets the amount of hugepage memory to assign per NUMA node. It is recommended to use the socket closest to the PCIe slot used for the desired DPDK NIC.  The format should be in \\\"<socket 0 mem>, <socket 1 mem>, <socket n mem>\\\", where the value is specified in MB.  For example: \\\"1024,0\\\".\\n\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"MonitoringSubscriptionNovaCompute\": {\"default\": \"overcloud-nova-compute\", \"type\": \"string\"}, \"MigrationSshKey\": {\"type\": \"json\", \"description\": \"SSH key for migration. Expects a dictionary with keys \'public_key\' and \'private_key\'. Values should be identical to SSH public/private key files.\\n\", \"default\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}}, \"MigrationSshPort\": {\"default\": 2022, \"description\": \"Target port for migration over ssh\", \"type\": \"number\"}, \"VerifyGlanceSignatures\": {\"default\": false, \"description\": \"Whether to verify image signatures.\", \"type\": \"boolean\"}, \"NovaAutoDisabling\": {\"default\": \"10\", \"description\": \"Max number of consecutive build failures before the nova-compute will disable itself.\", \"type\": \"string\"}, \"NeutronPhysnetNUMANodesMapping\": {\"description\": \"Map of physnet name as key and NUMA nodes as value.\\nEx. NeutronPhysnetNUMANodesMapping: {\'foo\': [0, 1], \'bar\': [1]} where `foo` and `bar` are\\nphysnet names and corresponding values are list of associated numa_nodes.\\n\", \"type\": \"json\", \"default\": {}, \"tags\": [\"role_specific\"]}, \"NeutronTunnelNUMANodes\": {\"description\": \"Used to configure NUMA affinity for all tunneled networks.\", \"type\": \"comma_delimited_list\", \"default\": [], \"tags\": [\"role_specific\"]}, \"NovaResumeGuestsStateOnHostBoot\": {\"default\": false, \"description\": \"Whether to start running instance on compute host reboot\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaLibvirtRxQueueSize\": {\"description\": \"virtio-net RX queue size. Valid values are 256, 512, 1024\\n\", \"default\": 512, \"type\": \"number\", \"constraints\": [{\"allowed_values\": [256, 512, 1024]}], \"tags\": [\"role_specific\"]}, \"NovaLibvirtTxQueueSize\": {\"description\": \"virtio-net TX queue size. Valid values are 256, 512, 1024\\n\", \"default\": 512, \"type\": \"number\", \"constraints\": [{\"allowed_values\": [256, 512, 1024]}], \"tags\": [\"role_specific\"]}, \"NovaLibvirtFileBackedMemory\": {\"description\": \"Available capacity in MiB for file-backed memory. When configured, the ``NovaRAMAllocationRatio`` and ``NovaReservedHostMemory`` parameters must be set to 0.\\n\", \"default\": 0, \"type\": \"number\", \"tags\": [\"role_specific\"]}, \"NovaLibvirtVolumeUseMultipath\": {\"default\": false, \"description\": \"Whether to enable or not the multipath connection of the volumes.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaHWMachineType\": {\"description\": \"To specify a default machine type per host architecture.\\n\", \"default\": \"x86_64=pc-q35-rhel9.0.0\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"DeployIdentifier\": {\"default\": 1781252715, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"NovaAdditionalCell\": {\"default\": true, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"NovaComputeEnableKsm\": {\"default\": false, \"description\": \"Whether to enable KSM on compute nodes or not. Especially in NFV use case one wants to keep it disabled.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"AdminPassword\": {\"description\": \"The password for the keystone admin account, used for monitoring, querying neutron etc.\", \"type\": \"string\", \"hidden\": true, \"default\": \"bUe66HleZhJpBVjnSHAhIOXaa\"}, \"CinderPassword\": {\"description\": \"The password for the cinder service and db account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"NovaLibvirtNumPciePorts\": {\"description\": \"Set `num_pcie_ports` to specify the number of PCIe ports an instance will get. Libvirt allows a custom number of PCIe ports (pcie-root-port controllers) a target instance will get. Some will be used by default, rest will be available for hotplug use.\\n\", \"default\": 16, \"type\": \"number\", \"tags\": [\"role_specific\"]}, \"NovaLibvirtMemStatsPeriodSeconds\": {\"description\": \"A number of seconds to memory usage statistics period, zero or negative value mean to disable memory usage statistics.\\n\", \"default\": 10, \"type\": \"number\", \"tags\": [\"role_specific\"]}, \"NovaLiveMigrationWaitForVIFPlug\": {\"description\": \"Whether to wait for `network-vif-plugged` events before starting guest transfer.\", \"default\": true, \"type\": \"boolean\"}, \"NovaLiveMigrationPermitPostCopy\": {\"description\": \"If \\\"True\\\" activates the instance on the destination node before migration is complete, and to set an upper bound on the memory that needs to be transferred. Post copy gets enabled per default if the compute roles is not a realtime role or disabled by this parameter.\\n\", \"default\": true, \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaLiveMigrationPermitAutoConverge\": {\"description\": \"Defaults to \\\"True\\\" to slow down the instance CPU until the memory copy process is faster than the instance\'s memory writes when the migration performance is slow and might not complete. Auto converge will only be used if this flag is set to True and post copy is not permitted or post copy is unavailable due to the version of libvirt and QEMU.\\n\", \"default\": true, \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"NovaCPUAllocationRatio\": {\"type\": \"number\", \"description\": \"Virtual CPU to physical CPU allocation ratio.\", \"default\": 0.0, \"tags\": [\"role_specific\"]}, \"NovaRAMAllocationRatio\": {\"type\": \"number\", \"description\": \"Virtual RAM to physical RAM allocation ratio.\", \"default\": 1.0, \"tags\": [\"role_specific\"]}, \"NovaDiskAllocationRatio\": {\"type\": \"number\", \"description\": \"Virtual disk to physical disk allocation ratio.\", \"default\": 0.0, \"tags\": [\"role_specific\"]}, \"NovaEnableVTPM\": {\"type\": \"boolean\", \"description\": \"Whether to enable support for enumlated Trusted Platform Module (TPM) devices.\\n\", \"default\": false, \"tags\": [\"role_specific\"]}, \"NovaMaxDiskDevicesToAttach\": {\"type\": \"number\", \"description\": \"Maximum number of disk devices allowed to attach to a single server. Note that the number of disks supported by an server depends on the bus used. For example, the ide disk bus is limited to 4 attached devices. The configured maximum is enforced during server create, rebuild, evacuate, unshelve, live migrate, and attach volume. Operators changing this parameter on a compute service that is hosting servers should be aware that it could cause rebuilds to fail, if the maximum is decreased lower than the number of devices already attached to servers. Operators should also be aware that during a cold migration, the configured maximum is only enforced in-place and the destination is not checked before the move. -1 means unlimited\\n\", \"default\": -1, \"tags\": [\"role_specific\"]}, \"NovaPMEMMappings\": {\"type\": \"string\", \"description\": \"PMEM namespace mappings as backend for vPMEM feature. This parameter sets Nova\'s `pmem_namespaces` configuration options. PMEM namespaces needs to be create manually or with conjunction with `NovaPMEMNamespaces` parameter. Requires format: $LABEL:$NSNAME[|$NSNAME][,$LABEL:$NSNAME[|$NSNAME]].\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaPMEMNamespaces\": {\"type\": \"string\", \"description\": \"Creates PMEM namespaces on the host server using `ndctl` tool through Ansible. Requires format: $SIZE:$NSNAME[,$SIZE:$NSNAME...]. $SIZE supports the suffixes \\\"k\\\" or \\\"K\\\" for KiB, \\\"m\\\" or \\\"M\\\" for MiB, \\\"g\\\" or \\\"G\\\" for GiB and \\\"t\\\" or \\\"T\\\" for TiB. NOTE: This requires properly configured NVDIMM regions and enough space for requested namespaces.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaImageCacheTTL\": {\"type\": \"number\", \"description\": \"Time in seconds that nova compute should continue caching an image once it is no longer used by any instances on the host\\n\", \"default\": 86400, \"tags\": [\"role_specific\"]}, \"NovaVGPUTypesDeviceAddressesMapping\": {\"type\": \"json\", \"description\": \"Map of vgpu type(s) the instances can get as key and list of corresponding device addresses as value. Ex. NovaVGPUTypesDeviceAddressesMapping: {\'nvidia-35\': [\'0000:84:00.0\', \'0000:85:00.0\'],\\n                                  \'nvidia-36\': [\'0000:86:00.0\']}\\nwhere `nvidia-35` and `nvidia-36` are vgpu types and corresponding values are list of associated device addresses.\\n\", \"default\": {}, \"tags\": [\"role_specific\"]}, \"NovaComputeDisableIrqBalance\": {\"default\": false, \"description\": \"Whether to disable irqbalance on compute nodes or not. Especially in Realtime Compute role one wants to keep it disabled.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaLibvirtCPUMode\": {\"type\": \"string\", \"description\": \"The libvirt CPU mode to configure. Defaults to \'host-model\' if virt_type is set to kvm, otherwise defaults to \'none\'\\n\", \"default\": \"host-model\", \"constraints\": [{\"allowed_values\": [\"custom\", \"host-model\", \"none\", \"host-passthrough\"]}], \"tags\": [\"role_specific\"]}, \"NovaLibvirtCPUModels\": {\"type\": \"comma_delimited_list\", \"description\": \"The named libvirt CPU model (see names listed in /usr/share/libvirt/cpu_map.xml). Only has effect if cpu_mode=\\\"custom\\\" and virt_type=\\\"kvm|qemu\\\"\\n\", \"default\": [], \"tags\": [\"role_specific\"]}, \"NovaLibvirtCPUModelExtraFlags\": {\"type\": \"string\", \"description\": \"This allows specifying granular CPU feature flags when specifying CPU models. Only has effect if cpu_mode is not set to \'none\'.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaDisableImageDownloadToRbd\": {\"type\": \"boolean\", \"description\": \"Refuse to boot an instance if it would require downloading from glance and uploading to ceph instead of a COW clone.\\n\", \"default\": false, \"tags\": [\"role_specific\"]}, \"NovaDisableComputeServiceCheckForFfu\": {\"type\": \"boolean\", \"description\": \"Facilitate a Fast-Forward upgrade where new control services are being started before compute nodes have been able to update their service record.\\n\", \"default\": false}, \"NovaStatedirOwnershipSkip\": {\"type\": \"comma_delimited_list\", \"description\": \"List of paths relative to nova_statedir to ignore when recursively setting the ownership and selinux context.\\n\", \"default\": [\"triliovault-mounts\"]}, \"NovaImageTypeExcludeList\": {\"type\": \"comma_delimited_list\", \"description\": \"List of image formats that should not be advertised as supported by the compute service.\\n\", \"default\": [], \"tags\": [\"role_specific\"]}, \"NovaLibvirtMaxQueues\": {\"type\": \"number\", \"description\": \"Add parameter to configure the libvirt max_queues. The maximum number of virtio queue pairs that can be enabled when creating a multiqueue guest. The number of virtio queues allocated will be the lesser of the CPUs requested by the guest and the max value defined. Default 0 corresponds to not set\\n\", \"default\": 0, \"tags\": [\"role_specific\"]}, \"GlanceRbdPoolName\": {\"default\": \"images\", \"type\": \"string\"}, \"GlanceMultistoreConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring additional glance backends. The\\nhash key is the backend ID, and the value is a dictionary of parameter\\nvalues unique to that backend. Multiple rbd and cinder backends are allowed, but\\nfile and swift backends are limited to one each. Example:\\n  # Default glance store is rbd.\\n  GlanceBackend: rbd\\n  GlanceStoreDescription: \'Default rbd store\'\\n  # GlanceMultistoreConfig specifies a second rbd backend, plus a cinder\\n  # backend.\\n  GlanceMultistoreConfig:\\n    rbd2_store:\\n      GlanceBackend: rbd\\n      GlanceStoreDescription: \'Second rbd store\'\\n      CephClusterName: ceph2\\n      # Override CephClientUserName if this cluster uses a different\\n      # client name.\\n      CephClientUserName: client2\\n    cinder1_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-1\'\\n      GlanceStoreDescription: \'First cinder store\'\\n    cinder2_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-2\'\\n      GlanceStoreDescription: \'Seconde cinder store\'\\n\"}, \"NovaGlanceEnableRbdDownload\": {\"type\": \"boolean\", \"description\": \"Enable download of Glance images directly via RBD.\\n\", \"default\": false, \"tags\": [\"role_specific\"]}, \"NovaGlanceRbdDownloadMultistoreID\": {\"type\": \"string\", \"description\": \"The hash key, which is the backend ID, of the GlanceMultistoreConfig to be used for the role where NovaGlanceEnableRbdDownload is enabled and defaults should be overridden. If CephClientUserName or GlanceRbdPoolName are not set in the GlanceMultistoreConfig, the global values of those parameters will be used.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"GlanceBackendID\": {\"type\": \"string\", \"default\": \"default_backend\", \"description\": \"The default backend\'s identifier.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9_-]+\"}]}, \"NovaGlanceRbdCopyPollInterval\": {\"type\": \"number\", \"description\": \"The interval in seconds with which to poll Glance after asking for it to copy an image to the local rbd store.\\n\", \"default\": 15, \"tags\": [\"role_specific\"]}, \"NovaGlanceRbdCopyTimeout\": {\"type\": \"number\", \"description\": \"The overall maximum time we will wait for Glance to complete an image copy to our local rbd store.\\n\", \"default\": 600, \"tags\": [\"role_specific\"]}, \"CustomProviderInventories\": {\"description\": \"Array of hashes describing the custom providers for the compute role.\\nFormat:\\nname/uuid - Resource providers to target can be identified by either\\nUUID or name. In addition, the value $COMPUTE_NODE can be used in\\nthe UUID field to identify all nodes managed by the service.\\nExactly one of uuid or name is mandatory. If neither uuid or name\\nis provided, the special uuid $COMPUTE_NODE gets set in the template.\\n\\ninventories - (Optional) Hash of custom provider inventories. \'total\' is\\na mandatory property. Any other optional properties not populated will\\nbe given a default value by placement. If overriding a pre-existing\\nprovider values will not be preserved from the existing inventory.\\n\\ntraits - (Optional) Array of additional traits.\\nExample:\\nComputeParameters:\\n  CustomProviderInventories:\\n    - uuid: $COMPUTE_NODE\\n      inventories:\\n        CUSTOM_EXAMPLE_RESOURCE_CLASS:\\n          total: 100\\n          reserved: 0\\n          min_unit: 1\\n          max_unit: 10\\n          step_size: 1\\n          allocation_ratio: 1.0\\n        CUSTOM_ANOTHER_EXAMPLE_RESOURCE_CLASS:\\n          total: 100\\n      traits:\\n        - CUSTOM_P_STATE_ENABLED\\n        - CUSTOM_C_STATE_ENABLED\\n\", \"type\": \"json\", \"default\": {}, \"tags\": [\"role_specific\"]}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"UseTLSTransportForLiveMigration\": {\"type\": \"boolean\", \"default\": true, \"description\": \"If set to true and if EnableInternalTLS is enabled, it will set the libvirt URI\'s transport to tls and configure the relevant keys for libvirt.\"}, \"NovaVcpuPinSet\": {\"description\": \"A list or range of host CPU cores to which processes for unpinned instance CPUs (VCPUs) can be scheduled, if NovaCpuSharedSet is set, or to which both emulator threads and processes for unpinned instance CPUs (VCPUs) can be scheduled, if NovaCpuSharedSet is unset. Ex. NovaVcpuPinSet: [\'4-12\',\'^8\'] will reserve cores from 4-12 excluding 8\\n\", \"type\": \"comma_delimited_list\", \"default\": [], \"tags\": [\"role_specific\"]}, \"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\", \"default\": \"cell1\"}, \"RbdDiskCachemodes\": {\"type\": \"comma_delimited_list\", \"default\": [\"network=writeback\"], \"description\": \"Disk cachemodes for RBD backend.\\n\"}, \"AuthCloudName\": {\"description\": \"Entry in clouds.yaml to use for authentication\", \"type\": \"string\", \"default\": \"overcloud\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenstack mailing list.\\n\", \"parameters\": [\"NovaVcpuPinSet\"]}], \"conditions\": {\"auth_cloud_name_set\": {\"not\": {\"equals\": [{\"get_param\": \"AuthCloudName\"}, \"\"]}}, \"compute_startup_delay\": {\"and\": [{\"not\": {\"get_param\": \"EnableInstanceHA\"}}, {\"not\": {\"and\": [{\"equals\": [{\"get_param\": \"NovaComputeStartupDelay\"}, 0]}, {\"or\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaComputeStartupDelay\"]}, 0]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaComputeStartupDelay\"]}, \"\"]}]}]}}]}, \"use_tls_for_live_migration\": {\"and\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"UseTLSTransportForLiveMigration\"}]}, \"enable_live_migration_tunnelled\": {\"and\": [{\"or\": [{\"and\": [{\"get_param\": \"NovaNfsEnabled\"}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaNfsEnabled\"]}, \"\"]}]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaNfsEnabled\"]}, true]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaEnableRbdBackend\"]}, true]}, {\"and\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaEnableRbdBackend\"]}, \"\"]}, {\"get_param\": \"NovaEnableRbdBackend\"}]}]}, {\"not\": \"use_tls_for_live_migration\"}]}, \"libvirt_file_backed_memory_enabled\": {\"not\": {\"and\": [{\"equals\": [{\"get_param\": \"NovaLibvirtFileBackedMemory\"}, 0]}, {\"or\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaLibvirtFileBackedMemory\"]}, 0]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaLibvirtFileBackedMemory\"]}, \"\"]}]}]}}, \"reserved_huge_pages_set\": {\"not\": {\"and\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaReservedHugePages\"]}, \"\"]}, {\"equals\": [{\"get_param\": \"NovaReservedHugePages\"}, []]}]}}, \"is_realtime\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"TunedProfileName\"]}, \"realtime-virtual-host\"]}, \"ovs_dpdk_socket_memory_not_set\": {\"and\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}, \"\"]}, {\"equals\": [{\"get_param\": \"OvsDpdkSocketMemory\"}, \"\"]}]}, \"nova_libvirt_max_queues_set\": {\"not\": {\"and\": [{\"equals\": [{\"get_param\": \"NovaLibvirtMaxQueues\"}, 0]}, {\"or\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaLibvirtMaxQueues\"]}, \"\"]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaLibvirtMaxQueues\"]}, 0]}]}]}}, \"glance_enable_rbd_download_set\": {\"or\": [{\"and\": [{\"get_param\": \"NovaGlanceEnableRbdDownload\"}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaGlanceEnableRbdDownload\"]}, \"\"]}]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaGlanceEnableRbdDownload\"]}, true]}]}, \"nova_glance_rbd_download_multistore_id_set\": {\"not\": {\"and\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaGlanceRbdDownloadMultistoreID\"]}, \"\"]}, {\"equals\": [{\"get_param\": \"NovaGlanceRbdDownloadMultistoreID\"}, \"\"]}]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}, \"NovaComputeCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-common-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"NovaLogging\": {\"type\": \"OS::TripleO::Services::Logging::NovaCommon\", \"properties\": {\"ContainerNovaImage\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaComputeImage\"]}, \"NovaServiceName\": \"compute\"}}, \"NovaBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"nova::compute::vcpu_pin_set\": \"NovaVcpuPinSet\", \"nova::compute::cpu_shared_set\": \"NovaComputeCpuSharedSet\", \"nova::compute::cpu_dedicated_set\": \"NovaComputeCpuDedicatedSet\", \"nova::compute::reserved_host_memory\": \"NovaReservedHostMemory\", \"nova::compute::reserved_huge_pages\": \"NovaReservedHugePages\", \"nova::compute::neutron_physnets_numa_nodes_mapping\": \"NeutronPhysnetNUMANodesMapping\", \"nova::compute::neutron_tunnel_numa_nodes\": \"NeutronTunnelNUMANodes\", \"nova::compute::resume_guests_state_on_host_boot\": \"NovaResumeGuestsStateOnHostBoot\", \"nova::compute::libvirt::rx_queue_size\": \"NovaLibvirtRxQueueSize\", \"nova::compute::libvirt::tx_queue_size\": \"NovaLibvirtTxQueueSize\", \"nova::compute::libvirt::file_backed_memory\": \"NovaLibvirtFileBackedMemory\", \"nova::compute::libvirt::volume_use_multipath\": \"NovaLibvirtVolumeUseMultipath\", \"nova::compute::libvirt::hw_machine_type\": \"NovaHWMachineType\", \"nova::compute::mkisofs_cmd\": \"NovaMkisofsCmd\", \"compute_enable_ksm\": \"NovaComputeEnableKsm\", \"nova::compute::rbd::libvirt_images_rbd_pool\": \"NovaRbdPoolName\", \"tripleo::profile::base::nova::compute::nova_nfs_enabled\": \"NovaNfsEnabled\", \"nfs_backend_enable\": \"NovaNfsEnabled\", \"nfs_share\": \"NovaNfsShare\", \"nfs_options\": \"NovaNfsOptions\", \"nfs_vers\": \"NovaNfsVersion\", \"nova::compute::libvirt::num_pcie_ports\": \"NovaLibvirtNumPciePorts\", \"nova::compute::libvirt::mem_stats_period_seconds\": \"NovaLibvirtMemStatsPeriodSeconds\", \"nova::compute::rbd::ephemeral_storage\": \"NovaEnableRbdBackend\", \"resume_guests_state_on_host_boot\": \"NovaResumeGuestsStateOnHostBoot\", \"nova::cpu_allocation_ratio\": \"NovaCPUAllocationRatio\", \"nova::ram_allocation_ratio\": \"NovaRAMAllocationRatio\", \"nova::disk_allocation_ratio\": \"NovaDiskAllocationRatio\", \"nova::compute::max_disk_devices_to_attach\": \"NovaMaxDiskDevicesToAttach\", \"nova::compute::libvirt::pmem_namespaces\": \"NovaPMEMMappings\", \"nova_pmem_namespaces\": \"NovaPMEMNamespaces\", \"nova::compute::image_cache::remove_unused_original_minimum_age_seconds\": \"NovaImageCacheTTL\", \"nova::compute::libvirt::swtpm_enabled\": \"NovaEnableVTPM\", \"nova::compute::vgpu::vgpu_types_device_addresses_mapping\": \"NovaVGPUTypesDeviceAddressesMapping\", \"compute_disable_irqbalance\": \"NovaComputeDisableIrqBalance\", \"nova::compute::libvirt::cpu_mode\": \"NovaLibvirtCPUMode\", \"nova::compute::libvirt::cpu_models\": \"NovaLibvirtCPUModels\", \"nova::compute::libvirt::cpu_model_extra_flags\": \"NovaLibvirtCPUModelExtraFlags\", \"nova_compute_opt_volumes\": \"NovaComputeOptVolumes\", \"nova_compute_startup_delay\": \"NovaComputeStartupDelay\", \"nova_compute_opt_env_vars\": \"NovaComputeOptEnvVars\", \"nova::workarounds::never_download_image_if_on_rbd\": \"NovaDisableImageDownloadToRbd\", \"nova::compute::image_type_exclude_list\": \"NovaImageTypeExcludeList\", \"nova_permit_post_copy\": \"NovaLiveMigrationPermitPostCopy\", \"nova_permit_auto_converge\": \"NovaLiveMigrationPermitAutoConverge\", \"nova_libvirt_max_queues\": \"NovaLibvirtMaxQueues\", \"nova_glance_enable_rbd_download\": \"NovaGlanceEnableRbdDownload\", \"nova_glance_rbd_download_multistore_id\": \"NovaGlanceRbdDownloadMultistoreID\", \"nova::compute::force_raw_images\": \"NovaComputeForceRawImages\", \"nova::compute::use_cow_images\": \"NovaComputeUseCowImages\", \"nova::compute::libvirt::preallocate_images\": \"NovaComputeLibvirtPreAllocateImages\", \"nova::compute::image_cache::manager_interval\": \"NovaComputeImageCacheManagerInterval\", \"nova::compute::image_cache::remove_unused_base_images\": \"NovaComputeImageCacheRemoveUnusedBaseImages\", \"nova::compute::image_cache::remove_unused_resized_minimum_age_seconds\": \"NovaComputeImageCacheRemoveUnusedResizedMinimumAge\", \"nova::compute::image_cache::precache_concurrency\": \"NovaComputeImageCachePrecacheConcurrency\", \"nova::compute::provider::custom_inventories\": \"CustomProviderInventories\", \"nova::compute::rbd::libvirt_images_rbd_glance_copy_poll_interval\": \"NovaGlanceRbdCopyPollInterval\", \"nova::compute::rbd::libvirt_images_rbd_glance_copy_timeout\": \"NovaGlanceRbdCopyTimeout\", \"ContainerNovaComputeImage\": \"ContainerNovaComputeImage\", \"ContainerNovaLibvirtConfigImage\": \"ContainerNovaLibvirtConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NovaVcpuPinSet\": {\"get_param\": \"NovaVcpuPinSet\"}, \"NovaComputeCpuSharedSet\": {\"get_param\": \"NovaComputeCpuSharedSet\"}, \"NovaComputeCpuDedicatedSet\": {\"get_param\": \"NovaComputeCpuDedicatedSet\"}, \"NovaReservedHostMemory\": {\"get_param\": \"NovaReservedHostMemory\"}, \"NovaReservedHugePages\": {\"if\": [\"reserved_huge_pages_set\", {\"get_param\": \"NovaReservedHugePages\"}, {\"if\": [\"ovs_dpdk_socket_memory_not_set\", {\"get_param\": \"NovaReservedHugePages\"}, {\"repeat\": {\"for_each\": {\"<%node%>\": {\"yaql\": {\"expression\": \"range(0,len($.data.dpdk_p)).join(\\\",\\\").split(\\\",\\\")\", \"data\": {\"dpdk_p\": {\"if\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}, \"\"]}, {\"str_split\": [\",\", {\"get_param\": \"OvsDpdkSocketMemory\"}]}, {\"str_split\": [\",\", {\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}]}]}}}}, \"<%size%>\": {\"yaql\": {\"expression\": \"let(hzx => regex(\\\"([0-9]+[K|M|G])\\\").search($.data.kern_p+$.data.kern_g)) -> let(hz =>switch($hzx = \\\"4K\\\" => \\\"4\\\", $hzx = \\\"2M\\\" => \\\"2048\\\", $hzx = \\\"1G\\\" => \\\"1048576\\\", $hzx  => \\\"2048\\\", $hzx = null => \\\"2048\\\")) -> [$hz]*len($.data.dpdk_p)\", \"data\": {\"dpdk_p\": {\"if\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}, \"\"]}, {\"str_split\": [\",\", {\"get_param\": \"OvsDpdkSocketMemory\"}]}, {\"str_split\": [\",\", {\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}]}]}, \"kern_p\": {\"get_param\": [\"RoleParameters\", \"KernelArgs\"]}, \"kern_g\": {\"get_param\": \"KernelArgs\"}}}}, \"<%count%>\": {\"yaql\": {\"expression\": \"let(hzx => regex(\\\"([0-9]+[K|M|G])\\\").search($.data.kern_p+$.data.kern_g)) -> let(hz =>int(switch($hzx = \\\"4K\\\" => \\\"4\\\", $hzx = \\\"2M\\\" => \\\"2048\\\", $hzx = \\\"1G\\\" => \\\"1048576\\\", $hzx  => \\\"2048\\\", $hzx = null => \\\"2048\\\"))) -> $.data.dpdk_p.select(int($)*1024/$hz).join(\\\",\\\").split(\',\')\", \"data\": {\"dpdk_p\": {\"if\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}, \"\"]}, {\"str_split\": [\",\", {\"get_param\": \"OvsDpdkSocketMemory\"}]}, {\"str_split\": [\",\", {\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}]}]}, \"kern_p\": {\"get_param\": [\"RoleParameters\", \"KernelArgs\"]}, \"kern_g\": {\"get_param\": \"KernelArgs\"}}}}}, \"template\": \"node:<%node%>,size:<%size%>,count:<%count%>\", \"permutations\": false}}]}]}, \"NeutronPhysnetNUMANodesMapping\": {\"get_param\": \"NeutronPhysnetNUMANodesMapping\"}, \"NeutronTunnelNUMANodes\": {\"get_param\": \"NeutronTunnelNUMANodes\"}, \"NovaResumeGuestsStateOnHostBoot\": {\"get_param\": \"NovaResumeGuestsStateOnHostBoot\"}, \"NovaLibvirtRxQueueSize\": {\"get_param\": \"NovaLibvirtRxQueueSize\"}, \"NovaLibvirtTxQueueSize\": {\"get_param\": \"NovaLibvirtTxQueueSize\"}, \"NovaLibvirtFileBackedMemory\": {\"get_param\": \"NovaLibvirtFileBackedMemory\"}, \"NovaLibvirtVolumeUseMultipath\": {\"get_param\": \"NovaLibvirtVolumeUseMultipath\"}, \"NovaHWMachineType\": {\"get_param\": \"NovaHWMachineType\"}, \"NovaComputeEnableKsm\": {\"get_param\": \"NovaComputeEnableKsm\"}, \"NovaRbdPoolName\": {\"get_param\": \"NovaRbdPoolName\"}, \"NovaMkisofsCmd\": {\"get_param\": \"NovaMkisofsCmd\"}, \"NovaNfsEnabled\": {\"get_param\": \"NovaNfsEnabled\"}, \"NovaNfsShare\": {\"get_param\": \"NovaNfsShare\"}, \"NovaNfsOptions\": {\"get_param\": \"NovaNfsOptions\"}, \"NovaNfsVersion\": {\"get_param\": \"NovaNfsVersion\"}, \"NovaLibvirtNumPciePorts\": {\"get_param\": \"NovaLibvirtNumPciePorts\"}, \"NovaLibvirtMemStatsPeriodSeconds\": {\"get_param\": \"NovaLibvirtMemStatsPeriodSeconds\"}, \"NovaEnableRbdBackend\": {\"get_param\": \"NovaEnableRbdBackend\"}, \"NovaCPUAllocationRatio\": {\"get_param\": \"NovaCPUAllocationRatio\"}, \"NovaRAMAllocationRatio\": {\"get_param\": \"NovaRAMAllocationRatio\"}, \"NovaDiskAllocationRatio\": {\"get_param\": \"NovaDiskAllocationRatio\"}, \"NovaEnableVTPM\": {\"get_param\": \"NovaEnableVTPM\"}, \"NovaMaxDiskDevicesToAttach\": {\"get_param\": \"NovaMaxDiskDevicesToAttach\"}, \"NovaPMEMMappings\": {\"get_param\": \"NovaPMEMMappings\"}, \"NovaPMEMNamespaces\": {\"get_param\": \"NovaPMEMNamespaces\"}, \"NovaImageCacheTTL\": {\"get_param\": \"NovaImageCacheTTL\"}, \"NovaVGPUTypesDeviceAddressesMapping\": {\"get_param\": \"NovaVGPUTypesDeviceAddressesMapping\"}, \"NovaComputeDisableIrqBalance\": {\"get_param\": \"NovaComputeDisableIrqBalance\"}, \"NovaLibvirtCPUMode\": {\"get_param\": \"NovaLibvirtCPUMode\"}, \"NovaLibvirtCPUModels\": {\"get_param\": \"NovaLibvirtCPUModels\"}, \"NovaLibvirtCPUModelExtraFlags\": {\"get_param\": \"NovaLibvirtCPUModelExtraFlags\"}, \"NovaComputeOptVolumes\": {\"get_param\": \"NovaComputeOptVolumes\"}, \"NovaComputeStartupDelay\": {\"get_param\": \"NovaComputeStartupDelay\"}, \"NovaComputeOptEnvVars\": {\"get_param\": \"NovaComputeOptEnvVars\"}, \"NovaDisableImageDownloadToRbd\": {\"get_param\": \"NovaDisableImageDownloadToRbd\"}, \"NovaImageTypeExcludeList\": {\"get_param\": \"NovaImageTypeExcludeList\"}, \"NovaLiveMigrationPermitPostCopy\": {\"get_param\": \"NovaLiveMigrationPermitPostCopy\"}, \"NovaLiveMigrationPermitAutoConverge\": {\"get_param\": \"NovaLiveMigrationPermitAutoConverge\"}, \"NovaLibvirtMaxQueues\": {\"get_param\": \"NovaLibvirtMaxQueues\"}, \"NovaGlanceEnableRbdDownload\": {\"get_param\": \"NovaGlanceEnableRbdDownload\"}, \"NovaGlanceRbdDownloadMultistoreID\": {\"get_param\": \"NovaGlanceRbdDownloadMultistoreID\"}, \"NovaComputeForceRawImages\": {\"get_param\": \"NovaComputeForceRawImages\"}, \"NovaComputeUseCowImages\": {\"get_param\": \"NovaComputeUseCowImages\"}, \"NovaComputeLibvirtPreAllocateImages\": {\"get_param\": \"NovaComputeLibvirtPreAllocateImages\"}, \"NovaComputeImageCacheManagerInterval\": {\"get_param\": \"NovaComputeImageCacheManagerInterval\"}, \"NovaComputeImageCacheRemoveUnusedBaseImages\": {\"get_param\": \"NovaComputeImageCacheRemoveUnusedBaseImages\"}, \"NovaComputeImageCacheRemoveUnusedResizedMinimumAge\": {\"get_param\": \"NovaComputeImageCacheRemoveUnusedResizedMinimumAge\"}, \"NovaComputeImageCachePrecacheConcurrency\": {\"get_param\": \"NovaComputeImageCachePrecacheConcurrency\"}, \"CustomProviderInventories\": {\"get_param\": \"CustomProviderInventories\"}, \"NovaGlanceRbdCopyPollInterval\": {\"get_param\": \"NovaGlanceRbdCopyPollInterval\"}, \"NovaGlanceRbdCopyTimeout\": {\"get_param\": \"NovaGlanceRbdCopyTimeout\"}, \"ContainerNovaComputeImage\": {\"get_param\": \"ContainerNovaComputeImage\"}, \"ContainerNovaLibvirtConfigImage\": {\"get_param\": \"ContainerNovaLibvirtConfigImage\"}}}]}}}}, \"outputs\": {\"nova_compute_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for nova_compute\", \"value\": [{\"name\": \"Mount Nova NFS Share\", \"vars\": {\"nfs_backend_enable\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_backend_enable\"]}, \"nfs_share\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_share\"]}, \"nfs_options\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_options\"]}, \"nfs_vers\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_vers\"]}}, \"mount\": {\"name\": \"/var/lib/nova/instances\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{nfs_share}}\", \"opts\": \"_netdev,bg,{{nfs_options}},nfsvers={{nfs_vers}}\"}, \"when\": \"nfs_backend_enable|bool\"}]}, \"role_data\": {\"description\": \"Role data for the Nova Compute service.\", \"value\": {\"service_name\": \"nova_compute\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionNovaCompute\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"NovaLogging\", \"config_settings\"]}, {\"get_attr\": [\"NovaBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\"]}, {\"nova::compute::libvirt::manage_libvirt_services\": false, \"nova::compute::pci::passthrough\": {\"str_replace\": {\"template\": \"JSON_PARAM\", \"params\": {\"map_replace\": [{\"map_replace\": [{\"JSON_PARAM\": \"NovaPCIPassthrough\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NovaPCIPassthrough\": {\"get_param\": \"NovaPCIPassthrough\"}}}]}}}, \"nova::compute::libvirt::migration_support\": false, \"tripleo::profile::base::nova::migration::client::nova_compute_enabled\": true, \"tripleo::profile::base::nova::migration::client::ssh_private_key\": {\"get_param\": [\"MigrationSshKey\", \"private_key\"]}, \"tripleo::profile::base::nova::migration::client::ssh_port\": {\"get_param\": \"MigrationSshPort\"}, \"nova::compute::rbd::libvirt_images_rbd_glance_store_name\": {\"get_param\": \"GlanceBackendID\"}, \"nova::compute::rbd::libvirt_images_rbd_ceph_conf\": {\"list_join\": [\"\", [\"/etc/ceph/\", {\"get_param\": \"CephClusterName\"}, \".conf\"]]}, \"nova::compute::rbd::libvirt_rbd_user\": {\"get_param\": \"CephClientUserName\"}, \"nova::compute::rbd::rbd_keyring\": {\"list_join\": [\".\", [\"client\", {\"get_param\": \"CephClientUserName\"}]]}, \"tripleo::profile::base::nova::compute::cinder_nfs_backend\": {\"get_param\": \"CinderEnableNfsBackend\"}, \"rbd_persistent_storage\": {\"get_param\": \"CinderEnableRbdBackend\"}, \"rbd_disk_cachemodes\": {\"get_param\": \"RbdDiskCachemodes\"}, \"nova::cinder::username\": \"cinder\", \"nova::cinder::auth_type\": \"v3password\", \"nova::cinder::project_name\": \"service\", \"nova::cinder::password\": {\"get_param\": \"CinderPassword\"}, \"nova::cinder::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"nova::cinder::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::compute::rbd::libvirt_rbd_secret_key\": {\"get_param\": \"CephClientKey\"}, \"nova::compute::rbd::libvirt_rbd_secret_uuid\": {\"get_param\": \"CephClusterFSID\"}, \"nova::compute::instance_usage_audit\": true, \"nova::compute::instance_usage_audit_period\": \"hour\", \"nova::compute::consecutive_build_service_disable_threshold\": {\"get_param\": \"NovaAutoDisabling\"}, \"nova::compute::live_migration_wait_for_vif_plug\": {\"get_param\": \"NovaLiveMigrationWaitForVIFPlug\"}, \"nova::migration::libvirt::live_migration_permit_post_copy\": {\"if\": [\"is_realtime\", false, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_permit_post_copy\"]}]}, \"nova::migration::libvirt::live_migration_permit_auto_converge\": {\"if\": [\"is_realtime\", false, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_permit_auto_converge\"]}]}, \"nova::migration::libvirt::live_migration_tunnelled\": false, \"nova::compute::vncserver_proxyclient_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"nova::compute::vncproxy_host\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"host_nobrackets\"]}, \"nova::vncproxy::common::vncproxy_protocol\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyCellPublic\", \"protocol\"]}, \"nova::vncproxy::common::vncproxy_host\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyCellPublic\", \"host_nobrackets\"]}, \"nova::vncproxy::common::vncproxy_port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyCellPublic\", \"port\"]}, \"nova::compute::verify_glance_signatures\": {\"get_param\": [\"VerifyGlanceSignatures\"]}, \"nova::ram_allocation_ratio\": {\"if\": [\"libvirt_file_backed_memory_enabled\", \"1.0\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova::ram_allocation_ratio\"]}]}, \"nova::compute::libvirt::max_queues\": {\"if\": [\"nova_libvirt_max_queues_set\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_libvirt_max_queues\"]}]}, \"nova::workarounds::disable_compute_service_check_for_ffu\": {\"get_param\": \"NovaDisableComputeServiceCheckForFfu\"}}, {\"if\": [\"glance_enable_rbd_download_set\", {\"nova::glance::enable_rbd_download\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_glance_enable_rbd_download\"]}, \"nova::glance::rbd_user\": {\"if\": [\"nova_glance_rbd_download_multistore_id_set\", {\"yaql\": {\"expression\": \"let(k => $.data.key, d => $.data.default_ceph_client_user_name) -> $.data.multistore.get($k).get(\\\"CephClientUserName\\\", $d)\", \"data\": {\"key\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_glance_rbd_download_multistore_id\"]}, \"multistore\": {\"get_param\": \"GlanceMultistoreConfig\"}, \"default_ceph_client_user_name\": {\"get_param\": \"CephClientUserName\"}}}}, {\"get_param\": \"CephClientUserName\"}]}, \"nova::glance::rbd_pool\": {\"if\": [\"nova_glance_rbd_download_multistore_id_set\", {\"yaql\": {\"expression\": \"let(k => $.data.key, d => $.data.default_glance_rbd_pool_name) -> $.data.multistore.get($k).get(\\\"GlanceRbdPoolName\\\", $d)\", \"data\": {\"key\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_glance_rbd_download_multistore_id\"]}, \"multistore\": {\"get_param\": \"GlanceMultistoreConfig\"}, \"default_glance_rbd_pool_name\": {\"get_param\": \"GlanceRbdPoolName\"}}}}, {\"get_param\": \"GlanceRbdPoolName\"}]}, \"nova::glance::rbd_ceph_conf\": {\"list_join\": [\"\", [\"/etc/ceph/\", {\"if\": [\"nova_glance_rbd_download_multistore_id_set\", {\"yaql\": {\"expression\": \"let(k => $.data.key) -> list(coalesce($.data.multistore, {}).get($k)).flatten().select($.get(\\\"CephClusterName\\\"))\", \"data\": {\"key\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_glance_rbd_download_multistore_id\"]}, \"multistore\": {\"get_param\": \"GlanceMultistoreConfig\"}}}}, {\"get_param\": \"CephClusterName\"}]}, \".conf\"]]}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_nova_compute\": [{\"get_param\": \"NovaComputeLoggingSource\"}]}, \"collectd\": {\"tripleo.collectd.plugins.nova_compute\": [\"virt\"], \"collectd::plugin::virt::connection\": \"qemu:///system\"}}, \"puppet_config\": {\"config_volume\": \"nova_libvirt\", \"puppet_tags\": \"nova_config\", \"step_config\": \"# TODO(emilien): figure how to deal with libvirt profile.\\n# We\'ll probably treat it like we do with Neutron plugins.\\n# Until then, just include it in the default nova-compute role.\\ninclude tripleo::profile::base::nova::compute::libvirt\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/nova_compute.json\": {\"command\": {\"list_join\": [\" \", [{\"if\": [\"compute_startup_delay\", {\"str_replace\": {\"template\": \"/var/lib/nova/delay-nova-compute --delay DELAY --nova-binary\", \"params\": {\"DELAY\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_compute_startup_delay\"]}}}}]}, \"/usr/bin/nova-compute\", {\"get_attr\": [\"NovaLogging\", \"cmd_extra_args\"]}]]}, \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": {\"list_concat\": [[{\"path\": \"/var/log/nova\", \"owner\": \"nova:nova\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"nova:nova\", \"perm\": \"0600\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%keyring%>\", \"owner\": \"nova:nova\", \"perm\": \"0600\"}, \"for_each\": {\"<%keyring%>\": {\"yaql\": {\"expression\": \"let(u => $.data.user) -> $.data.multistore.values().where($.get(\\\"CephClusterName\\\")).select($.CephClusterName + \\\".client.\\\" + $.get(\\\"CephClientUserName\\\", $u) + \\\".keyring\\\")\", \"data\": {\"user\": {\"get_param\": \"CephClientUserName\"}, \"multistore\": {\"get_param\": \"GlanceMultistoreConfig\"}}}}}}}, {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%keyring%>\", \"owner\": \"nova:nova\", \"perm\": \"0600\"}, \"for_each\": {\"<%keyring%>\": {\"yaql\": {\"expression\": \"let(u => $.data.default_user) -> $.data.multiconfig.values().select($.CephClusterName + \\\".client.\\\" + $.get(\\\"CephClientUserName\\\", $u) + \\\".keyring\\\")\", \"data\": {\"default_user\": {\"get_param\": \"CephClientUserName\"}, \"multiconfig\": {\"get_param\": \"CinderRbdMultiConfig\"}}}}}}}]}}, \"/var/lib/kolla/config_files/nova_compute_wait_for_compute_service.json\": {\"command\": \"/container-config-scripts/pyshim.sh /container-config-scripts/nova_wait_for_compute_service.py\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/nova\", \"owner\": \"nova:nova\", \"recurse\": true}]}}, \"container_config_scripts\": {\"map_merge\": [{\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, {\"get_attr\": [\"NovaComputeCommon\", \"container_config_scripts\"]}]}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"NovaLogging\", \"docker_config\", \"step_2\"]}, \"step_3\": {\"nova_statedir_owner\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaComputeImage\"]}, \"net\": \"none\", \"user\": \"root\", \"security_opt\": [\"label=disable\"], \"privileged\": false, \"detach\": false, \"volumes\": [\"/var/lib/nova:/var/lib/nova:shared\", \"/var/lib/_nova_secontext:/var/lib/_nova_secontext:shared,z\", \"/var/lib/container-config-scripts:/container-config-scripts:z\"], \"command\": \"/container-config-scripts/pyshim.sh /container-config-scripts/nova_statedir_ownership.py\", \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}, \"__OS_DEBUG\": {\"yaql\": {\"expression\": \"str($.data.debug)\", \"data\": {\"debug\": {\"get_attr\": [\"NovaBase\", \"role_data\", \"config_settings\", \"nova::logging::debug\"]}}}}, \"NOVA_STATEDIR_OWNERSHIP_SKIP\": {\"list_join\": [\":\", {\"get_param\": \"NovaStatedirOwnershipSkip\"}]}}}}, \"step_5\": {\"map_merge\": [{\"nova_compute\": {\"start_order\": 3, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaComputeImage\"]}, \"ulimit\": {\"get_param\": \"DockerNovaComputeUlimit\"}, \"ipc\": \"host\", \"net\": \"host\", \"privileged\": true, \"user\": \"nova\", \"restart\": \"always\", \"depends_on\": {\"list_concat\": [[\"tripleo_nova_libvirt.target\"], {\"if\": [{\"get_param\": \"NovaNfsEnabled\"}, [\"var-lib-nova-instances.mount\"]]}]}, \"healthcheck\": {\"get_attr\": [\"ContainersCommon\", \"healthcheck_rpc_port\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLogging\", \"volumes\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_compute_opt_volumes\"]}, [\"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\", \"/var/lib/kolla/config_files/nova_compute.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/lib/modules:/lib/modules:ro\", \"/run:/run\", \"/run/nova:/run/nova:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\", \"/var/lib/libvirt:/var/lib/libvirt:shared\", \"/sys/class/net:/sys/class/net\", \"/sys/bus/pci:/sys/bus/pci\", \"/boot:/boot:ro\", \"/var/lib/nova:/var/lib/nova:shared\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}]}, \"environment\": {\"map_merge\": [{\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_compute_opt_env_vars\"]}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}, {\"LIBGUESTFS_BACKEND\": \"direct\"}]}}}, {\"if\": [{\"not\": {\"get_param\": \"NovaAdditionalCell\"}}, {\"nova_wait_for_compute_service\": {\"start_order\": 4, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaComputeImage\"]}, \"net\": \"host\", \"detach\": false, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/nova_compute_wait_for_compute_service.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/nova:/var/log/nova\", \"/var/lib/container-config-scripts:/container-config-scripts\"]]}, \"user\": \"nova\", \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"__OS_DEBUG\": {\"yaql\": {\"expression\": \"str($.data.debug)\", \"data\": {\"debug\": {\"get_attr\": [\"NovaBase\", \"role_data\", \"config_settings\", \"nova::logging::debug\"]}}}}}}}]}]}}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"NovaLogging\", \"host_prep_tasks\"]}, [{\"name\": \"Check for /var/lib/nova/instances directory exitance\", \"stat\": {\"path\": \"/var/lib/nova/instances\"}, \"register\": \"check_nova_instances_result\"}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype | default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/lib/nova\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/_nova_secontext\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/nova/instances\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/libvirt\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/tmpfiles.d\"}]}, {\"name\": \"ensure /run/nova is present upon reboot\", \"copy\": {\"dest\": \"/etc/tmpfiles.d/run-nova.conf\", \"content\": \"d /run/nova 0777 root root - -\\n\"}}, {\"name\": \"create tempfiles\", \"command\": \"systemd-tmpfiles --create\"}], [{\"name\": \"Mount Nova NFS Share\", \"vars\": {\"nfs_backend_enable\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_backend_enable\"]}, \"nfs_share\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_share\"]}, \"nfs_options\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_options\"]}, \"nfs_vers\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_vers\"]}}, \"mount\": {\"name\": \"/var/lib/nova/instances\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{nfs_share}}\", \"opts\": \"_netdev,bg,{{nfs_options}},nfsvers={{nfs_vers}}\"}, \"when\": \"nfs_backend_enable|bool\"}], [{\"name\": \"delay installation of systemd-container\", \"when\": \"check_nova_instances_result.stat.exists\", \"block\": [{\"name\": \"check systemd-container package installed or not\", \"package\": {\"name\": \"systemd-container\", \"state\": \"present\"}, \"check_mode\": true, \"register\": \"is_systemd_container_package\", \"failed_when\": false}, {\"name\": \"get latest package from downloaded package versions\", \"shell\": \"ls -1t /var/tmp/systemd-container* | head -1\", \"register\": \"latest_systemd_container_package\", \"when\": [\"is_systemd_container_package is defined\", \"(\'changed\' in is_systemd_container_package)\", \"is_systemd_container_package.changed\"], \"failed_when\": false}, {\"name\": \"Install systemd-container package on boot\", \"copy\": {\"dest\": \"/etc/systemd/system/install-systemd-container.service\", \"content\": \"[Unit]\\nDescription=Install systemd container package on system boot\\nBefore=tripleo_nova_virtqemud.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/usr/bin/rpm -ivh {{ latest_systemd_container_package.stdout }}\\nExecStartPost=rm -f /var/tmp/systemd-container*\\n\\n[Install]\\nWantedBy=multi-user.target\\n\"}, \"when\": [\"latest_systemd_container_package is defined\", \"(\'stdout\' in latest_systemd_container_package)\", \"is_systemd_container_package is defined\", \"(\'changed\' in is_systemd_container_package)\", \"is_systemd_container_package.changed\"]}, {\"name\": \"enable install-systemd-container on compute boot\", \"systemd\": {\"name\": \"install-systemd-container\", \"state\": \"stopped\", \"enabled\": true, \"daemon_reload\": true}, \"when\": [\"is_systemd_container_package is defined\", \"(\'changed\' in is_systemd_container_package)\", \"is_systemd_container_package.changed\"]}, {\"name\": \"check if install-systemd-container service exists\", \"stat\": {\"path\": \"/etc/systemd/system/install-systemd-container.service\"}, \"register\": \"install_systemd_container_result\"}, {\"name\": \"disable and mask install-systemd-container on compute boot\", \"systemd\": {\"name\": \"install-systemd-container\", \"enabled\": false, \"masked\": true, \"daemon_reload\": true}, \"when\": [\"is_systemd_container_package is defined\", \"(\'changed\' in is_systemd_container_package)\", \"not is_systemd_container_package.changed\", \"install_systemd_container_result.stat.exists\"]}]}, {\"name\": \"is Nova Resume Guests State On Host Boot enabled\", \"set_fact\": {\"resume_guests_state_on_host_boot_enabled\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"resume_guests_state_on_host_boot\"]}}}, {\"name\": \"install libvirt-guests systemd unit file (docker)\", \"when\": [\"resume_guests_state_on_host_boot_enabled|bool\", \"container_cli == \'docker\'\"], \"block\": [{\"name\": \"libvirt-guests unit to stop nova_compute container before shutdown VMs\", \"copy\": {\"dest\": \"/etc/systemd/system/libvirt-guests.service\", \"content\": \"[Unit]\\nDescription=Suspend/Resume Running libvirt Guests\\nAfter=network.target\\nAfter=time-sync.target\\nAfter=virt-guest-shutdown.target\\nAfter=docker.service\\nAfter=tripleo-container-shutdown.service\\nAfter=rhel-push-plugin.service\\nDocumentation=man:libvirtd(8)\\nDocumentation=https://libvirt.org\\n\\n[Service]\\nEnvironmentFile=-/var/lib/config-data/puppet-generated/nova_libvirt/etc/sysconfig/libvirt-guests\\n# Hack just call traditional service until we factor\\n# out the code\\nExecStart=/bin/{{container_cli}} exec nova_libvirt /bin/sh -x /usr/libexec/libvirt-guests.sh start\\nExecStop=/bin/{{container_cli}} stop nova_compute\\nExecStop=/bin/{{container_cli}}  exec nova_libvirt /bin/sh -x /usr/libexec/libvirt-guests.sh stop\\nType=oneshot\\nRemainAfterExit=yes\\nStandardOutput=journal+console\\nTimeoutStopSec=0\\n\\n[Install]\\nWantedBy=multi-user.target\\n\"}}, {\"name\": \"Making sure virt-guest-shutdown.target is present\", \"copy\": {\"dest\": \"/etc/systemd/system/virt-guest-shutdown.target\", \"content\": \"[Unit]\\nDescription=Libvirt guests shutdown\\nDocumentation=https://libvirt.org\\nAfter=systemd-machined.service\\nAfter=network-online.target\\nAfter=tripleo_nova_libvirt.target\\nBefore=tripleo_nova_compute.service\\n\"}}, {\"name\": \"libvirt-guests enable VM shutdown on compute reboot/shutdown\", \"systemd\": {\"name\": \"libvirt-guests\", \"enabled\": true, \"daemon_reload\": true}}]}, {\"name\": \"install tripleo_nova_libvirt_guests systemd unit file (podman)\", \"when\": [\"resume_guests_state_on_host_boot_enabled|bool\", \"container_cli == \'podman\'\"], \"block\": [{\"name\": \"libvirt-guests unit to stop nova_compute container before shutdown VMs (monolithic libvirt)\", \"copy\": {\"dest\": \"/etc/systemd/system/tripleo_nova_libvirt_guests.service\", \"content\": \"[Unit]\\nDescription=Suspend libvirt Guests in tripleo\\nRequires=virt-guest-shutdown.target\\nAfter=systemd-machined.service\\nAfter=network-online.target\\nAfter=tripleo_nova_libvirt.target\\nBefore=tripleo_nova_compute.service\\nDocumentation=man:libvirtd(8)\\nDocumentation=https://libvirt.org\\n\\n[Service]\\nEnvironmentFile=-/etc/sysconfig/libvirt-guests\\nExecStart=/bin/podman exec nova_libvirt /bin/rm -f /var/lib/libvirt/libvirt-guests\\nExecStop=/bin/podman exec nova_libvirt /bin/sh -x /usr/libexec/libvirt-guests.sh shutdown\\nType=oneshot\\nRemainAfterExit=yes\\nStandardOutput=journal+console\\nTimeoutStopSec=0\\n\\n[Install]\\nWantedBy=multi-user.target\\n\"}, \"when\": \"tripleo_nova_libvirt_virsh_container | default(\'nova_libvirt\') == \'nova_libvirt\'\"}, {\"name\": \"libvirt-guests unit to stop nova_compute container before shutdown VMs (modular libvirt)\", \"copy\": {\"dest\": \"/etc/systemd/system/tripleo_nova_libvirt_guests.service\", \"content\": \"[Unit]\\nDescription=Suspend libvirt Guests in tripleo\\nRequires=virt-guest-shutdown.target\\nAfter=systemd-machined.service\\nAfter=network-online.target\\nAfter=tripleo_nova_libvirt.target\\nBefore=tripleo_nova_compute.service\\nDocumentation=man:libvirtd(8)\\nDocumentation=https://libvirt.org\\n\\n[Service]\\nEnvironmentFile=-/etc/sysconfig/libvirt-guests\\nExecStart=/bin/podman exec nova_virtproxyd /bin/rm -f /var/lib/libvirt/libvirt-guests\\nExecStop=/bin/podman exec nova_virtproxyd /bin/sh -x /usr/libexec/libvirt-guests.sh shutdown\\nType=oneshot\\nRemainAfterExit=yes\\nStandardOutput=journal+console\\nTimeoutStopSec=0\\n\\n[Install]\\nWantedBy=multi-user.target\\n\"}, \"when\": \"tripleo_nova_libvirt_virsh_container | default(\'nova_libvirt\') != \'nova_libvirt\'\"}, {\"name\": \"Making sure virt-guest-shutdown.target is present\", \"copy\": {\"dest\": \"/etc/systemd/system/virt-guest-shutdown.target\", \"content\": \"[Unit]\\nDescription=Libvirt guests shutdown\\nDocumentation=https://libvirt.org\\nAfter=systemd-machined.service\\nAfter=network-online.target\\nAfter=tripleo_nova_libvirt.target\\nBefore=tripleo_nova_compute.service\\n\"}}, {\"name\": \"tripleo_nova_libvirt_guests enable VM shutdown on compute reboot/shutdown\", \"systemd\": {\"name\": \"tripleo_nova_libvirt_guests\", \"enabled\": true, \"daemon_reload\": true}}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}, {\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}, {\"name\": \"Do we prepend nova startup with a delay\", \"set_fact\": {\"nova_compute_delay\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_compute_startup_delay\"]}}}, {\"name\": \"install nova-compute delay wrapper script\", \"copy\": {\"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/scripts/delay-nova-compute\"}, \"dest\": \"/var/lib/nova/delay-nova-compute\", \"mode\": 493}, \"when\": \"nova_compute_delay|int > 0\"}, {\"name\": \"Is irqbalance enabled\", \"set_fact\": {\"compute_irqbalance_disabled\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"compute_disable_irqbalance\"]}}}, {\"name\": \"disable irqbalance service on compute\", \"when\": \"compute_irqbalance_disabled|bool\", \"service\": {\"name\": \"irqbalance.service\", \"state\": \"stopped\", \"enabled\": false}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, \"deploy_steps_tasks\": [{\"name\": \"install systemd-container for a greenfield\", \"when\": [\"step|int == 1\", \"not check_nova_instances_result.stat.exists\"], \"package\": {\"name\": \"systemd-container\", \"state\": \"present\"}}, {\"name\": \"validate nova-compute container state\", \"containers.podman.podman_container_info\": {\"name\": \"nova_compute\"}, \"register\": \"nova_compute_infos\", \"failed_when\": [\"nova_compute_infos.containers.0.Healthcheck.Status is defined\", \"\'healthy\' not in nova_compute_infos.containers.0.Healthcheck.Status\"], \"retries\": 10, \"delay\": 30, \"tags\": [\"opendev-validation\", \"opendev-validation-nova\"], \"when\": [\"container_cli == \'podman\'\", \"not container_healthcheck_disabled\", \"step|int == 6\"]}, {\"name\": \"manage PMEM namespaces for vPMEM\", \"include_role\": {\"name\": \"tripleo_nvdimm\"}, \"vars\": {\"tripleo_nvdimm_pmem_namespaces\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_pmem_namespaces\"]}}, \"when\": [\"step|int == 1\", \"tripleo_nvdimm_pmem_namespaces != \'\'\"]}, {\"name\": \"manage OS version 9 specific sysctls\", \"when\": [\"step|int == 1\", \"ansible_facts[\'os_family\'] == \'RedHat\'\", \"ansible_facts[\'distribution_major_version\'] is version(\'9\', \'==\')\"], \"block\": [{\"name\": \"Enable post-copy by setting unprivileged_userfaultfd\", \"sysctl\": {\"name\": \"vm.unprivileged_userfaultfd\", \"value\": 1, \"sysctl_set\": true, \"sysctl_file\": \"/etc/sysctl.d/99-tripleo-postcopy.conf\", \"state\": \"present\", \"reload\": true}}]}, {\"name\": \"enable/disable ksm\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"is KSM enabled\", \"set_fact\": {\"compute_ksm_enabled\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"compute_enable_ksm\"]}}}, {\"name\": \"disable KSM on compute\", \"when\": \"not compute_ksm_enabled|bool\", \"block\": [{\"name\": \"Check for ksm\", \"shell\": \"systemctl is-active ksm.service || systemctl is-enabled ksm.service\", \"become\": true, \"failed_when\": false, \"register\": \"ksm_service_check\"}, {\"name\": \"disable KSM services\", \"service\": {\"name\": \"{{ item }}\", \"state\": \"stopped\", \"enabled\": false}, \"with_items\": [\"ksm.service\", \"ksmtuned.service\"], \"when\": [\"ksm_service_check.rc is defined\", \"ksm_service_check.rc == 0\"], \"register\": \"ksmdisabled\"}, {\"name\": \"delete PageKSM after disable ksm on compute\", \"command\": \"echo 2 >/sys/kernel/mm/ksm/run\", \"when\": [\"ksm_service_check.rc is defined\", \"ksm_service_check.rc == 0\", \"ksmdisabled is changed\"]}]}, {\"name\": \"enable KSM on compute\", \"when\": \"compute_ksm_enabled|bool\", \"block\": [{\"name\": \"make sure package providing ksmtuned is installed (RHEL8 or CentOS8)\", \"package\": {\"name\": \"qemu-kvm-common\", \"state\": \"present\"}, \"when\": [\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\"]}, {\"name\": \"make sure package providing ksmtuned is installed (RHEL9 or CentOS9)\", \"package\": {\"name\": \"ksmtuned\", \"state\": \"present\"}, \"when\": [\"ansible_facts[\'distribution_major_version\'] is version(\'9\', \'==\')\"]}, {\"name\": \"enable ksmtunded\", \"service\": {\"name\": \"{{ item }}\", \"state\": \"started\", \"enabled\": true}, \"with_items\": [\"ksm.service\", \"ksmtuned.service\"]}]}]}], \"external_post_deploy_tasks\": {\"get_attr\": [\"NovaComputeCommon\", \"nova_compute_common_deploy_steps_tasks\"]}, \"upgrade_tasks\": [{\"name\": \"Remove openstack-nova-compute and python-nova package during upgrade\", \"package\": {\"name\": [\"openstack-nova-compute\", \"python-nova\"], \"state\": \"removed\"}, \"failed_when\": false, \"when\": \"step|int == 2\"}, {\"name\": \"nova_compute pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount Nova NFS Share\", \"vars\": {\"nfs_backend_enable\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_backend_enable\"]}}, \"mount\": {\"name\": \"/var/lib/nova/instances\", \"state\": \"absent\", \"fstype\": \"nfs4\"}, \"when\": \"nfs_backend_enable|bool\"}]}, {\"name\": \"nova_compute post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Mount Nova NFS Share\", \"vars\": {\"nfs_backend_enable\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_backend_enable\"]}, \"nfs_share\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_share\"]}, \"nfs_options\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_options\"]}, \"nfs_vers\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_vers\"]}}, \"mount\": {\"name\": \"/var/lib/nova/instances\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{nfs_share}}\", \"opts\": \"_netdev,bg,{{nfs_options}},nfsvers={{nfs_vers}}\"}, \"when\": \"nfs_backend_enable|bool\"}]}], \"update_tasks\": [{\"name\": \"Remove openstack-nova-compute and python-nova package during upgrade\", \"package\": {\"name\": [\"openstack-nova-compute\", \"python-nova\"], \"state\": \"removed\"}, \"failed_when\": false, \"when\": \"step|int == 2\"}], \"post_update_tasks\": [{\"name\": \"Ensure instanceha directory is purged\", \"when\": \"step|int == 1\", \"become\": true, \"file\": {\"path\": \"/var/lib/nova/instanceha\", \"state\": \"absent\"}}], \"post_upgrade_tasks\": [{\"name\": \"Ensure instanceha directory is purged\", \"when\": \"step|int == 1\", \"become\": true, \"file\": {\"path\": \"/var/lib/nova/instanceha\", \"state\": \"absent\"}}], \"scale_tasks\": [{\"when\": [\"step|int == 1\", \"container_cli == \'podman\'\"], \"tags\": \"down\", \"become\": true, \"environment\": {\"OS_CLOUD\": {\"if\": [\"auth_cloud_name_set\", {\"get_param\": \"AuthCloudName\"}, {\"get_param\": \"RootStackName\"}]}}, \"block\": [{\"name\": \"Get nova-compute service ID\", \"command\": \"openstack compute service list --service nova-compute --column ID --column Host --format yaml\", \"register\": \"nova_compute_service_result\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false, \"changed_when\": false}, {\"name\": \"is additional Cell?\", \"set_fact\": {\"is_additional_cell\": {\"get_param\": \"NovaAdditionalCell\"}}}, {\"name\": \"Set fact for nova_compute services\", \"set_fact\": {\"nova_compute_service\": \"{{ nova_compute_service_result.stdout | from_yaml | selectattr(\'Host\', \'match\', ansible_facts[\'fqdn\'] ~ \'.*\') | list }}\"}, \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false}, {\"name\": \"Check search output\", \"fail\": {\"msg\": \"Found multiple `{{ ansible_facts[\'fqdn\'] }}`, which is unexpected. This means that the FQDN of the selected device to disable is either wrong or is sharing a name with another host, which is also wrong. Please correct this issue before continuing. Nova service list return data can be found here -> {{ nova_compute_service }}.\"}, \"when\": [\"(nova_compute_service | length) > 1\"]}, {\"name\": \"Disable nova services\", \"when\": [\"(nova_compute_service | length) == 1\"], \"block\": [{\"name\": \"Disable nova-compute service\", \"command\": \"openstack compute service set {{ nova_compute_service[0].Host }} nova-compute --disable\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false, \"when\": [\"not is_additional_cell|bool\"]}, {\"name\": \"Stop nova-compute container\", \"service\": {\"name\": \"tripleo_nova_compute\", \"state\": \"stopped\", \"enabled\": false}, \"become\": true, \"register\": \"stop_nova_compute\", \"failed_when\": \"(\'msg\' in stop_nova_compute and \'Could not find the requested service tripleo_nova_compute\' not in stop_nova_compute.msg) or (\'rc\' in stop_nova_compute and stop_nova_compute.rc != 0)\"}, {\"name\": \"Delete nova-compute service\", \"command\": \"openstack compute service delete {{ nova_compute_service[0].ID }}\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false}]}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(99,'2026-06-12 08:26:03',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for nova-compute containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": true, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared docker config scripts\", \"value\": {\"nova_statedir_ownership.py\": {\"mode\": \"0700\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/nova_statedir_ownership.py\"}}, \"nova_wait_for_compute_service.py\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/nova_wait_for_compute_service.py\"}}}}, \"nova_compute_common_deploy_steps_tasks\": {\"description\": \"Common host prep tasks for nova-compute services (compute + ironic)\", \"value\": [{\"block\": [{\"name\": \"is additonal Cell?\", \"set_fact\": {\"nova_additional_cell\": {\"get_param\": \"NovaAdditionalCell\"}}}, {\"name\": \"check if discover hosts is required\", \"when\": [\"not nova_additional_cell|bool\", \"nova_cellv2_discovery_done is not defined\"], \"block\": [{\"name\": \"discover via nova_manager?\", \"set_fact\": {\"nova_cellv2_discovery_delegate_host\": \"{{ groups[\'nova_manager\'][0] }}\", \"nova_cellv2_discovery_container\": \"nova_manager\"}, \"when\": [\"groups[\'nova_manager\'] is defined and (groups[\'nova_manager\']|length>0)\"]}, {\"name\": \"discover via nova_api?\", \"set_fact\": {\"nova_cellv2_discovery_delegate_host\": \"{{ groups[\'nova_api\'][0] }}\", \"nova_cellv2_discovery_container\": \"nova_api\"}, \"when\": [\"nova_cellv2_discovery_delegate_host is not defined\", \"groups[\'nova_api\'] is defined and (groups[\'nova_api\']|length>0)\"]}, {\"name\": \"Warn if no discovery host available\", \"fail\": {\"msg\": \"No hosts available to run nova cell_v2 host discovery.\"}, \"ignore_errors\": true, \"when\": [\"nova_cellv2_discovery_delegate_host is not defined\"]}, {\"name\": \"Discovering nova hosts\", \"command\": \"{{ container_cli }} exec {{ nova_cellv2_discovery_container }} nova-manage cell_v2 discover_hosts --by-service\", \"become\": true, \"changed_when\": false, \"delegate_to\": \"{{ nova_cellv2_discovery_delegate_host }}\", \"when\": [\"nova_cellv2_discovery_delegate_host is defined\"]}, {\"set_fact\": {\"nova_cellv2_discovery_done\": true}}]}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(100,'2026-06-12 08:26:03',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(101,'2026-06-12 08:26:03',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Nova database client service.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"NovaPassword\": {\"description\": \"The password for the nova service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"1Ii49H1EfmLUfEWsgfy9vla3q\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova base service.\", \"value\": {\"config_settings\": {\"nova::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlCellInternal\", \"protocol\"]}, \"username\": \"nova\", \"password\": {\"get_param\": \"NovaPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlCellInternal\", \"host\"]}, \"path\": \"/nova\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"nova\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}}, \"service_config_settings\": {\"mysql\": {\"nova::db::mysql::password\": {\"get_param\": \"NovaPassword\"}, \"nova::db::mysql::user\": \"nova\", \"nova::db::mysql::host\": \"%\", \"nova::db::mysql::dbname\": \"nova\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(102,'2026-06-12 08:26:03',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(103,'2026-06-12 08:26:04',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry.  This mapping overrides those in ServiceNetMapDefaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CinderRbdMultiConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring multiple RBD backends. The\\nhash key is the backend name, and the value is a dictionary of parameter\\nvalues unique to that backend. The following parameters are required,\\nand must match the corresponding value defined in CephExternalMultiConfig.\\n  CephClusterName (must match the CephExternalMultiConfig entry\'s \'cluster\')\\n  CephClusterFSID (must match the CephExternalMultiConfig entry\'s \'fsid\')\\nThe following parameters are optional, and override the corresponding\\nparameter\'s default value.\\n  CephClientUserName\\n  CinderRbdPoolName\\n  CinderRbdExtraPools\\n  CinderRbdAvailabilityZone\\n  CinderRbdFlattenVolumeFromSnapshot\\n\"}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"QemuMemoryBackingDir\": {\"type\": \"string\", \"description\": \"Directory used for memoryBacking source if configured as file. NOTE: big files will be stored here\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}}, \"conditions\": {\"memory_backing_dir_set\": {\"not\": {\"and\": [{\"equals\": [{\"get_param\": \"QemuMemoryBackingDir\"}, \"\"]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"QemuMemoryBackingDir\"]}, \"\"]}]}}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"nova::compute::libvirt::qemu::memory_backing_dir\": \"QemuMemoryBackingDir\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"QemuMemoryBackingDir\": {\"get_param\": \"QemuMemoryBackingDir\"}}}]}}}}, \"outputs\": {\"kolla_config_files\": {\"description\": \"Common kolla config_files.\", \"value\": {\"list_concat\": [[{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}]]}}, \"kolla_permissions\": {\"description\": \"Common kolla permissions.\", \"value\": {\"list_concat\": [[{\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"nova:nova\", \"perm\": \"0600\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%keyring%>\", \"owner\": \"nova:nova\", \"perm\": \"0600\"}, \"for_each\": {\"<%keyring%>\": {\"yaql\": {\"expression\": \"let(u => $.data.default_user) -> $.data.multiconfig.values().select($.CephClusterName + \\\".client.\\\" + $.get(\\\"CephClientUserName\\\", $u) + \\\".keyring\\\")\", \"data\": {\"default_user\": {\"get_param\": \"CephClientUserName\"}, \"multiconfig\": {\"get_param\": \"CinderRbdMultiConfig\"}}}}}}}]}}, \"config_settings\": {\"description\": \"Extra hieradata for all modular virt daemons.\", \"value\": {\"get_attr\": [\"RoleParametersValue\", \"value\"]}}, \"volumes\": {\"description\": \"Common volumes for all modular virt daemons.\", \"value\": {\"list_concat\": [[\"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys/fs/cgroup:/sys/fs/cgroup\", \"/sys/fs/selinux:/sys/fs/selinux\", \"/etc/selinux/config:/etc/selinux/config:ro\", \"/etc/libvirt:/etc/libvirt:shared\", \"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\", \"/run/libvirt:/run/libvirt:shared,z\", \"/var/lib/nova:/var/lib/nova:shared\", \"/var/lib/libvirt:/var/lib/libvirt:shared\", \"/var/cache/libvirt:/var/cache/libvirt:shared\", \"/var/lib/vhost_sockets:/var/lib/vhost_sockets\", \"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/CA/cacert.pem:/etc/pki/CA/cacert.pem:ro\", \"/etc/pki/libvirt:/etc/pki/libvirt:ro\", \"/etc/pki/qemu:/etc/pki/qemu:ro\"]]}, {\"if\": [\"memory_backing_dir_set\", [{\"str_replace\": {\"template\": \"MEMORY_BACKING_DIR:MEMORY_BACKING_DIR\", \"params\": {\"MEMORY_BACKING_DIR\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova::compute::libvirt::qemu::memory_backing_dir\"]}}}}]]}]}}, \"update_tasks\": {\"description\": \"Common update tasks for modular virt daemons\", \"value\": [{\"name\": \"check systemd-container package present or not\", \"package\": {\"name\": \"systemd-container\", \"state\": \"present\"}, \"check_mode\": true, \"register\": \"is_systemd_container_package\"}, {\"name\": \"download systemd-container package if not present\", \"yum\": {\"name\": \"systemd-container\", \"state\": \"present\", \"download_only\": true, \"download_dir\": \"/var/tmp/\"}, \"when\": \"is_systemd_container_package.changed\"}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(104,'2026-06-12 08:26:04',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (105,'2026-06-12 08:26:04',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Nova base service. Shared for all Nova services.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"NovaPassword\": {\"description\": \"The password for the nova service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"1Ii49H1EfmLUfEWsgfy9vla3q\"}, \"NeutronPassword\": {\"description\": \"The password for the neutron service and db account, used by neutron agents.\", \"type\": \"string\", \"hidden\": true, \"default\": \"qnvMdngIoyiS9ntQpzmg868ob\"}, \"PlacementPassword\": {\"description\": \"The password for the Placement service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\"}, \"PlacementAPIInterface\": {\"type\": \"string\", \"description\": \"Endpoint interface to be used for the placement API.\\n\", \"default\": \"internal\"}, \"NovaOVSBridge\": {\"default\": \"br-int\", \"description\": \"Name of integration bridge used by Open vSwitch\", \"type\": \"string\"}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"NovaDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Nova services.\", \"type\": \"boolean\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"EnableConfigPurge\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Remove configuration that is not generated by TripleO. Used to avoid configuration remnants after upgrades.\\n\"}, \"UpgradeLevelNovaCompute\": {\"type\": \"string\", \"description\": \"Nova Compute upgrade level\", \"default\": \"\"}, \"NovaOVSDBConnection\": {\"type\": \"string\", \"description\": \"OVS DB connection string to used by Nova\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaSyncPowerStateInterval\": {\"type\": \"number\", \"description\": \"Interval to sync power states between the database and the hypervisor. Set to -1 to disable. Setting this to 0 will run at the default rate(60) defined in oslo.service.\", \"default\": 600}, \"RpcUseSSL\": {\"default\": false, \"description\": \"Messaging client subscriber parameter to specify an SSL connection to the messaging host.\\n\", \"type\": \"string\"}, \"NovaAdditionalCell\": {\"default\": true, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"NovaCrossAZAttach\": {\"default\": true, \"description\": \"Whether instances can attach cinder volumes from a different availability zone.\", \"type\": \"boolean\"}, \"MemcachedTLS\": {\"default\": false, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"conditions\": {\"compute_upgrade_level_set\": {\"not\": {\"equals\": [{\"get_param\": \"UpgradeLevelNovaCompute\"}, \"\"]}}, \"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"nova::ovsdb_connection\": \"NovaOVSDBConnection\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NovaOVSDBConnection\": {\"get_param\": \"NovaOVSDBConnection\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova base service.\", \"value\": {\"service_name\": \"nova_base\", \"config_settings\": {\"map_merge\": [{\"nova::my_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}}}, \"nova::rabbit_use_ssl\": {\"get_param\": \"RpcUseSSL\"}, \"nova::keystone::service_user::send_service_user_token\": true, \"nova::keystone::service_user::project_name\": \"service\", \"nova::keystone::service_user::password\": {\"get_param\": \"NovaPassword\"}, \"nova::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::placement::project_name\": \"service\", \"nova::placement::password\": {\"get_param\": \"PlacementPassword\"}, \"nova::placement::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::placement::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::placement::valid_interfaces\": {\"get_param\": \"PlacementAPIInterface\"}, \"nova::os_region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::logging::debug\": {\"if\": [{\"get_param\": \"NovaDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"nova::purge_config\": {\"get_param\": \"EnableConfigPurge\"}, \"nova::network::neutron::project_name\": \"service\", \"nova::network::neutron::username\": \"neutron\", \"nova::network::neutron::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::dhcp_domain\": \"\", \"nova::network::neutron::password\": {\"get_param\": \"NeutronPassword\"}, \"nova::network::neutron::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"nova::network::neutron::valid_interfaces\": \"internal\", \"nova::glance::valid_interfaces\": \"internal\", \"nova::rabbit_heartbeat_timeout_threshold\": 60, \"nova::cinder_catalog_info\": \"volumev3:cinderv3:internalURL\", \"nova::host\": \"%{hiera(\'fqdn_canonical\')}\", \"nova::notify_on_state_change\": \"vm_and_task_state\", \"nova::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"nova::notification_format\": \"unversioned\", \"nova::network::neutron::auth_type\": \"v3password\", \"nova::db::database_db_max_retries\": -1, \"nova::db::database_max_retries\": -1, \"nova::network::neutron::ovs_bridge\": {\"get_param\": \"NovaOVSBridge\"}, \"nova::compute::sync_power_state_interval\": {\"get_param\": \"NovaSyncPowerStateInterval\"}, \"nova_is_additional_cell\": {\"get_param\": \"NovaAdditionalCell\"}, \"nova::cross_az_attach\": {\"get_param\": \"NovaCrossAZAttach\"}, \"nova::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"nova::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}, \"nova::cache::backend\": {\"if\": [\"tls_cache_enabled\", \"dogpile.cache.pymemcache\", \"dogpile.cache.memcached\"]}, \"nova::rabbit_heartbeat_in_pthread\": false, \"nova::upgrade_level_compute\": {\"if\": [\"compute_upgrade_level_set\", {\"get_param\": \"UpgradeLevelNovaCompute\"}]}}, {\"get_attr\": [\"RoleParametersValue\", \"value\"]}]}, \"service_config_settings\": {\"rabbitmq\": {\"nova::rabbit_use_ssl\": {\"get_param\": \"RpcUseSSL\"}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(106,'2026-06-12 08:26:04',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(107,'2026-06-12 08:26:04',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(108,'2026-06-12 08:26:04',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(109,'2026-06-12 08:26:04',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Nova database client service.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"NovaPassword\": {\"description\": \"The password for the nova service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"1Ii49H1EfmLUfEWsgfy9vla3q\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova base service.\", \"value\": {\"config_settings\": {\"nova::api_database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"nova_api\", \"password\": {\"get_param\": \"NovaPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/nova_api\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"nova_api\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}}, \"service_config_settings\": {\"mysql\": {\"nova::db::mysql_api::password\": {\"get_param\": \"NovaPassword\"}, \"nova::db::mysql_api::user\": \"nova_api\", \"nova::db::mysql_api::host\": \"%\", \"nova::db::mysql_api::dbname\": \"nova_api\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(110,'2026-06-12 08:26:04',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Rabbitmq service\\n\", \"parameters\": {\"ContainerRabbitmqImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\"}, \"ContainerRabbitmqConfigImage\": {\"description\": \"The container image to use for the rabbitmq config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\"}, \"ClusterCommonTag\": {\"default\": false, \"description\": \"When set to false, a pacemaker service is configured to use a floating tag for its container image name, e.g. \'REGISTRY/NAMESPACE/IMAGENAME:pcmklatest\'. When set to true, the service uses a floating prefix as well, e.g. \'cluster.common.tag/IMAGENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"ClusterFullTag\": {\"default\": true, \"description\": \"When set to true, the pacemaker service uses a fully constant tag for its container image name, e.g. \'cluster.common.tag/SERVICENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RabbitCookie\": {\"type\": \"string\", \"default\": \"2ljqdppvti5CXNoMTl6c\", \"hidden\": true}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ConfigDebug\": {\"default\": false, \"description\": \"Whether to run config management (e.g. Puppet) in debug mode.\", \"type\": \"boolean\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"DeployIdentifier\": {\"default\": 1781252715, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}}, \"conditions\": {\"puppet_debug_enabled\": {\"get_param\": \"ConfigDebug\"}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}, \"common_tag_enabled\": {\"equals\": [{\"get_param\": \"ClusterCommonTag\"}, true]}, \"common_tag_full\": {\"equals\": [{\"get_param\": \"ClusterFullTag\"}, true]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RabbitmqBase\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-container-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerRabbitmqImage\": \"ContainerRabbitmqImage\", \"ContainerRabbitmqConfigImage\": \"ContainerRabbitmqConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerRabbitmqImage\": {\"get_param\": \"ContainerRabbitmqImage\"}, \"ContainerRabbitmqConfigImage\": {\"get_param\": \"ContainerRabbitmqConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Rabbitmq API role.\", \"value\": {\"service_name\": {\"get_attr\": [\"RabbitmqBase\", \"role_data\", \"service_name\"]}, \"firewall_rules\": {\"109 rabbitmq-bundle\": {\"dport\": [3122, 4369, 5672, 25672, \"25673-25683\"]}}, \"global_config_settings\": {\"get_attr\": [\"RabbitmqBase\", \"role_data\", \"global_config_settings\"]}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"RabbitmqBase\", \"role_data\", \"config_settings\"]}, {\"rabbitmq::service_manage\": false, \"tripleo::profile::pacemaker::rabbitmq_bundle::rabbitmq_docker_image\": {\"if\": [\"common_tag_full\", \"cluster.common.tag/rabbitmq:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [\"common_tag_enabled\", {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"tripleo::profile::pacemaker::rabbitmq_bundle::control_port\": 3122, \"tripleo::profile::pacemaker::rabbitmq_bundle::container_backend\": {\"get_param\": \"ContainerCli\"}, \"tripleo::profile::pacemaker::rabbitmq_bundle::force_ocf\": true}]}, \"service_config_settings\": {\"get_attr\": [\"RabbitmqBase\", \"role_data\", \"service_config_settings\"]}, \"puppet_config\": {\"config_volume\": \"rabbitmq\", \"puppet_tags\": \"file,file_line\", \"step_config\": {\"list_join\": [\"\\n\", [\"[\'Rabbitmq_policy\', \'Rabbitmq_user\'].each |String $val| { noop_resource($val) }\", \"include tripleo::profile::pacemaker::rabbitmq_bundle\"]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/rabbitmq.json\": {\"command\": \"/usr/sbin/pacemaker_remoted\", \"config_files\": [{\"dest\": \"/etc/libqb/force-filesystem-sockets\", \"source\": \"/dev/null\", \"owner\": \"root\", \"perm\": \"0644\"}, {\"dest\": \"/var/log/btmp\", \"source\": \"/dev/null\", \"owner\": \"root:utmp\", \"perm\": \"0600\"}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"optional\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/lib/rabbitmq\", \"owner\": \"rabbitmq:rabbitmq\", \"recurse\": true}, {\"path\": \"/var/log/rabbitmq\", \"owner\": \"rabbitmq:rabbitmq\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/rabbitmq.crt\", \"owner\": \"rabbitmq:rabbitmq\", \"perm\": \"0600\", \"optional\": true}, {\"path\": \"/etc/pki/tls/private/rabbitmq.key\", \"owner\": \"rabbitmq:rabbitmq\", \"perm\": \"0600\", \"optional\": true}]}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"docker_config\": {\"step_1\": {\"rabbitmq_bootstrap\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}, \"net\": \"host\", \"privileged\": false, \"user\": \"root\", \"command\": [\"bash\", \"-ec\", {\"list_join\": [\"\\n\", [\"kolla_set_configs\", \"if [[ -e \\\"/var/lib/rabbitmq/.erlang.cookie\\\" ]]; then rm -f /var/lib/rabbitmq/.erlang.cookie; fi\", \"hiera \'rabbitmq::erlang_cookie\' > /var/lib/rabbitmq/.erlang.cookie\", \"chown rabbitmq:rabbitmq /var/lib/rabbitmq/.erlang.cookie\", \"chmod 400 /var/lib/rabbitmq/.erlang.cookie\"]]}], \"volumes\": [\"/var/lib/kolla/config_files/rabbitmq.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/rabbitmq:/var/lib/kolla/config_files/src:ro\", \"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/var/lib/rabbitmq:/var/lib/rabbitmq:z\", \"/etc/puppet:/etc/puppet:ro,z\"], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}, \"step_2\": {\"rabbitmq_wait_bundle\": {\"start_order\": 0, \"detach\": false, \"net\": \"host\", \"ipc\": \"host\", \"user\": \"root\", \"command\": {\"list_concat\": [[\"/container_puppet_apply.sh\", \"2\", \"file,file_line,concat,augeas,rabbitmq_policy,rabbitmq_user,rabbitmq_ready\", \"include tripleo::profile::pacemaker::rabbitmq_bundle\"], {\"if\": [\"puppet_debug_enabled\", [\"--debug\"], [\"\"]]}]}, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"container_puppet_apply_volumes\"]}, [\"/bin/true:/bin/epmd\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"KOLLA_BOOTSTRAP\": true, \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}}, \"metadata_settings\": {\"get_attr\": [\"RabbitmqBase\", \"role_data\", \"metadata_settings\"]}, \"host_prep_tasks\": [{\"name\": \"create fcontext for rabbitmq data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/rabbitmq(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/lib/rabbitmq\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/log/containers/rabbitmq\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}, {\"name\": \"stop the Erlang port mapper on the host and make sure it cannot bind to the port used by container\", \"shell\": \"echo \'export ERL_EPMD_ADDRESS=127.0.0.1\' > /etc/rabbitmq/rabbitmq-env.conf\\necho \'export ERL_EPMD_PORT=4370\' >> /etc/rabbitmq/rabbitmq-env.conf\\nfor pid in $(pgrep epmd --ns 1 --nslist pid); do kill $pid; done\\n\"}], \"deploy_steps_tasks\": {\"list_concat\": [{\"get_attr\": [\"RabbitmqBase\", \"role_data\", \"deploy_steps_tasks\"]}, [{\"name\": \"RabbitMQ tag container image for pacemaker\", \"when\": \"step|int == 1\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}, \"container_image_latest\": {\"if\": [\"common_tag_full\", \"cluster.common.tag/rabbitmq:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [\"common_tag_enabled\", {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}}}, {\"name\": \"RabbitMQ RPC HA Wrappers Step\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Rabbitmq rpc puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"oslo_messaging_rpc\", \"tripleo_ha_wrapper_resource_name\": \"rabbitmq\", \"tripleo_ha_wrapper_bundle_name\": \"rabbitmq-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"rabbitmq\", \"tripleo_ha_wrapper_puppet_execute\": \"[\\\"Rabbitmq_policy\\\", \\\"Rabbitmq_user\\\"].each |String $val| { noop_resource($val) }; include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::rabbitmq_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}]}]]}, \"external_update_tasks\": [{\"when\": \"step|int == 1\", \"tags\": \"ha_image_update\", \"block\": [{\"block\": [{\"name\": \"Get rabbitmq image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_rabbitmq_rpc_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'rabbitmq-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container rabbitmq image\", \"set_fact\": {\"rabbitmq_rpc_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}, \"rabbitmq_rpc_image_latest\": {\"if\": [\"common_tag_full\", \"cluster.common.tag/rabbitmq:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [\"common_tag_enabled\", {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_rabbitmq_rpc_image\": \"{{xmllint_pcmk_rabbitmq_rpc_image.stdout}}\"}}], \"delegate_to\": \"{{ (groups[\\\"oslo_messaging_rpc\\\"] | difference(groups[\\\"excluded_overcloud\\\"]))[0] }}\"}, {\"name\": \"rabbitmq temporary pacemaker container tag in case of image switch\", \"become\": true, \"import_role\": {\"name\": \"tripleo_ha_image_update\"}, \"vars\": {\"tripleo_ha_image_update_node_names\": \"{{ groups[\\\"oslo_messaging_rpc\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) }}\", \"tripleo_ha_image_update_bundle\": \"rabbitmq-bundle\", \"tripleo_ha_image_update_new_image\": \"{{rabbitmq_rpc_image_latest}}\", \"tripleo_ha_image_update_old_image\": \"{{pcmk_rabbitmq_rpc_image}}\"}, \"when\": [\"(pcmk_rabbitmq_rpc_image != \\\"\\\")\", \"(pcmk_rabbitmq_rpc_image != rabbitmq_rpc_image_latest)\"]}]}], \"update_tasks\": [{\"block\": [{\"name\": \"Get rabbitmq image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_rabbitmq_rpc_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'rabbitmq-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container rabbitmq image\", \"set_fact\": {\"rabbitmq_rpc_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}, \"rabbitmq_rpc_image_latest\": {\"if\": [\"common_tag_full\", \"cluster.common.tag/rabbitmq:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [\"common_tag_enabled\", {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_rabbitmq_rpc_image\": \"{{xmllint_pcmk_rabbitmq_rpc_image.stdout}}\"}}], \"when\": \"(step|int == 0 or step|int == 2)\"}, {\"name\": \"Check for update of rabbitmq container image name\", \"when\": \"step|int == 0\", \"assert\": {\"that\": \"pcmk_rabbitmq_rpc_image == rabbitmq_rpc_image_latest\", \"fail_msg\": \"rabbitmq image change detected, run overcloud external-update --tags ha_image_update first\"}}, {\"name\": \"Tear-down non-HA rabbitmq container\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Remove non-HA rabbitmq container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"rabbitmq\"]}}]}, {\"name\": \"Rabbitmq fetch and retag container image for pacemaker\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Retag pcmklatest to latest rabbitmq image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{rabbitmq_rpc_image}}\", \"container_image_latest\": \"{{rabbitmq_rpc_image_latest}}\"}}]}], \"post_update_tasks\": [{\"name\": \"Rabbitmq rpc bundle post update\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Rabbitmq rpc puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"oslo_messaging_rpc\", \"tripleo_ha_wrapper_resource_name\": \"rabbitmq\", \"tripleo_ha_wrapper_bundle_name\": \"rabbitmq-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"rabbitmq\", \"tripleo_ha_wrapper_puppet_execute\": \"[\\\"Rabbitmq_policy\\\", \\\"Rabbitmq_user\\\"].each |String $val| { noop_resource($val) }; include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::rabbitmq_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}], \"vars\": {\"tripleo_ha_wrapper_minor_update\": true}}], \"upgrade_tasks\": [{\"name\": \"Tear-down non-HA rabbitmq container\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Remove non-HA rabbitmq container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"rabbitmq\"]}}]}, {\"name\": \"Prepare switch of rabbitmq image name\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Get rabbitmq image id currently used by pacemaker\", \"shell\": \"pcs resource config rabbitmq-bundle | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\", \"register\": \"rabbitmq_rpc_image_current_res\", \"failed_when\": false}, {\"name\": \"Image facts for rabbitmq\", \"set_fact\": {\"rabbitmq_rpc_image_latest\": {\"if\": [\"common_tag_full\", \"cluster.common.tag/rabbitmq:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [\"common_tag_enabled\", {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"rabbitmq_rpc_image_current\": \"{{rabbitmq_rpc_image_current_res.stdout}}\"}}, {\"name\": \"Temporarily tag the current rabbitmq image id with the upgraded image name\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{rabbitmq_rpc_image_current}}\", \"container_image_latest\": \"{{rabbitmq_rpc_image_latest}}\", \"pull_image\": false}, \"when\": [\"rabbitmq_rpc_image_current != \'\'\", \"rabbitmq_rpc_image_current != rabbitmq_rpc_image_latest\"]}, {\"name\": \"Create rabbitmq_rpc retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/rabbitmq_rpc_needs_retag\", \"state\": \"touch\"}, \"when\": [\"rabbitmq_rpc_image_current != \'\'\", \"rabbitmq_rpc_image_current != rabbitmq_rpc_image_latest\"]}]}, {\"name\": \"Update rabbitmq-bundle pcs resource bundle for new container image\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"set is_rpc_rabbitmq_bootstrap_node fact\", \"set_fact\": \"is_rpc_rabbitmq_bootstrap_node={{oslo_messaging_rpc_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\"}, {\"name\": \"Check for rabbitmq_rpc retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/rabbitmq_rpc_needs_retag\"}, \"register\": \"rabbitmq_rpc_retag_state_file\"}]}, {\"name\": \"Update rabbitmq-bundle pcs resource bundle for new container image\", \"when\": [\"step|int == 1\", \"is_rpc_rabbitmq_bootstrap_node|bool\", \"rabbitmq_rpc_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the rabbitmq cluster resource before container upgrade\", \"pacemaker_resource\": {\"resource\": \"rabbitmq-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Check rabbitmq logging configuration in pacemaker\", \"command\": \"cibadmin --query --xpath \\\"//storage-mapping[@id=\'rabbitmq-log\']\\\"\", \"failed_when\": false, \"register\": \"rabbitmq_logs_moved\"}, {\"name\": \"Add a bind mount for logging in the rabbitmq bundle\", \"when\": \"rabbitmq_logs_moved.rc == 6\", \"command\": \"pcs resource bundle update rabbitmq-bundle storage-map add id=rabbitmq-log source-dir=/var/log/containers/rabbitmq target-dir=/var/log/rabbitmq options=rw\"}, {\"name\": \"Update the rabbitmq bundle to use the new container image name\", \"command\": \"pcs resource bundle update rabbitmq-bundle container image={{rabbitmq_rpc_image_latest}}\"}, {\"name\": \"Enable the rabbitmq cluster resource\", \"pacemaker_resource\": {\"resource\": \"rabbitmq-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}]}, {\"name\": \"Check for rabbitmq_rpc retag statefile\", \"when\": [\"step|int == 3\"], \"stat\": {\"path\": \"/var/lib/tripleo/rabbitmq_rpc_needs_retag\"}, \"register\": \"rabbitmq_rpc_retag_state_file\"}, {\"name\": \"Retag rabbitmq-bundle container image\", \"when\": [\"step|int == 3\", \"rabbitmq_rpc_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the rabbitmq cluster resource before container upgrade\", \"pacemaker_resource\": {\"resource\": \"rabbitmq-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Retag the pacemaker image if containerized\", \"block\": [{\"block\": [{\"name\": \"Get rabbitmq image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_rabbitmq_rpc_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'rabbitmq-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container rabbitmq image\", \"set_fact\": {\"rabbitmq_rpc_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}, \"rabbitmq_rpc_image_latest\": {\"if\": [\"common_tag_full\", \"cluster.common.tag/rabbitmq:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [\"common_tag_enabled\", {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_rabbitmq_rpc_image\": \"{{xmllint_pcmk_rabbitmq_rpc_image.stdout}}\"}}]}, {\"block\": [{\"name\": \"Retag pcmklatest to latest rabbitmq image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{rabbitmq_rpc_image}}\", \"container_image_latest\": \"{{rabbitmq_rpc_image_latest}}\"}}]}]}, {\"name\": \"Enable the rabbitmq cluster resource\", \"pacemaker_resource\": {\"resource\": \"rabbitmq-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Remove rabbitmq_rpc retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/rabbitmq_rpc_needs_retag\", \"state\": \"absent\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(111,'2026-06-12 08:26:05',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Nova libvirt service\\n\", \"parameters\": {\"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"LibvirtDebug\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Set to True to enable debugging libvirt services.\"}, \"LibvirtLogLevel\": {\"default\": 3, \"description\": \"Defines log level in libvirt to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}, \"LibvirtVirtlogdLogLevel\": {\"default\": 3, \"description\": \"Defines log level in virtlogd to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}, \"LibvirtVirtsecretdLogLevel\": {\"default\": 3, \"description\": \"Defines log level in virtsecretd to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}, \"LibvirtVirtnodedevdLogLevel\": {\"default\": 3, \"description\": \"Defines log level in virtnodedevd to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}, \"LibvirtVirtqemudLogLevel\": {\"default\": 3, \"description\": \"Defines log level in virtqemud to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}, \"LibvirtVirtproxydLogLevel\": {\"default\": 3, \"description\": \"Defines log level in virtproxyd to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}, \"LibvirtVirtstoragedLogLevel\": {\"default\": 3, \"description\": \"Defines log level in virtstoraged to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}}, \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": {\"nova::compute::libvirt::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/libvirtd.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtLogLevel\"}]}}}}, \"nova::compute::libvirt::virtlogd::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/virtlogd.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtVirtlogdLogLevel\"}]}}}}, \"nova::compute::libvirt::virtsecretd::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/virtsecretd.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtVirtsecretdLogLevel\"}]}}}}, \"nova::compute::libvirt::virtnodedevd::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/virtnodedevd.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtVirtnodedevdLogLevel\"}]}}}}, \"nova::compute::libvirt::virtqemud::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/virtqemud.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtVirtqemudLogLevel\"}]}}}}, \"nova::compute::libvirt::virtproxyd::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/virtproxyd.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtVirtproxydLogLevel\"}]}}}}, \"nova::compute::libvirt::virtstoraged::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/virtstoraged.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtVirtstoragedLogLevel\"}]}}}}}}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/libvirt:/var/log/libvirt:shared,z\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to file in the host.\", \"value\": null}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"setype\": \"{{ item.setype }}\", \"state\": \"directory\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/libvirt\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(112,'2026-06-12 08:26:05',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configure libvirt-guests\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerNovaLibvirtConfigImage\": {\"description\": \"The container image to use for the nova_libvirt config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\"}, \"NovaResumeGuestsStateOnHostBoot\": {\"default\": false, \"description\": \"Whether to start running instance on compute host reboot\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaResumeGuestsShutdownTimeout\": {\"default\": 300, \"description\": \"Number of seconds we\'re willing to wait for a guest to shut down. If this is 0, then there is no time out (use with caution, as guests might not respond to a shutdown request). The default value is 300 seconds (5 minutes).\", \"type\": \"string\", \"tags\": [\"role_specific\"]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"tripleo::profile::base::nova::compute::libvirt_guests::enabled\": \"NovaResumeGuestsStateOnHostBoot\", \"nova::compute::libvirt_guests::shutdown_timeout\": \"NovaResumeGuestsShutdownTimeout\", \"ContainerNovaLibvirtConfigImage\": \"ContainerNovaLibvirtConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NovaResumeGuestsStateOnHostBoot\": {\"get_param\": \"NovaResumeGuestsStateOnHostBoot\"}, \"NovaResumeGuestsShutdownTimeout\": {\"get_param\": \"NovaResumeGuestsShutdownTimeout\"}, \"ContainerNovaLibvirtConfigImage\": {\"get_param\": \"ContainerNovaLibvirtConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for libvirt-guests\", \"value\": {\"service_name\": \"nova_libvirt_guests\", \"config_settings\": {\"get_attr\": [\"RoleParametersValue\", \"value\"]}, \"puppet_config\": {\"config_volume\": \"nova_libvirt\", \"puppet_tags\": \"libvirtd_config,nova_config,file,libvirt_tls_password\", \"step_config\": \"include tripleo::profile::base::nova::compute::libvirt_guests\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtConfigImage\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (113,'2026-06-12 08:26:05',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Template for nova\'s logging to files\\n\", \"parameters\": {\"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerNovaImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"NovaServiceName\": {\"description\": \"service name\", \"type\": \"string\"}, \"DeployIdentifier\": {\"default\": 1781252715, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}}, \"resources\": {\"InitLogContainerName\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"str_replace\": {\"template\": \"nova_SERVICE_init_log\", \"params\": {\"SERVICE\": {\"get_param\": \"NovaServiceName\"}}}}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerNovaImage\": \"ContainerNovaImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerNovaImage\": {\"get_param\": \"ContainerNovaImage\"}}}]}}}}, \"outputs\": {\"cmd_extra_args\": {\"description\": \"Extra command line arguments for running the service in the container.\", \"value\": \"\"}, \"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/nova:/var/log/nova\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {\"map_replace\": [{\"CONTAINERNAME\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/nova:/var/log/nova:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R nova:nova /var/log/nova\"], \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}, {\"keys\": {\"CONTAINERNAME\": {\"get_attr\": [\"InitLogContainerName\", \"value\"]}}}]}}}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"setype\": \"{{ item.setype }}\", \"state\": \"directory\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/nova\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ContainerNovaImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"NovaServiceName\": \"compute\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(114,'2026-06-12 08:26:05',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Template for nova\'s logging to files\\n\", \"parameters\": {\"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerNovaImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"NovaServiceName\": {\"description\": \"service name\", \"type\": \"string\"}, \"DeployIdentifier\": {\"default\": 1781252715, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}}, \"resources\": {\"InitLogContainerName\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"str_replace\": {\"template\": \"nova_SERVICE_init_log\", \"params\": {\"SERVICE\": {\"get_param\": \"NovaServiceName\"}}}}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerNovaImage\": \"ContainerNovaImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerNovaImage\": {\"get_param\": \"ContainerNovaImage\"}}}]}}}}, \"outputs\": {\"cmd_extra_args\": {\"description\": \"Extra command line arguments for running the service in the container.\", \"value\": \"\"}, \"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/nova:/var/log/nova\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {\"map_replace\": [{\"CONTAINERNAME\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/nova:/var/log/nova:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R nova:nova /var/log/nova\"], \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}, {\"keys\": {\"CONTAINERNAME\": {\"get_attr\": [\"InitLogContainerName\", \"value\"]}}}]}}}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"setype\": \"{{ item.setype }}\", \"state\": \"directory\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/nova\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ContainerNovaImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"NovaServiceName\": \"conductor\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(115,'2026-06-12 08:26:05',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Nova Migration Target service\\n\", \"parameters\": {\"ContainerNovaComputeImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\"}, \"ContainerNovaLibvirtConfigImage\": {\"description\": \"The container image to use for the nova_libvirt config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"DockerNovaMigrationSshdPort\": {\"default\": 2022, \"description\": \"Port that dockerized nova migration target sshd service binds to.\", \"type\": \"number\"}, \"MigrationSshKey\": {\"type\": \"json\", \"description\": \"SSH key for migration. Expects a dictionary with keys \'public_key\' and \'private_key\'. Values should be identical to SSH public/private key files.\\n\", \"default\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}}, \"MigrationSshPort\": {\"default\": 2022, \"description\": \"Target port for migration over ssh\", \"type\": \"number\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"SshdBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerNovaComputeImage\": \"ContainerNovaComputeImage\", \"ContainerNovaLibvirtConfigImage\": \"ContainerNovaLibvirtConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerNovaComputeImage\": {\"get_param\": \"ContainerNovaComputeImage\"}, \"ContainerNovaLibvirtConfigImage\": {\"get_param\": \"ContainerNovaLibvirtConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova Migration Target service.\", \"value\": {\"service_name\": \"nova_migration_target\", \"firewall_rules\": {\"map_merge\": [{\"map_merge\": {\"repeat\": {\"for_each\": {\"<%net_cidr%>\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}]}}, \"template\": {\"113 nova_migration_target accept libvirt subnet <%net_cidr%>\": {\"source\": \"<%net_cidr%>\", \"proto\": \"tcp\", \"dport\": {\"get_param\": \"MigrationSshPort\"}}}}}}, {\"map_merge\": {\"repeat\": {\"for_each\": {\"<%net_cidr%>\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}}, \"template\": {\"113 nova_migration_target accept api subnet <%net_cidr%>\": {\"source\": \"<%net_cidr%>\", \"proto\": \"tcp\", \"dport\": {\"get_param\": \"MigrationSshPort\"}}}}}}]}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"SshdBase\", \"role_data\", \"config_settings\"]}, {\"tripleo::profile::base::nova::migration::target::ssh_authorized_keys\": [{\"get_param\": [\"MigrationSshKey\", \"public_key\"]}], \"tripleo::profile::base::nova::migration::target::ssh_localaddrs\": [\"%{hiera(\'cold_migration_ssh_inbound_addr\')}\", \"%{hiera(\'live_migration_ssh_inbound_addr\')}\"], \"live_migration_ssh_inbound_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"cold_migration_ssh_inbound_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}}}, \"tripleo::profile::base::sshd::port\": [22]}]}, \"puppet_config\": {\"config_volume\": \"nova_libvirt\", \"step_config\": {\"list_join\": [\"\\n\", [{\"get_attr\": [\"SshdBase\", \"role_data\", \"step_config\"]}, \"include tripleo::profile::base::nova::migration::target\"]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/nova-migration-target.json\": {\"command\": {\"str_replace\": {\"template\": \"dumb-init --single-child -- /usr/sbin/sshd -D -p SSHDPORT\", \"params\": {\"SSHDPORT\": {\"get_param\": \"DockerNovaMigrationSshdPort\"}}}}, \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/host-ssh/ssh_host_*_key\", \"dest\": \"/etc/ssh/\", \"owner\": \"root\", \"perm\": \"0600\"}]}}, \"host_prep_tasks\": [{\"name\": \"Create libvirt persistent data directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\"}, \"loop\": [{\"path\": \"/run/libvirt\", \"setype\": \"virt_var_run_t\"}]}, {\"name\": \"ensure /run/libvirt is present upon reboot\", \"copy\": {\"dest\": \"/etc/tmpfiles.d/run-libvirt.conf\", \"content\": \"d /run/libvirt 0755 root root - -\\n\"}}], \"docker_config\": {\"step_4\": {\"nova_migration_target\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaComputeImage\"]}, \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/nova-migration-target.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\", \"/etc/ssh:/host-ssh:ro\", \"/run/libvirt:/run/libvirt:shared,z\", \"/var/lib/nova:/var/lib/nova:shared\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"deploy_steps_tasks\": [{\"name\": \"validate nova-migration-target container state\", \"containers.podman.podman_container_info\": {\"name\": \"nova_migration_target\"}, \"register\": \"nova_migration_target_infos\", \"failed_when\": [\"nova_migration_target_infos.containers.0.Healthcheck.Status is defined\", \"\'healthy\' not in nova_migration_target_infos.containers.0.Healthcheck.Status\"], \"retries\": 10, \"delay\": 30, \"tags\": [\"opendev-validation\", \"opendev-validation-nova\"], \"when\": [\"container_cli == \'podman\'\", \"not container_healthcheck_disabled\", \"step|int == 5\"]}], \"update_tasks\": [{\"name\": \"nova_migration_target_tmpfile_cleanup\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Remove old tmpfiles.d config\", \"file\": {\"path\": \"/etc/tmpfiles.d/var-run-libvirt.conf\", \"state\": \"absent\"}}]}], \"upgrade_tasks\": [{\"name\": \"nova_migration_target_tmpfile_cleanup\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Remove old tmpfiles.d config\", \"file\": {\"path\": \"/etc/tmpfiles.d/var-run-libvirt.conf\", \"state\": \"absent\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(116,'2026-06-12 08:26:06',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configure sshd_config\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"BannerText\": {\"default\": \"\", \"description\": \"Configures Banner text in sshd_config\", \"type\": \"string\"}, \"MessageOfTheDay\": {\"default\": \"\", \"description\": \"Configures /etc/motd text\", \"type\": \"string\"}, \"SshServerOptions\": {\"default\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"description\": \"Mapping of sshd_config values\", \"type\": \"json\"}, \"SshServerOptionsOverrides\": {\"default\": {}, \"description\": \"Mapping of sshd_config values to override definitions in SshServerOptions\", \"type\": \"json\"}, \"PasswordAuthentication\": {\"default\": \"no\", \"description\": \"Whether or not disable password authentication\", \"type\": \"string\"}, \"SshFirewallAllowAll\": {\"default\": true, \"description\": \"Set this to true to open up ssh access from all sources.\", \"type\": \"boolean\"}}, \"conditions\": {\"ssh_firewall_allow_all\": {\"equals\": [{\"get_param\": \"SshFirewallAllowAll\"}, true]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the ssh\", \"value\": {\"service_name\": \"sshd\", \"firewall_rules\": {\"003 accept ssh from all\": {\"proto\": \"tcp\", \"dport\": 22, \"extras\": {\"ensure\": {\"if\": [\"ssh_firewall_allow_all\", \"present\", \"absent\"]}}}}, \"config_settings\": {\"tripleo::profile::base::sshd::bannertext\": {\"get_param\": \"BannerText\"}, \"tripleo::profile::base::sshd::motd\": {\"get_param\": \"MessageOfTheDay\"}, \"tripleo::profile::base::sshd::options\": {\"map_merge\": [{\"get_param\": \"SshServerOptions\"}, {\"get_param\": \"SshServerOptionsOverrides\"}]}, \"tripleo::profile::base::sshd::password_authentication\": {\"get_param\": \"PasswordAuthentication\"}}, \"step_config\": \"include tripleo::profile::base::sshd\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(117,'2026-06-12 08:26:06',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Apache service configured with Puppet. Note this is typically included automatically via other services which run via Apache.\\n\", \"parameters\": {\"ApacheMaxRequestWorkers\": {\"default\": 100, \"description\": \"Maximum number of simultaneously processed requests.\", \"type\": \"number\"}, \"ApacheServerLimit\": {\"default\": 100, \"description\": \"Maximum number of Apache processes.\", \"type\": \"number\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ApacheCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"ApacheTimeout\": {\"type\": \"number\", \"default\": 90, \"description\": \"The timeout in seconds for Apache, which defines duration Apache waits for I/O operations\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ApacheCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"ApacheNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CellController\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CellControllerCompute\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"Compute\": [\"ctlplane\", \"storage\", \"internal_api\"], \"BlockStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"ObjectStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CephStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"Networker\": [\"ctlplane\", \"internal_api\"]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Apache role.\", \"value\": {\"service_name\": \"apache\", \"config_settings\": {\"map_merge\": [{\"apache::ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}}}}, \"apache::default_vhost\": false, \"apache::trace_enable\": \"Off\", \"apache::server_signature\": \"Off\", \"apache::server_tokens\": \"Prod\", \"apache::timeout\": {\"get_param\": \"ApacheTimeout\"}, \"apache::default_mods\": false, \"apache::mod::prefork::maxrequestworkers\": {\"get_param\": \"ApacheMaxRequestWorkers\"}, \"apache::mod::prefork::serverlimit\": {\"get_param\": \"ApacheServerLimit\"}, \"apache::mod::remoteip::proxy_ips\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}]}, \"apache::mod::alias::icons_options\": \"None\"}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"apache::mod::ssl::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}, \"apache::mod::ssl::ssl_protocol\": [\"all\", \"-SSLv2\", \"-SSLv3\", \"-TLSv1\"], \"apache_certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"httpd-NETWORK\": {\"service_certificate\": \"/etc/pki/tls/certs/httpd/httpd-NETWORK.crt\", \"service_key\": \"/etc/pki/tls/private/httpd/httpd-NETWORK.key\"}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}, \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"repeat\": {\"template\": [{\"service\": \"HTTP\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}]}, \"upgrade_tasks\": [], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/tls/certs/httpd\", \"/etc/pki/tls/private/httpd\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"httpd-NETWORK\", \"dns\": \"{{ fqdn_NETWORK }}\", \"principal\": \"HTTP/{{ fqdn_NETWORK }}@{{ idm_realm }}\", \"run_after\": \"cp /etc/pki/tls/certs/httpd-NETWORK.crt /etc/pki/tls/certs/httpd/httpd-NETWORK.crt\\ncp /etc/pki/tls/private/httpd-NETWORK.key /etc/pki/tls/private/httpd/httpd-NETWORK.key\\npkill -USR1 httpd\\n\", \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"ApacheCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"EnableInternalTLS\": false}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(118,'2026-06-12 08:26:06',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Rabbitmq service\\n\", \"parameters\": {\"ContainerRabbitmqImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\"}, \"ContainerRabbitmqConfigImage\": {\"description\": \"The container image to use for the rabbitmq config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"RabbitCookie\": {\"type\": \"string\", \"default\": \"2ljqdppvti5CXNoMTl6c\", \"hidden\": true}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"RpcUserName\": {\"default\": \"guest\", \"description\": \"The username for messaging backend\", \"type\": \"string\"}, \"RpcPassword\": {\"description\": \"The password for messaging backend\", \"type\": \"string\", \"hidden\": true, \"default\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\"}, \"RpcUseSSL\": {\"default\": false, \"description\": \"Messaging client subscriber parameter to specify an SSL connection to the messaging host.\\n\", \"type\": \"string\"}, \"DeployIdentifier\": {\"default\": 1781252715, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"RpcCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"RabbitFIPS\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Configures RabbitMQ to run in FIPS mode\"}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"key_size_override_unset\": {\"equals\": [{\"get_param\": \"RpcCertificateKeySize\"}, \"\"]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RabbitMQServiceBase\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerRabbitmqImage\": \"ContainerRabbitmqImage\", \"ContainerRabbitmqConfigImage\": \"ContainerRabbitmqConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerRabbitmqImage\": {\"get_param\": \"ContainerRabbitmqImage\"}, \"ContainerRabbitmqConfigImage\": {\"get_param\": \"ContainerRabbitmqConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Rabbitmq API role.\", \"value\": {\"service_name\": \"oslo_messaging_rpc\", \"firewall_rules\": {\"109 rabbitmq\": {\"dport\": [4369, {\"get_param\": \"RpcPort\"}, 25672, \"25673-25683\"]}}, \"monitoring_subscription\": {\"get_attr\": [\"RabbitMQServiceBase\", \"role_data\", \"monitoring_subscription\"]}, \"global_config_settings\": {\"map_merge\": [{\"get_attr\": [\"RabbitMQServiceBase\", \"role_data\", \"global_config_settings\"]}, {\"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_user_name\": {\"get_param\": \"RpcUserName\"}, \"oslo_messaging_rpc_password\": {\"get_param\": \"RpcPassword\"}, \"oslo_messaging_rpc_use_ssl\": {\"get_param\": \"RpcUseSSL\"}, \"oslo_messaging_rpc_port\": {\"get_param\": \"RpcPort\"}}]}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"RabbitMQServiceBase\", \"role_data\", \"config_settings\"]}, {\"rabbitmq::default_user\": {\"get_param\": \"RpcUserName\"}, \"rabbitmq::default_pass\": {\"get_param\": \"RpcPassword\"}, \"rabbitmq::port\": {\"get_param\": \"RpcPort\"}, \"rabbitmq::interface\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OsloMessagingRpcNetwork\"]}}}}, \"rabbitmq::ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"rabbitmq::ssl_erl_dist\": {\"get_param\": \"EnableInternalTLS\"}, \"rabbitmq::ssl_port\": {\"get_param\": \"RpcPort\"}, \"rabbitmq::ssl_only\": {\"get_param\": \"EnableInternalTLS\"}, \"rabbitmq::ssl_interface\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OsloMessagingRpcNetwork\"]}}}}, \"tripleo::profile::base::rabbitmq::enable_internal_tls\": {\"get_param\": \"EnableInternalTLS\"}, \"rabbitmq::collect_statistics_interval\": 30000, \"rabbitmq::admin_enable\": false, \"rabbitmq::management_enable\": true, \"rabbitmq::use_config_file_for_plugins\": true, \"rabbitmq::management_ip_address\": \"127.0.0.1\", \"rabbitmq::config_management_variables\": {\"rates_mode\": \"none\"}}, {\"if\": [\"internal_tls_enabled\", {\"tripleo::rabbitmq::service_certificate\": \"/etc/pki/tls/certs/rabbitmq.crt\", \"tripleo::certmonger::rabbitmq::postsave_cmd\": \"true\", \"tripleo::profile::base::rabbitmq::certificate_specs\": {\"service_certificate\": \"/etc/pki/tls/certs/rabbitmq.crt\", \"service_key\": \"/etc/pki/tls/private/rabbitmq.key\"}, \"rabbitmq::ssl_versions\": {\"if\": [{\"get_param\": \"RabbitFIPS\"}, [\"tlsv1.2\", \"tlsv1.3\"], [\"tlsv1.2\"]]}}, {}]}]}, \"puppet_config\": {\"config_volume\": \"rabbitmq\", \"step_config\": {\"list_join\": [\"\\n\", [\"[\'Rabbitmq_policy\', \'Rabbitmq_user\'].each |String $val| { noop_resource($val) }\", \"include tripleo::profile::base::rabbitmq\"]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/rabbitmq.json\": {\"command\": \"/usr/lib/rabbitmq/bin/rabbitmq-server\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/lib/rabbitmq\", \"owner\": \"rabbitmq:rabbitmq\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/rabbitmq.crt\", \"owner\": \"rabbitmq:rabbitmq\", \"optional\": true}, {\"path\": \"/etc/pki/tls/private/rabbitmq.key\", \"owner\": \"rabbitmq:rabbitmq\", \"optional\": true}]}}, \"docker_config\": {\"step_1\": {\"rabbitmq_init_logs\": {\"start_order\": 0, \"detach\": false, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/rabbitmq:/var/log/rabbitmq:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R rabbitmq:rabbitmq /var/log/rabbitmq\"]}, \"rabbitmq_bootstrap\": {\"start_order\": 1, \"detach\": false, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}, \"net\": \"host\", \"privileged\": false, \"user\": \"root\", \"command\": [\"bash\", \"-ec\", {\"list_join\": [\"\\n\", [\"kolla_set_configs\", \"if [[ -e \\\"/var/lib/rabbitmq/.erlang.cookie\\\" ]]; then rm -f /var/lib/rabbitmq/.erlang.cookie; fi\", \"hiera \'rabbitmq::erlang_cookie\' > /var/lib/rabbitmq/.erlang.cookie\", \"chown rabbitmq:rabbitmq /var/lib/rabbitmq/.erlang.cookie\", \"chmod 400 /var/lib/rabbitmq/.erlang.cookie\"]]}], \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/rabbitmq.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/rabbitmq:/var/lib/kolla/config_files/src:ro\", \"/var/lib/rabbitmq:/var/lib/rabbitmq:z\", \"/var/log/containers/rabbitmq:/var/log/rabbitmq:z\"], {\"if\": [\"internal_tls_enabled\", [\"/etc/pki/tls/certs/rabbitmq.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/rabbitmq.crt:ro\", \"/etc/pki/tls/private/rabbitmq.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/rabbitmq.key:ro\"], null]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}, \"rabbitmq\": {\"start_order\": 2, \"stop_grace_period\": 60, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/rabbitmq.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/rabbitmq:/var/lib/kolla/config_files/src:ro\", \"/var/lib/rabbitmq:/var/lib/rabbitmq:z\", \"/var/log/containers/rabbitmq:/var/log/rabbitmq:z\"], {\"if\": [\"internal_tls_enabled\", [\"/etc/pki/tls/certs/rabbitmq.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/rabbitmq.crt:ro\", \"/etc/pki/tls/private/rabbitmq.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/rabbitmq.key:ro\"], null]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"container_puppet_tasks\": {\"step_2\": {\"config_volume\": \"rabbit_init_tasks\", \"puppet_tags\": \"rabbitmq_policy,rabbitmq_user\", \"step_config\": \"include tripleo::profile::base::rabbitmq\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqConfigImage\"]}, \"volumes\": [\"/var/lib/config-data/puppet-generated/rabbitmq/etc/rabbitmq:/etc/rabbitmq:ro\", \"/var/lib/rabbitmq:/var/lib/rabbitmq:z\"]}}, \"metadata_settings\": {\"if\": [\"internal_tls_enabled\", [{\"service\": \"rabbitmq\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"OsloMessagingRpcNetwork\"]}, \"type\": \"node\"}], null]}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"rabbitmq\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OsloMessagingRpcNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"rabbitmq/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OsloMessagingRpcNetwork\"]}}}}, \"run_after\": \"container_name=$({{container_cli}} ps --format=\\\\{\\\\{.Names\\\\}\\\\} | grep -w -E \'rabbitmq(-bundle-.*-[0-9]+)?\')\\nservice_crt=\\\"/etc/pki/tls/certs/rabbitmq.crt\\\"\\nservice_key=\\\"/etc/pki/tls/private/rabbitmq.key\\\"\\nif echo \\\"$container_name\\\" | grep -q \\\"^rabbitmq-bundle\\\"; then\\n  # lp#1917868: Do not use podman cp with HA containers as they get\\n  # frozen temporarily and that can make pacemaker operation fail.\\n  tar -c \\\"$service_crt\\\" \\\"$service_key\\\" | {{container_cli}} exec -i \\\"$container_name\\\" tar -C / -xv\\n  # no need to update the mount point, because pacemaker\\n  # recreates the container when it\'s restarted\\nelse\\n  # Refresh the cert at the mount-point\\n  {{container_cli}} cp $service_crt \\\"$container_name:/var/lib/kolla/config_files/src-tls/$service_crt\\\"\\n  # Refresh the key at the mount-point\\n  {{container_cli}} cp $service_key \\\"$container_name:/var/lib/kolla/config_files/src-tls/$service_key\\\"\\n  # Copy the new cert from the mount-point to the real path\\n  {{container_cli}} exec -u root \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_crt\\\" \\\"$service_crt\\\"\\n  # Copy the new key from the mount-point to the real path\\n  {{container_cli}} exec -u root \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_key\\\" \\\"$service_key\\\"\\nfi\\n# Set appropriate permissions\\n{{container_cli}} exec -u root \\\"$container_name\\\" chown rabbitmq:rabbitmq \\\"$service_crt\\\"\\n{{container_cli}} exec -u root \\\"$container_name\\\" chown rabbitmq:rabbitmq \\\"$service_key\\\"\\n# Trigger a pem cache clear in RabbitMQ to read the new certificates\\n{{container_cli}} exec \\\"$container_name\\\" rabbitmqctl eval \\\"ssl:clear_pem_cache().\\\"\\n\", \"key_size\": {\"if\": [\"key_size_override_unset\", {\"get_param\": \"CertificateKeySize\"}, {\"get_param\": \"RpcCertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}], \"host_prep_tasks\": [{\"name\": \"create fcontext for rabbitmq data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/rabbitmq(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/rabbitmq\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/rabbitmq\", \"setype\": \"container_file_t\"}]}], \"upgrade_tasks\": [], \"update_tasks\": null}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(119,'2026-06-12 08:26:06',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configures podman on the host\\n\", \"parameters\": {\"DockerInsecureRegistryAddress\": {\"description\": \"Optional. The IP Address and Port of an insecure docker namespace that will be configured in /etc/sysconfig/docker. The value can be multiple addresses separated by commas.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerImageRegistryLogin\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Flag to enable container registry login actions during the deployment. Setting this to true will cause login calls to be performed during the deployment.\"}, \"ContainerImageRegistryCredentials\": {\"type\": \"json\", \"hidden\": true, \"default\": {}, \"description\": \"Mapping of image registry hosts to login credentials. Must be in the following example format\\n\\n  docker.io:\\n    username: pa55word\\n  \'192.0.2.1:8787\':\\n    registry_username: password\\n\"}, \"ContainerDefaultPidsLimit\": {\"type\": \"number\", \"default\": 4096, \"description\": \"Setting to configure the default pids_limit in /etc/container/container.conf. This is supported starting with podman 2.0.x\"}, \"ContainerDefaultEventsLogger\": {\"type\": \"string\", \"default\": \"journald\", \"description\": \"Setting to configure where podman logs its events. Uses journald by default as that will rotate data stored in tmpfs.\", \"constraints\": [{\"allowed_values\": [\"journald\", \"file\", \"none\"]}]}, \"SystemdDropInDependencies\": {\"default\": true, \"description\": \"tell the tripleo_container_manage to inject additional ordering dependencies for the systemd scopes associated to podman containers.\", \"type\": \"boolean\"}, \"deployment_source_hosts\": {\"default\": \"Undercloud\", \"type\": \"string\", \"description\": \"Host or hostgroup that runs the deployment\"}}, \"conditions\": {\"insecure_registry_is_empty\": {\"equals\": [{\"get_param\": \"DockerInsecureRegistryAddress\"}, []]}, \"systemd_drop_in_dependencies_enabled\": {\"get_param\": \"SystemdDropInDependencies\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the podman service\", \"value\": {\"service_name\": \"podman\", \"config_settings\": {}, \"step_config\": \"\", \"host_prep_tasks\": [{\"name\": \"Install and configure Podman\", \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}, {\"if\": [\"systemd_drop_in_dependencies_enabled\", [{\"name\": \"Configure tripleo_container_manage to generate systemd drop-in dependencies\", \"copy\": {\"dest\": \"/etc/sysconfig/podman_drop_in\", \"content\": \"This file makes tripleo_container_manage generate additional systemd\\ndependencies for containers that have special\\nstart/stop ordering constraints. It ensures that\\nthose constraints are enforced on reboot/shutdown.\\n\"}}], [{\"name\": \"Configure tripleo_container_manage to not generate drop-in dependencies\", \"file\": {\"path\": \"/etc/sysconfig/podman_drop_in\", \"state\": \"absent\"}}]]}], \"deploy_steps_tasks\": [{\"when\": [\"(step|int) == 1\"], \"block\": [{\"name\": \"Pre-fetch all the containers\", \"become\": true, \"containers.podman.podman_image\": {\"name\": \"{{ prefetch_image }}\", \"validate_certs\": false, \"force\": true}, \"register\": \"result\", \"until\": \"result is succeeded\", \"retries\": 5, \"delay\": 5, \"loop_control\": {\"loop_var\": \"prefetch_image\"}, \"loop\": \"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\"}]}], \"service_config_settings\": {}, \"workaround_upgrade_tasks\": [{\"name\": \"Configure Podman registry\", \"when\": [\"step|int == 0\"], \"tags\": [\"setup_packages\"], \"block\": [{\"name\": \"Make sure the Undercloud hostname is included in /etc/hosts\", \"when\": [\"undercloud_hosts_entries is defined\"], \"lineinfile\": {\"dest\": \"/etc/hosts\", \"line\": \"{{ undercloud_hosts_entries | join(\'\') }}\", \"state\": \"present\"}}]}, {\"name\": \"Run podman install\", \"tags\": [\"system_upgrade\", \"system_upgrade_run\", \"setup_packages\"], \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}, {\"name\": \"Comment infra_image in container.conf\", \"lineinfile\": {\"dest\": \"/usr/share/containers/containers.conf\", \"regexp\": \"(?i)^(infra_image.*)\", \"line\": \"#\\\\1\", \"backrefs\": true, \"state\": \"present\"}, \"tags\": [\"setup_packages\"], \"when\": [\"step|int == 0\"]}], \"upgrade_tasks\": [{\"name\": \"Configure Podman registry\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Make sure the Undercloud hostname is included in /etc/hosts\", \"when\": [\"undercloud_hosts_entries is defined\"], \"lineinfile\": {\"dest\": \"/etc/hosts\", \"line\": \"{{ undercloud_hosts_entries | join(\'\') }}\", \"state\": \"present\"}}]}, {\"name\": \"Run podman install\", \"tags\": [\"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}], \"update_tasks\": [{\"name\": \"Force pre-fetch of container images\", \"when\": [\"(step|int) == 5\"], \"block\": [{\"name\": \"Pre-fetch all the containers\", \"become\": true, \"containers.podman.podman_image\": {\"name\": \"{{ prefetch_image }}\", \"validate_certs\": false, \"force\": true}, \"register\": \"result\", \"until\": \"result is succeeded\", \"retries\": 5, \"delay\": 5, \"loop_control\": {\"loop_var\": \"prefetch_image\"}, \"loop\": \"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\"}]}], \"post_upgrade_tasks\": [{\"name\": \"Purge Podman\", \"when\": [\"(step | int) == 3\", \"container_cli == \'podman\'\", \"deployment_source_hosts not in group_names\"], \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_purge.yml\"}, \"vars\": {\"deployment_source_hosts\": {\"get_param\": \"deployment_source_hosts\"}}}], \"post_update_tasks\": [{\"name\": \"Purge Podman\", \"when\": [\"(step | int) == 3\", \"container_cli == \'podman\'\", \"deployment_source_hosts not in group_names\"], \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_purge.yml\"}, \"vars\": {\"deployment_source_hosts\": {\"get_param\": \"deployment_source_hosts\"}}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(120,'2026-06-12 08:26:06',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (121,'2026-06-12 08:26:06',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Containerized rsyslogd service for purposes of centralized log collection of OpenStack services\' logs.\\n\", \"parameters\": {\"ContainerRsyslogImage\": {\"description\": \"The container image to use for container\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\"}, \"ContainerRsyslogConfigImage\": {\"description\": \"The container image to use for the rsyslog config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"RsyslogReopenOnTruncate\": {\"default\": true, \"description\": \"Rsyslog imfile reopenOnTruncate parameter\", \"type\": \"boolean\"}, \"RsyslogElasticsearchSetting\": {\"default\": {}, \"description\": \"Configuration for rsyslog-elasticsearch plugin\", \"type\": \"json\"}, \"RsyslogElasticsearchTlsCACert\": {\"default\": \"\", \"description\": \"Contains content of the CA cert for the CA that issued Elasticsearch server cert.\", \"type\": \"string\"}, \"RsyslogElasticsearchTlsClientCert\": {\"default\": \"\", \"description\": \"Contains content of the client cert for doing client cert auth against Elasticsearch.\", \"type\": \"string\"}, \"RsyslogElasticsearchTlsClientKey\": {\"default\": \"\", \"description\": \"Contains content of the private key corresponding to the cert RsyslogElasticsearchTlsClientCert.\", \"type\": \"string\"}, \"CloudName\": {\"default\": \"multicell.ooo.test\", \"description\": \"The DNS name of this cloud. E.g. ci-overcloud.tripleo.org\", \"type\": \"string\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"RsyslogAmqp1Setting\": {\"default\": {}, \"description\": \"Configuration for rsyslog-omamqp1 plugin\", \"type\": \"json\"}, \"RsyslogAmqp1Local\": {\"default\": true, \"description\": \"Set to false to disable prefilling host connection value to local QDR in RsyslogAmqp1Setting.\", \"type\": \"boolean\"}, \"MetricsQdrPort\": {\"default\": 5666, \"description\": \"Service name or port number on which the qdrouterd will accept connections.\", \"type\": \"number\"}, \"RsyslogMaxMessageSize\": {\"default\": \"32k\", \"description\": \"Maximum supported message size (both for sending and receiving) for rsyslogd.\", \"type\": \"string\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerRsyslogImage\": \"ContainerRsyslogImage\", \"ContainerRsyslogConfigImage\": \"ContainerRsyslogConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerRsyslogImage\": {\"get_param\": \"ContainerRsyslogImage\"}, \"ContainerRsyslogConfigImage\": {\"get_param\": \"ContainerRsyslogConfigImage\"}}}]}}}}, \"conditions\": {\"use_tls\": {\"not\": {\"and\": [{\"equals\": [{\"get_param\": \"RsyslogElasticsearchTlsCACert\"}, \"\"]}, {\"equals\": [{\"get_param\": \"RsyslogElasticsearchTlsClientCert\"}, \"\"]}, {\"equals\": [{\"get_param\": \"RsyslogElasticsearchTlsClientKey\"}, \"\"]}]}}, \"use_elasticsearch\": {\"not\": {\"equals\": [{\"get_param\": \"RsyslogElasticsearchSetting\"}, {}]}}, \"use_amqp1\": {\"not\": {\"equals\": [{\"get_param\": \"RsyslogAmqp1Setting\"}, {}]}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the rsyslog role.\", \"value\": {\"service_name\": \"rsyslog\", \"config_settings\": {\"map_merge\": [{\"rsyslog::server::global_config\": {\"WorkDirectory\": {\"type\": \"legacy\", \"target\": \"00_rsyslog.conf\", \"value\": \"/var/lib/rsyslog\"}, \"MaxMessageSize\": {\"type\": \"legacy\", \"target\": \"00_rsyslog.conf\", \"value\": {\"get_param\": \"RsyslogMaxMessageSize\"}}}, \"rsyslog::confdir\": \"/etc/rsyslog.d\", \"rsyslog::package_name\": \"rsyslog\", \"rsyslog::package_version\": \"installed\", \"rsyslog::manage_package\": true, \"rsyslog::manage_confdir\": true, \"rsyslog::purge_config_files\": true, \"rsyslog::override_default_config\": true, \"rsyslog::config_file\": \"/etc/rsyslog.conf\", \"rsyslog::manage_service\": true, \"rsyslog::service_name\": \"rsyslog\", \"rsyslog::service_status\": \"running\", \"rsyslog::service_enabled\": true, \"rsyslog::external_service\": false, \"rsyslog::use_upstream_repo\": false, \"rsyslog::feature_packages\": [\"rsyslog-elasticsearch\", \"rsyslog-mmnormalize\"], \"rsyslog::global_config_priority\": 10, \"rsyslog::module_load_priority\": 20, \"rsyslog::input_priority\": 30, \"rsyslog::main_queue_priority\": 40, \"rsyslog::parser_priority\": 45, \"rsyslog::template_priority\": 50, \"rsyslog::filter_priority\": 55, \"rsyslog::action_priority\": 60, \"rsyslog::ruleset_priority\": 65, \"rsyslog::lookup_table_priority\": 70, \"rsyslog::legacy_config_priority\": 80, \"rsyslog::custom_priority\": 90, \"rsyslog::target_file\": \"50_openstack_logs.conf\", \"rsyslog::server::modules\": {\"imfile\": {}, \"omelasticsearch\": {}, \"omamqp1\": {}}, \"rsyslog::server::templates\": {\"rsyslog-node-index\": {\"type\": \"list\", \"list_descriptions\": [{\"constant\": {\"value\": \"%{hiera(\'fqdn_canonical\')}-\"}}, {\"property\": {\"name\": \"timereported\", \"dateFormat\": \"year\"}}, {\"constant\": {\"value\": \".\"}}, {\"property\": {\"name\": \"timereported\", \"dateFormat\": \"month\"}}, {\"constant\": {\"value\": \".\"}}, {\"property\": {\"name\": \"timereported\", \"dateFormat\": \"day\"}}]}, \"rsyslog-record\": {\"type\": \"list\", \"options\": {\"jsonf\": \"on\"}, \"list_descriptions\": [{\"property\": {\"outname\": \"@timestamp\", \"name\": \"timereported\", \"dateFormat\": \"rfc3339\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"host\", \"name\": \"hostname\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"severity\", \"name\": \"syslogseverity\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"facility\", \"name\": \"syslogfacility-text\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"tag\", \"name\": \"syslogtag\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"source\", \"name\": \"app-name\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"message\", \"name\": \"msg\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"file\", \"name\": \"$!metadata!filename\", \"format\": \"jsonf\"}}, {\"constant\": {\"outname\": \"cloud\", \"value\": {\"get_param\": \"CloudName\"}, \"format\": \"jsonf\"}}, {\"constant\": {\"outname\": \"region\", \"value\": {\"get_param\": \"KeystoneRegion\"}, \"format\": \"jsonf\"}}]}}}, {\"if\": [\"use_elasticsearch\", {\"tripleo::profile::base::logging::rsyslog::elasticsearch\": {\"map_merge\": [{\"get_param\": \"RsyslogElasticsearchSetting\"}, {\"template\": \"rsyslog-record\", \"searchIndex\": \"rsyslog-node-index\", \"dynSearchIndex\": \"on\", \"errorfile\": \"/var/log/rsyslog/omelasticsearch.log\"}]}}, {}]}, {\"if\": [\"use_amqp1\", {\"tripleo::profile::base::logging::rsyslog::amqp1\": {\"map_merge\": [{\"get_param\": \"RsyslogAmqp1Setting\"}, {\"template\": \"rsyslog-record\"}, {\"if\": [{\"get_param\": \"RsyslogAmqp1Local\"}, {\"host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}:$PORT\", \"params\": {\"$PORT\": {\"get_param\": \"MetricsQdrPort\"}, \"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}}]}]}}, {}]}, {\"if\": [{\"get_param\": \"RsyslogReopenOnTruncate\"}, {\"tripleo::profile::base::logging::rsyslog::reopen_on_truncate\": \"on\"}, {}]}, {\"if\": [\"use_tls\", {\"tripleo::profile::base::logging::rsyslog::elasticsearch_tls_ca_cert\": {\"get_param\": \"RsyslogElasticsearchTlsCACert\"}, \"tripleo::profile::base::logging::rsyslog::elasticsearch_tls_client_cert\": {\"get_param\": \"RsyslogElasticsearchTlsClientCert\"}, \"tripleo::profile::base::logging::rsyslog::elasticsearch_tls_client_key\": {\"get_param\": \"RsyslogElasticsearchTlsClientKey\"}}]}]}, \"puppet_config\": {\"config_volume\": \"rsyslog\", \"puppet_tags\": \"rsyslog::generate_concat,concat::fragment\", \"step_config\": \"include tripleo::profile::base::logging::rsyslog\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRsyslogConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/rsyslog.json\": {\"command\": \"/usr/sbin/rsyslogd -n -iNONE\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/lib/rsyslog\", \"owner\": \"root:root\", \"recurse\": true}, {\"path\": \"/var/log/rsyslog\", \"owner\": \"root:root\", \"recurse\": true}]}}, \"docker_config\": {\"step_3\": {\"rsyslog\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRsyslogImage\"]}, \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"restart\": \"always\", \"security_opt\": [\"label=disable\"], \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/rsyslog.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/rsyslog:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers:/var/log/containers:ro\", \"/var/log/containers/rsyslog:/var/log/rsyslog:rw,z\", \"/var/log:/var/log/host:ro\", \"/var/lib/rsyslog.container:/var/lib/rsyslog:rw,z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent logs directory for rsyslog\", \"file\": {\"path\": \"/var/log/containers/rsyslog\", \"state\": \"directory\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}}, {\"name\": \"create persistent state directory for rsyslog\", \"file\": {\"path\": \"/var/lib/rsyslog.container\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(122,'2026-06-12 08:26:06',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Chrony time service deployment using ansible, this YAML file creates the interface between the HOT template and the ansible role that actually installs and configure chronyd.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"NtpServer\": {\"default\": \"pool.ntp.org\", \"description\": \"NTP servers list. Defaulted to a set of pool.ntp.org servers in order to have a sane default for Pacemaker deployments when not configuring this parameter by default.\", \"type\": \"comma_delimited_list\"}, \"NtpPool\": {\"default\": [], \"description\": \"NTP pool list.  Defaults to [], so only NtpServer is used by default.\", \"type\": \"comma_delimited_list\"}, \"ChronyGlobalServerOptions\": {\"default\": \"\", \"description\": \"Default server options for the configured NTP servers in chrony.conf. If this is specified, NtpIburstEnable, MaxPoll, and MinPoll are ignored.\", \"type\": \"string\"}, \"ChronyGlobalPoolOptions\": {\"default\": \"\", \"description\": \"Default pool options for the configured NTP pools in chrony.conf. If this is specified, NtpIburstEnable, MaxPoll, and MinPoll are ignored.\", \"type\": \"string\"}, \"NtpIburstEnable\": {\"default\": true, \"description\": \"Specifies whether to enable the iburst option for every NTP peer. If iburst is enabled, when the ntp server is unreachable ntp will send a burst of eight packages instead of one. This is designed to speed up the initial syncrhonization.\", \"type\": \"boolean\"}, \"MaxPoll\": {\"description\": \"Specify maximum poll interval of upstream servers for NTP messages, in seconds to the power of two. The maximum poll interval defaults to 10 (1,024 s). Allowed values are 4 to 17.\", \"type\": \"number\", \"default\": 10, \"constraints\": [{\"range\": {\"min\": 4, \"max\": 17}}]}, \"MinPoll\": {\"description\": \"Specify minimum poll interval of upstream servers for NTP messages, in seconds to the power of two. The minimum poll interval defaults to 6 (64 s). Allowed values are 4 to 17.\", \"type\": \"number\", \"default\": 6, \"constraints\": [{\"range\": {\"min\": 4, \"max\": 17}}]}, \"EnablePackageInstall\": {\"default\": true, \"description\": \"Set to true to enable package installation at deploy time\", \"type\": \"boolean\"}, \"ChronyAclRules\": {\"default\": [\"deny all\"], \"description\": \"Access Control List of NTP clients.  By default no clients are permitted.\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"chrony_global_server_settings_is_empty\": {\"equals\": [{\"get_param\": \"ChronyGlobalServerOptions\"}, \"\"]}, \"chrony_global_pool_settings_is_empty\": {\"equals\": [{\"get_param\": \"ChronyGlobalPoolOptions\"}, \"\"]}, \"ntp_iburst\": {\"equals\": [{\"get_param\": \"NtpIburstEnable\"}, true]}}, \"outputs\": {\"role_data\": {\"description\": \"Role chrony using composable timesync services.\", \"value\": {\"service_name\": \"chrony\", \"firewall_rules\": {\"105 ntp\": {\"dport\": 123, \"proto\": \"udp\"}}, \"host_prep_tasks\": [{\"name\": \"Check for NTP service\", \"shell\": \"systemctl is-active ntpd.service || systemctl is-enabled ntpd.service\", \"failed_when\": false, \"become\": true, \"register\": \"ntp_service_check\"}, {\"name\": \"Disable NTP before configuring Chrony\", \"service\": {\"name\": \"ntpd\", \"state\": \"stopped\", \"enabled\": false}, \"when\": [\"ntp_service_check.rc is defined\", \"ntp_service_check.rc == 0\"]}, {\"name\": \"Install, Configure and Run Chrony\", \"include_role\": {\"name\": \"chrony\"}}, {\"name\": \"Force NTP sync\", \"command\": \"chronyc makestep\"}, {\"name\": \"Ensure system is NTP time synced\", \"command\": \"chronyc waitsync 30\"}], \"ansible_group_vars\": {\"chrony_role_action\": \"all\", \"chrony_ntp_servers\": {\"get_param\": \"NtpServer\"}, \"chrony_ntp_pools\": {\"get_param\": \"NtpPool\"}, \"chrony_global_server_settings\": {\"if\": [\"chrony_global_server_settings_is_empty\", {\"str_replace\": {\"template\": \"IBURST minpoll MINPOLL maxpoll MAXPOLL\", \"params\": {\"IBURST\": {\"if\": [\"ntp_iburst\", \"iburst\", \"\"]}, \"MINPOLL\": {\"get_param\": \"MinPoll\"}, \"MAXPOLL\": {\"get_param\": \"MaxPoll\"}}}}, {\"get_param\": \"ChronyGlobalServerOptions\"}]}, \"chrony_global_pool_settings\": {\"if\": [\"chrony_global_pool_settings_is_empty\", {\"str_replace\": {\"template\": \"IBURST minpoll MINPOLL maxpoll MAXPOLL\", \"params\": {\"IBURST\": {\"if\": [\"ntp_iburst\", \"iburst\", \"\"]}, \"MINPOLL\": {\"get_param\": \"MinPoll\"}, \"MAXPOLL\": {\"get_param\": \"MaxPoll\"}}}}, {\"get_param\": \"ChronyGlobalPoolOptions\"}]}, \"chrony_manage_package\": {\"get_param\": \"EnablePackageInstall\"}, \"chrony_acl_rules\": {\"get_param\": \"ChronyAclRules\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(123,'2026-06-12 08:26:06',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(124,'2026-06-12 08:26:07',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(125,'2026-06-12 08:26:07',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(126,'2026-06-12 08:26:07',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(127,'2026-06-12 08:26:07',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configure tuned\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"TunedCustomProfile\": {\"default\": \"\", \"description\": \"The definition of a new tuned profile in INI format which will be named after the TunedProfileName and applied to the host. E.g. if TunedProfileName is \'my_profile\', it creates the file \'/etc/tuned/my_profile/tuned.conf\' on host whose content is the value of TunedCustomProfile, e.g. \\\"[main]\\\\n include=throughput-performance\\\\n[sysctl]\\\\nvm.dirty_ratio=10\\\"\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"TunedProfileName\": {\"default\": \"throughput-performance\", \"description\": \"Tuned Profile to apply to the host\", \"type\": \"string\", \"tags\": [\"role_specific\"]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"tuned_profile\": \"TunedProfileName\", \"tuned_custom_profile\": \"TunedCustomProfile\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"TunedProfileName\": {\"get_param\": \"TunedProfileName\"}, \"TunedCustomProfile\": {\"get_param\": \"TunedCustomProfile\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for tuned\", \"value\": {\"service_name\": \"tuned\", \"host_prep_tasks\": [{\"include_role\": {\"name\": \"tuned\"}}], \"ansible_group_vars\": {\"tuned_profile\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"tuned_profile\"]}, \"tuned_custom_profile\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"tuned_custom_profile\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(128,'2026-06-12 08:26:07',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"MySQL service deployment with pacemaker bundle\\n\", \"parameters\": {\"ContainerMysqlImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\"}, \"ContainerMysqlConfigImage\": {\"description\": \"The container image to use for the mysql config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\"}, \"ClusterCommonTag\": {\"default\": false, \"description\": \"When set to false, a pacemaker service is configured to use a floating tag for its container image name, e.g. \'REGISTRY/NAMESPACE/IMAGENAME:pcmklatest\'. When set to true, the service uses a floating prefix as well, e.g. \'cluster.common.tag/IMAGENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"ClusterFullTag\": {\"default\": true, \"description\": \"When set to true, the pacemaker service uses a fully constant tag for its container image name, e.g. \'cluster.common.tag/SERVICENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"MysqlRootPassword\": {\"type\": \"string\", \"hidden\": true, \"default\": \"lewodgEGks\"}, \"MysqlClustercheckPassword\": {\"type\": \"string\", \"hidden\": true, \"default\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\"}, \"MysqlUpgradePersist\": {\"type\": \"boolean\", \"default\": false}, \"MysqlUpgradeTransfer\": {\"type\": \"boolean\", \"default\": true}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"ConfigDebug\": {\"default\": false, \"description\": \"Whether to run config management (e.g. Puppet) in debug mode.\", \"type\": \"boolean\"}, \"DeployIdentifier\": {\"default\": 1781252715, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"MysqlGaleraSSTMethod\": {\"type\": \"string\", \"default\": \"rsync\", \"description\": \"Method used by galera to perform State Snapshot Transfers\", \"constraints\": [{\"allowed_values\": [\"rsync\", \"mariabackup\"]}]}, \"MysqlMariabackupUser\": {\"type\": \"string\", \"default\": \"mariabackup\", \"description\": \"When MysqlGaleraSSTMethod is set to mariabackup, the name of the database user that executes the SST.\"}, \"MysqlMariabackupPassword\": {\"type\": \"string\", \"hidden\": true, \"description\": \"When MysqlGaleraSSTMethod is set to mariabackup, the password of the database user that executes the SST.\", \"default\": \"zgFej84GkeJYRMxOd5txIKJHX\"}, \"MysqlGaleraSSLCipher\": {\"type\": \"string\", \"default\": \"AES128-SHA256\", \"description\": \"Symmetric cipher to use.\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MysqlBase\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerMysqlImage\": \"ContainerMysqlImage\", \"ContainerMysqlConfigImage\": \"ContainerMysqlConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerMysqlImage\": {\"get_param\": \"ContainerMysqlImage\"}, \"ContainerMysqlConfigImage\": {\"get_param\": \"ContainerMysqlConfigImage\"}}}]}}}}, \"conditions\": {\"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"role_data\": {\"description\": \"Containerized service MySQL using composable services.\", \"value\": {\"service_name\": {\"get_attr\": [\"MysqlBase\", \"role_data\", \"service_name\"]}, \"firewall_rules\": {\"104 mysql galera-bundle\": {\"dport\": [873, 3123, 3306, 4444, 4567, 4568, 9200]}}, \"firewall_frontend_rules\": {\"100 mysql_haproxy\": {\"dport\": [3306]}}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"MysqlBase\", \"role_data\", \"config_settings\"]}, {\"tripleo::profile::pacemaker::database::mysql::bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::pacemaker::database::mysql::gmcast_listen_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::pacemaker::database::mysql::ca_file\": {\"get_param\": \"InternalTLSCAFile\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::mysql_docker_image\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"tripleo::profile::pacemaker::database::mysql_bundle::control_port\": 3123, \"tripleo::profile::pacemaker::database::mysql_bundle::container_backend\": {\"get_param\": \"ContainerCli\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::pacemaker::database::mysql_bundle::ca_file\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"InternalTLSCAFile\"}]}, \"tripleo::profile::pacemaker::database::mysql_bundle::sst_method\": {\"get_param\": \"MysqlGaleraSSTMethod\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::mariabackup_user\": {\"get_param\": \"MysqlMariabackupUser\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::mariabackup_password\": {\"get_param\": \"MysqlMariabackupPassword\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::force_ocf\": true, \"tripleo::profile::pacemaker::database::mysql_bundle::gcomm_cipher\": {\"get_param\": \"MysqlGaleraSSLCipher\"}}]}, \"puppet_config\": {\"config_volume\": \"mysql\", \"puppet_tags\": \"file\", \"step_config\": {\"list_join\": [\"\\n\", [\"[\'Mysql_datadir\', \'Mysql_user\', \'Mysql_database\', \'Mysql_grant\', \'Mysql_plugin\'].each |String $val| { noop_resource($val) }\", \"exec {\'wait-for-settle\': command => \'/bin/true\' }\", \"include tripleo::profile::pacemaker::database::mysql_bundle\"]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/mysql.json\": {\"command\": \"/usr/sbin/pacemaker_remoted\", \"config_files\": [{\"dest\": \"/etc/libqb/force-filesystem-sockets\", \"source\": \"/dev/null\", \"owner\": \"root\", \"perm\": \"0644\"}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"optional\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/mysql\", \"owner\": \"mysql:mysql\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/mysql.crt\", \"owner\": \"mysql:mysql\", \"perm\": \"0600\", \"optional\": true}, {\"path\": \"/etc/pki/tls/private/mysql.key\", \"owner\": \"mysql:mysql\", \"perm\": \"0600\", \"optional\": true}]}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"docker_config\": {\"step_1\": {\"mysql_data_ownership\": {\"start_order\": 0, \"detach\": false, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"net\": \"host\", \"user\": \"root\", \"command\": [\"chown\", \"-R\", \"mysql:\", \"/var/lib/mysql\"], \"volumes\": [\"/var/lib/mysql:/var/lib/mysql:z\"]}, \"mysql_bootstrap\": {\"start_order\": 1, \"detach\": false, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"net\": \"host\", \"user\": \"root\", \"command\": [\"bash\", \"-ec\", {\"list_join\": [\"\\n\", [\"if [ -e /var/lib/mysql/mysql ]; then exit 0; fi\", \"echo -e \\\"\\\\n[mysqld]\\\\nwsrep_provider=none\\\" >> /etc/my.cnf\", \"export DB_ROOT_PASSWORD=$(hiera \'mysql::server::root_password\')\", \"kolla_set_configs\", \"sudo -u mysql -E kolla_extend_start\", \"timeout ${DB_MAX_TIMEOUT} /bin/bash -c \'while pgrep -af /usr/bin/mysqld_safe | grep -q -v grep; do sleep 1; done\'\", \"mysqld_safe --skip-networking --wsrep-on=OFF &\", \"timeout ${DB_MAX_TIMEOUT} /bin/bash -c \'until mysqladmin -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" ping 2>/dev/null; do sleep 1; done\'\"], {\"if\": [{\"equals\": [{\"get_param\": \"MysqlGaleraSSTMethod\"}, \"mariabackup\"]}, [\"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"CREATE USER \'${DB_MARIABACKUP_USER}\'@\'localhost\' IDENTIFIED BY \'${DB_MARIABACKUP_PASSWORD}\';\\\"\", \"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"GRANT RELOAD, PROCESS, LOCK TABLES, REPLICATION CLIENT ON *.* TO \'${DB_MARIABACKUP_USER}\'@\'localhost\';\\\"\"]]}, [\"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"CREATE USER \'clustercheck\'@\'localhost\' IDENTIFIED BY \'$(hiera mysql_clustercheck_password)\';\\\"\", \"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"GRANT PROCESS ON *.* TO \'clustercheck\'@\'localhost\' WITH GRANT OPTION;\\\"\", \"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"DELETE FROM mysql.user WHERE user = \'root\' AND host NOT IN (\'%\',\'localhost\');\\\"\", \"timeout ${DB_MAX_TIMEOUT} mysqladmin -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" shutdown\"]]}], \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/mysql.json:/var/lib/kolla/config_files/config.json:rw,z\", \"/var/lib/config-data/puppet-generated/mysql:/var/lib/kolla/config_files/src:ro,z\", \"/var/lib/mysql:/var/lib/mysql:rw,z\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/mysql.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/mysql.crt:ro\", \"/etc/pki/tls/private/mysql.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/mysql.key:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"KOLLA_BOOTSTRAP\": true, \"DB_MAX_TIMEOUT\": 60, \"DB_MARIABACKUP_USER\": {\"get_param\": \"MysqlMariabackupUser\"}, \"DB_MARIABACKUP_PASSWORD\": {\"get_param\": \"MysqlMariabackupPassword\"}}}}, \"step_2\": {\"mysql_wait_bundle\": {\"start_order\": 0, \"detach\": false, \"net\": \"host\", \"ipc\": \"host\", \"user\": \"root\", \"command\": {\"list_concat\": [[\"/container_puppet_apply.sh\", \"2\", \"file,file_line,concat,augeas,galera_ready,mysql_database,mysql_grant,mysql_user\", \"include tripleo::profile::pacemaker::database::mysql_bundle\"], {\"if\": [{\"get_param\": \"ConfigDebug\"}, [\"--debug\"]]}]}, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"container_puppet_apply_volumes\"]}, [\"/var/lib/mysql:/var/lib/mysql:rw,z\", \"/var/lib/config-data/puppet-generated/mysql/root:/root:rw\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"]]}]}, \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/mysql\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/mysql\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/log/mariadb\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}], \"metadata_settings\": {\"get_attr\": [\"MysqlBase\", \"role_data\", \"metadata_settings\"]}, \"deploy_steps_tasks\": {\"list_concat\": [{\"get_attr\": [\"MysqlBase\", \"role_data\", \"deploy_steps_tasks\"]}, [{\"name\": \"MySQL tag container image for pacemaker\", \"when\": \"step|int == 1\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"container_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}}}, {\"name\": \"MySQL HA Wrappers Step\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Mysql puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"mysql\", \"tripleo_ha_wrapper_resource_name\": \"galera\", \"tripleo_ha_wrapper_bundle_name\": \"galera-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Master\", \"tripleo_ha_wrapper_puppet_config_volume\": \"mysql\", \"tripleo_ha_wrapper_puppet_execute\": \"[\\\"Mysql_datadir\\\", \\\"Mysql_user\\\", \\\"Mysql_database\\\", \\\"Mysql_grant\\\", \\\"Mysql_plugin\\\"].each |String $val| { noop_resource($val) }; include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::database::mysql_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}]}]]}, \"external_update_tasks\": [{\"when\": \"step|int == 1\", \"tags\": \"ha_image_update\", \"block\": [{\"block\": [{\"name\": \"Get galera image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_galera_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'galera-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container galera image\", \"set_fact\": {\"galera_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"galera_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_galera_image\": \"{{xmllint_pcmk_galera_image.stdout}}\"}}], \"delegate_to\": \"{{ (groups[\\\"mysql\\\"] | difference(groups[\\\"excluded_overcloud\\\"]))[0] }}\"}, {\"name\": \"MySQL temporary pacemaker container tag in case of image switch\", \"become\": true, \"import_role\": {\"name\": \"tripleo_ha_image_update\"}, \"vars\": {\"tripleo_ha_image_update_node_names\": \"{{ groups[\\\"mysql\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) }}\", \"tripleo_ha_image_update_bundle\": \"galera-bundle\", \"tripleo_ha_image_update_new_image\": \"{{galera_image_latest}}\", \"tripleo_ha_image_update_old_image\": \"{{pcmk_galera_image}}\"}, \"when\": [\"(pcmk_galera_image != \\\"\\\")\", \"(pcmk_galera_image != galera_image_latest)\"]}]}], \"update_tasks\": [{\"block\": [{\"name\": \"Get galera image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_galera_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'galera-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container galera image\", \"set_fact\": {\"galera_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"galera_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_galera_image\": \"{{xmllint_pcmk_galera_image.stdout}}\"}}], \"when\": \"(step|int == 0 or step|int == 2)\"}, {\"name\": \"Check for update of galera container image name\", \"when\": \"step|int == 0\", \"assert\": {\"that\": \"pcmk_galera_image == galera_image_latest\", \"fail_msg\": \"galera image change detected, run overcloud external-update --tags ha_image_update first\"}}, {\"name\": \"Tear-down non-HA mysql container\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"stat mysql container\", \"command\": \"podman container exists mysql\", \"failed_when\": false, \"changed_when\": false, \"register\": \"stat_mysql_container\"}, {\"name\": \"Create clustercheck user and permissions\", \"command\": {\"argv\": \"{{ mysql_exec_data | container_exec_cmd }}\"}, \"changed_when\": true, \"when\": [\"stat_mysql_container.rc == 0\"], \"vars\": {\"mysql_exec_data\": {\"environment\": {\"CLUSTERCHECK_PASSWORD\": {\"get_param\": \"MysqlClustercheckPassword\"}}, \"command\": [\"mysql\", \"/bin/sh\", \"-c\", \"mysql -e \\\"CREATE USER IF NOT EXISTS \'clustercheck\'@\'localhost\' IDENTIFIED BY \'${CLUSTERCHECK_PASSWORD}\'; GRANT PROCESS ON *.* TO \'clustercheck\'@\'localhost\' WITH GRANT OPTION;\\\"\"]}}}, {\"name\": \"Remove non-HA mysql container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"mysql\"]}}]}, {\"name\": \"Mariadb fetch and retag container image for pacemaker\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Retag pcmklatest to latest galera image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{galera_image}}\", \"container_image_latest\": \"{{galera_image_latest}}\"}}]}, {\"name\": \"Ensure mariadb-server is not installed on the host\", \"when\": \"step|int == 2\", \"yum\": {\"name\": \"mariadb-server*\", \"state\": \"absent\"}}], \"post_update_tasks\": [{\"name\": \"Mysql bundle post update\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Mysql puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"mysql\", \"tripleo_ha_wrapper_resource_name\": \"galera\", \"tripleo_ha_wrapper_bundle_name\": \"galera-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Master\", \"tripleo_ha_wrapper_puppet_config_volume\": \"mysql\", \"tripleo_ha_wrapper_puppet_execute\": \"[\\\"Mysql_datadir\\\", \\\"Mysql_user\\\", \\\"Mysql_database\\\", \\\"Mysql_grant\\\", \\\"Mysql_plugin\\\"].each |String $val| { noop_resource($val) }; include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::database::mysql_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}], \"vars\": {\"tripleo_ha_wrapper_minor_update\": true}}], \"upgrade_tasks\": {\"list_concat\": [[{\"name\": \"Tear-down non-HA mysql container\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"stat mysql container\", \"command\": \"podman container exists mysql\", \"failed_when\": false, \"changed_when\": false, \"register\": \"stat_mysql_container\"}, {\"name\": \"Create clustercheck user and permissions\", \"command\": {\"argv\": \"{{ mysql_exec_data | container_exec_cmd }}\"}, \"changed_when\": true, \"when\": [\"stat_mysql_container.rc == 0\"], \"vars\": {\"mysql_exec_data\": {\"environment\": {\"CLUSTERCHECK_PASSWORD\": {\"get_param\": \"MysqlClustercheckPassword\"}}, \"command\": [\"mysql\", \"/bin/sh\", \"-c\", \"mysql -e \\\"CREATE USER IF NOT EXISTS \'clustercheck\'@\'localhost\' IDENTIFIED BY \'${CLUSTERCHECK_PASSWORD}\'; GRANT PROCESS ON *.* TO \'clustercheck\'@\'localhost\' WITH GRANT OPTION;\\\"\"]}}}, {\"name\": \"Remove non-HA mysql container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"mysql\"]}}]}], [{\"name\": \"set mysql container name fact\", \"when\": [\"step|int == 1\"], \"set_fact\": {\"mysql_container_name\": \"galera-bundle\"}}], {\"get_attr\": [\"MysqlBase\", \"mysql_drop_unused_users\"]}, [{\"vars\": {\"mysql_upgrade_persist\": {\"get_param\": \"MysqlUpgradePersist\"}}, \"when\": [\"step|int == 3\", \"mysql_upgrade_persist\"], \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"block\": [{\"name\": \"Persist mysql data\", \"include_role\": {\"name\": \"tripleo_persist\", \"tasks_from\": \"persist.yml\"}, \"vars\": {\"tripleo_persist_dir\": \"/var/lib/mysql\"}}]}, {\"vars\": {\"mysql_upgrade_persist\": {\"get_param\": \"MysqlUpgradePersist\"}}, \"when\": [\"step|int == 5\", \"mysql_upgrade_persist\"], \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\"], \"block\": [{\"name\": \"Restore mysql data\", \"include_role\": {\"name\": \"tripleo_persist\", \"tasks_from\": \"restore.yml\"}, \"vars\": {\"tripleo_persist_dir\": \"/var/lib/mysql\"}}]}, {\"name\": \"Prepare switch of galera image name\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Get galera image id currently used by pacemaker\", \"shell\": \"pcs resource config galera-bundle | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\", \"register\": \"galera_image_current_res\", \"failed_when\": false}, {\"name\": \"Image facts for galera\", \"set_fact\": {\"galera_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"galera_image_current\": \"{{galera_image_current_res.stdout}}\"}}, {\"name\": \"Temporarily tag the current galera image id with the upgraded image name\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{galera_image_current}}\", \"container_image_latest\": \"{{galera_image_latest}}\", \"pull_image\": false}, \"when\": [\"galera_image_current != \'\'\", \"galera_image_current != galera_image_latest\"]}, {\"name\": \"Create galera retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/galera_needs_retag\", \"state\": \"touch\"}, \"when\": [\"galera_image_current != \'\'\", \"galera_image_current != galera_image_latest\"]}]}, {\"name\": \"Update galera pcs resource bundle for new container image - check\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"set is_mysql_bootstrap_node fact\", \"tags\": \"common\", \"set_fact\": \"is_mysql_bootstrap_node={{mysql_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\"}, {\"name\": \"Check for galera retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/galera_needs_retag\"}, \"register\": \"galera_retag_state_file\"}]}, {\"name\": \"Update galera pcs resource bundle for new container image\", \"when\": [\"step|int == 1\", \"is_mysql_bootstrap_node|bool\", \"galera_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the galera cluster resource before container upgrade\", \"pacemaker_resource\": {\"resource\": \"galera-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Move Mysql logging to /var/log/containers\", \"block\": [{\"name\": \"Check Mysql logging configuration in pacemaker\", \"command\": \"cibadmin --query --xpath \\\"//storage-mapping[@id=\'mysql-log\']\\\"\", \"failed_when\": false, \"register\": \"mysql_logs_moved\"}, {\"name\": \"Change Mysql logging configuration in pacemaker\", \"when\": \"mysql_logs_moved.rc == 6\", \"block\": [{\"name\": \"Add a bind mount for logging in the galera bundle\", \"command\": \"pcs resource bundle update galera-bundle storage-map add id=mysql-log source-dir=/var/log/containers/mysql target-dir=/var/log/mysql options=rw\"}, {\"name\": \"Reconfigure Mysql log file in the galera resource agent\", \"command\": \"pcs resource update galera log=/var/log/mysql/mysqld.log\"}]}]}, {\"name\": \"Update the galera bundle to use the new container image name\", \"command\": \"pcs resource bundle update galera-bundle container image={{galera_image_latest}}\"}, {\"name\": \"Enable the galera cluster resource\", \"pacemaker_resource\": {\"resource\": \"galera-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}]}, {\"name\": \"Upgrade galera in step3\", \"when\": [\"step|int == 3\"], \"block\": [{\"name\": \"Bind mounts for temporary container\", \"set_fact\": {\"mysql_upgrade_db_bind_mounts\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/mysql.json:/var/lib/kolla/config_files/config.json:rw,z\", \"/var/lib/config-data/puppet-generated/mysql:/var/lib/kolla/config_files/src:ro,z\", \"/var/lib/mysql:/var/lib/mysql:rw,z\"], [\"/var/log/containers/mysql:/var/log/mysql:rw,z\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/mysql.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/mysql.crt:ro\", \"/etc/pki/tls/private/mysql.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/mysql.key:ro\"]]}]}}}, {\"name\": \"Check if Galera needs upgrade\", \"shell\": {\"str_replace\": {\"template\": \"CONTAINER_CLI run --rm --log-driver=k8s-file --log-opt path=LOG_DIR/db-upgrade.log \\\\ -u root --net=host UPGRADE_ENV UPGRADE_VOLUMES \\\"UPGRADE_IMAGE\\\" /bin/bash -ecx \\\"$UPGRADE_SCRIPT\\\"\", \"params\": {\"UPGRADE_ENV\": \"-e \\\"KOLLA_CONFIG_STRATEGY=COPY_ALWAYS\\\"\", \"UPGRADE_IMAGE\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"UPGRADE_VOLUMES\": \"-v {{ mysql_upgrade_db_bind_mounts | join(\' -v \')}}\", \"CONTAINER_CLI\": \"{{ container_cli }}\", \"LOG_DIR\": \"/var/log/containers/mysql\"}}}, \"environment\": {\"UPGRADE_SCRIPT\": \"kolla_set_configs\\nupgraded_ver=$(cat /var/lib/mysql/mysql_upgrade_info 2>/dev/null || true)\\nmysql_ver=$(mysql --version | awk -F\'[ ,]*\' \'{print $5}\')\\nif [ \\\"${upgraded_ver}\\\" = \\\"${mysql_ver}\\\" ]; then\\n    echo \\\"mysql already upgraded\\\"\\nelse\\n    echo \\\"${upgraded_ver} VS ${mysql_ver}\\\"\\nfi\\n\"}, \"register\": \"mysql_upgrade_needed\"}, {\"name\": \"Set fact upgrade_mysql\", \"set_fact\": {\"upgrade_mysql\": \"{{ (mysql_upgrade_needed.stdout != \\\"mysql already upgraded\\\") | bool }}\"}}, {\"debug\": {\"msg\": \"MYSQL check - {{ mysql_upgrade_needed.stdout }} - Upgrade needed: {{ upgrade_mysql }}\"}}, {\"name\": \"Disable the galera cluster resource before container upgrade\", \"when\": [\"upgrade_mysql|bool\"], \"pacemaker_resource\": {\"resource\": \"galera-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"block\": [{\"name\": \"Get galera image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_galera_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'galera-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container galera image\", \"set_fact\": {\"galera_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"galera_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_galera_image\": \"{{xmllint_pcmk_galera_image.stdout}}\"}}]}, {\"name\": \"Check for galera retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/galera_needs_retag\"}, \"register\": \"galera_retag_state_file\"}, {\"name\": \"Retag the pacemaker image if containerized\", \"when\": [\"galera_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Retag pcmklatest to latest galera image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{galera_image}}\", \"container_image_latest\": \"{{galera_image_latest}}\"}}]}, {\"name\": \"Remove galera retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/galera_needs_retag\", \"state\": \"absent\"}}, {\"name\": \"Mysql upgrade script\", \"when\": [\"upgrade_mysql|bool\"], \"set_fact\": {\"mysql_upgrade_script\": {\"list_join\": [\"\\n\", [\"kolla_set_configs\\nif mysqladmin ping --silent; then exit 0; fi\\nupgraded_ver=$(cat /var/lib/mysql/mysql_upgrade_info 2>/dev/null || true)\\nmysql_ver=$(mysql --version | awk -F\'[ ,]*\' \'{print $5}\')\\nif [ \\\"${upgraded_ver}\\\" = \\\"${mysql_ver}\\\" ]; then\\n    echo \\\"mysql already upgraded\\\"\\n    exit 0\\nfi\\nchown -R mysql:mysql /var/lib/mysql\\nchown -R mysql:mysql /var/log/mysql\\nmysqld_safe --user=mysql --wsrep-provider=none --skip-networking --wsrep-on=off --log-error=/var/log/mysql/mysqld-upgrade.log &\\n\", {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/mysql_upgrade_db.sh\"}, \"mysqladmin shutdown\"]]}}}, {\"name\": \"Upgrade Mysql database from a temporary container\", \"when\": [\"upgrade_mysql|bool\"], \"shell\": {\"str_replace\": {\"template\": \"CONTAINER_CLI run --rm --log-driver=k8s-file --log-opt path=LOG_DIR/db-upgrade.log \\\\ -u root --net=host UPGRADE_ENV UPGRADE_VOLUMES \\\"UPGRADE_IMAGE\\\" /bin/bash -ecx \\\"$UPGRADE_SCRIPT\\\"\", \"params\": {\"UPGRADE_ENV\": \"-e \\\"KOLLA_CONFIG_STRATEGY=COPY_ALWAYS\\\"\", \"UPGRADE_IMAGE\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"UPGRADE_VOLUMES\": \"-v {{ mysql_upgrade_db_bind_mounts | join(\' -v \')}}\", \"CONTAINER_CLI\": \"{{ container_cli }}\", \"LOG_DIR\": \"/var/log/containers/mysql\"}}}, \"environment\": {\"UPGRADE_SCRIPT\": \"{{ mysql_upgrade_script }}\"}}, {\"name\": \"Enable the galera cluster resource\", \"when\": [\"upgrade_mysql|bool\"], \"pacemaker_resource\": {\"resource\": \"galera-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}]}]]}, \"external_upgrade_tasks\": [{\"vars\": {\"mysql_upgrade_transfer\": {\"get_param\": \"MysqlUpgradeTransfer\"}}, \"when\": [\"step|int == 2\", \"mysql_upgrade_transfer\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\"], \"block\": [{\"name\": \"Transfer mysql data\", \"include_role\": {\"name\": \"tripleo_transfer\"}, \"vars\": {\"tripleo_transfer_src_dir\": \"/var/lib/mysql\", \"tripleo_transfer_src_host\": \"{{hostvars[groups[\'overcloud\'][0]][\'mysql_short_node_names\'][1]}}\", \"tripleo_transfer_dest_dir\": \"/var/lib/mysql\", \"tripleo_transfer_dest_host\": \"{{hostvars[groups[\'overcloud\'][0]][\'mysql_short_bootstrap_node_name\']}}\", \"tripleo_transfer_flag_file\": \"/var/lib/tripleo/transfer-flags/var-lib-mysql\", \"tripleo_transfer_sync_options\": \"--whole-file --ignore-times --inplace --archive --delete\", \"tripleo_transfer_include\": [\"/ibdata*\", \"/ib_lru_dump\", \"/ib_logfile[0-9]*\", \"/undo*\", \"/*/\"], \"tripleo_transfer_exclude\": \"/*\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (129,'2026-06-12 08:26:07',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Rabbitmq service\\n\", \"parameters\": {\"ContainerRabbitmqImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\"}, \"ContainerRabbitmqConfigImage\": {\"description\": \"The container image to use for the rabbitmq config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"RabbitCookie\": {\"type\": \"string\", \"default\": \"2ljqdppvti5CXNoMTl6c\", \"hidden\": true}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"RabbitUserName\": {\"default\": \"guest\", \"description\": \"The username for RabbitMQ\", \"type\": \"string\"}, \"RabbitPassword\": {\"description\": \"The password for RabbitMQ\", \"type\": \"string\", \"hidden\": true, \"default\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\"}, \"RabbitFDLimit\": {\"default\": 65536, \"description\": \"Configures RabbitMQ FD limit\", \"type\": \"number\"}, \"RabbitTCPBacklog\": {\"default\": 4096, \"description\": \"Configures RabbitMQ maximum TCP Backlog\", \"type\": \"number\"}, \"RabbitIPv6\": {\"default\": false, \"description\": \"Enable IPv6 in RabbitMQ\", \"type\": \"boolean\"}, \"RabbitHAQueues\": {\"description\": \"The number of HA queues to be configured in rabbit. The default is -1 which translates to \\\"ha-mode all\\\". The special value 0 will be automatically overridden to CEIL(N/2) where N is the number of nodes running rabbitmq.\", \"default\": 0, \"type\": \"number\"}, \"RabbitNetTickTime\": {\"description\": \"The number of seconds to configure the value of the erlang net_ticktime kernel variable.\", \"default\": 15, \"type\": \"number\"}, \"RabbitFIPS\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Configures RabbitMQ to run in FIPS mode\"}, \"RabbitAdditionalErlArgs\": {\"description\": \"Additional parameters passed to the Erlang subsystem. The string needs to be enclosed in quotes twice. We default to \'+sbwt none +sbwtdcpu none +sbwtdio none\' in order to have the erlang vm be less busy on spinlocks, but we allow a simple way of overriding it.\", \"default\": \"\'+sbwt none +sbwtdcpu none +sbwtdio none\'\", \"type\": \"string\"}, \"MonitoringSubscriptionRabbitmq\": {\"default\": \"overcloud-rabbitmq\", \"type\": \"string\"}, \"DeployIdentifier\": {\"default\": 1781252715, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"RabbitmqCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RabbitmqEnableManagementAccess\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Allow access to RabbitMQ management plugin over network\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"RabbitIPv6\"]}], \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"is_ipv6\": {\"equals\": [{\"get_param\": [\"ServiceData\", \"net_ip_version_map\", {\"get_param\": [\"ServiceNetMap\", \"RabbitmqNetwork\"]}]}, 6]}, \"key_size_override_unset\": {\"equals\": [{\"get_param\": \"RabbitmqCertificateKeySize\"}, \"\"]}, \"rabbitmq_cacert_set\": {\"not\": {\"equals\": [{\"get_param\": \"InternalTLSCAFile\"}, \"\"]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerRabbitmqImage\": \"ContainerRabbitmqImage\", \"ContainerRabbitmqConfigImage\": \"ContainerRabbitmqConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerRabbitmqImage\": {\"get_param\": \"ContainerRabbitmqImage\"}, \"ContainerRabbitmqConfigImage\": {\"get_param\": \"ContainerRabbitmqConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Rabbitmq API role.\", \"value\": {\"service_name\": \"rabbitmq\", \"firewall_rules\": {\"109 rabbitmq\": {\"dport\": {\"list_concat\": [[4369, 5672, 25672, \"25673-25683\"], {\"if\": [{\"get_param\": \"RabbitmqEnableManagementAccess\"}, [15672]]}]}}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionRabbitmq\"}, \"config_settings\": {\"map_merge\": [{\"rabbitmq::file_limit\": {\"get_param\": \"RabbitFDLimit\"}, \"rabbitmq::default_user\": {\"get_param\": \"RabbitUserName\"}, \"rabbitmq::default_pass\": {\"get_param\": \"RabbitPassword\"}, \"rabbit_ipv6\": {\"if\": [\"is_ipv6\", true, false]}, \"rabbitmq::delete_guest_user\": false, \"rabbitmq::wipe_db_on_cookie_change\": true, \"rabbitmq::port\": 5672, \"rabbitmq::loopback_users\": [], \"rabbitmq::tcp_backlog\": {\"get_param\": \"RabbitTCPBacklog\"}, \"rabbitmq::repos_ensure\": false, \"rabbitmq::tcp_keepalive\": true, \"rabbitmq_environment\": {\"LANG\": \"en_US.UTF-8\", \"LC_ALL\": \"en_US.UTF-8\", \"NODE_PORT\": \"\", \"NODE_IP_ADDRESS\": \"\", \"RABBITMQ_NODENAME\": {\"str_replace\": {\"template\": \"rabbit@%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"RabbitmqNetwork\"]}}}}, \"RABBITMQ_USE_LONGNAME\": \"true\", \"RABBITMQ_CTL_DIST_PORT_MIN\": \"25673\", \"RABBITMQ_CTL_DIST_PORT_MAX\": \"25683\", \"export ERL_EPMD_ADDRESS\": \"%{hiera(\'rabbitmq::interface\')}\"}, \"tripleo::profile::base::rabbitmq::additional_erl_args\": {\"get_param\": \"RabbitAdditionalErlArgs\"}, \"rabbitmq_kernel_variables\": {\"inet_dist_listen_min\": \"25672\", \"inet_dist_listen_max\": \"25672\", \"net_ticktime\": {\"get_param\": \"RabbitNetTickTime\"}}, \"rabbitmq_config_variables\": {\"cluster_partition_handling\": \"ignore\", \"queue_master_locator\": \"<<\\\"min-masters\\\">>\"}, \"rabbitmq::config_additional_variables\": {\"lager\": \"[{crash_log_count, 0}, { crash_log_date, \\\"\\\"}, { crash_log_size, 0 }]\"}, \"rabbitmq::erlang_cookie\": {\"get_param\": \"RabbitCookie\"}, \"rabbitmq::interface\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"RabbitmqNetwork\"]}}}}, \"rabbitmq::nr_ha_queues\": {\"get_param\": \"RabbitHAQueues\"}, \"rabbitmq::ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"rabbitmq::ssl_erl_dist\": {\"get_param\": \"EnableInternalTLS\"}, \"rabbitmq::ssl_port\": 5672, \"rabbitmq::ssl_depth\": 1, \"rabbitmq::ssl_only\": {\"get_param\": \"EnableInternalTLS\"}, \"rabbitmq::ssl_interface\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"RabbitmqNetwork\"]}}}}, \"tripleo::profile::base::rabbitmq::enable_internal_tls\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::rabbitmq::fips_mode\": {\"get_param\": \"RabbitFIPS\"}, \"rabbitmq::collect_statistics_interval\": 30000}, {\"if\": [\"internal_tls_enabled\", {\"tripleo::rabbitmq::service_certificate\": \"/etc/pki/tls/certs/rabbitmq.crt\", \"tripleo::profile::base::rabbitmq::certificate_specs\": {\"service_certificate\": \"/etc/pki/tls/certs/rabbitmq.crt\", \"service_key\": \"/etc/pki/tls/private/rabbitmq.key\"}, \"rabbitmq::ssl_versions\": {\"if\": [{\"get_param\": \"RabbitFIPS\"}, [\"tlsv1.2\", \"tlsv1.3\"], [\"tlsv1.2\"]]}}, {}]}, {\"rabbitmq::admin_enable\": false, \"rabbitmq::management_enable\": true, \"rabbitmq::use_config_file_for_plugins\": true, \"rabbitmq::management_ip_address\": {\"if\": [{\"get_param\": \"RabbitmqEnableManagementAccess\"}, {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"RabbitmqManagementNetwork\"]}}}}, \"127.0.0.1\"]}, \"rabbitmq::management_port\": 15672, \"rabbitmq::config_management_variables\": {\"rates_mode\": \"none\"}}, {\"if\": [\"rabbitmq_cacert_set\", {\"rabbitmq::ssl_cacert\": {\"get_param\": \"InternalTLSCAFile\"}, \"rabbitmq::ssl_management_cacert\": {\"get_param\": \"InternalTLSCAFile\"}}]}, {\"if\": [\"internal_tls_enabled\", {\"tripleo::certmonger::rabbitmq::postsave_cmd\": \"true\"}, {}]}]}, \"puppet_config\": {\"config_volume\": \"rabbitmq\", \"step_config\": {\"list_join\": [\"\\n\", [\"[\'Rabbitmq_policy\', \'Rabbitmq_user\'].each |String $val| { noop_resource($val) }\", \"include tripleo::profile::base::rabbitmq\"]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/rabbitmq.json\": {\"command\": \"/usr/lib/rabbitmq/bin/rabbitmq-server\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/lib/rabbitmq\", \"owner\": \"rabbitmq:rabbitmq\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/rabbitmq.crt\", \"owner\": \"rabbitmq:rabbitmq\", \"optional\": true}, {\"path\": \"/etc/pki/tls/private/rabbitmq.key\", \"owner\": \"rabbitmq:rabbitmq\", \"optional\": true}]}}, \"docker_config\": {\"step_1\": {\"rabbitmq_init_logs\": {\"start_order\": 0, \"detach\": false, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/rabbitmq:/var/log/rabbitmq\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R rabbitmq:rabbitmq /var/log/rabbitmq\"]}, \"rabbitmq_bootstrap\": {\"start_order\": 1, \"detach\": false, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}, \"net\": \"host\", \"privileged\": false, \"user\": \"root\", \"command\": [\"bash\", \"-ec\", {\"list_join\": [\"\\n\", [\"kolla_set_configs\", \"if [[ -e \\\"/var/lib/rabbitmq/.erlang.cookie\\\" ]]; then rm -f /var/lib/rabbitmq/.erlang.cookie; fi\", \"hiera \'rabbitmq::erlang_cookie\' > /var/lib/rabbitmq/.erlang.cookie\", \"chown rabbitmq:rabbitmq /var/lib/rabbitmq/.erlang.cookie\", \"chmod 400 /var/lib/rabbitmq/.erlang.cookie\"]]}], \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/rabbitmq.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/rabbitmq:/var/lib/kolla/config_files/src:ro\", \"/etc/puppet:/etc/puppet:ro\", \"/var/lib/rabbitmq:/var/lib/rabbitmq\", \"/var/log/containers/rabbitmq:/var/log/rabbitmq\"], {\"if\": [\"internal_tls_enabled\", [\"/etc/pki/tls/certs/rabbitmq.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/rabbitmq.crt:ro\", \"/etc/pki/tls/private/rabbitmq.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/rabbitmq.key:ro\"], null]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}, \"rabbitmq\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/rabbitmq.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/rabbitmq:/var/lib/kolla/config_files/src:ro\", \"/var/lib/rabbitmq:/var/lib/rabbitmq:z\", \"/var/log/containers/rabbitmq:/var/log/rabbitmq:z\"], {\"if\": [\"internal_tls_enabled\", [\"/etc/pki/tls/certs/rabbitmq.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/rabbitmq.crt:ro\", \"/etc/pki/tls/private/rabbitmq.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/rabbitmq.key:ro\"], null]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"container_puppet_tasks\": {\"step_2\": {\"config_volume\": \"rabbit_init_tasks\", \"puppet_tags\": \"rabbitmq_policy,rabbitmq_user\", \"step_config\": \"include tripleo::profile::base::rabbitmq\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRabbitmqConfigImage\"]}, \"volumes\": [\"/var/lib/config-data/puppet-generated/rabbitmq/etc/rabbitmq:/etc/rabbitmq:ro\", \"/var/lib/rabbitmq:/var/lib/rabbitmq\"]}}, \"metadata_settings\": {\"if\": [\"internal_tls_enabled\", [{\"service\": \"rabbitmq\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"RabbitmqNetwork\"]}, \"type\": \"node\"}], null]}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"rabbitmq\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"RabbitmqNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"rabbitmq/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"RabbitmqNetwork\"]}}}}, \"run_after\": \"container_name=$({{container_cli}} ps --format=\\\\{\\\\{.Names\\\\}\\\\} | grep -w -E \'rabbitmq(-bundle-.*-[0-9]+)?\')\\nservice_crt=\\\"/etc/pki/tls/certs/rabbitmq.crt\\\"\\nservice_key=\\\"/etc/pki/tls/private/rabbitmq.key\\\"\\nif echo \\\"$container_name\\\" | grep -q \\\"^rabbitmq-bundle\\\"; then\\n  # lp#1917868: Do not use podman cp with HA containers as they get\\n  # frozen temporarily and that can make pacemaker operation fail.\\n  tar -c \\\"$service_crt\\\" \\\"$service_key\\\" | {{container_cli}} exec -i \\\"$container_name\\\" tar -C / -xv\\n  # no need to update the mount point, because pacemaker\\n  # recreates the container when it\'s restarted\\nelse\\n  # Refresh the cert at the mount-point\\n  {{container_cli}} cp $service_crt \\\"$container_name:/var/lib/kolla/config_files/src-tls/$service_crt\\\"\\n  # Refresh the key at the mount-point\\n  {{container_cli}} cp $service_key \\\"$container_name:/var/lib/kolla/config_files/src-tls/$service_key\\\"\\n  # Copy the new cert from the mount-point to the real path\\n  {{container_cli}} exec -u root \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_crt\\\" \\\"$service_crt\\\"\\n  # Copy the new key from the mount-point to the real path\\n  {{container_cli}} exec -u root \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_key\\\" \\\"$service_key\\\"\\nfi\\n# Set appropriate permissions\\n{{container_cli}} exec -u root \\\"$container_name\\\" chown rabbitmq:rabbitmq \\\"$service_crt\\\"\\n{{container_cli}} exec -u root \\\"$container_name\\\" chown rabbitmq:rabbitmq \\\"$service_key\\\"\\n# Trigger a pem cache clear in RabbitMQ to read the new certificates\\n{{container_cli}} exec \\\"$container_name\\\" rabbitmqctl eval \\\"ssl:clear_pem_cache().\\\"\\n\", \"key_size\": {\"if\": [\"key_size_override_unset\", {\"get_param\": \"CertificateKeySize\"}, {\"get_param\": \"RabbitmqCertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}], \"host_prep_tasks\": [{\"name\": \"creat fcontext entry for rabbitmq data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/rabbitmq(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/rabbitmq\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/rabbitmq\", \"setype\": \"container_file_t\"}]}], \"upgrade_tasks\": [], \"update_tasks\": null}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(130,'2026-06-12 08:26:07',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Nova base service. Shared for all Nova services.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"NovaPassword\": {\"description\": \"The password for the nova service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"1Ii49H1EfmLUfEWsgfy9vla3q\"}, \"NeutronPassword\": {\"description\": \"The password for the neutron service and db account, used by neutron agents.\", \"type\": \"string\", \"hidden\": true, \"default\": \"qnvMdngIoyiS9ntQpzmg868ob\"}, \"PlacementPassword\": {\"description\": \"The password for the Placement service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\"}, \"PlacementAPIInterface\": {\"type\": \"string\", \"description\": \"Endpoint interface to be used for the placement API.\\n\", \"default\": \"internal\"}, \"NovaOVSBridge\": {\"default\": \"br-int\", \"description\": \"Name of integration bridge used by Open vSwitch\", \"type\": \"string\"}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"NovaDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Nova services.\", \"type\": \"boolean\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"EnableConfigPurge\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Remove configuration that is not generated by TripleO. Used to avoid configuration remnants after upgrades.\\n\"}, \"UpgradeLevelNovaCompute\": {\"type\": \"string\", \"description\": \"Nova Compute upgrade level\", \"default\": \"\"}, \"NovaOVSDBConnection\": {\"type\": \"string\", \"description\": \"OVS DB connection string to used by Nova\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaSyncPowerStateInterval\": {\"type\": \"number\", \"description\": \"Interval to sync power states between the database and the hypervisor. Set to -1 to disable. Setting this to 0 will run at the default rate(60) defined in oslo.service.\", \"default\": 600}, \"RpcUseSSL\": {\"default\": false, \"description\": \"Messaging client subscriber parameter to specify an SSL connection to the messaging host.\\n\", \"type\": \"string\"}, \"NovaAdditionalCell\": {\"default\": true, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"NovaCrossAZAttach\": {\"default\": true, \"description\": \"Whether instances can attach cinder volumes from a different availability zone.\", \"type\": \"boolean\"}, \"MemcachedTLS\": {\"default\": false, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"conditions\": {\"compute_upgrade_level_set\": {\"not\": {\"equals\": [{\"get_param\": \"UpgradeLevelNovaCompute\"}, \"\"]}}, \"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"nova::ovsdb_connection\": \"NovaOVSDBConnection\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NovaOVSDBConnection\": {\"get_param\": \"NovaOVSDBConnection\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova base service.\", \"value\": {\"service_name\": \"nova_base\", \"config_settings\": {\"map_merge\": [{\"nova::my_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}}}, \"nova::rabbit_use_ssl\": {\"get_param\": \"RpcUseSSL\"}, \"nova::keystone::service_user::send_service_user_token\": true, \"nova::keystone::service_user::project_name\": \"service\", \"nova::keystone::service_user::password\": {\"get_param\": \"NovaPassword\"}, \"nova::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::placement::project_name\": \"service\", \"nova::placement::password\": {\"get_param\": \"PlacementPassword\"}, \"nova::placement::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::placement::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::placement::valid_interfaces\": {\"get_param\": \"PlacementAPIInterface\"}, \"nova::os_region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::logging::debug\": {\"if\": [{\"get_param\": \"NovaDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"nova::purge_config\": {\"get_param\": \"EnableConfigPurge\"}, \"nova::network::neutron::project_name\": \"service\", \"nova::network::neutron::username\": \"neutron\", \"nova::network::neutron::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::dhcp_domain\": \"\", \"nova::network::neutron::password\": {\"get_param\": \"NeutronPassword\"}, \"nova::network::neutron::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"nova::network::neutron::valid_interfaces\": \"internal\", \"nova::glance::valid_interfaces\": \"internal\", \"nova::rabbit_heartbeat_timeout_threshold\": 60, \"nova::cinder_catalog_info\": \"volumev3:cinderv3:internalURL\", \"nova::host\": \"%{hiera(\'fqdn_canonical\')}\", \"nova::notify_on_state_change\": \"vm_and_task_state\", \"nova::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"nova::notification_format\": \"unversioned\", \"nova::network::neutron::auth_type\": \"v3password\", \"nova::db::database_db_max_retries\": -1, \"nova::db::database_max_retries\": -1, \"nova::network::neutron::ovs_bridge\": {\"get_param\": \"NovaOVSBridge\"}, \"nova::compute::sync_power_state_interval\": {\"get_param\": \"NovaSyncPowerStateInterval\"}, \"nova_is_additional_cell\": {\"get_param\": \"NovaAdditionalCell\"}, \"nova::cross_az_attach\": {\"get_param\": \"NovaCrossAZAttach\"}, \"nova::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"nova::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}, \"nova::cache::backend\": {\"if\": [\"tls_cache_enabled\", \"dogpile.cache.pymemcache\", \"dogpile.cache.memcached\"]}, \"nova::rabbit_heartbeat_in_pthread\": false, \"nova::upgrade_level_compute\": {\"if\": [\"compute_upgrade_level_set\", {\"get_param\": \"UpgradeLevelNovaCompute\"}]}}, {\"get_attr\": [\"RoleParametersValue\", \"value\"]}]}, \"service_config_settings\": {\"rabbitmq\": {\"nova::rabbit_use_ssl\": {\"get_param\": \"RpcUseSSL\"}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(131,'2026-06-12 08:26:07',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(132,'2026-06-12 08:26:08',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Nova database client service.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"NovaPassword\": {\"description\": \"The password for the nova service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"1Ii49H1EfmLUfEWsgfy9vla3q\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova base service.\", \"value\": {\"config_settings\": {\"nova::api_database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"nova_api\", \"password\": {\"get_param\": \"NovaPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/nova_api\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"nova_api\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}}, \"service_config_settings\": {\"mysql\": {\"nova::db::mysql_api::password\": {\"get_param\": \"NovaPassword\"}, \"nova::db::mysql_api::user\": \"nova_api\", \"nova::db::mysql_api::host\": \"%\", \"nova::db::mysql_api::dbname\": \"nova_api\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(133,'2026-06-12 08:26:08',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(134,'2026-06-12 08:26:08',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(135,'2026-06-12 08:26:09',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Template for nova-metadata\'s logging to files\\n\", \"parameters\": {\"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerNovaMetadataImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\"}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerNovaMetadataImage\": \"ContainerNovaMetadataImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerNovaMetadataImage\": {\"get_param\": \"ContainerNovaMetadataImage\"}}}]}}}}, \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/nova:/var/log/nova:z\", \"/var/log/containers/httpd/nova-metadata:/var/log/httpd:z\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {\"nova_metadata_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaMetadataImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/nova:/var/log/nova:z\", \"/var/log/containers/httpd/nova-metadata:/var/log/httpd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R nova:nova /var/log/nova\"]}}}}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/nova\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/nova-metadata\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(136,'2026-06-12 08:26:09',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Composable Timezone service\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"TimeZone\": {\"default\": \"UTC\", \"description\": \"The timezone to be set on the overcloud.\", \"type\": \"string\"}}, \"outputs\": {\"role_data\": {\"description\": \"Timezone role using composable services.\", \"value\": {\"service_name\": \"timezone\", \"host_prep_tasks\": [{\"name\": \"Run timezone role\", \"include_role\": {\"name\": \"tripleo_timezone\"}, \"vars\": {\"tripleo_timezone\": {\"get_param\": \"TimeZone\"}}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (137,'2026-06-12 08:26:09',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Pacemaker service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"MonitoringSubscriptionPacemaker\": {\"default\": \"overcloud-pacemaker\", \"type\": \"string\"}, \"CorosyncIPv6\": {\"default\": false, \"description\": \"Enable IPv6 in Corosync\", \"type\": \"boolean\"}, \"EnableFencing\": {\"default\": false, \"description\": \"Whether to enable fencing in Pacemaker or not.\", \"type\": \"boolean\"}, \"PacemakerTLSPriorities\": {\"type\": \"string\", \"description\": \"Pacemaker TLS Priorities\", \"default\": \"\"}, \"PacemakerRemoteAuthkey\": {\"type\": \"string\", \"description\": \"The authkey for the pacemaker remote service.\", \"hidden\": true, \"default\": \" \"}, \"PcsdPassword\": {\"type\": \"string\", \"description\": \"The password for the \'pcsd\' user for pacemaker.\", \"hidden\": true, \"default\": \"NvleZPciNHzWAChh\"}, \"CorosyncTokenTimeout\": {\"type\": \"number\", \"description\": \"Time in milliseconds until a token loss is declared after not receiving a token.\", \"default\": 10000}, \"CorosyncSettleTries\": {\"type\": \"number\", \"description\": \"Number of tries for cluster settling. This has the same default as the pacemaker puppet module. Override to a smaller value when in need to replace a controller node.\", \"default\": 360}, \"FencingConfig\": {\"default\": {}, \"description\": \"Pacemaker fencing configuration. The JSON should have\\nthe following structure:\\n  {\\n    \\\"devices\\\": [\\n      {\\n        \\\"agent\\\": \\\"AGENT_NAME\\\",\\n        \\\"host_mac\\\": \\\"HOST_MAC_ADDRESS\\\",\\n        \\\"params\\\": {\\\"PARAM_NAME\\\": \\\"PARAM_VALUE\\\"}\\n      }\\n    ]\\n  }\\nFor instance:\\n  {\\n    \\\"devices\\\": [\\n      {\\n        \\\"agent\\\": \\\"fence_xvm\\\",\\n        \\\"host_mac\\\": \\\"52:54:00:aa:bb:cc\\\",\\n        \\\"params\\\": {\\n          \\\"multicast_address\\\": \\\"225.0.0.12\\\",\\n          \\\"port\\\": \\\"baremetal_0\\\",\\n          \\\"manage_fw\\\": true,\\n          \\\"manage_key_file\\\": true,\\n          \\\"key_file\\\": \\\"/etc/fence_xvm.key\\\",\\n          \\\"key_file_password\\\": \\\"abcdef\\\"\\n        }\\n      }\\n    ]\\n  }\\n\", \"type\": \"json\"}, \"PacemakerLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"system.pacemaker\", \"file\": \"/var/log/host/pacemaker/pacemaker.log\", \"startmsg.regex\": \"^[a-zA-Z]{3} [0-9]{2} [:0-9]{8}\"}}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"EnableInstanceHA\": {\"default\": false, \"description\": \"Whether to enable an Instance Ha configurarion or not. This setup requires the Compute role to have the PacemakerRemote service added to it.\", \"type\": \"boolean\"}, \"PacemakerBundleOperationTimeout\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The timeout for start, monitor and stop operations run by the container resource agent, in seconds. When set to default \'\', the timeout comes from pacemaker\'s default operation timeouts (20s). When set to default and podman is used, force the timeout to 120s.\", \"constraints\": [{\"allowed_pattern\": \"([1-9][0-9]*s)?\"}]}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"CorosyncIPv6\"]}], \"conditions\": {\"pcmk_tls_priorities_empty\": {\"equals\": [{\"get_param\": \"PacemakerTLSPriorities\"}, \"\"]}, \"pcmk_bundle_op_timeout_empty\": {\"equals\": [{\"get_param\": \"PacemakerBundleOperationTimeout\"}, \"\"]}, \"podman_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"podman\"]}, \"is_ipv6\": {\"equals\": [{\"get_param\": [\"ServiceData\", \"net_ip_version_map\", {\"get_param\": [\"ServiceNetMap\", \"PacemakerNetwork\"]}]}, 6]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Pacemaker role.\", \"value\": {\"service_name\": \"pacemaker\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionPacemaker\"}, \"firewall_rules\": {\"130 pacemaker tcp\": {\"proto\": \"tcp\", \"dport\": [2224, 3121, 21064]}, \"131 pacemaker udp\": {\"proto\": \"udp\", \"dport\": 5405}}, \"config_settings\": {\"map_merge\": [{\"pacemaker::corosync::cluster_name\": \"tripleo_cluster\", \"pacemaker::corosync::manage_fw\": false, \"pacemaker::resource_defaults::defaults\": {\"resource-stickiness\": {\"value\": \"INFINITY\"}}, \"corosync_token_timeout\": {\"get_param\": \"CorosyncTokenTimeout\"}, \"pacemaker::corosync::settle_tries\": {\"get_param\": \"CorosyncSettleTries\"}, \"pacemaker::resource::bundle::deep_compare\": true, \"pacemaker::resource::ip::deep_compare\": true, \"pacemaker::resource::ocf::deep_compare\": true, \"corosync_ipv6\": {\"if\": [\"is_ipv6\", true, false]}, \"tripleo::fencing::config\": {\"get_param\": \"FencingConfig\"}, \"tripleo::fencing::deep_compare\": true, \"enable_fencing\": {\"get_param\": \"EnableFencing\"}, \"hacluster_pwd\": {\"get_param\": \"PcsdPassword\"}, \"tripleo::profile::base::pacemaker::remote_authkey\": {\"get_param\": \"PacemakerRemoteAuthkey\"}, \"tripleo::profile::base::pacemaker::pcsd_bind_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PacemakerNetwork\"]}}}}}, {\"if\": [\"pcmk_tls_priorities_empty\", {}, {\"tripleo::pacemaker::tls_priorities\": {\"get_param\": \"PacemakerTLSPriorities\"}}]}, {\"if\": [{\"and\": [\"pcmk_bundle_op_timeout_empty\", {\"not\": \"podman_enabled\"}]}, {}, {\"tripleo::profile::base::pacemaker::resource_op_defaults\": {\"bundle\": {\"name\": \"timeout\", \"value\": {\"if\": [\"pcmk_bundle_op_timeout_empty\", \"120s\", {\"get_param\": \"PacemakerBundleOperationTimeout\"}]}}}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_pacemaker\": [{\"get_param\": \"PacemakerLoggingSource\"}]}}, \"step_config\": \"include tripleo::profile::base::pacemaker\\n\", \"host_prep_tasks\": [{\"name\": \"Make sure python3-novaclient is installed when IHA is enabled\", \"package\": {\"name\": \"python3-novaclient\", \"state\": \"present\"}, \"when\": {\"get_param\": \"EnableInstanceHA\"}}, {\"name\": \"Remove existing entries from logind conf\", \"ansible.builtin.lineinfile\": {\"path\": \"/etc/systemd/logind.conf\", \"regexp\": \"^\\\\s*#?\\\\s*HandlePowerKey\\\\s*=.*\", \"state\": \"absent\"}}, {\"name\": \"Make sure systemd-logind ignores power off\", \"ansible.builtin.lineinfile\": {\"path\": \"/etc/systemd/logind.conf\", \"regexp\": \"^#?HandlePowerKey\", \"line\": \"HandlePowerKey=ignore\"}}, {\"name\": \"Restart systemd-logind\", \"ansible.builtin.service\": {\"name\": \"systemd-logind\", \"state\": \"restarted\"}}, {\"name\": \"Gather service_facts on pacemaker_bootstrap_node\", \"ansible.builtin.service_facts\": null, \"when\": [\"{{(pacemaker_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower)|bool}}\", {\"get_param\": \"EnableInstanceHA\"}]}, {\"name\": \"Check and eventually delete duplicate constraints (bootstrap node)\", \"become\": true, \"shell\": \"COUNT=$(cibadmin --query | xmllint --xpath \'//rsc_location[@rsc=\\\"stonith-fence_compute-fence-nova\\\"]/@id\' - |grep -oP \'(?<=[\\\"])[^\\\"]*\' -c)\\nif [[ $COUNT > 1 ]]; then\\n    echo \\\"Detected $COUNT duplicate constraints, deleting them\\\"\\n    # assemble string with current list of computes\\n    GOOD=$(echo location-stonith-fence_compute-fence-nova-$(hiera pacemaker_remote_short_node_names |grep -oP \'\\\".*?\\\"\' |tr -d \'\\\"\'|tr -d \'\\\\n\' )--10000)\\n    # delete old constraints\\n    for i in $(cibadmin --query | xmllint --xpath \'//rsc_location[@rsc=\\\"stonith-fence_compute-fence-nova\\\"]/@id\' - |grep -oP \'(?<=[\\\"])[^\\\"]*\' |grep -v $GOOD ); do pcs constraint delete $i ; done\\nelse\\n    echo \\\"No duplicate constraint found\\\"\\nfi\\n\", \"when\": [\"{{(pacemaker_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower)|bool}}\", {\"get_param\": \"EnableInstanceHA\"}, \"ansible_facts[\'services\'][\'pacemaker.service\'][\'state\'] == \'running\'\"]}], \"scale_tasks\": [{\"when\": [\"step|int == 1\", \"container_cli == \'podman\'\", \"\\\"pacemaker_remote\\\" in enabled_services|list\", \"inventory_hostname_short in compute_instanceha_short_node_names\"], \"tags\": \"down\", \"become\": true, \"block\": [{\"name\": \"Getting Nova compute hostname\", \"command\": \"crm_node -n\", \"register\": \"nova_compute_hostname\"}, {\"name\": \"Check if pacemaker_short_bootstrap_node_name is a defined variable\", \"when\": \"pacemaker_short_bootstrap_node_name is not defined\", \"fail\": {\"msg\": \"Cannot delegate pacemaker cleanup to the bootstrap node. Please delete the resources manually.\"}, \"ignore_errors\": true}, {\"name\": \"Clean up Pacemaker remote and STONITH resources for Compute node\", \"when\": [\"nova_compute_hostname.stdout in compute_instanceha_short_node_names\", \"pacemaker_short_bootstrap_node_name is defined\"], \"block\": [{\"name\": \"List STONITH resource for the Compute node\", \"command\": \"stonith_admin -l {{ nova_compute_hostname.stdout }}\", \"register\": \"stonith_service_results\", \"delegate_to\": \"{{ pacemaker_short_bootstrap_node_name }}\"}, {\"name\": \"Disable the STONITH resources for the Compute node\", \"command\": \"pcs stonith disable \\\"{{ item }}\\\"\", \"loop\": \"{{ stonith_service_results.stdout | regex_findall(\'^(stonith-fence(?!_compute-fence-nova).*)\', multiline=True)}}\", \"delegate_to\": \"{{ pacemaker_short_bootstrap_node_name }}\", \"register\": \"disable_output\", \"failed_when\": \"disable_output.rc != 0\", \"retries\": 3, \"delay\": 5, \"until\": \"disable_output.rc == 0\"}, {\"name\": \"Delete the STONITH resources for the Compute node\", \"command\": \"pcs stonith delete \\\"{{ item }}\\\"\", \"loop\": \"{{ stonith_service_results.stdout | regex_findall(\'^(stonith-fence(?!_compute-fence-nova).*)\', multiline=True)}}\", \"delegate_to\": \"{{ pacemaker_short_bootstrap_node_name }}\", \"register\": \"delete_output\", \"failed_when\": \"delete_output.rc != 0\", \"retries\": 3, \"delay\": 5, \"until\": \"delete_output.rc == 0\"}, {\"name\": \"Clear the stonith level hierarchy for the Compute node target\", \"command\": \"pcs stonith level clear target {{ nova_compute_hostname.stdout }}\", \"delegate_to\": \"{{ pacemaker_short_bootstrap_node_name }}\"}, {\"name\": \"Delete Compute node from cluster\", \"command\": \"pcs cluster node remove-remote {{ nova_compute_hostname.stdout }}\", \"delegate_to\": \"{{ pacemaker_short_bootstrap_node_name }}\"}, {\"name\": \"Remove compute node in pcmk_host_list parameter from stonith-fence_compute-fence-nova\", \"command\": \"crm_resource --set-parameter=pcmk_host_list -r stonith-fence_compute-fence-nova -v \\\"{{ pacemaker_remote_short_node_names | reject(\'search\', nova_compute_hostname.stdout) | join(\',\') }}\\\"\", \"delegate_to\": \"{{ pacemaker_short_bootstrap_node_name }}\"}]}]}], \"upgrade_tasks\": [{\"name\": \"Ensure redis is removed\", \"when\": [\"step|int == 5\", \"\\\"redis\\\" not in enabled_services|list\", \"{{ (pacemaker_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower)|bool}}\"], \"become\": true, \"shell\": \"if crm_resource -r redis-bundle -q &>/dev/null; then\\n   pcs resource delete redis-bundle || true\\n   pcs resource delete ip-$(hiera redis_vip) || true\\nfi\\n\"}, {\"name\": \"Clean up cluster node cache\", \"when\": [\"step|int == 5\", \"\\\"redis\\\" not in enabled_services|list\", \"{{ (pacemaker_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower)|bool}}\"], \"become\": true, \"shell\": \"pcs cluster node clear redis-bundle-0\\npcs cluster node clear redis-bundle-1\\npcs cluster node clear redis-bundle-2\\ncrm_attribute --name redis_REPL_INFO --delete\\n\"}, {\"name\": \"Clean up redis attribute\", \"when\": [\"step|int == 5\", \"\\\"redis\\\" not in enabled_services|list\", \"{{ (pacemaker_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower)|bool}}\"], \"become\": true, \"shell\": \"pcs node attribute \\\"{{ item }}\\\" redis-role= || true\\n\", \"loop\": \"{{ pacemaker_short_node_names }}\"}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_stop_services\", \"system_upgrade_transfer_data\"], \"block\": [{\"name\": \"Stop cluster\", \"become\": true, \"shell\": \"set -eu\\nFILE=/usr/sbin/pcs\\nif test -f \\\"$FILE\\\"; then\\n  /usr/sbin/pcs cluster stop --force\\nfi\\n\", \"delegate_to\": \"{{ item }}\", \"with_items\": \"{{ groups[\'pacemaker\'] | difference(groups[\'excluded_overcloud\']) }}\"}]}], \"update_tasks\": [{\"name\": \"Check pacemaker cluster running before the minor update\", \"when\": \"step|int == 0\", \"pacemaker_cluster\": \"state=online check_and_fail=true\", \"async\": 30, \"poll\": 4}, {\"name\": \"Acquire the cluster shutdown lock to stop pacemaker cluster\", \"when\": \"step|int == 1\", \"command\": \"systemd-cat -t ha-shutdown /var/lib/container-config-scripts/pacemaker_mutex_shutdown.sh --acquire\"}, {\"name\": \"Stop pacemaker cluster\", \"when\": \"step|int == 1\", \"pacemaker_cluster\": \"state=offline\"}, {\"name\": \"Start pacemaker cluster\", \"when\": \"step|int == 4\", \"pacemaker_cluster\": \"state=online\"}, {\"name\": \"Release the cluster shutdown lock\", \"when\": \"step|int == 4\", \"command\": \"systemd-cat -t ha-shutdown /var/lib/container-config-scripts/pacemaker_mutex_shutdown.sh --release\"}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(138,'2026-06-12 08:26:09',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"SNMP client configured with Puppet, to facilitate Ceilometer Hardware monitoring in the undercloud. This service is required to enable hardware monitoring.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"SnmpdReadonlyUserName\": {\"default\": \"ro_snmp_user\", \"description\": \"The user name for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\"}, \"SnmpdReadonlyUserPassword\": {\"description\": \"The user password for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\", \"hidden\": true, \"default\": \"KjPkLxPsqu3qjdbO0SJ0shPX\"}, \"SnmpdBindHost\": {\"description\": \"An array of bind host addresses on which SNMP daemon will listen.\", \"type\": \"comma_delimited_list\", \"default\": [\"udp:161\", \"udp6:[::1]:161\"]}, \"SnmpdOptions\": {\"description\": \"A string containing the commandline options passed to snmpd\", \"type\": \"string\", \"default\": \"-LS0-5d\"}, \"SnmpdIpSubnet\": {\"default\": \"\", \"description\": \"IP address/subnet on the snmpd network. If empty (default), SnmpdNetwork will be taken.\", \"type\": \"string\"}}, \"conditions\": {\"snmpd_network_unset\": {\"equals\": [{\"get_param\": \"SnmpdIpSubnet\"}, \"\"]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the SNMP services\", \"value\": {\"service_name\": \"snmp\", \"firewall_rules\": {\"if\": [\"snmpd_network_unset\", {\"map_merge\": {\"repeat\": {\"for_each\": {\"<%net_cidr%>\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"SnmpdNetwork\"]}]}}, \"template\": {\"124 snmp <%net_cidr%>\": {\"dport\": 161, \"proto\": \"udp\", \"source\": \"<%net_cidr%>\"}}}}}, {\"124 snmp\": {\"dport\": 161, \"proto\": \"udp\", \"source\": {\"get_param\": \"SnmpdIpSubnet\"}}}]}, \"config_settings\": {\"tripleo::profile::base::snmp::snmpd_user\": {\"get_param\": \"SnmpdReadonlyUserName\"}, \"tripleo::profile::base::snmp::snmpd_password\": {\"get_param\": \"SnmpdReadonlyUserPassword\"}, \"snmp::agentaddress\": {\"get_param\": \"SnmpdBindHost\"}, \"snmp::snmpd_options\": {\"get_param\": \"SnmpdOptions\"}}, \"step_config\": \"include tripleo::profile::base::snmp\\n\", \"upgrade_tasks\": [{\"when\": \"step|int == 0\", \"block\": [{\"name\": \"Check if snmpd is enabled\", \"command\": \"systemctl is-enabled --quiet snmpd\", \"failed_when\": false, \"register\": \"snmpd_enabled_result\"}, {\"name\": \"Set fact snmpd_enabled\", \"set_fact\": {\"snmpd_enabled\": \"{{ snmpd_enabled_result.rc == 0 }}\"}}]}, {\"name\": \"Stop snmp service\", \"when\": [\"step|int == 1\", \"snmpd_enabled|bool\"], \"service\": \"name=snmpd state=stopped\"}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(139,'2026-06-12 08:26:09',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"MySQL service deployment using puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"MysqlMaxConnections\": {\"description\": \"Configures MySQL max_connections config setting\", \"type\": \"number\", \"default\": 4096}, \"MysqlIncreaseFileLimit\": {\"description\": \"Flag to increase MySQL open-files-limit to 16384\", \"type\": \"boolean\", \"default\": true}, \"MysqlRootPassword\": {\"type\": \"string\", \"hidden\": true, \"default\": \"lewodgEGks\"}, \"MysqlClustercheckPassword\": {\"type\": \"string\", \"hidden\": true, \"default\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\"}, \"EnableGalera\": {\"default\": true, \"description\": \"Whether to use Galera instead of regular MariaDB.\", \"type\": \"boolean\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"EnableMysqlAuthEd25519\": {\"type\": \"boolean\", \"description\": \"Whether to configure MySQL users to connect to the server using the Ed25519-based client authentication.\", \"default\": false}, \"MysqlIPv6\": {\"default\": false, \"description\": \"Enable IPv6 in MySQL\", \"type\": \"boolean\"}, \"MysqlInnodbBufferPoolSize\": {\"type\": \"string\", \"description\": \"Buffer pool size for MySQL database; this needs to be larger for at-scale deployments\", \"default\": \"128M\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"MysqlCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"MysqlIPv6\"]}], \"conditions\": {\"is_ipv6\": {\"equals\": [{\"get_param\": [\"ServiceData\", \"net_ip_version_map\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}, 6]}, \"innodb_buffer_pool_set\": {\"not\": {\"equals\": [{\"get_param\": \"MysqlInnodbBufferPoolSize\"}, \"\"]}}, \"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"MysqlCertificateKeySize\"}, \"\"]}}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared docker config scripts\", \"value\": {\"mysql_upgrade_db.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/mysql_upgrade_db.sh\"}}}}, \"mysql_drop_unused_users\": {\"description\": \"Ansible block to clean up unusued Openstack DB users\", \"value\": [{\"name\": \"Drop unused OpenStack DB users\", \"when\": [\"step|int == 1\", \"mysql_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower\"], \"block\": [{\"name\": \"mysql container id\", \"command\": \"podman ps -q --filter name={{ mysql_container_name }} --filter status=running\", \"register\": \"mysql_container_id\"}, {\"name\": \"set mysql container id fact\", \"set_fact\": {\"mysql_container\": \"{{ mysql_container_id.stdout }}\"}}, {\"name\": \"Mysql script to drop unused DB users\", \"when\": \"( mysql_container | length ) > 0\", \"block\": [{\"name\": \"Get the list of all OpenStack DB users\", \"shell\": \"jq -r \'to_entries[] | select(.key|endswith(\\\"::db::mysql::user\\\")) | .value\' /etc/puppet/hieradata/service_configs.json\", \"register\": \"openstack_db_users\"}, {\"name\": \"List all DB users that match the DB users to be dropped\", \"shell\": \"for u in {{ openstack_db_users.stdout_lines | join(\' \') }}; do podman exec -u root -it \\\"{{ mysql_container }}\\\" mysql -sNe \\\"select concat(\'\\\\`\',user,\'\\\\`@\\\\`\',host,\'\\\\`\') from mysql.user where user = \'$u\' and host != \'%\';\\\"; done\", \"register\": \"mysql_db_users\"}, {\"name\": \"resulting DB users to be dropped\", \"debug\": {\"msg\": \"{{ mysql_db_users.stdout_lines }}\"}}, {\"name\": \"Drop all unneeded Openstack DB users\", \"shell\": \"podman exec -u root -it \\\"{{ mysql_container }}\\\" mysql -sNe \'drop user {{ item }};\'\", \"loop\": \"{{ mysql_db_users.stdout_lines }}\"}]}]}]}, \"role_data\": {\"description\": \"Service MySQL using composable services.\", \"value\": {\"service_name\": \"mysql\", \"config_settings\": {\"mysql::server::package_name\": \"mariadb-galera-server\", \"mysql::server::manage_config_file\": true, \"mysql_ipv6\": {\"if\": [\"is_ipv6\", true, false]}, \"mysql_max_connections\": {\"get_param\": \"MysqlMaxConnections\"}, \"mysql::server::root_password\": {\"get_param\": \"MysqlRootPassword\"}, \"mysql_clustercheck_password\": {\"get_param\": \"MysqlClustercheckPassword\"}, \"enable_galera\": {\"get_param\": \"EnableGalera\"}, \"mysql_auth_ed25519\": {\"get_param\": \"EnableMysqlAuthEd25519\"}, \"mysql_bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::generate_dropin_file_limit\": {\"get_param\": \"MysqlIncreaseFileLimit\"}, \"tripleo::profile::base::database::mysql::certificate_specs\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"service_certificate\": \"/etc/pki/tls/certs/mysql.crt\", \"service_key\": \"/etc/pki/tls/private/mysql.key\"}]}, \"innodb_buffer_pool_size\": {\"if\": [\"innodb_buffer_pool_set\", {\"get_param\": \"MysqlInnodbBufferPoolSize\"}]}}, \"step_config\": \"include tripleo::profile::base::database::mysql\\n\", \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [{\"service\": \"mysql\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}, \"type\": \"vip\"}, {\"service\": \"mysql\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}, \"type\": \"node\"}]]}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"mysql\", \"dns\": [{\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, {\"str_replace\": {\"template\": \"{{cloud_names.cloud_name_NETWORK}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}], \"principal\": {\"str_replace\": {\"template\": \"mysql/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"MysqlCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(140,'2026-06-12 08:26:09',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Ovn Controller agent.\\n\", \"parameters\": {\"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\", \"default\": \"cell1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ContainerOvnControllerImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\"}, \"ContainerOvnControllerConfigImage\": {\"description\": \"The container image to use for the ovn_controller config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1781252715, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"OVNSouthboundServerPort\": {\"description\": \"Port of the Southbound DB Server\", \"type\": \"number\", \"default\": 6642}, \"NeutronBridgeMappings\": {\"description\": \"The OVS logical->physical bridge mappings to use. See the Neutron documentation for details. Defaults to mapping br-ex - the external bridge on hosts - to a physical name \'datacentre\' which can be used to create provider networks (and we use this for the default floating network) - if changing this either use different post-install network scripts or be sure to keep \'datacentre\' as a mapping network name.\\n\", \"type\": \"comma_delimited_list\", \"default\": \"datacentre:br-ex\", \"tags\": [\"role_specific\"]}, \"EnableVLANTransparency\": {\"default\": false, \"description\": \"If True, then allow plugins that support it to create VLAN transparent networks.\\n\", \"type\": \"boolean\"}, \"OVNEncapType\": {\"description\": \"Type of encapsulation used in OVN. It can be \\\"geneve\\\" or \\\"vxlan\\\".\\n\", \"type\": \"string\", \"default\": \"geneve\", \"constraints\": [{\"allowed_values\": [\"geneve\", \"vxlan\"]}]}, \"OVNIntegrationBridge\": {\"description\": \"Name of the OVS bridge to use as integration bridge by OVN Controller.\\n\", \"type\": \"string\", \"default\": \"br-int\"}, \"OVNMetadataEnabled\": {\"description\": \"Whether Metadata Service has to be enabled\", \"type\": \"boolean\", \"default\": true}, \"OVNAvailabilityZone\": {\"description\": \"The az options to configure in ovs db. eg. [\'az-0\', \'az-1\', \'az-2\']\", \"type\": \"comma_delimited_list\", \"default\": [], \"tags\": [\"role_specific\"]}, \"OVNCMSOptions\": {\"description\": \"The CMS options to configure in ovs db\", \"type\": \"string\", \"default\": \"enable-chassis-as-gw\", \"tags\": [\"role_specific\"]}, \"OVNEncapTos\": {\"description\": \"The value to be applied to OVN tunnel interface\'s option:tos as specified in the Open_vSwitch database Interface table. This feature is supported from OVN v21.12.0.\\n\", \"type\": \"string\", \"default\": \"0\", \"tags\": [\"role_specific\"]}, \"OvsHwOffload\": {\"default\": false, \"description\": \"Enable OVS Hardware Offload. This feature supported from OVS 2.8.0\\n\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"OVNRemoteProbeInterval\": {\"description\": \"Probe interval in ms\", \"type\": \"number\", \"default\": 60000}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"OVNOpenflowProbeInterval\": {\"description\": \"The inactivity probe interval of the OpenFlow connection to the OpenvSwitch integration bridge, in seconds.\\n\", \"type\": \"number\", \"default\": 60}, \"OVNOfctrlWaitBeforeClear\": {\"description\": \"Sets the time ovn-controller will wait on startup before clearing all openflow rules and installing the new ones, in ms.\\n\", \"type\": \"number\", \"default\": 8000}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ContainerOvnCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"OVNContainerCpusetCpus\": {\"description\": \"Limit the specific CPUs or cores a container can use. It can be specified as a single core (ex. 0), as a comma-separated list (ex. 0,1), as a range (ex. 0-3) or a combination if previous methods (ex 0-3,7,11-15).  The selected cores should be isolated from guests and hypervisor in order to obtain best possible performance.\\n\", \"type\": \"string\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"OVNStaticBridgeMacMappings\": {\"type\": \"json\", \"default\": {}, \"description\": \"Static OVN Bridge MAC address mappings. Unique OVN bridge mac addresses\\nis dynamically allocated by creating neutron ports. When neutron isn\'t\\navailable, for instance in the standalone deployment, use this parameter\\nto provide static OVN bridge mac addresses. For example:\\n   controller-0:\\n     datacenter: 00:00:5E:00:53:00\\n     provider: 00:00:5E:00:53:01\\n   compute-0:\\n     datacenter: 00:00:5E:00:54:00\\n     provider: 00:00:5E:00:54:01\\n\", \"tags\": [\"role_specific\"]}, \"AuthCloudName\": {\"description\": \"Entry in clouds.yaml to use for authentication\", \"type\": \"string\", \"default\": \"overcloud\"}, \"OVNControllerImageUpdateTimeout\": {\"description\": \"During update, how long we wait for the container image to be updated, in seconds.\\n\", \"type\": \"number\", \"default\": 600}, \"OVNControllerUpdateTimeout\": {\"description\": \"During update, how long we wait for the container to be updated, in seconds.\\n\", \"type\": \"number\", \"default\": 600}, \"OVNControllerGarpMaxTimeout\": {\"description\": \"When used, this configuration value specifies the maximum timeout (in seconds) between two consecutive GARP packets sent by ovn-controller.\\n\", \"type\": \"number\", \"default\": 0}}, \"conditions\": {\"force_config_drive\": {\"equals\": [{\"get_param\": \"OVNMetadataEnabled\"}, false]}, \"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"key_size_override_unset\": {\"equals\": [{\"get_param\": \"ContainerOvnCertificateKeySize\"}, \"\"]}, \"enable_vlan_transparency\": {\"equals\": [{\"get_param\": \"EnableVLANTransparency\"}, true]}, \"auth_cloud_name_set\": {\"not\": {\"equals\": [{\"get_param\": \"AuthCloudName\"}, \"\"]}}, \"ovn_cpu_set\": {\"or\": [{\"not\": {\"equals\": [{\"get_param\": \"OVNContainerCpusetCpus\"}, \"\"]}}, {\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"OVNContainerCpusetCpus\"]}, \"\"]}}]}, \"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ContainerOvnCertificateKeySize\"}, \"\"]}}, \"az_ovn_unset\": {\"and\": [{\"equals\": [{\"get_param\": \"OVNAvailabilityZone\"}, []]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"OVNAvailabilityZone\"]}, \"\"]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ovn::controller::ovn_bridge_mappings\": \"NeutronBridgeMappings\", \"ovn::controller::ovn_cms_options\": {\"if\": [\"az_ovn_unset\", \"OVNCMSOptions\", \"OVNCMSOptionsMerged\"]}, \"ovn::controller::ovn_encap_tos\": \"OVNEncapTos\", \"vswitch::ovs::enable_hw_offload\": \"OvsHwOffload\", \"container_cpuset_cpus\": \"OVNContainerCpusetCpus\", \"ContainerOvnControllerImage\": \"ContainerOvnControllerImage\", \"ContainerOvnControllerConfigImage\": \"ContainerOvnControllerConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NeutronBridgeMappings\": {\"get_param\": \"NeutronBridgeMappings\"}, \"OVNCMSOptions\": {\"get_param\": \"OVNCMSOptions\"}, \"OVNCMSOptionsMerged\": {\"list_join\": [\"\", [{\"str_replace\": {\"template\": \"$OVNCMSOptions\", \"params\": {\"if\": [{\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"OVNCMSOptions\"]}, \"\"]}}, {\"$OVNCMSOptions\": {\"get_param\": [\"RoleParameters\", \"OVNCMSOptions\"]}}, {\"$OVNCMSOptions\": {\"get_param\": \"OVNCMSOptions\"}}]}}}, {\"str_replace\": {\"template\": \",availability-zones=$OVNAvailabilityZone\", \"params\": {\"if\": [{\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"OVNAvailabilityZone\"]}, \"\"]}}, {\"$OVNAvailabilityZone\": {\"get_param\": [\"RoleParameters\", \"OVNAvailabilityZone\"]}}, {\"$OVNAvailabilityZone\": {\"list_join\": [\",\", {\"get_param\": \"OVNAvailabilityZone\"}]}}]}}}]]}, \"OVNEncapTos\": {\"get_param\": \"OVNEncapTos\"}, \"OvsHwOffload\": {\"get_param\": \"OvsHwOffload\"}, \"OVNContainerCpusetCpus\": {\"get_param\": \"OVNContainerCpusetCpus\"}, \"ContainerOvnControllerImage\": {\"get_param\": \"ContainerOvnControllerImage\"}, \"ContainerOvnControllerConfigImage\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}}}]}}}, \"OVNBridgeMappingsValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ovn_bridge_mappings\": \"NeutronBridgeMappings\", \"ovn_static_bridge_mac_mappings\": \"OVNStaticBridgeMacMappings\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NeutronBridgeMappings\": {\"get_param\": \"NeutronBridgeMappings\"}, \"OVNStaticBridgeMacMappings\": {\"get_param\": \"OVNStaticBridgeMacMappings\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ovn Controller agent.\", \"value\": {\"service_name\": \"ovn_controller\", \"firewall_rules\": {\"118 neutron vxlan networks\": {\"proto\": \"udp\", \"dport\": 4789, \"state\": []}, \"119 neutron geneve networks\": {\"proto\": \"udp\", \"dport\": 6081, \"state\": []}, \"120 neutron geneve networks no conntrack\": {\"proto\": \"udp\", \"dport\": 6081, \"table\": \"raw\", \"chain\": \"OUTPUT\", \"jump\": \"NOTRACK\", \"action\": \"append\", \"state\": [\"INVALID\"]}, \"121 neutron geneve networks no conntrack\": {\"proto\": \"udp\", \"dport\": 6081, \"table\": \"raw\", \"chain\": \"PREROUTING\", \"jump\": \"NOTRACK\", \"action\": \"append\", \"state\": [\"INVALID\"]}}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"RoleParametersValue\", \"value\"]}, {\"ovn::southbound::port\": {\"get_param\": \"OVNSouthboundServerPort\"}, \"ovn::controller::ovn_encap_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronTenantNetwork\"]}}}}, \"ovn::controller::ovn_encap_type\": {\"get_param\": \"OVNEncapType\"}, \"ovn::controller::ovn_bridge\": {\"get_param\": \"OVNIntegrationBridge\"}, \"ovn::controller::hostname\": \"%{hiera(\'fqdn_canonical\')}\", \"ovn::controller::ovn_remote_probe_interval\": {\"get_param\": \"OVNRemoteProbeInterval\"}, \"ovn::controller::ovn_openflow_probe_interval\": {\"get_param\": \"OVNOpenflowProbeInterval\"}, \"ovn::controller::ovn_ofctrl_wait_before_clear\": {\"get_param\": \"OVNOfctrlWaitBeforeClear\"}, \"ovn::controller::garp_max_timeout_sec\": {\"get_param\": \"OVNControllerGarpMaxTimeout\"}, \"ovn::controller::ovn_monitor_all\": true}, {\"if\": [\"force_config_drive\", {\"nova::compute::force_config_drive\": true}, {}]}, {\"if\": [\"internal_tls_enabled\", {\"tripleo::profile::base::neutron::agents::ovn::protocol\": \"ssl\"}, {}]}, {\"if\": [\"enable_vlan_transparency\", {\"vswitch::ovs::vlan_limit\": 0}, {}]}]}, \"service_config_settings\": {}, \"puppet_config\": {\"puppet_tags\": \"vs_config,exec\", \"config_volume\": \"ovn_controller\", \"step_config\": \"include tripleo::profile::base::neutron::agents::ovn\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnControllerConfigImage\"]}, \"volumes\": [\"/lib/modules:/lib/modules:ro\", \"/run/openvswitch:/run/openvswitch:shared,z\", \"/etc/sysconfig/modules:/etc/sysconfig/modules\"]}, \"kolla_config\": {\"/var/lib/kolla/config_files/ovn_controller.json\": {\"command\": {\"list_join\": [\" \", [\"/usr/bin/ovn-controller --pidfile --log-file unix:/run/openvswitch/db.sock\", {\"if\": [\"internal_tls_enabled\", {\"list_join\": [\" \", [\"-p /etc/pki/tls/private/ovn_controller.key -c /etc/pki/tls/certs/ovn_controller.crt -C\", {\"get_param\": \"InternalTLSCAFile\"}]]}, \"\"]}]]}, \"permissions\": [{\"path\": \"/var/log/openvswitch\", \"owner\": \"root:root\", \"recurse\": true}, {\"path\": \"/var/log/ovn\", \"owner\": \"root:root\", \"recurse\": true}]}}, \"metadata_settings\": {\"if\": [\"internal_tls_enabled\", [{\"service\": \"ovn_controller\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}, \"type\": \"node\"}], null]}, \"docker_config\": {\"step_4\": {\"configure_cms_options\": {\"start_order\": 0, \"detach\": false, \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"CMS_OPTS=$(hiera ovn::controller::ovn_cms_options -c /etc/puppet/hiera.yaml);  if [ X\\\"$CMS_OPTS\\\" !=  X ]; then ovs-vsctl set open . external_ids:ovn-cms-options=$CMS_OPTS;else ovs-vsctl remove open . external_ids ovn-cms-options; fi\"], \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnControllerImage\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/lib/modules:/lib/modules:ro\", \"/run/openvswitch:/run/openvswitch:shared,z\"]]}, \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}, \"ovn_controller\": {\"map_merge\": [{\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnControllerImage\"]}, \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"restart\": \"always\", \"depends_on\": [\"openvswitch.service\"]}, {\"if\": [\"ovn_cpu_set\", {\"cpuset_cpus\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"container_cpuset_cpus\"]}}]}, {\"healthcheck\": {\"test\": {\"list_join\": [\" \", [\"/openstack/healthcheck\", {\"yaql\": {\"expression\": \"str($.data.port)\", \"data\": {\"port\": {\"get_param\": \"OVNSouthboundServerPort\"}}}}]]}}, \"volumes\": {\"list_concat\": [[\"/var/lib/kolla/config_files/ovn_controller.json:/var/lib/kolla/config_files/config.json:ro\", \"/lib/modules:/lib/modules:ro\", \"/run:/run\", \"/var/lib/openvswitch/ovn:/run/ovn:shared,z\", \"/var/log/containers/openvswitch:/var/log/openvswitch:z\", \"/var/log/containers/openvswitch:/var/log/ovn:z\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}, \"/etc/pki/tls/certs/ovn_controller.crt:/etc/pki/tls/certs/ovn_controller.crt\", \"/etc/pki/tls/private/ovn_controller.key:/etc/pki/tls/private/ovn_controller.key\"], null]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}]}}}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"ovn_controller\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"ovn_controller/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}}}}, \"run_after\": \"systemctl restart tripleo_ovn_controller\\n\", \"key_size\": {\"if\": [\"key_size_override_unset\", {\"get_param\": \"CertificateKeySize\"}, {\"get_param\": \"ContainerOvnCertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}], \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/openvswitch\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/openvswitch/ovn\", \"setype\": \"container_file_t\"}]}, {\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}, {\"name\": \"Copy in cleanup script\", \"copy\": {\"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-cleanup\"}, \"dest\": \"/usr/libexec/neutron-cleanup\", \"force\": true, \"mode\": \"0755\"}}, {\"name\": \"Copy in cleanup service\", \"copy\": {\"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-cleanup.service\"}, \"dest\": \"/usr/lib/systemd/system/neutron-cleanup.service\", \"force\": true}}, {\"name\": \"Enabling the cleanup service\", \"service\": {\"name\": \"neutron-cleanup\", \"enabled\": true}, \"when\": \"not (ansible_check_mode|bool)\"}], \"external_deploy_tasks\": [{\"when\": [\"step|int == 0\"], \"name\": \"ovn_controller_external_deploy_init\", \"block\": [{\"name\": {\"str_replace\": {\"template\": \"create ovn mac address for $ROLE_NAME role nodes\", \"params\": {\"$ROLE_NAME\": {\"get_param\": \"RoleName\"}}}}, \"tripleo_ovn_mac_addresses\": {\"playbook_dir\": \"{{ playbook_dir }}\", \"stack_name\": {\"get_param\": \"RootStackName\"}, \"role_name\": {\"get_param\": \"RoleName\"}, \"server_resource_names\": {\"str_replace\": {\"template\": \"{{ groups[\\\"$ROLE_NAME\\\"] }}\", \"params\": {\"$ROLE_NAME\": {\"get_param\": \"RoleName\"}}}}, \"ovn_bridge_mappings\": {\"get_attr\": [\"OVNBridgeMappingsValue\", \"value\", \"ovn_bridge_mappings\"]}, \"ovn_static_bridge_mac_mappings\": {\"get_attr\": [\"OVNBridgeMappingsValue\", \"value\", \"ovn_static_bridge_mac_mappings\"]}}}]}], \"external_update_tasks\": [{\"name\": \"Force pull image in case image name doesn\'t change.\", \"when\": \"step|int == 1\", \"tags\": [\"ovn\", \"ovn_image\"], \"become\": true, \"loop\": \"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\", \"delegate_to\": \"{{ item }}\", \"async\": {\"get_param\": \"OVNControllerImageUpdateTimeout\"}, \"poll\": 0, \"register\": \"ovn_controller_image_update\", \"containers.podman.podman_image\": {\"name\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}, \"validate_certs\": false, \"force\": true}}, {\"name\": \"Was the ovn_controller image pull successful.\", \"when\": [\"step|int == 1\", \"\'results\' in ovn_controller_image_update\"], \"tags\": [\"ovn\", \"ovn_image\"], \"become\": true, \"delegate_to\": \"{{ async_result_item.item }}\", \"async_status\": {\"jid\": \"{{ async_result_item.ansible_job_id }}\"}, \"loop\": \"{{ovn_controller_image_update.results }}\", \"loop_control\": {\"loop_var\": \"async_result_item\"}, \"register\": \"async_poll_results\", \"until\": \"async_poll_results.finished\", \"retries\": {\"get_param\": \"OVNControllerImageUpdateTimeout\"}, \"delay\": 1}, {\"name\": \"OVN Container image used\", \"debug\": {\"msg\": \"ovn container will be using {{ image }}\"}, \"vars\": {\"image\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}}, \"when\": \"step|int == 1\", \"tags\": \"ovn\"}, {\"name\": \"Update OVN OVS related parameters before update.\", \"when\": [\"step|int == 1\"], \"tags\": [\"ovn\"], \"become\": true, \"vars\": {\"timeout\": {\"get_param\": \"OVNOfctrlWaitBeforeClear\"}}, \"shell\": \"set -e\\novs-vsctl set Open_vSwitch . external_ids:ovn-ofctrl-wait-before-clear={{ timeout }}\\novs-vsctl set Open_vSwitch . external_ids:ovn-monitor-all=true\\novs-vsctl set Open_vSwitch . external_ids:ovn-match-northd-version=false\\n\", \"async\": {\"get_param\": \"OVNControllerUpdateTimeout\"}, \"poll\": 0, \"register\": \"ovs_vsctl\", \"loop\": \"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\", \"delegate_to\": \"{{ item }}\"}, {\"name\": \"Was the update of OVN OVS related parameter successful.\", \"when\": [\"step|int == 1\", \"\'results\' in ovs_vsctl\"], \"become\": true, \"tags\": [\"ovn\"], \"delegate_to\": \"{{ async_result_item.item }}\", \"async_status\": {\"jid\": \"{{ async_result_item.ansible_job_id }}\"}, \"loop\": \"{{ovs_vsctl.results }}\", \"loop_control\": {\"loop_var\": \"async_result_item\"}, \"register\": \"async_poll_results\", \"until\": \"async_poll_results.finished\", \"retries\": {\"get_param\": \"OVNControllerUpdateTimeout\"}, \"delay\": 1}, {\"set_fact\": {\"any_ovn_host\": \"{{groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) | first }}\"}, \"tags\": \"ovn\", \"when\": \"step|int == 1\"}, {\"name\": \"Find ovn_controller configs in container-startup-configs\", \"find\": {\"paths\": \"/var/lib/tripleo-config/container-startup-config/\", \"patterns\": \"*ovn_controller.json\", \"recurse\": true}, \"register\": \"ovn_cont_17_0\", \"delegate_to\": \"{{ any_ovn_host }}\", \"when\": \"(step|int == 1) and (any_ovn_host is defined) and (any_ovn_host|length > 0)\", \"tags\": [\"ovn\"], \"become\": true}, {\"name\": \"get directory path from the ovn_cont_17_0\", \"set_fact\": {\"ovn_config_path\": \"{{ ovn_cont_17_0.files.0.path | dirname }}\"}, \"when\": \"step|int == 1\", \"tags\": \"ovn\"}, {\"name\": \"Get PIDfile used by systemd on each ovn node\", \"when\": [\"step|int == 1\"], \"tags\": [\"ovn\"], \"become\": true, \"shell\": \"set -e\\ngrep PID /etc/systemd/system/tripleo_ovn_controller.service | cut -d= -f2\\n\", \"register\": \"pidfile\", \"loop\": \"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\", \"delegate_to\": \"{{ item }}\"}, {\"name\": \"Update ovn_controller.\", \"vars\": {\"config_step\": \"{{ (\'step_4\' in ovn_config_path) | ternary(\'4\', \'3\')}}\", \"query\": \"results[?item == \'{{item}}\'].stdout\"}, \"when\": \"step|int == 1\", \"tags\": \"ovn\", \"become\": true, \"loop\": \"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\", \"delegate_to\": \"{{ item }}\", \"async\": {\"get_param\": \"OVNControllerUpdateTimeout\"}, \"poll\": 0, \"register\": \"ovn_controller_update\", \"tripleo_container_manage\": {\"config_dir\": \"{{ ovn_config_path }}\", \"config_patterns\": \"*ovn_controller.json\", \"config_id\": [\"tripleo_step{{config_step}}\"], \"log_base_path\": \"{{ container_log_stdout_path }}\", \"debug\": \"{{ enable_debug | bool }}\", \"config_overrides\": {\".*ovn_controller\": {\"image\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}, \"conmon_pidfile\": \"{{ pidfile | json_query(query) | first }}\", \"name\": \"ovn_controller\"}}}}, {\"name\": \"Was the ovn_controller successful.\", \"when\": [\"step|int == 1\", \"\'results\' in ovn_controller_update\"], \"tags\": \"ovn\", \"become\": true, \"delegate_to\": \"{{ async_result_item.item }}\", \"async_status\": {\"jid\": \"{{ async_result_item.ansible_job_id }}\"}, \"loop\": \"{{ovn_controller_update.results }}\", \"loop_control\": {\"loop_var\": \"async_result_item\"}, \"register\": \"async_poll_results\", \"until\": \"async_poll_results.finished\", \"retries\": {\"get_param\": \"OVNControllerUpdateTimeout\"}, \"delay\": 1}, {\"name\": \"Pause for 30s to give ovn_controllers time to reconnect to dbs\", \"when\": [\"step|int == 1\"], \"tags\": \"ovn\", \"wait_for\": {\"timeout\": 30}}], \"upgrade_tasks\": [{\"name\": \"Fetch running ovn_controller image\", \"shell\": \"set -e\\npodman inspect --format \\\"{{\'{{\'}}.ImageName{{\'}}\'}}\\\" ovn_controller\\n\", \"register\": \"running_ovn_image\", \"when\": [\"step|int == 4\"], \"tags\": [\"ovn\", \"ovn_image\"]}, {\"name\": \"Run ovn_controller upgrade\", \"tags\": [\"ovn\", \"ovn_image\"], \"vars\": {\"ovn_controller_image\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}}, \"when\": [\"step|int == 4\", \"running_ovn_image.stdout != ovn_controller_image\"], \"block\": [{\"name\": \"Force pull image in case image name doesn\'t change.\", \"when\": \"step|int == 4\", \"tags\": [\"ovn\", \"ovn_image\"], \"containers.podman.podman_image\": {\"name\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}, \"validate_certs\": false, \"force\": true}}, {\"name\": \"Update OVN OVS related parameters before update.\", \"when\": [\"step|int == 4\"], \"tags\": [\"ovn\"], \"vars\": {\"timeout\": {\"get_param\": \"OVNOfctrlWaitBeforeClear\"}}, \"shell\": \"set -e\\novs-vsctl set Open_vSwitch . external_ids:ovn-ofctrl-wait-before-clear={{ timeout }}\\novs-vsctl set Open_vSwitch . external_ids:ovn-monitor-all=true\\novs-vsctl set Open_vSwitch . external_ids:ovn-match-northd-version=false\\n\"}, {\"name\": \"Find ovn_controller configs in container-startup-configs\", \"find\": {\"paths\": \"/var/lib/tripleo-config/container-startup-config/\", \"patterns\": \"*ovn_controller.json\", \"recurse\": true}, \"register\": \"ovn_cont_17_0\", \"when\": [\"step|int == 4\"], \"tags\": [\"ovn\"]}, {\"name\": \"get directory path from the ovn_cont_17_0\", \"set_fact\": {\"ovn_config_path\": \"{{ ovn_cont_17_0.files.0.path | dirname }}\"}, \"when\": \"step|int == 4\", \"tags\": \"ovn\"}, {\"name\": \"Get PIDfile used by systemd on each ovn node\", \"when\": [\"step|int == 4\"], \"tags\": [\"ovn\"], \"shell\": \"set -e\\ngrep PID /etc/systemd/system/tripleo_ovn_controller.service | cut -d= -f2\\n\", \"register\": \"pidfile\"}, {\"name\": \"Update ovn_controller.\", \"vars\": {\"config_step\": \"{{ (\'step_4\' in ovn_config_path) | ternary(\'4\', \'3\')}}\"}, \"when\": \"step|int == 4\", \"tags\": \"ovn\", \"tripleo_container_manage\": {\"config_dir\": \"{{ ovn_config_path }}\", \"config_patterns\": \"*ovn_controller.json\", \"config_id\": [\"tripleo_step{{config_step}}\"], \"log_base_path\": \"{{ container_log_stdout_path }}\", \"debug\": \"{{ enable_debug | bool }}\", \"config_overrides\": {\".*ovn_controller\": {\"image\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}, \"conmon_pidfile\": \"{{ pidfile.stdout }}\", \"name\": \"ovn_controller\"}}}}, {\"name\": \"Pause for 30s to give ovn_controllers time to reconnect to dbs\", \"when\": [\"step|int == 4\"], \"tags\": \"ovn\", \"wait_for\": {\"timeout\": 30}}]}], \"scale_tasks\": [{\"when\": [\"step|int == 1\", \"container_cli == \'podman\'\"], \"tags\": \"down\", \"become\": true, \"environment\": {\"OS_CLOUD\": {\"if\": [\"auth_cloud_name_set\", {\"get_param\": \"AuthCloudName\"}, {\"get_param\": \"RootStackName\"}]}}, \"block\": [{\"name\": \"Get neutron agents ID\", \"command\": \"openstack network agent list --column ID --column Host --column Binary --format yaml\", \"register\": \"neutron_agents_result\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false, \"changed_when\": false}, {\"name\": \"Filter only current host\", \"set_fact\": {\"neutron_agents\": \"{{ neutron_agents_result.stdout | from_yaml | selectattr(\'Host\', \'match\', ansible_facts[\'fqdn\'] ~ \'.*\') | list }}\"}, \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false}, {\"name\": \"Deleting OVN agents\", \"block\": [{\"name\": \"Stop OVN containers\", \"loop\": [\"tripleo_ovn_controller\", \"tripleo_ovn_metadata_agent\"], \"service\": {\"name\": \"{{ item }}\", \"state\": \"stopped\", \"enabled\": false}, \"become\": true, \"register\": \"stop_containers\", \"failed_when\": \"(\'msg\' in stop_containers and \'Could not find the requested service\' not in stop_containers.msg) or (\'rc\' in stop_containers and stop_containers.rc != 0)\"}, {\"name\": \"Delete neutron agents\", \"loop\": \"{{ neutron_agents }}\", \"loop_control\": {\"loop_var\": \"agent\", \"label\": \"{{ agent.Host }}/{{ agent.Binary }}\"}, \"command\": \"openstack network agent delete {{ agent.ID }}\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false}]}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(141,'2026-06-12 08:26:10',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Nova database client service.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"NovaPassword\": {\"description\": \"The password for the nova service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"1Ii49H1EfmLUfEWsgfy9vla3q\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova base service.\", \"value\": {\"config_settings\": {\"nova::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlCellInternal\", \"protocol\"]}, \"username\": \"nova\", \"password\": {\"get_param\": \"NovaPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlCellInternal\", \"host\"]}, \"path\": \"/nova\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"nova\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}}, \"service_config_settings\": {\"mysql\": {\"nova::db::mysql::password\": {\"get_param\": \"NovaPassword\"}, \"nova::db::mysql::user\": \"nova\", \"nova::db::mysql::host\": \"%\", \"nova::db::mysql::dbname\": \"nova\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(142,'2026-06-12 08:26:10',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Containerized logrotate with crond for containerized service logs rotation\\n\", \"parameters\": {\"ContainerCrondImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\"}, \"ContainerCrondConfigImage\": {\"description\": \"The container image to use for the crond config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"LogrotateMaxsize\": {\"description\": \"Configures the maxsize param for containerized logrotate.\", \"type\": \"string\", \"default\": \"10M\"}, \"LogrotateRotationInterval\": {\"description\": \"Configures rotation interval for containerized logrotate.\", \"type\": \"string\", \"default\": \"daily\", \"constraints\": [{\"allowed_values\": [\"hourly\", \"daily\", \"weekly\", \"monthly\"]}]}, \"LogrotateRotate\": {\"description\": \"Configures the rotate param for containerized logrotate.\", \"type\": \"string\", \"default\": \"14\"}, \"LogrotatePurgeAfterDays\": {\"description\": \"Enforces life time (days) of rotated and compressed files.\", \"type\": \"string\", \"default\": \"14\"}, \"LogrotateDateExt\": {\"description\": \"Enable/disable dateext parameter.\", \"type\": \"boolean\", \"default\": false}, \"LogrotateDateFormat\": {\"description\": \"Configures dateformat strings for containerized logrotate. This is valid when LogrotateDateExt is true. The allowed specifiers are only %Y %m %d %H %M %S %V and %s.\", \"type\": \"string\", \"default\": \"-%Y%m%d\", \"constraints\": [{\"allowed_pattern\": \"-(%[YmdHMSVs])+$\"}]}, \"LogrotateDateYesterday\": {\"description\": \"Configures dateyesterday paramter for containerized logrotate. This is valid when LogrotateDateExt is true.\", \"type\": \"boolean\", \"default\": false}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCrondImage\": \"ContainerCrondImage\", \"ContainerCrondConfigImage\": \"ContainerCrondConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCrondImage\": {\"get_param\": \"ContainerCrondImage\"}, \"ContainerCrondConfigImage\": {\"get_param\": \"ContainerCrondConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the crond role.\", \"value\": {\"service_name\": \"logrotate_crond\", \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::logging::logrotate::maxsize\": {\"get_param\": \"LogrotateMaxsize\"}, \"tripleo::profile::base::logging::logrotate::rotation\": {\"get_param\": \"LogrotateRotationInterval\"}, \"tripleo::profile::base::logging::logrotate::rotate\": {\"get_param\": \"LogrotateRotate\"}, \"tripleo::profile::base::logging::logrotate::purge_after_days\": {\"get_param\": \"LogrotatePurgeAfterDays\"}, \"tripleo::profile::base::logging::logrotate::dateext\": {\"get_param\": \"LogrotateDateExt\"}}, {\"if\": [{\"get_param\": \"LogrotateDateExt\"}, {\"tripleo::profile::base::logging::logrotate::dateformat\": {\"get_param\": \"LogrotateDateFormat\"}, \"tripleo::profile::base::logging::logrotate::dateyesterday\": {\"get_param\": \"LogrotateDateYesterday\"}}]}]}, \"host_prep_tasks\": [{\"name\": \"allow logrotate to read inside containers\", \"seboolean\": {\"name\": \"logrotate_read_inside_containers\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}], \"deploy_steps_tasks\": [{\"name\": \"configure tmpwatch on the host\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Push script\", \"copy\": {\"dest\": \"/usr/local/sbin/containers-tmpwatch\", \"owner\": \"root\", \"group\": \"root\", \"mode\": 493, \"content\": \"#!/bin/sh\\ntmpwatch --nodirs \\\\\\n  -X \\\"/var/log/containers/*/*log\\\" \\\\\\n  -X \\\"/var/log/containers/*/*/*log\\\" \\\\\\n  -X \\\"/var/log/containers/*/*err\\\" \\\\\\n  {{ LogrotatePurgeAfterDays|int +1 }}d \\\\\\n  /var/log/containers/ 2>&1 | logger -t container-tmpwatch\\n\"}, \"vars\": {\"LogrotatePurgeAfterDays\": {\"get_param\": \"LogrotatePurgeAfterDays\"}}}, {\"name\": \"Insert cronjob in root crontab\", \"cron\": {\"name\": \"Remove old logs\", \"special_time\": \"daily\", \"user\": \"root\", \"job\": \"/usr/local/sbin/containers-tmpwatch\"}}]}], \"update_tasks\": [{\"name\": \"Ensure old cron.daily is absent\", \"when\": \"step|int == 1\", \"file\": {\"path\": \"/etc/cron.daily/containers-tmpwatch\", \"state\": \"absent\"}}], \"upgrade_tasks\": [{\"name\": \"Ensure old cron.daily is absent\", \"when\": \"step|int == 1\", \"file\": {\"path\": \"/etc/cron.daily/containers-tmpwatch\", \"state\": \"absent\"}}], \"puppet_config\": {\"config_volume\": \"crond\", \"step_config\": \"include tripleo::profile::base::logging::logrotate\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCrondConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/logrotate-crond.json\": {\"command\": \"/usr/sbin/crond -s -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_4\": {\"logrotate_crond\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCrondImage\"]}, \"net\": \"none\", \"pid\": \"host\", \"privileged\": true, \"user\": \"root\", \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/logrotate-crond.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/crond:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers:/var/log/containers:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop logrotate container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"logrotate_crond\"], \"tripleo_delegate_to\": \"{{ groups[\'logrotate_crond\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(143,'2026-06-12 08:26:10',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (144,'2026-06-12 08:26:10',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configure sshd_config\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"BannerText\": {\"default\": \"\", \"description\": \"Configures Banner text in sshd_config\", \"type\": \"string\"}, \"MessageOfTheDay\": {\"default\": \"\", \"description\": \"Configures /etc/motd text\", \"type\": \"string\"}, \"SshServerOptions\": {\"default\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"description\": \"Mapping of sshd_config values\", \"type\": \"json\"}, \"PasswordAuthentication\": {\"default\": \"no\", \"description\": \"Whether or not disable password authentication\", \"type\": \"string\"}, \"SshFirewallAllowAll\": {\"default\": true, \"description\": \"Set this to true to open up ssh access from all sources.\", \"type\": \"boolean\"}, \"SshServerOptionsOverrides\": {\"default\": {}, \"description\": \"Mapping of sshd_config values to override definitions in SshServerOptions\", \"type\": \"json\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"SshServerOptionsOverrides\"]}], \"conditions\": {\"ssh_firewall_allow_all\": {\"equals\": [{\"get_param\": \"SshFirewallAllowAll\"}, true]}, \"ssh_banner_text_set\": {\"not\": {\"equals\": [{\"get_param\": \"BannerText\"}, \"\"]}}, \"ssh_motd_text_set\": {\"not\": {\"equals\": [{\"get_param\": \"MessageOfTheDay\"}, \"\"]}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the ssh\", \"value\": {\"service_name\": \"sshd\", \"firewall_rules\": {\"003 accept ssh from all\": {\"proto\": \"tcp\", \"dport\": 22, \"extras\": {\"ensure\": {\"if\": [\"ssh_firewall_allow_all\", \"present\", \"absent\"]}}}}, \"host_prep_tasks\": [{\"include_role\": {\"name\": \"tripleo_sshd\"}, \"vars\": {\"tripleo_sshd_server_options\": {\"map_merge\": [{\"get_param\": \"SshServerOptions\"}, {\"get_param\": \"SshServerOptionsOverrides\"}]}, \"tripleo_sshd_password_authentication\": {\"get_param\": \"PasswordAuthentication\"}, \"tripleo_sshd_banner_enabled\": {\"if\": [\"ssh_banner_text_set\", true, false]}, \"tripleo_sshd_banner_text\": {\"get_param\": \"BannerText\"}, \"tripleo_sshd_motd_enabled\": {\"if\": [\"ssh_motd_text_set\", true, false]}, \"tripleo_sshd_message_of_the_day\": {\"get_param\": \"MessageOfTheDay\"}}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(145,'2026-06-12 08:26:10',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"TripleO Firewall settings\\n\", \"parameters\": {\"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ExtraFirewallRules\": {\"default\": {}, \"description\": \"Mapping of firewall rules.\", \"type\": \"json\", \"tags\": [\"role_specific\"]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"extra_firewall_rules\": \"ExtraFirewallRules\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ExtraFirewallRules\": {\"get_param\": \"ExtraFirewallRules\"}}}]}}}}, \"conditions\": {\"no_ctlplane\": {\"equals\": [{\"get_params\": [\"ServiceData\", \"net_cidr_map\", \"ctlplane\"]}, null]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the TripleO firewall settings\", \"value\": {\"service_name\": \"tripleo_firewall\", \"config_settings\": {\"tripleo::firewall::manage_firewall\": false, \"tripleo::firewall::purge_firewall_rules\": false}, \"ansible_group_vars\": {\"tripleo_nftables_debug\": {\"get_param\": \"Debug\"}}, \"firewall_rules\": {\"map_merge\": [{\"map_merge\": {\"repeat\": {\"for_each\": {\"<%net_cidr%>\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", \"ctlplane\"]}}, \"template\": {\"003 accept ssh from ctlplane subnet <%net_cidr%>\": {\"source\": \"<%net_cidr%>\", \"proto\": \"tcp\", \"dport\": 22}}}}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"extra_firewall_rules\"]}]}, \"host_prep_tasks\": [{\"if\": [\"no_ctlplane\", {\"name\": \"Failure - ctlplane subnet is unset\", \"fail\": {\"msg\": \"No CIDRs found in the ctlplane network tags.\\nPlease refer to the documentation in order to\\nset the correct network tags in DeployedServerPortMap.\\n\"}}, {\"name\": \"Notice - ctlplane subnet is set\", \"debug\": {\"msg\": \"CIDRs found in the ctlplane network tags.\\n\"}}]}], \"host_firewall_tasks\": [{\"name\": \"Run firewall role\", \"include_role\": {\"name\": \"tripleo_firewall\"}}], \"update_tasks\": [{\"name\": \"Cleanup tripleo-iptables services\", \"when\": [\"(step | int) == 1\"], \"block\": [{\"name\": \"Disable tripleo-iptables.service\", \"systemd\": {\"name\": \"tripleo-iptables.service\", \"state\": \"stopped\", \"enabled\": false}, \"register\": \"systemd_tripleo_iptables\", \"failed_when\": false}, {\"name\": \"Cleanup tripleo-iptables.services\", \"file\": {\"path\": \"/etc/systemd/system/tripleo-iptables.service\", \"state\": \"absent\"}}, {\"name\": \"Disable tripleo-ip6tables.service\", \"systemd\": {\"name\": \"tripleo-ip6tables.service\", \"state\": \"stopped\", \"enabled\": false}, \"register\": \"systemd_tripleo_ip6tables\", \"failed_when\": false}, {\"name\": \"Cleanup tripleo-ip6tables.services\", \"file\": {\"path\": \"/etc/systemd/system/tripleo-ip6tables.service\", \"state\": \"absent\"}}, {\"name\": \"Reload systemd\", \"systemd\": {\"daemon_reload\": true}, \"when\": [\"(systemd_tripleo_iptables is changed or systemd_tripleo_ip6tables is changed)\"]}]}], \"upgrade_tasks\": [{\"name\": \"Cleanup tripleo-iptables services\", \"when\": [\"(step | int) == 1\"], \"block\": [{\"name\": \"Disable tripleo-iptables.service\", \"systemd\": {\"name\": \"tripleo-iptables.service\", \"state\": \"stopped\", \"enabled\": false}, \"register\": \"systemd_tripleo_iptables\", \"failed_when\": false}, {\"name\": \"Cleanup tripleo-iptables.services\", \"file\": {\"path\": \"/etc/systemd/system/tripleo-iptables.service\", \"state\": \"absent\"}}, {\"name\": \"Disable tripleo-ip6tables.service\", \"systemd\": {\"name\": \"tripleo-ip6tables.service\", \"state\": \"stopped\", \"enabled\": false}, \"register\": \"systemd_tripleo_ip6tables\", \"failed_when\": false}, {\"name\": \"Cleanup tripleo-ip6tables.services\", \"file\": {\"path\": \"/etc/systemd/system/tripleo-ip6tables.service\", \"state\": \"absent\"}}, {\"name\": \"Reload systemd\", \"systemd\": {\"daemon_reload\": true}, \"when\": [\"(systemd_tripleo_iptables is changed or systemd_tripleo_ip6tables is changed)\"]}]}, {\"when\": [\"(step | int) == 3\"], \"block\": [{\"name\": \"blank ipv6 rule before activating ipv6 firewall.\", \"shell\": \"cat /etc/sysconfig/ip6tables > /etc/sysconfig/ip6tables.n-o-upgrade; cat</dev/null>/etc/sysconfig/ip6tables\", \"args\": {\"creates\": \"/etc/sysconfig/ip6tables.n-o-upgrade\"}}, {\"name\": \"cleanup unmanaged rules pushed by iptables-services\", \"shell\": \"iptables -C INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT &>/dev/null && \\\\\\n  iptables -D INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT\\niptables -C INPUT -p icmp -j ACCEPT &>/dev/null && \\\\\\n  iptables -D INPUT -p icmp -j ACCEPT\\niptables -C INPUT -i lo -j ACCEPT &>/dev/null && \\\\\\n  iptables -D INPUT -i lo -j ACCEPT\\niptables -C INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT &>/dev/null && \\\\\\n  iptables -D INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT\\niptables -C INPUT -j REJECT --reject-with icmp-host-prohibited &>/dev/null && \\\\\\n  iptables -D INPUT -j REJECT --reject-with icmp-host-prohibited\\niptables -C FORWARD -j REJECT --reject-with icmp-host-prohibited &>/dev/null && \\\\\\n  iptables -D FORWARD -j REJECT --reject-with icmp-host-prohibited\\n\\nsed -i \'/^-A INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A INPUT -p icmp -j ACCEPT$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A INPUT -i lo -j ACCEPT$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A INPUT -j REJECT --reject-with icmp-host-prohibited$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A FORWARD -j REJECT --reject-with icmp-host-prohibited$/d\' /etc/sysconfig/iptables\\n\\nip6tables -C INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT\\nip6tables -C INPUT -p ipv6-icmp -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -p ipv6-icmp -j ACCEPT\\nip6tables -C INPUT -i lo -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -i lo -j ACCEPT\\nip6tables -C INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT\\nip6tables -C INPUT -d fe80::/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -d fe80::/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT\\nip6tables -C INPUT -j REJECT --reject-with icmp6-adm-prohibited &>/dev/null && \\\\\\n  ip6tables -D INPUT -j REJECT --reject-with icmp6-adm-prohibited\\nip6tables -C FORWARD -j REJECT --reject-with icmp6-adm-prohibited &>/dev/null && \\\\\\n  ip6tables -D FORWARD -j REJECT --reject-with icmp6-adm-prohibited\\n\\nsed -i \'/^-A INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -p ipv6-icmp -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -i lo -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -d fe80::\\\\/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -j REJECT --reject-with icmp6-adm-prohibited$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A FORWARD -j REJECT --reject-with icmp6-adm-prohibited$/d\' /etc/sysconfig/ip6tables\"}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(146,'2026-06-12 08:26:11',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Nova Vncproxy service\\n\", \"parameters\": {\"ContainerNovaVncProxyImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\"}, \"ContainerNovaConfigImage\": {\"description\": \"The container image to use for the nova config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\"}, \"NovaVncproxyLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.nova.vncproxy\", \"file\": \"/var/log/containers/nova/nova-novncproxy.log\"}}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"UseTLSTransportForVnc\": {\"type\": \"boolean\", \"default\": true, \"description\": \"If set to true and if EnableInternalTLS is enabled, it will enable TLS transaport for libvirt VNC and configure the relevant keys for libvirt.\"}, \"InternalTLSVncProxyCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the CA cert to use for VNC TLS.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"NovaVNCCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"LibvirtVNCClientCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"LibvirtVncCACert\": {\"type\": \"string\", \"default\": \"\", \"description\": \"This specifies the CA certificate to use for VNC TLS. This file will be symlinked to the default CA path, which is /etc/pki/CA/certs/vnc.crt. This parameter should be used if the default (which comes from the InternalTLSVncProxyCAFile parameter) is not desired. The current default reflects TripleO\'s default CA, which is FreeIPA. It will only be used if internal TLS is enabled.\"}, \"NovaVNCProxySSLCiphers\": {\"type\": \"string\", \"default\": \"\", \"description\": \"OpenSSL cipher preference string that specifies what ciphers to allow for TLS connections from clients.  See the man page for the OpenSSL \'ciphers\' command for details of the cipher preference string format and allowed values.\"}, \"NovaVNCProxySSLMinimumVersion\": {\"type\": \"string\", \"default\": \"default\", \"description\": \"Minimum allowed SSL/TLS protocol version.  Valid values are \'default\', \'tlsv1_1\', \'tlsv1_2\', and \'tlsv1_3\'.  A value of \'default\' will use the underlying system OpenSSL defaults.\", \"constraints\": [{\"allowed_values\": [\"default\", \"tlsv1_1\", \"tlsv1_2\", \"tlsv1_3\"]}]}, \"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\", \"default\": \"cell1\"}, \"AuthCloudName\": {\"description\": \"Entry in clouds.yaml to use for authentication\", \"type\": \"string\", \"default\": \"overcloud\"}}, \"conditions\": {\"auth_cloud_name_set\": {\"not\": {\"equals\": [{\"get_param\": \"AuthCloudName\"}, \"\"]}}, \"use_tls_for_vnc\": {\"and\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"UseTLSTransportForVnc\"}]}, \"libvirt_vnc_specific_ca_set\": {\"not\": {\"equals\": [{\"get_param\": \"LibvirtVncCACert\"}, \"\"]}}, \"proxy_ssl_ciphers_set\": {\"not\": {\"equals\": [{\"get_param\": \"NovaVNCProxySSLCiphers\"}, \"\"]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"NovaLogging\": {\"type\": \"OS::TripleO::Services::Logging::NovaCommon\", \"properties\": {\"ContainerNovaImage\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaVncProxyImage\"]}, \"NovaServiceName\": \"vncproxy\"}}, \"NovaBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"NovaDBClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerNovaVncProxyImage\": \"ContainerNovaVncProxyImage\", \"ContainerNovaConfigImage\": \"ContainerNovaConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerNovaVncProxyImage\": {\"get_param\": \"ContainerNovaVncProxyImage\"}, \"ContainerNovaConfigImage\": {\"get_param\": \"ContainerNovaConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova Vncproxy service.\", \"value\": {\"service_name\": \"nova_vnc_proxy\", \"firewall_rules\": {\"137 nova_vnc_proxy\": {\"dport\": [6080]}}, \"firewall_frontend_rules\": {\"100 nova_vncproxy_haproxy_frontend\": {\"dport\": [6080]}}, \"firewall_ssl_frontend_rules\": {\"100 nova_vncproxy_haproxy_frontend_ssl\": {\"dport\": [13080]}}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"NovaBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"NovaDBClient\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"NovaLogging\", \"config_settings\"]}, {\"nova::vncproxy::enabled\": true, \"nova::vncproxy::common::vncproxy_protocol\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyCellPublic\", \"protocol\"]}, \"nova::vncproxy::common::vncproxy_host\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyCellPublic\", \"host_nobrackets\"]}, \"nova::vncproxy::common::vncproxy_port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyCellPublic\", \"port\"]}, \"nova::vncproxy::host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}}, {\"if\": [\"use_tls_for_vnc\", {\"nova::vncproxy::allow_vencrypt\": true, \"nova::vncproxy::vencrypt_key\": \"/etc/pki/tls/private/libvirt-vnc-client-cert.key\", \"nova::vncproxy::vencrypt_cert\": \"/etc/pki/tls/certs/libvirt-vnc-client-cert.crt\", \"nova::vncproxy::vencrypt_ca\": \"/etc/pki/CA/certs/vnc.crt\", \"nova::ssl_only\": true, \"nova::console_ssl_ciphers\": {\"if\": [\"proxy_ssl_ciphers_set\", {\"get_param\": \"NovaVNCProxySSLCiphers\"}]}, \"nova::console_ssl_minimum_version\": {\"get_param\": \"NovaVNCProxySSLMinimumVersion\"}, \"nova::cert\": \"/etc/pki/tls/certs/novnc-proxy.crt\", \"nova::key\": \"/etc/pki/tls/private/novnc-proxy.key\"}]}]}, \"service_config_settings\": {\"rabbitmq\": {\"get_attr\": [\"NovaBase\", \"role_data\", \"service_config_settings\"], \"rabbitmq\": null}, \"mysql\": {\"map_merge\": [{\"get_attr\": [\"NovaDBClient\", \"role_data\", \"service_config_settings\", \"mysql\"]}]}, \"rsyslog\": {\"tripleo_logging_sources_nova_vnc_proxy\": [{\"get_param\": \"NovaVncproxyLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"nova\", \"puppet_tags\": \"nova_config\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::nova::vncproxy\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/nova_vnc_proxy.json\": {\"command\": {\"list_join\": [\" \", [\"/usr/bin/nova-novncproxy --web /usr/share/novnc/\", {\"get_attr\": [\"NovaLogging\", \"cmd_extra_args\"]}]]}, \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/log/nova\", \"owner\": \"nova:nova\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/novnc-proxy.crt\", \"owner\": \"root:root\", \"perm\": \"0644\"}, {\"path\": \"/etc/pki/tls/private/novnc-proxy.key\", \"owner\": \"root:qemu\", \"perm\": \"0640\"}, {\"path\": \"/etc/pki/tls/certs/libvirt-vnc-client-cert.crt\", \"owner\": \"root:root\", \"perm\": \"0644\"}, {\"path\": \"/etc/pki/tls/private/libvirt-vnc-client-cert.key\", \"owner\": \"root:qemu\", \"perm\": \"0640\"}]}}, \"docker_config\": {\"step_4\": {\"nova_vnc_proxy\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaVncProxyImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/nova_vnc_proxy.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/nova:/var/lib/kolla/config_files/src:ro\"], {\"if\": [\"use_tls_for_vnc\", [{\"str_replace\": {\"template\": \"CACERT:/etc/pki/CA/certs/vnc.crt:ro\", \"params\": {\"CACERT\": {\"if\": [\"libvirt_vnc_specific_ca_set\", {\"get_param\": \"LibvirtVncCACert\"}, {\"get_param\": \"InternalTLSVncProxyCAFile\"}]}}}}, \"/etc/pki/tls/certs/libvirt-vnc-client-cert.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/libvirt-vnc-client-cert.crt:ro\", \"/etc/pki/tls/private/libvirt-vnc-client-cert.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/libvirt-vnc-client-cert.key:ro\", \"/etc/pki/tls/certs/novnc-proxy.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/novnc-proxy.crt:ro\", \"/etc/pki/tls/private/novnc-proxy.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/novnc-proxy.key:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"metadata_settings\": {\"if\": [\"use_tls_for_vnc\", [{\"service\": \"libvirt-vnc\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}, \"type\": \"node\"}, {\"service\": \"novnc-proxy\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}, \"type\": \"node\"}]]}, \"deploy_steps_tasks\": {\"list_concat\": [[{\"name\": \"validate nova-vnc-proxy container state\", \"containers.podman.podman_container_info\": {\"name\": \"nova_vnc_proxy\"}, \"register\": \"nova_vnc_proxy_infos\", \"failed_when\": [\"nova_vnc_proxy_infos.containers.0.Healthcheck.Status is defined\", \"\'healthy\' not in nova_vnc_proxy_infos.containers.0.Healthcheck.Status\"], \"retries\": 10, \"delay\": 30, \"tags\": [\"opendev-validation\", \"opendev-validation-nova\"], \"when\": [\"container_cli == \'podman\'\", \"not container_healthcheck_disabled\", \"step|int == 5\"]}], {\"if\": [\"use_tls_for_vnc\", [{\"name\": \"Certificate generation\", \"when\": \"step|int == 1\", \"vars\": {\"cert_key_size\": {\"get_param\": \"CertificateKeySize\"}, \"nova_vnc_key_size\": {\"get_param\": \"NovaVNCCertificateKeySize\"}, \"libvirt_vnc_key_size\": {\"get_param\": \"LibvirtVNCClientCertificateKeySize\"}, \"libvirt_network\": {\"str_replace\": {\"template\": \"{{ fqdn_NETWORK }}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}}, \"block\": [{\"name\": \"Execute system role for Nova/Libvirt VNC certs\", \"loop\": [{\"name\": \"libvirt-vnc-client-cert\", \"key_size\": \"{{ libvirt_vnc_key_size | default(cert_key_size, true) }}\", \"principal\": \"libvirt-vnc/{{ libvirt_network }}@{{ idm_realm }}\"}, {\"name\": \"novnc-proxy\", \"key_size\": \"{{ nova_vnc_key_size | default(cert_key_size, true) }}\", \"principal\": \"novnc-proxy/{{ libvirt_network }}@{{ idm_realm }}\"}], \"loop_control\": {\"loop_var\": \"cert\"}, \"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"{{ cert.name }}\", \"dns\": \"{{ libvirt_network }}\", \"principal\": \"{{ cert.principal }}\", \"key_size\": \"{{ cert.key_size }}\", \"run_after\": \"container_name=$({{container_cli}} ps --format=\\\\{\\\\{.Names\\\\}\\\\} | grep nova_vnc_proxy)\\nservice_crt=\\\"/etc/pki/tls/certs/{{ cert.name }}.crt\\\"\\nservice_key=\\\"/etc/pki/tls/private/{{ cert.name }}.key\\\"\\n# Copy the new cert from the mount-point to the real path\\n{{container_cli}} exec -u root \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_crt\\\" \\\"$service_crt\\\"\\n# Copy the new key from the mount-point to the real path\\n{{container_cli}} exec -u root \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_key\\\" \\\"$service_key\\\"\\n\\n# Set permissions\\n{{container_cli}} exec -u root \\\"$container_name\\\" chmod 0644 $service_crt\\n{{container_cli}} exec -u root \\\"$container_name\\\" chmod 0640 $service_key\\n{{container_cli}} exec -u root \\\"$container_name\\\" chgrp qemu $service_key\\n\\n# No need to trigger a reload for novnc proxy since the cert is not cached\\n\", \"ca\": \"ipa\"}]}}]}]]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"NovaLogging\", \"host_prep_tasks\"]}, [{\"name\": \"ensure qemu group is present on the host\", \"group\": {\"name\": \"qemu\", \"gid\": 107, \"state\": \"present\"}}, {\"name\": \"ensure qemu user is present on the host\", \"user\": {\"name\": \"qemu\", \"uid\": 107, \"group\": \"qemu\", \"state\": \"present\", \"shell\": \"/sbin/nologin\", \"comment\": \"qemu user\"}}]]}, \"post_upgrade_tasks\": [{\"when\": [\"step|int == 3\"], \"become\": true, \"environment\": {\"OS_CLOUD\": {\"if\": [\"auth_cloud_name_set\", {\"get_param\": \"AuthCloudName\"}, {\"get_param\": \"RootStackName\"}]}}, \"block\": [{\"name\": \"Get nova-consoleauth service ID\", \"command\": \"openstack compute service list --service nova-consoleauth --column ID  --column Host --format yaml\", \"register\": \"nova_compute_service_result\", \"check_mode\": false, \"run_once\": true, \"changed_when\": false, \"failed_when\": false, \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\"}, {\"name\": \"Deleting nova-consoleauth\", \"command\": \"openstack compute service delete {{ item.ID }}\", \"loop\": \"{{ nova_compute_service_result.stdout | from_yaml | default([]) }}\", \"run_once\": true, \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"failed_when\": false}]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop nova vnc proxy container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"nova_vnc_proxy\"], \"tripleo_delegate_to\": \"{{ groups[\'nova_vnc_proxy\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(147,'2026-06-12 08:26:11',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"SNMP client configured with Puppet, to facilitate Ceilometer Hardware monitoring in the undercloud. This service is required to enable hardware monitoring.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"SnmpdReadonlyUserName\": {\"default\": \"ro_snmp_user\", \"description\": \"The user name for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\"}, \"SnmpdReadonlyUserPassword\": {\"description\": \"The user password for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\", \"hidden\": true, \"default\": \"KjPkLxPsqu3qjdbO0SJ0shPX\"}, \"SnmpdBindHost\": {\"description\": \"An array of bind host addresses on which SNMP daemon will listen.\", \"type\": \"comma_delimited_list\", \"default\": [\"udp:161\", \"udp6:[::1]:161\"]}, \"SnmpdOptions\": {\"description\": \"A string containing the commandline options passed to snmpd\", \"type\": \"string\", \"default\": \"-LS0-5d\"}, \"SnmpdIpSubnet\": {\"default\": \"\", \"description\": \"IP address/subnet on the snmpd network. If empty (default), SnmpdNetwork will be taken.\", \"type\": \"string\"}}, \"conditions\": {\"snmpd_network_unset\": {\"equals\": [{\"get_param\": \"SnmpdIpSubnet\"}, \"\"]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the SNMP services\", \"value\": {\"service_name\": \"snmp\", \"firewall_rules\": {\"if\": [\"snmpd_network_unset\", {\"map_merge\": {\"repeat\": {\"for_each\": {\"<%net_cidr%>\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"SnmpdNetwork\"]}]}}, \"template\": {\"124 snmp <%net_cidr%>\": {\"dport\": 161, \"proto\": \"udp\", \"source\": \"<%net_cidr%>\"}}}}}, {\"124 snmp\": {\"dport\": 161, \"proto\": \"udp\", \"source\": {\"get_param\": \"SnmpdIpSubnet\"}}}]}, \"config_settings\": {\"tripleo::profile::base::snmp::snmpd_user\": {\"get_param\": \"SnmpdReadonlyUserName\"}, \"tripleo::profile::base::snmp::snmpd_password\": {\"get_param\": \"SnmpdReadonlyUserPassword\"}, \"snmp::agentaddress\": {\"get_param\": \"SnmpdBindHost\"}, \"snmp::snmpd_options\": {\"get_param\": \"SnmpdOptions\"}}, \"step_config\": \"include tripleo::profile::base::snmp\\n\", \"upgrade_tasks\": [{\"when\": \"step|int == 0\", \"block\": [{\"name\": \"Check if snmpd is enabled\", \"command\": \"systemctl is-enabled --quiet snmpd\", \"failed_when\": false, \"register\": \"snmpd_enabled_result\"}, {\"name\": \"Set fact snmpd_enabled\", \"set_fact\": {\"snmpd_enabled\": \"{{ snmpd_enabled_result.rc == 0 }}\"}}]}, {\"name\": \"Stop snmp service\", \"when\": [\"step|int == 1\", \"snmpd_enabled|bool\"], \"service\": \"name=snmpd state=stopped\"}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(148,'2026-06-12 08:26:11',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(149,'2026-06-12 08:26:12',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"TripleO Package installation settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnablePackageInstall\": {\"default\": true, \"description\": \"Set to true to enable package installation at deploy time\", \"type\": \"boolean\"}, \"UpgradeLeappEnabled\": {\"description\": \"Use Leapp for operating system upgrade\", \"type\": \"boolean\", \"default\": false}, \"UpgradeLeappDebug\": {\"description\": \"Print debugging output when running Leapp\", \"type\": \"boolean\", \"default\": false}, \"UpgradeLeappDevelSkip\": {\"description\": \"Skip Leapp checks by setting env variables when running Leapp in\\ndevelopment/testing. For example, LEAPP_DEVEL_SKIP_RHSM=1.\\n\", \"type\": \"string\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeLeappCommandOptions\": {\"description\": \"In case or using UpgradeLeappDevelSkip with LEAPP_NO_RHSM=1 user\\ncan specify --enablerepo <repo1> --enablerepo <repo2> options for\\nleapp to use these repositories for the upgrade process.\\n\", \"type\": \"string\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeLeappRebootTimeout\": {\"description\": \"Timeout (seconds) for the OS upgrade phase via Leapp\", \"type\": \"number\", \"default\": 3600}, \"UpgradeLeappPostRebootDelay\": {\"description\": \"Maximum (seconds) to wait for machine to reboot and respond to a test\\ncommand.\\n\", \"type\": \"number\", \"default\": 120}, \"UpgradeLeappToRemove\": {\"default\": [], \"description\": \"List of packages to remove during Leapp upgrade.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"UpgradeLeappToInstall\": {\"default\": [], \"description\": \"List of packages to install after Leapp upgrade.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"LeappUnloadKernelDrivers\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"List of modules to unload from the system due to being incompatible\\nwith the next RHEL version. If not being unloaded Leapp will\\ninhibit the upgrade.\\n\"}, \"LeappActorsToRemove\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"List of actors to remove from the leapp process to prevent them\\nfrom inhibiting the upgrade.\\n\"}, \"LeappRepoInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\ninitialize the Leapp process. E.g. a repository switch.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"LeappInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\napply any necessary workarounds to get Leapp working.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NICsPrefixesToUdev\": {\"default\": [], \"description\": \"List of NIC prefixes to hardcode into udev in order to prevent\\nrenaming.\\n\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"LeappPreRebootCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\napply any necessary workarounds before rebooting into Leapp.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"LeappPostRebootCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\napply any necessary workarounds after rebooting from Leapp.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\ninitialize the upgrade process. E.g. a repository switch.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeInitCommonCommand\": {\"type\": \"string\", \"description\": \"Common commands required by the upgrades process. This should not\\nnormally be modified by the operator and is set and unset in the\\nmajor-upgrade-composable-steps.yaml and major-upgrade-converge.yaml\\nenvironment files.\\n\", \"default\": \"\"}, \"SkipPackageUpdate\": {\"default\": false, \"description\": \"Set to true to skip the update all packages\", \"type\": \"boolean\"}, \"SkipRhelEnforcement\": {\"default\": false, \"description\": \"Whether to avoid or not RHEL/OSP policies enforcement on Red Hat. Mainly for CI purpose.  It shouldn\'t matter on other distributions where it\'s disabled in the role. Set to true to skip the enforcement.\", \"type\": \"boolean\"}, \"DnfStreams\": {\"default\": [], \"description\": \"List of streams to be configured before updating packages. Each list element contains a dictionary with the following values defined module[mandatory], stream[mandatory], distribution_version[mandatory] and profile[optional]. If the profile is not specified \'common\' will be used instead.\", \"type\": \"json\", \"tags\": [\"role_specific\"]}, \"BaseTripleoPackages\": {\"default\": [], \"description\": \"List of packages to install.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"ContainerImageRegistryLogin\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Flag to enable container registry login actions during the deployment. Setting this to true will cause login calls to be performed during the deployment.\"}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"dnf_module_list\": \"DnfStreams\", \"upgrade_leapp_devel_skip\": \"UpgradeLeappDevelSkip\", \"upgrade_leapp_command_options\": \"UpgradeLeappCommandOptions\", \"upgrade_leapp_to_remove\": \"UpgradeLeappToRemove\", \"upgrade_leapp_to_install\": \"UpgradeLeappToInstall\", \"leapp_repo_init_command\": \"LeappRepoInitCommand\", \"leapp_init_command\": \"LeappInitCommand\", \"nics_prefixes_to_keep\": \"NICsPrefixesToUdev\", \"upgrade_leapp_modules_to_unload\": \"LeappUnloadKernelDrivers\", \"upgrade_leapp_actors_to_remove\": \"LeappActorsToRemove\", \"upgrade_init_command\": \"UpgradeInitCommand\", \"base_tripleo_packages\": \"BaseTripleoPackages\", \"leapp_pre_reboot_command\": \"LeappPreRebootCommand\", \"leapp_post_reboot_command\": \"LeappPostRebootCommand\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"DnfStreams\": {\"get_param\": \"DnfStreams\"}, \"UpgradeLeappDevelSkip\": {\"get_param\": \"UpgradeLeappDevelSkip\"}, \"UpgradeLeappCommandOptions\": {\"get_param\": \"UpgradeLeappCommandOptions\"}, \"UpgradeLeappToRemove\": {\"get_param\": \"UpgradeLeappToRemove\"}, \"UpgradeLeappToInstall\": {\"get_param\": \"UpgradeLeappToInstall\"}, \"LeappUnloadKernelDrivers\": {\"get_param\": \"LeappUnloadKernelDrivers\"}, \"LeappPreRebootCommand\": {\"get_param\": \"LeappPreRebootCommand\"}, \"LeappPostRebootCommand\": {\"get_param\": \"LeappPostRebootCommand\"}, \"LeappActorsToRemove\": {\"get_param\": \"LeappActorsToRemove\"}, \"UpgradeInitCommand\": {\"get_param\": \"UpgradeInitCommand\"}, \"LeappRepoInitCommand\": {\"get_param\": \"LeappRepoInitCommand\"}, \"LeappInitCommand\": {\"get_param\": \"LeappInitCommand\"}, \"NICsPrefixesToUdev\": {\"get_param\": \"NICsPrefixesToUdev\"}, \"BaseTripleoPackages\": {\"get_param\": \"BaseTripleoPackages\"}}}]}}}, \"Podman\": {\"type\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"conditions\": {\"podman_requires_login\": {\"equals\": [{\"get_param\": \"ContainerImageRegistryLogin\"}, true]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the TripleO package settings\", \"value\": {\"service_name\": \"tripleo_packages\", \"config_settings\": {\"tripleo::packages::enable_install\": {\"get_param\": \"EnablePackageInstall\"}}, \"step_config\": \"include ::tripleo::packages\\n\", \"upgrade_tasks\": {\"list_concat\": [[{\"name\": \"Gather missing facts\", \"setup\": {\"gather_subset\": [\"!all\", \"!min\", \"distribution\"]}, \"tags\": [\"always\"]}, {\"name\": \"Set leapp facts\", \"set_fact\": {\"upgrade_leapp_enabled\": \"{{ _upgradeLeappEnabled | bool and\\n   ansible_facts[\'distribution\'] == \'RedHat\' and\\n   ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\') }}\", \"upgrade_leapp_debug\": {\"get_param\": \"UpgradeLeappDebug\"}, \"upgrade_leapp_devel_skip\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_devel_skip\"]}, \"upgrade_leapp_command_options\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_command_options\"]}, \"upgrade_leapp_reboot_timeout\": {\"get_param\": \"UpgradeLeappRebootTimeout\"}, \"upgrade_leapp_post_reboot_delay\": {\"get_param\": \"UpgradeLeappPostRebootDelay\"}}, \"vars\": {\"_upgradeLeappEnabled\": {\"get_param\": \"UpgradeLeappEnabled\"}}, \"tags\": [\"always\"]}, {\"name\": \"system_upgrade_prepare step 3\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Run LeappRepoInitCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"leapp_repo_init_command\"]}]]}}, {\"name\": \"Remove firewalld bindings\", \"package\": {\"name\": \"python3-firewall\", \"state\": \"absent\"}}, {\"name\": \"install leapp\", \"package\": {\"name\": \"leapp-repository-openstack\", \"state\": \"latest\"}}, {\"name\": \"Run LeappInitCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"leapp_init_command\"]}]]}}, {\"name\": \"Remove vdo\", \"package\": {\"name\": \"vdo\", \"state\": \"absent\"}}, {\"name\": \"add packages into Leapp\'s to_remove file\", \"vars\": {\"pkg_to_remove\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_to_remove\"]}}, \"lineinfile\": {\"path\": \"/etc/leapp/transaction/to_remove\", \"line\": \"{{ item }}\"}, \"loop\": \"{{ pkg_to_remove }}\"}, {\"name\": \"add packages into Leapp\'s to_install file\", \"vars\": {\"pkg_to_install\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_to_install\"]}}, \"lineinfile\": {\"path\": \"/etc/leapp/transaction/to_install\", \"line\": \"{{ item }}\"}, \"loop\": \"{{ pkg_to_install }}\"}, {\"name\": \"check sshd_config file\", \"stat\": {\"path\": \"/etc/ssh/sshd_config\"}, \"register\": \"sshd_config_result\"}, {\"name\": \"add PermitRootLogin option for leapp\", \"lineinfile\": {\"path\": \"/etc/ssh/sshd_config\", \"regexp\": \"^(# *)?PermitRootLogin\", \"line\": \"PermitRootLogin without-password\"}}, {\"name\": \"Remove paunch-services\", \"package\": {\"name\": \"paunch-services\", \"state\": \"absent\"}}, {\"name\": \"tripleo_container_manage reconfiguration\", \"import_role\": {\"name\": \"tripleo_container_manage\", \"tasks_from\": \"shutdown.yml\"}}]}, {\"name\": \"system_upgrade_prepare step 4\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"when\": [\"step|int == 4\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Delete the kernel modules in Leapp database (device_driver_deprecation_data.json)\", \"vars\": {\"modules_to_unload\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_modules_to_unload\"]}}, \"shell\": \"set -o pipefail && jq \'. | del(.data[] | select(.driver_name == \\\"{{ item }}\\\"))\' /etc/leapp/files/device_driver_deprecation_data.json > /etc/leapp/files/device_driver_deprecation_data.json_modified && mv /etc/leapp/files/device_driver_deprecation_data.json_modified /etc/leapp/files/device_driver_deprecation_data.json\\n\", \"loop\": \"{{ modules_to_unload }}\"}, {\"name\": \"Remove leapp actors to prevent them inhibiting the upgrade\", \"vars\": {\"actors_to_remove\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_actors_to_remove\"]}}, \"command\": {\"cmd\": \"find /usr/share/leapp-repository/repositories/ -name {{ item }} -type d -print -exec rm -rf \\\"{}\\\" +\"}, \"loop\": \"{{ actors_to_remove }}\"}, {\"name\": \"set leapp required answers\", \"shell\": \"leapp answer --add --section check_vdo.confirm=True\\n\"}, {\"name\": \"Replace EFI grub.cfg with redirect to /boot/grub2/grub.cfg\", \"import_role\": {\"name\": \"tripleo_kernel\", \"tasks_from\": \"efigrub.yml\"}}, {\"name\": \"Keep nics with prefix in NICsPrefixesToUdev from renaming\", \"vars\": {\"nics_prefixes_to_keep\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nics_prefixes_to_keep\"]}}, \"shell\": \"ip -j link show | \\\\ jq -r --arg prefix \\\"{{ item }}\\\" \'.[] |\\n  select((.ifname | startswith($prefix)) and\\n  (.ifname | test(\\\"^.*v[0-9]*$\\\") | not) and\\n  (.ifname | test(\\\"^.*_[0-9]*$\\\") | not) and\\n  (.ifname | test(\\\"^.*\\\\\\\\..*$\\\") | not)) |\\n  if .permaddr? then .address=.permaddr else . end |\\n  \\\"SUBSYSTEM==\\\\\\\"net\\\\\\\",ACTION==\\\\\\\"add\\\\\\\",DRIVERS==\\\\\\\"?*\\\\\\\",\\\" + \\\"NAME=\\\\\\\"\\\" + .ifname +\\\"\\\\\\\" ,ATTR{address}==\\\\\\\"\\\" + .address + \\\"\\\\\\\"\\\"\' >> /etc/udev/rules.d/70-rhosp-persistent-net.rules\\n\", \"loop\": \"{{ nics_prefixes_to_keep|list }}\"}, {\"name\": \"run leapp upgrade (download packages)\", \"shell\": \"{% if upgrade_leapp_devel_skip|default(false) %}{{ upgrade_leapp_devel_skip }}{% endif %} leapp upgrade {% if upgrade_leapp_debug|default(true) %}--debug{% endif %} {% if upgrade_leapp_command_options|default(false) %}{{ upgrade_leapp_command_options }}{% endif %}\\n\", \"when\": \"upgrade_leapp_enabled\"}]}, {\"name\": \"system_upgrade_run step 4\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_reboot\"], \"when\": [\"step|int == 4\", \"upgrade_leapp_enabled\", \"\'Undercloud\' not in group_names\"], \"block\": [{\"name\": \"Run LeappPreRebootCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"leapp_pre_reboot_command\"]}]]}}, {\"name\": \"Check that nova_libvirt is running\", \"shell\": \"podman ps --filter name=^nova_virtlogd$ --format \\\"{% raw %}{{ .Image }}{% endraw %}\\\"\\n\", \"register\": \"is_virtlogd_image_running\"}, {\"name\": \"Remove systemd files to disable them\", \"file\": {\"path\": \"/etc/systemd/system/{{ item }}\", \"state\": \"absent\"}, \"with_items\": [\"tripleo_nova_libvirt.service\", \"tripleo_nova_virtlogd_wrapper.service\", \"tripleo_nova_libvirt.target\"], \"when\": \"is_virtlogd_image_running.stdout != \'\'\"}, {\"name\": \"reboot to perform the upgrade\", \"reboot\": {\"reboot_timeout\": \"{{upgrade_leapp_reboot_timeout}}\", \"test_command\": \"source /etc/os-release; [ \\\"${VERSION_ID%.*}\\\" -ge \\\"8\\\" ] && systemctl is-system-running | grep -qE \\\"running|degraded\\\" || exit 1\", \"post_reboot_delay\": \"{{ upgrade_leapp_post_reboot_delay }}\"}}, {\"name\": \"Set selinux back to enforcing after leapp reboot\", \"selinux\": {\"policy\": \"targeted\", \"state\": \"enforcing\"}}, {\"name\": \"Run LeappPostRebootCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"leapp_post_reboot_command\"]}]]}}]}, {\"name\": \"Host packages setup step0\", \"tags\": \"setup_packages\", \"when\": \"step|int == 0\", \"block\": [{\"name\": \"Package and repo update tasks\", \"block\": [{\"name\": \"Run UpgradeInitCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", \"if [[ -f /etc/resolv.conf.save ]] ; then rm /etc/resolv.conf.save; fi\\n\\n\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_init_command\"]}]]}}, {\"name\": \"Run UpgradeInitCommonCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", {\"get_param\": \"UpgradeInitCommonCommand\"}]]}}, {\"name\": \"Ensure DNF modules have the right stream\", \"vars\": {\"dnf_module_list\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"dnf_module_list\"]}}, \"dnf\": {\"name\": \"@{{ item.module }}:{{ item.stream }}/{{ item.profile|default(\'common\') }}\", \"state\": \"present\"}, \"loop\": \"{{ dnf_module_list|list }}\", \"when\": [\"dnf_module_list|length > 0\", \"item.distribution_version is defined\", \"ansible_facts[\'distribution_major_version\'] is version(item.distribution_version, \'==\')\"]}, {\"name\": \"Ensure TripleO prerequisite packages are installed\", \"package\": {\"name\": [\"jq\", \"lvm2\", \"openstack-selinux\", \"os-net-config\", \"puppet-tripleo\", \"python3-heat-agent*\", \"rsync\"], \"state\": \"present\"}, \"when\": \"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\"}, {\"name\": \"Ensure TripleO prerequisite packages are installed and use role based heat variable to provide specific list of packages\", \"vars\": {\"base_tripleo_packages\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"base_tripleo_packages\"]}}, \"package\": {\"name\": \"{{ base_tripleo_packages }}\", \"state\": \"present\"}, \"when\": [\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\", \"base_tripleo_packages|length > 0\"]}, {\"name\": \"WA for 2240185 - If the image is schema 1 and lacks signatures than add empty signatures\", \"shell\": \"for manifest_file in `find /var/lib/containers/storage/overlay-images/ -name \'manifest\'`\\ndo\\n    cat <<< $( jq  \'if .schemaVersion == 1 then if has(\\\"signatures\\\") then . else .signatures=[] end else . end\' $manifest_file ) > $manifest_file\\ndone\\n\", \"when\": \"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\"}]}, {\"name\": \"check if libvirt is installed\", \"command\": \"/usr/bin/rpm -q libvirt-daemon\", \"failed_when\": false, \"register\": \"libvirt_installed\", \"check_mode\": false}, {\"name\": \"make sure libvirt services are disabled and masked\", \"service\": {\"name\": \"{{ item }}\", \"state\": \"stopped\", \"enabled\": false, \"masked\": true, \"daemon_reload\": true}, \"loop\": [\"libvirtd.service\", \"virtlogd.socket\"], \"when\": [\"libvirt_installed.rc == 0\"]}]}, {\"name\": \"Host packages setup step2\", \"tags\": \"setup_packages\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Special treatment for OpenvSwitch\", \"tripleo_ovs_upgrade\": null, \"register\": \"ovs_upgrade\"}, {\"name\": \"Always ensure the openvswitch service is enabled and running after upgrades\", \"service\": {\"name\": \"openvswitch\", \"enabled\": true, \"state\": \"started\"}, \"when\": [\"ovs_upgrade.changed|bool\"]}]}, {\"name\": \"Host packages setup step3\", \"tags\": \"setup_packages\", \"when\": \"step|int == 3\", \"block\": [{\"name\": \"Check for os-net-config upgrade\", \"shell\": \"yum check-upgrade | awk \'/os-net-config/{print}\'\", \"register\": \"os_net_config_need_upgrade\"}, {\"name\": \"Check that os-net-config has legacy configuration\", \"stat\": {\"path\": \"/etc/os-net-config/config.json\", \"get_attributes\": false, \"get_checksum\": false, \"get_mime\": false}, \"register\": \"stat_config_json\"}, {\"name\": \"Check that os-net-config has new configuration\", \"stat\": {\"path\": \"/etc/os-net-config/config.yaml\", \"get_attributes\": false, \"get_checksum\": false, \"get_mime\": false}, \"register\": \"stat_config_yaml\"}, {\"name\": \"Slurp the os-net-config config.json\", \"slurp\": {\"src\": \"/etc/os-net-config/config.json\"}, \"register\": \"os_config_json\", \"when\": [\"stat_config_json.stat.exists\", \"not stat_config_yaml.stat.exists\"]}, {\"name\": \"Write updated /etc/os-net-config/config.yaml\", \"copy\": {\"content\": \"{{ os_config_json.content | b64decode | from_json | to_yaml }}\", \"dest\": \"/etc/os-net-config/config.yaml\"}, \"when\": [\"stat_config_json.stat.exists\", \"not stat_config_yaml.stat.exists\"]}, {\"name\": \"Remove legacy os-net-config configuration\", \"command\": \"mv /etc/os-net-config/config.json /etc/os-net-config/deprecated_config.json\", \"when\": [\"stat_config_json.stat.exists\"]}, {\"block\": [{\"name\": \"Upgrade os-net-config\", \"package\": \"name=os-net-config state=latest\"}, {\"name\": \"take new os-net-config parameters into account now\", \"command\": \"os-net-config --no-activate -c /etc/os-net-config/config.yaml -v --detailed-exit-codes\", \"register\": \"os_net_config_upgrade\", \"failed_when\": \"os_net_config_upgrade.rc not in [0,2]\", \"changed_when\": \"os_net_config_upgrade.rc == 2\"}], \"when\": [\"os_net_config_need_upgrade.stdout\", \"stat_config_yaml.stat.exists or stat_config_json.stat.exists\"]}, {\"name\": \"Update all packages\", \"when\": [\"not skip_package_update|bool\"], \"yum\": {\"name\": \"*\", \"state\": \"latest\", \"exclude\": \"ansible-core\"}, \"vars\": {\"skip_package_update\": {\"get_param\": \"SkipPackageUpdate\"}}}, {\"name\": \"Check whether openvswitch exits\", \"command\": \"systemctl status openvswitch.service\", \"register\": \"ovs_service\", \"ignore_errors\": true}, {\"name\": \"Always ensure the openvswitch service is enabled and running after upgrades rhbz#2329821\", \"service\": {\"name\": \"openvswitch\", \"enabled\": true, \"state\": \"started\"}, \"when\": [\"ovs_service.stderr != \\\"Unit openvswitch.service could not be found.\\\"\"]}]}], {\"if\": [\"podman_requires_login\", {\"get_attr\": [\"Podman\", \"role_data\", \"workaround_upgrade_tasks\"]}, []]}]}, \"external_upgrade_tasks\": [{\"name\": \"Clean up upgrade artifacts\", \"when\": \"step|int == 1\", \"tags\": [\"never\", \"system_upgrade_cleanup\"], \"block\": [{\"name\": \"cleanup tripleo_persist\", \"include_role\": {\"name\": \"tripleo_persist\", \"tasks_from\": \"cleanup.yml\"}}]}], \"update_tasks\": [{\"name\": \"Enforce RHOSP rules regarding subscription.\", \"include_role\": {\"name\": \"tripleo_redhat_enforce\"}, \"vars\": {\"skip_rhel_enforcement\": {\"get_param\": \"SkipRhelEnforcement\"}}, \"when\": [\"step|int == 0\", \"ansible_facts[\'distribution\'] == \'RedHat\'\", \"not (skip_rhel_enforcement | bool)\"]}, {\"name\": \"Ensure DNF modules have the right stream enabled\", \"vars\": {\"dnf_module_list\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"dnf_module_list\"]}}, \"tripleo_dnf_stream\": {\"name\": \"{{ item.module }}:{{ item.stream }}\", \"state\": \"enabled\"}, \"loop\": \"{{ dnf_module_list|list }}\", \"when\": [\"step|int == 0\", \"dnf_module_list|length > 0\", \"item.distribution_version is defined\", \"ansible_facts[\'distribution_major_version\'] is version(item.distribution_version, \'==\')\"]}, {\"name\": \"Check for existing yum.pid\", \"stat\": \"path=/run/yum.pid\", \"register\": \"yum_pid_file\", \"when\": \"step|int == 0 or step|int == 3\"}, {\"name\": \"Exit if existing yum process\", \"fail\": \"msg=\\\"ERROR existing yum.pid detected - can\'t continue! Please ensure there is no other package update process for the duration of the minor update worfklow. Exiting.\\\"\", \"when\": \"(step|int == 0 or step|int == 3) and yum_pid_file.stat.exists\"}, {\"name\": \"Special treatment for OpenvSwitch\", \"tripleo_ovs_upgrade\": null, \"when\": [\"step|int == 2\"], \"register\": \"ovs_upgrade\"}, {\"name\": \"Always ensure the openvswitch service is enabled and running after upgrades\", \"service\": {\"name\": \"openvswitch\", \"enabled\": true, \"state\": \"started\"}, \"when\": [\"step|int == 2\", \"ovs_upgrade.changed|bool\"]}, {\"name\": \"Update packages and EFI grub.cfg\", \"when\": [\"step|int == 3\", \"not skip_package_update|bool\"], \"block\": [{\"name\": \"Update all packages\", \"yum\": {\"name\": \"*\", \"state\": \"latest\", \"exclude\": \"ansible-core\"}}, {\"name\": \"Replace EFI grub.cfg with redirect to /boot/grub2/grub.cfg\", \"import_role\": {\"name\": \"tripleo_kernel\", \"tasks_from\": \"efigrub.yml\"}}], \"vars\": {\"skip_package_update\": {\"get_param\": \"SkipPackageUpdate\"}}}, {\"name\": \"Ensure openvswitch is running after update\", \"when\": \"step|int == 3\", \"service\": {\"name\": \"openvswitch\", \"enabled\": true, \"state\": \"started\"}, \"ignore_errors\": true}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(150,'2026-06-12 08:26:12',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized OVN Metadata agent\\n\", \"parameters\": {\"ContainerOvnMetadataImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\"}, \"ContainerNeutronConfigImage\": {\"description\": \"The container image to use for the neutron config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\"}, \"OvnMetadataAgentLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.neutron.agent.ovn-metadata\", \"file\": \"/var/log/containers/neutron/networking-ovn-metadata-agent.log\"}}, \"OVNEnableHaproxyDockerWrapper\": {\"description\": \"Generate a wrapper script so that haproxy is launched in a separate container.\", \"type\": \"boolean\", \"default\": true}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"OVNWrapperDebug\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Controls debugging for the wrapper scripts.\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1781252715, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"NeutronMetadataProxySharedSecret\": {\"description\": \"Shared secret to prevent spoofing\", \"type\": \"string\", \"hidden\": true, \"default\": \"8w93bMk7ykp2VXaxsdJErpmNY\"}, \"NeutronMetadataWorkers\": {\"default\": 1, \"description\": \"Sets the number of worker processes for the neutron OVN metadata agent.\\nThe default value results in the configuration being left unset and a\\nsystem-dependent default will be chosen (usually the number of\\nprocessors). Please note that this can result in a large number of\\nprocesses and memory consumption on systems with a large core count. On\\nsuch systems it is recommended that a non-default value be selected that\\nmatches the load requirements.\\n\", \"type\": \"string\"}, \"NeutronPassword\": {\"description\": \"The password for the neutron service and db account, used by neutron agents.\", \"type\": \"string\", \"hidden\": true, \"default\": \"qnvMdngIoyiS9ntQpzmg868ob\"}, \"OVNNorthboundServerPort\": {\"description\": \"Port of the OVN Northbound DB server\", \"type\": \"number\", \"default\": 6641}, \"OVNSouthboundServerPort\": {\"description\": \"Port of the OVN Southbound DB server\", \"type\": \"number\", \"default\": 6642}, \"OVNDbConnectionTimeout\": {\"description\": \"Timeout in seconds for the OVSDB connection transaction\", \"type\": \"number\", \"default\": 180}, \"OVNOvsdbProbeInterval\": {\"description\": \"Probe interval in ms for the OVSDB session\", \"type\": \"number\", \"default\": 60000}, \"MonitoringSubscriptionOvnMetadata\": {\"default\": \"overcloud-ovn-metadata\", \"type\": \"string\"}, \"OvnMetadataAgentDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging for OVN Metadata agent.\", \"type\": \"boolean\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"DockerAdditionalSockets\": {\"default\": [\"/var/lib/openstack/docker.sock\"], \"description\": \"Additional domain sockets for the docker daemon to bind to (useful for mounting into containers that launch other containers)\", \"type\": \"comma_delimited_list\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"OvnMetadataCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"OvnHardwareOffloadedQos\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Enable the QoS support for hardware offloaded ports\"}, \"OVNMetadataImageUpdateTimeout\": {\"description\": \"During update, how long we wait for the container image to be updated, in seconds.\\n\", \"type\": \"number\", \"default\": 600}, \"OVNMetadataUpdateTimeout\": {\"description\": \"During update, how long we wait for the container to be updated, in seconds.\\n\", \"type\": \"number\", \"default\": 600}}, \"conditions\": {\"haproxy_wrapper_enabled\": {\"equals\": [{\"get_param\": \"OVNEnableHaproxyDockerWrapper\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}, \"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"neutron_metadata_workers_unset\": {\"equals\": [{\"get_param\": \"NeutronMetadataWorkers\"}, \"\"]}, \"key_size_override_unset\": {\"equals\": [{\"get_param\": \"OvnMetadataCertificateKeySize\"}, \"\"]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"NeutronBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"NeutronLogging\": {\"type\": \"OS::TripleO::Services::Logging::NeutronCommon\", \"properties\": {\"NeutronServiceName\": \"ovn-metadata-agent\"}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerOvnMetadataImage\": \"ContainerOvnMetadataImage\", \"ContainerNeutronConfigImage\": \"ContainerNeutronConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerOvnMetadataImage\": {\"get_param\": \"ContainerOvnMetadataImage\"}, \"ContainerNeutronConfigImage\": {\"get_param\": \"ContainerNeutronConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for OVNMetadata agent\", \"value\": {\"service_name\": \"ovn_metadata\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionOvnMetadata\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"NeutronBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"NeutronLogging\", \"config_settings\"]}, {\"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::enable_haproxy_wrapper\": {\"get_param\": \"OVNEnableHaproxyDockerWrapper\"}, \"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::haproxy_process_wrapper\": \"/var/lib/neutron/ovn_metadata_haproxy_wrapper\", \"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::haproxy_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnMetadataImage\"]}, \"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::debug\": {\"if\": [{\"get_param\": \"OVNWrapperDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"tripleo::profile::base::neutron::container_cli\": {\"get_param\": \"ContainerCli\"}, \"neutron::agents::ovn_metadata::shared_secret\": {\"get_param\": \"NeutronMetadataProxySharedSecret\"}, \"neutron::agents::ovn_metadata::auth_password\": {\"get_param\": \"NeutronPassword\"}, \"neutron::agents::ovn_metadata::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"neutron::agents::ovn_metadata::auth_tenant\": \"service\", \"neutron::agents::ovn_metadata::metadata_host\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataCellInternal\", \"host_nobrackets\"]}, \"neutron::agents::ovn_metadata::ovsdb_connection_timeout\": {\"get_param\": \"OVNDbConnectionTimeout\"}, \"neutron::agents::ovn_metadata::ovsdb_probe_interval\": {\"get_param\": \"OVNOvsdbProbeInterval\"}, \"neutron::agents::ovn_metadata::hwol_qos_enabled\": {\"get_param\": \"OvnHardwareOffloadedQos\"}, \"ovn::northbound::port\": {\"get_param\": \"OVNNorthboundServerPort\"}, \"ovn::southbound::port\": {\"get_param\": \"OVNSouthboundServerPort\"}, \"neutron::agents::ovn_metadata::debug\": {\"if\": [{\"get_param\": \"OvnMetadataAgentDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"neutron::agents::ovn_metadata::metadata_protocol\": {\"if\": [\"internal_tls_enabled\", \"https\", \"http\"]}}, {\"if\": [\"neutron_metadata_workers_unset\", {}, {\"neutron::agents::ovn_metadata::metadata_workers\": {\"get_param\": \"NeutronMetadataWorkers\"}}]}, {\"if\": [\"internal_tls_enabled\", {\"tripleo::profile::base::neutron::ovn_metadata::ovn_nb_ca_cert\": {\"get_param\": \"InternalTLSCAFile\"}, \"tripleo::profile::base::neutron::ovn_metadata::ovn_sb_ca_cert\": {\"get_param\": \"InternalTLSCAFile\"}, \"tripleo::profile::base::neutron::ovn_metadata::protocol\": \"ssl\", \"tripleo::profile::base::neutron::ovn_metadata::ovn_nb_certificate\": \"/etc/pki/tls/certs/ovn_metadata.crt\", \"tripleo::profile::base::neutron::ovn_metadata::ovn_nb_private_key\": \"/etc/pki/tls/private/ovn_metadata.key\", \"tripleo::profile::base::neutron::ovn_metadata::ovn_sb_certificate\": \"/etc/pki/tls/certs/ovn_metadata.crt\", \"tripleo::profile::base::neutron::ovn_metadata::ovn_sb_private_key\": \"/etc/pki/tls/private/ovn_metadata.key\"}, {}]}]}, \"puppet_config\": {\"puppet_tags\": \"neutron_config,ovn_metadata_agent_config\", \"config_volume\": \"neutron\", \"step_config\": \"include tripleo::profile::base::neutron::ovn_metadata\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNeutronConfigImage\"]}, \"volumes\": [\"/lib/modules:/lib/modules:ro\", \"/run/openvswitch:/run/openvswitch:shared,z\"]}, \"kolla_config\": {\"/var/lib/kolla/config_files/ovn_metadata_agent.json\": {\"command\": {\"list_join\": [\" \", [\"/usr/bin/networking-ovn-metadata-agent --config-file /etc/neutron/neutron.conf --config-file /etc/neutron/plugins/networking-ovn/networking-ovn-metadata-agent.ini\", {\"get_attr\": [\"NeutronLogging\", \"cmd_extra_args\"]}]]}, \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/neutron\", \"owner\": \"neutron:neutron\", \"recurse\": true}, {\"path\": \"/var/lib/neutron\", \"owner\": \"neutron:neutron\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/ovn_metadata.crt\", \"owner\": \"neutron:neutron\", \"optional\": true, \"perm\": \"0644\"}, {\"path\": \"/etc/pki/tls/private/ovn_metadata.key\", \"owner\": \"neutron:neutron\", \"optional\": true, \"perm\": \"0644\"}]}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"docker_config\": {\"step_2\": {\"create_haproxy_wrapper\": {\"start_order\": 1, \"detach\": false, \"net\": \"host\", \"pid\": \"host\", \"user\": \"root\", \"command\": {\"list_concat\": [[\"/container_puppet_apply.sh\", \"4\", \"file\", \"include ::tripleo::profile::base::neutron::ovn_metadata_agent_wrappers\"]]}, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnMetadataImage\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"container_puppet_apply_volumes\"]}, [\"/run/openvswitch:/run/openvswitch:shared,z\", \"/var/lib/neutron:/var/lib/neutron:shared,z\"]]}}}, \"step_4\": {\"setup_ovs_manager\": {\"start_order\": 0, \"detach\": false, \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"command\": {\"list_concat\": [[\"/container_puppet_apply.sh\", \"4\", \"exec\", \"include tripleo::profile::base::neutron::ovn_metadata\"]]}, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnMetadataImage\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"container_puppet_apply_volumes\"]}, [\"/lib/modules:/lib/modules:ro\", \"/run/openvswitch:/run/openvswitch:shared,z\"]]}, \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}, \"ovn_metadata_agent\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnMetadataImage\"]}, \"net\": \"host\", \"pid\": \"host\", \"cgroupns\": \"host\", \"privileged\": true, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NeutronLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ovn_metadata_agent.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/neutron:/var/lib/kolla/config_files/src:ro\", \"/lib/modules:/lib/modules:ro\", \"/run/openvswitch:/run/openvswitch:shared,z\", \"/var/lib/neutron:/var/lib/neutron:shared,z\", \"/run/netns:/run/netns:shared\", \"/var/lib/neutron/kill_scripts:/etc/neutron/kill_scripts:shared,z\"], {\"if\": [\"docker_enabled\", [\"/var/lib/openstack:/var/lib/openstack\"], null]}, {\"if\": [\"haproxy_wrapper_enabled\", [\"/var/lib/neutron/ovn_metadata_haproxy_wrapper:/usr/local/bin/haproxy:ro\"], null]}, {\"if\": [\"internal_tls_enabled\", [\"/etc/pki/tls/certs/ovn_metadata.crt:/etc/pki/tls/certs/ovn_metadata.crt\", \"/etc/pki/tls/private/ovn_metadata.key:/etc/pki/tls/private/ovn_metadata.key\"], null]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"metadata_settings\": {\"list_concat\": [{\"get_attr\": [\"NeutronBase\", \"role_data\", \"metadata_settings\"]}, {\"if\": [\"internal_tls_enabled\", [{\"service\": \"ovn_metadata\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}, \"type\": \"node\"}], null]}]}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"ovn_metadata\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"ovn_metadata/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}}}}, \"run_after\": \"systemctl restart tripleo_ovn_metadata_agent\\n\", \"key_size\": {\"if\": [\"key_size_override_unset\", {\"get_param\": \"CertificateKeySize\"}, {\"get_param\": \"OvnMetadataCertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}], \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"NeutronLogging\", \"host_prep_tasks\"]}, [{\"name\": \"create /run/netns with temp namespace\", \"command\": \"ip netns add ns_temp\", \"register\": \"ipnetns_add_result\", \"failed_when\": false}, {\"name\": \"remove temp namespace\", \"command\": \"ip netns delete ns_temp\", \"failed_when\": false, \"when\": [\"ipnetns_add_result.rc is defined\", \"ipnetns_add_result.rc == 0\"]}, {\"name\": \"create /var/lib/neutron\", \"file\": {\"path\": \"/var/lib/neutron\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}, {\"name\": \"set conditions\", \"set_fact\": {\"haproxy_wrapper_enabled\": {\"get_param\": \"OVNEnableHaproxyDockerWrapper\"}, \"debug_enabled\": {\"if\": [{\"get_param\": \"OVNWrapperDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"docker_additional_sockets\": {\"get_param\": \"DockerAdditionalSockets\"}}}, {\"name\": \"create kill_scripts directory within /var/lib/neutron\", \"file\": {\"state\": \"directory\", \"path\": \"/var/lib/neutron/kill_scripts\"}}, {\"name\": \"create haproxy kill script\", \"when\": \"haproxy_wrapper_enabled|bool\", \"copy\": {\"dest\": \"/var/lib/neutron/kill_scripts/haproxy-kill\", \"mode\": 493, \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/kill-script\"}}}]]}, \"upgrade_tasks\": [], \"external_update_tasks\": [{\"name\": \"Check if python3-openvswitch3.1 workaround is needed\", \"delegate_to\": \"{{ item }}\", \"become\": true, \"tags\": [\"ovn\", \"ovn_image\"], \"when\": \"step|int == 1\", \"shell\": \"if podman exec ovn_metadata_agent rpm -q python3-openvswitch3.1 > /dev/null ; then echo REQUIRED; else echo OK ; fi\\n\", \"register\": \"metadata_python_ovs_3_1\", \"failed_when\": false, \"loop\": \"{{ groups[\'ovn_metadata\'] | difference(groups[\'excluded_overcloud\']) }}\"}, {\"name\": \"Update ovn_metadata_agents\", \"vars\": {\"hosts_to_update_metadata\": \"{{ metadata_python_ovs_3_1.results | selectattr(\'stdout\', \'eq\', \'REQUIRED\') | map(attribute=\'item\') | list }}\"}, \"tags\": [\"ovn\", \"ovn_image\"], \"when\": [\"step|int == 1\", \"hosts_to_update_metadata | length > 0\"], \"block\": [{\"name\": \"Force pull image in case image name doesn\'t change.\", \"become\": true, \"loop\": \"{{ hosts_to_update_metadata }}\", \"delegate_to\": \"{{ item }}\", \"async\": {\"get_param\": \"OVNMetadataImageUpdateTimeout\"}, \"poll\": 0, \"register\": \"ovn_metadata_image_update\", \"containers.podman.podman_image\": {\"name\": {\"get_param\": \"ContainerOvnMetadataImage\"}, \"validate_certs\": false, \"force\": true}}, {\"name\": \"Was the ovn_metadata_agent image pull successful.\", \"when\": [\"\'results\' in ovn_metadata_image_update\"], \"become\": true, \"delegate_to\": \"{{ async_result_item.item }}\", \"async_status\": {\"jid\": \"{{ async_result_item.ansible_job_id }}\"}, \"loop\": \"{{ovn_metadata_image_update.results }}\", \"loop_control\": {\"loop_var\": \"async_result_item\"}, \"register\": \"async_poll_results\", \"until\": \"async_poll_results.finished\", \"retries\": {\"get_param\": \"OVNMetadataImageUpdateTimeout\"}, \"delay\": 1}, {\"name\": \"Now rotate all ovn_metadata_agents\", \"tags\": [\"ovn_metadata_parallel\"], \"delegate_to\": \"{{ item }}\", \"become\": true, \"tripleo_container_manage\": {\"config_dir\": \"/var/lib/tripleo-config/container-startup-config/step_4\", \"config_id\": [\"ovn_metadata_agent\"], \"config_patterns\": \"*ovn_metadata_agent.json\", \"config_overrides\": {\".*ovn_metadata_agent\": {\"image\": {\"get_param\": \"ContainerOvnMetadataImage\"}, \"name\": \"ovn_metadata_agent\"}}}, \"loop\": \"{{ hosts_to_update_metadata }}\", \"async\": {\"get_param\": \"OVNMetadataImageUpdateTimeout\"}, \"poll\": 0}]}, {\"name\": \"Now rotate all ovn_metadata_agents\", \"vars\": {\"hosts_to_update_metadata\": \"{{ metadata_python_ovs_3_1.results | selectattr(\'stdout\', \'eq\', \'REQUIRED\') | map(attribute=\'item\') | list }}\"}, \"tags\": [\"never\", \"ovn_metadata_serial\"], \"when\": [\"step|int == 1\", \"hosts_to_update_metadata | length > 0\"], \"delegate_to\": \"{{ item }}\", \"become\": true, \"tripleo_container_manage\": {\"config_dir\": \"/var/lib/tripleo-config/container-startup-config/step_4\", \"config_id\": [\"ovn_metadata_agent\"], \"config_patterns\": \"*ovn_metadata_agent.json\", \"config_overrides\": {\".*ovn_metadata_agent\": {\"image\": {\"get_param\": \"ContainerOvnMetadataImage\"}, \"name\": \"ovn_metadata_agent\"}}}, \"loop\": \"{{ hosts_to_update_metadata }}\", \"loop_control\": {\"pause\": 1}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (151,'2026-06-12 08:26:12',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configures podman on the host\\n\", \"parameters\": {\"DockerInsecureRegistryAddress\": {\"description\": \"Optional. The IP Address and Port of an insecure docker namespace that will be configured in /etc/sysconfig/docker. The value can be multiple addresses separated by commas.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerImageRegistryLogin\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Flag to enable container registry login actions during the deployment. Setting this to true will cause login calls to be performed during the deployment.\"}, \"ContainerImageRegistryCredentials\": {\"type\": \"json\", \"hidden\": true, \"default\": {}, \"description\": \"Mapping of image registry hosts to login credentials. Must be in the following example format\\n\\n  docker.io:\\n    username: pa55word\\n  \'192.0.2.1:8787\':\\n    registry_username: password\\n\"}, \"ContainerDefaultPidsLimit\": {\"type\": \"number\", \"default\": 4096, \"description\": \"Setting to configure the default pids_limit in /etc/container/container.conf. This is supported starting with podman 2.0.x\"}, \"ContainerDefaultEventsLogger\": {\"type\": \"string\", \"default\": \"journald\", \"description\": \"Setting to configure where podman logs its events. Uses journald by default as that will rotate data stored in tmpfs.\", \"constraints\": [{\"allowed_values\": [\"journald\", \"file\", \"none\"]}]}, \"SystemdDropInDependencies\": {\"default\": true, \"description\": \"tell the tripleo_container_manage to inject additional ordering dependencies for the systemd scopes associated to podman containers.\", \"type\": \"boolean\"}, \"deployment_source_hosts\": {\"default\": \"Undercloud\", \"type\": \"string\", \"description\": \"Host or hostgroup that runs the deployment\"}}, \"conditions\": {\"insecure_registry_is_empty\": {\"equals\": [{\"get_param\": \"DockerInsecureRegistryAddress\"}, []]}, \"systemd_drop_in_dependencies_enabled\": {\"get_param\": \"SystemdDropInDependencies\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the podman service\", \"value\": {\"service_name\": \"podman\", \"config_settings\": {}, \"step_config\": \"\", \"host_prep_tasks\": [{\"name\": \"Install and configure Podman\", \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}, {\"if\": [\"systemd_drop_in_dependencies_enabled\", [{\"name\": \"Configure tripleo_container_manage to generate systemd drop-in dependencies\", \"copy\": {\"dest\": \"/etc/sysconfig/podman_drop_in\", \"content\": \"This file makes tripleo_container_manage generate additional systemd\\ndependencies for containers that have special\\nstart/stop ordering constraints. It ensures that\\nthose constraints are enforced on reboot/shutdown.\\n\"}}], [{\"name\": \"Configure tripleo_container_manage to not generate drop-in dependencies\", \"file\": {\"path\": \"/etc/sysconfig/podman_drop_in\", \"state\": \"absent\"}}]]}], \"deploy_steps_tasks\": [{\"when\": [\"(step|int) == 1\"], \"block\": [{\"name\": \"Pre-fetch all the containers\", \"become\": true, \"containers.podman.podman_image\": {\"name\": \"{{ prefetch_image }}\", \"validate_certs\": false, \"force\": true}, \"register\": \"result\", \"until\": \"result is succeeded\", \"retries\": 5, \"delay\": 5, \"loop_control\": {\"loop_var\": \"prefetch_image\"}, \"loop\": \"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\"}]}], \"service_config_settings\": {}, \"workaround_upgrade_tasks\": [{\"name\": \"Configure Podman registry\", \"when\": [\"step|int == 0\"], \"tags\": [\"setup_packages\"], \"block\": [{\"name\": \"Make sure the Undercloud hostname is included in /etc/hosts\", \"when\": [\"undercloud_hosts_entries is defined\"], \"lineinfile\": {\"dest\": \"/etc/hosts\", \"line\": \"{{ undercloud_hosts_entries | join(\'\') }}\", \"state\": \"present\"}}]}, {\"name\": \"Run podman install\", \"tags\": [\"system_upgrade\", \"system_upgrade_run\", \"setup_packages\"], \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}, {\"name\": \"Comment infra_image in container.conf\", \"lineinfile\": {\"dest\": \"/usr/share/containers/containers.conf\", \"regexp\": \"(?i)^(infra_image.*)\", \"line\": \"#\\\\1\", \"backrefs\": true, \"state\": \"present\"}, \"tags\": [\"setup_packages\"], \"when\": [\"step|int == 0\"]}], \"upgrade_tasks\": [{\"name\": \"Configure Podman registry\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Make sure the Undercloud hostname is included in /etc/hosts\", \"when\": [\"undercloud_hosts_entries is defined\"], \"lineinfile\": {\"dest\": \"/etc/hosts\", \"line\": \"{{ undercloud_hosts_entries | join(\'\') }}\", \"state\": \"present\"}}]}, {\"name\": \"Run podman install\", \"tags\": [\"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}], \"update_tasks\": [{\"name\": \"Force pre-fetch of container images\", \"when\": [\"(step|int) == 5\"], \"block\": [{\"name\": \"Pre-fetch all the containers\", \"become\": true, \"containers.podman.podman_image\": {\"name\": \"{{ prefetch_image }}\", \"validate_certs\": false, \"force\": true}, \"register\": \"result\", \"until\": \"result is succeeded\", \"retries\": 5, \"delay\": 5, \"loop_control\": {\"loop_var\": \"prefetch_image\"}, \"loop\": \"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\"}]}], \"post_upgrade_tasks\": [{\"name\": \"Purge Podman\", \"when\": [\"(step | int) == 3\", \"container_cli == \'podman\'\", \"deployment_source_hosts not in group_names\"], \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_purge.yml\"}, \"vars\": {\"deployment_source_hosts\": {\"get_param\": \"deployment_source_hosts\"}}}], \"post_update_tasks\": [{\"name\": \"Purge Podman\", \"when\": [\"(step | int) == 3\", \"container_cli == \'podman\'\", \"deployment_source_hosts not in group_names\"], \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_purge.yml\"}, \"vars\": {\"deployment_source_hosts\": {\"get_param\": \"deployment_source_hosts\"}}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(152,'2026-06-12 08:26:12',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Nova database client service.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"NovaPassword\": {\"description\": \"The password for the nova service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"1Ii49H1EfmLUfEWsgfy9vla3q\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova base service.\", \"value\": {\"config_settings\": {\"nova::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlCellInternal\", \"protocol\"]}, \"username\": \"nova\", \"password\": {\"get_param\": \"NovaPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlCellInternal\", \"host\"]}, \"path\": \"/nova\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"nova\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}}, \"service_config_settings\": {\"mysql\": {\"nova::db::mysql::password\": {\"get_param\": \"NovaPassword\"}, \"nova::db::mysql::user\": \"nova\", \"nova::db::mysql::host\": \"%\", \"nova::db::mysql::dbname\": \"nova\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(153,'2026-06-12 08:26:12',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configures podman on the host\\n\", \"parameters\": {\"DockerInsecureRegistryAddress\": {\"description\": \"Optional. The IP Address and Port of an insecure docker namespace that will be configured in /etc/sysconfig/docker. The value can be multiple addresses separated by commas.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerImageRegistryLogin\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Flag to enable container registry login actions during the deployment. Setting this to true will cause login calls to be performed during the deployment.\"}, \"ContainerImageRegistryCredentials\": {\"type\": \"json\", \"hidden\": true, \"default\": {}, \"description\": \"Mapping of image registry hosts to login credentials. Must be in the following example format\\n\\n  docker.io:\\n    username: pa55word\\n  \'192.0.2.1:8787\':\\n    registry_username: password\\n\"}, \"ContainerDefaultPidsLimit\": {\"type\": \"number\", \"default\": 4096, \"description\": \"Setting to configure the default pids_limit in /etc/container/container.conf. This is supported starting with podman 2.0.x\"}, \"ContainerDefaultEventsLogger\": {\"type\": \"string\", \"default\": \"journald\", \"description\": \"Setting to configure where podman logs its events. Uses journald by default as that will rotate data stored in tmpfs.\", \"constraints\": [{\"allowed_values\": [\"journald\", \"file\", \"none\"]}]}, \"SystemdDropInDependencies\": {\"default\": true, \"description\": \"tell the tripleo_container_manage to inject additional ordering dependencies for the systemd scopes associated to podman containers.\", \"type\": \"boolean\"}, \"deployment_source_hosts\": {\"default\": \"Undercloud\", \"type\": \"string\", \"description\": \"Host or hostgroup that runs the deployment\"}}, \"conditions\": {\"insecure_registry_is_empty\": {\"equals\": [{\"get_param\": \"DockerInsecureRegistryAddress\"}, []]}, \"systemd_drop_in_dependencies_enabled\": {\"get_param\": \"SystemdDropInDependencies\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the podman service\", \"value\": {\"service_name\": \"podman\", \"config_settings\": {}, \"step_config\": \"\", \"host_prep_tasks\": [{\"name\": \"Install and configure Podman\", \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}, {\"if\": [\"systemd_drop_in_dependencies_enabled\", [{\"name\": \"Configure tripleo_container_manage to generate systemd drop-in dependencies\", \"copy\": {\"dest\": \"/etc/sysconfig/podman_drop_in\", \"content\": \"This file makes tripleo_container_manage generate additional systemd\\ndependencies for containers that have special\\nstart/stop ordering constraints. It ensures that\\nthose constraints are enforced on reboot/shutdown.\\n\"}}], [{\"name\": \"Configure tripleo_container_manage to not generate drop-in dependencies\", \"file\": {\"path\": \"/etc/sysconfig/podman_drop_in\", \"state\": \"absent\"}}]]}], \"deploy_steps_tasks\": [{\"when\": [\"(step|int) == 1\"], \"block\": [{\"name\": \"Pre-fetch all the containers\", \"become\": true, \"containers.podman.podman_image\": {\"name\": \"{{ prefetch_image }}\", \"validate_certs\": false, \"force\": true}, \"register\": \"result\", \"until\": \"result is succeeded\", \"retries\": 5, \"delay\": 5, \"loop_control\": {\"loop_var\": \"prefetch_image\"}, \"loop\": \"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\"}]}], \"service_config_settings\": {}, \"workaround_upgrade_tasks\": [{\"name\": \"Configure Podman registry\", \"when\": [\"step|int == 0\"], \"tags\": [\"setup_packages\"], \"block\": [{\"name\": \"Make sure the Undercloud hostname is included in /etc/hosts\", \"when\": [\"undercloud_hosts_entries is defined\"], \"lineinfile\": {\"dest\": \"/etc/hosts\", \"line\": \"{{ undercloud_hosts_entries | join(\'\') }}\", \"state\": \"present\"}}]}, {\"name\": \"Run podman install\", \"tags\": [\"system_upgrade\", \"system_upgrade_run\", \"setup_packages\"], \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}, {\"name\": \"Comment infra_image in container.conf\", \"lineinfile\": {\"dest\": \"/usr/share/containers/containers.conf\", \"regexp\": \"(?i)^(infra_image.*)\", \"line\": \"#\\\\1\", \"backrefs\": true, \"state\": \"present\"}, \"tags\": [\"setup_packages\"], \"when\": [\"step|int == 0\"]}], \"upgrade_tasks\": [{\"name\": \"Configure Podman registry\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Make sure the Undercloud hostname is included in /etc/hosts\", \"when\": [\"undercloud_hosts_entries is defined\"], \"lineinfile\": {\"dest\": \"/etc/hosts\", \"line\": \"{{ undercloud_hosts_entries | join(\'\') }}\", \"state\": \"present\"}}]}, {\"name\": \"Run podman install\", \"tags\": [\"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}], \"update_tasks\": [{\"name\": \"Force pre-fetch of container images\", \"when\": [\"(step|int) == 5\"], \"block\": [{\"name\": \"Pre-fetch all the containers\", \"become\": true, \"containers.podman.podman_image\": {\"name\": \"{{ prefetch_image }}\", \"validate_certs\": false, \"force\": true}, \"register\": \"result\", \"until\": \"result is succeeded\", \"retries\": 5, \"delay\": 5, \"loop_control\": {\"loop_var\": \"prefetch_image\"}, \"loop\": \"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\"}]}], \"post_upgrade_tasks\": [{\"name\": \"Purge Podman\", \"when\": [\"(step | int) == 3\", \"container_cli == \'podman\'\", \"deployment_source_hosts not in group_names\"], \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_purge.yml\"}, \"vars\": {\"deployment_source_hosts\": {\"get_param\": \"deployment_source_hosts\"}}}], \"post_update_tasks\": [{\"name\": \"Purge Podman\", \"when\": [\"(step | int) == 3\", \"container_cli == \'podman\'\", \"deployment_source_hosts not in group_names\"], \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_purge.yml\"}, \"vars\": {\"deployment_source_hosts\": {\"get_param\": \"deployment_source_hosts\"}}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(154,'2026-06-12 08:26:12',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Neutron service\\n\", \"parameters\": {\"NeutronServiceName\": {\"description\": \"service name\", \"type\": \"string\"}}, \"outputs\": {\"cmd_extra_args\": {\"description\": \"Extra command line arguments for running the service in the container.\", \"value\": {\"str_replace\": {\"template\": \"--log-file=/var/log/neutron/SERVICE.log\", \"params\": {\"SERVICE\": {\"get_param\": \"NeutronServiceName\"}}}}}, \"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {}}}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/neutron:/var/log/neutron:z\"]}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/neutron\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"NeutronServiceName\": \"ovn-metadata-agent\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(155,'2026-06-12 08:26:12',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configure sshd_config\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"BannerText\": {\"default\": \"\", \"description\": \"Configures Banner text in sshd_config\", \"type\": \"string\"}, \"MessageOfTheDay\": {\"default\": \"\", \"description\": \"Configures /etc/motd text\", \"type\": \"string\"}, \"SshServerOptions\": {\"default\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"description\": \"Mapping of sshd_config values\", \"type\": \"json\"}, \"PasswordAuthentication\": {\"default\": \"no\", \"description\": \"Whether or not disable password authentication\", \"type\": \"string\"}, \"SshFirewallAllowAll\": {\"default\": true, \"description\": \"Set this to true to open up ssh access from all sources.\", \"type\": \"boolean\"}, \"SshServerOptionsOverrides\": {\"default\": {}, \"description\": \"Mapping of sshd_config values to override definitions in SshServerOptions\", \"type\": \"json\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"SshServerOptionsOverrides\"]}], \"conditions\": {\"ssh_firewall_allow_all\": {\"equals\": [{\"get_param\": \"SshFirewallAllowAll\"}, true]}, \"ssh_banner_text_set\": {\"not\": {\"equals\": [{\"get_param\": \"BannerText\"}, \"\"]}}, \"ssh_motd_text_set\": {\"not\": {\"equals\": [{\"get_param\": \"MessageOfTheDay\"}, \"\"]}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the ssh\", \"value\": {\"service_name\": \"sshd\", \"firewall_rules\": {\"003 accept ssh from all\": {\"proto\": \"tcp\", \"dport\": 22, \"extras\": {\"ensure\": {\"if\": [\"ssh_firewall_allow_all\", \"present\", \"absent\"]}}}}, \"host_prep_tasks\": [{\"include_role\": {\"name\": \"tripleo_sshd\"}, \"vars\": {\"tripleo_sshd_server_options\": {\"map_merge\": [{\"get_param\": \"SshServerOptions\"}, {\"get_param\": \"SshServerOptionsOverrides\"}]}, \"tripleo_sshd_password_authentication\": {\"get_param\": \"PasswordAuthentication\"}, \"tripleo_sshd_banner_enabled\": {\"if\": [\"ssh_banner_text_set\", true, false]}, \"tripleo_sshd_banner_text\": {\"get_param\": \"BannerText\"}, \"tripleo_sshd_motd_enabled\": {\"if\": [\"ssh_motd_text_set\", true, false]}, \"tripleo_sshd_message_of_the_day\": {\"get_param\": \"MessageOfTheDay\"}}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(156,'2026-06-12 08:26:13',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"TripleO Firewall settings\\n\", \"parameters\": {\"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ExtraFirewallRules\": {\"default\": {}, \"description\": \"Mapping of firewall rules.\", \"type\": \"json\", \"tags\": [\"role_specific\"]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"extra_firewall_rules\": \"ExtraFirewallRules\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ExtraFirewallRules\": {\"get_param\": \"ExtraFirewallRules\"}}}]}}}}, \"conditions\": {\"no_ctlplane\": {\"equals\": [{\"get_params\": [\"ServiceData\", \"net_cidr_map\", \"ctlplane\"]}, null]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the TripleO firewall settings\", \"value\": {\"service_name\": \"tripleo_firewall\", \"config_settings\": {\"tripleo::firewall::manage_firewall\": false, \"tripleo::firewall::purge_firewall_rules\": false}, \"ansible_group_vars\": {\"tripleo_nftables_debug\": {\"get_param\": \"Debug\"}}, \"firewall_rules\": {\"map_merge\": [{\"map_merge\": {\"repeat\": {\"for_each\": {\"<%net_cidr%>\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", \"ctlplane\"]}}, \"template\": {\"003 accept ssh from ctlplane subnet <%net_cidr%>\": {\"source\": \"<%net_cidr%>\", \"proto\": \"tcp\", \"dport\": 22}}}}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"extra_firewall_rules\"]}]}, \"host_prep_tasks\": [{\"if\": [\"no_ctlplane\", {\"name\": \"Failure - ctlplane subnet is unset\", \"fail\": {\"msg\": \"No CIDRs found in the ctlplane network tags.\\nPlease refer to the documentation in order to\\nset the correct network tags in DeployedServerPortMap.\\n\"}}, {\"name\": \"Notice - ctlplane subnet is set\", \"debug\": {\"msg\": \"CIDRs found in the ctlplane network tags.\\n\"}}]}], \"host_firewall_tasks\": [{\"name\": \"Run firewall role\", \"include_role\": {\"name\": \"tripleo_firewall\"}}], \"update_tasks\": [{\"name\": \"Cleanup tripleo-iptables services\", \"when\": [\"(step | int) == 1\"], \"block\": [{\"name\": \"Disable tripleo-iptables.service\", \"systemd\": {\"name\": \"tripleo-iptables.service\", \"state\": \"stopped\", \"enabled\": false}, \"register\": \"systemd_tripleo_iptables\", \"failed_when\": false}, {\"name\": \"Cleanup tripleo-iptables.services\", \"file\": {\"path\": \"/etc/systemd/system/tripleo-iptables.service\", \"state\": \"absent\"}}, {\"name\": \"Disable tripleo-ip6tables.service\", \"systemd\": {\"name\": \"tripleo-ip6tables.service\", \"state\": \"stopped\", \"enabled\": false}, \"register\": \"systemd_tripleo_ip6tables\", \"failed_when\": false}, {\"name\": \"Cleanup tripleo-ip6tables.services\", \"file\": {\"path\": \"/etc/systemd/system/tripleo-ip6tables.service\", \"state\": \"absent\"}}, {\"name\": \"Reload systemd\", \"systemd\": {\"daemon_reload\": true}, \"when\": [\"(systemd_tripleo_iptables is changed or systemd_tripleo_ip6tables is changed)\"]}]}], \"upgrade_tasks\": [{\"name\": \"Cleanup tripleo-iptables services\", \"when\": [\"(step | int) == 1\"], \"block\": [{\"name\": \"Disable tripleo-iptables.service\", \"systemd\": {\"name\": \"tripleo-iptables.service\", \"state\": \"stopped\", \"enabled\": false}, \"register\": \"systemd_tripleo_iptables\", \"failed_when\": false}, {\"name\": \"Cleanup tripleo-iptables.services\", \"file\": {\"path\": \"/etc/systemd/system/tripleo-iptables.service\", \"state\": \"absent\"}}, {\"name\": \"Disable tripleo-ip6tables.service\", \"systemd\": {\"name\": \"tripleo-ip6tables.service\", \"state\": \"stopped\", \"enabled\": false}, \"register\": \"systemd_tripleo_ip6tables\", \"failed_when\": false}, {\"name\": \"Cleanup tripleo-ip6tables.services\", \"file\": {\"path\": \"/etc/systemd/system/tripleo-ip6tables.service\", \"state\": \"absent\"}}, {\"name\": \"Reload systemd\", \"systemd\": {\"daemon_reload\": true}, \"when\": [\"(systemd_tripleo_iptables is changed or systemd_tripleo_ip6tables is changed)\"]}]}, {\"when\": [\"(step | int) == 3\"], \"block\": [{\"name\": \"blank ipv6 rule before activating ipv6 firewall.\", \"shell\": \"cat /etc/sysconfig/ip6tables > /etc/sysconfig/ip6tables.n-o-upgrade; cat</dev/null>/etc/sysconfig/ip6tables\", \"args\": {\"creates\": \"/etc/sysconfig/ip6tables.n-o-upgrade\"}}, {\"name\": \"cleanup unmanaged rules pushed by iptables-services\", \"shell\": \"iptables -C INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT &>/dev/null && \\\\\\n  iptables -D INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT\\niptables -C INPUT -p icmp -j ACCEPT &>/dev/null && \\\\\\n  iptables -D INPUT -p icmp -j ACCEPT\\niptables -C INPUT -i lo -j ACCEPT &>/dev/null && \\\\\\n  iptables -D INPUT -i lo -j ACCEPT\\niptables -C INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT &>/dev/null && \\\\\\n  iptables -D INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT\\niptables -C INPUT -j REJECT --reject-with icmp-host-prohibited &>/dev/null && \\\\\\n  iptables -D INPUT -j REJECT --reject-with icmp-host-prohibited\\niptables -C FORWARD -j REJECT --reject-with icmp-host-prohibited &>/dev/null && \\\\\\n  iptables -D FORWARD -j REJECT --reject-with icmp-host-prohibited\\n\\nsed -i \'/^-A INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A INPUT -p icmp -j ACCEPT$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A INPUT -i lo -j ACCEPT$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A INPUT -j REJECT --reject-with icmp-host-prohibited$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A FORWARD -j REJECT --reject-with icmp-host-prohibited$/d\' /etc/sysconfig/iptables\\n\\nip6tables -C INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT\\nip6tables -C INPUT -p ipv6-icmp -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -p ipv6-icmp -j ACCEPT\\nip6tables -C INPUT -i lo -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -i lo -j ACCEPT\\nip6tables -C INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT\\nip6tables -C INPUT -d fe80::/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -d fe80::/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT\\nip6tables -C INPUT -j REJECT --reject-with icmp6-adm-prohibited &>/dev/null && \\\\\\n  ip6tables -D INPUT -j REJECT --reject-with icmp6-adm-prohibited\\nip6tables -C FORWARD -j REJECT --reject-with icmp6-adm-prohibited &>/dev/null && \\\\\\n  ip6tables -D FORWARD -j REJECT --reject-with icmp6-adm-prohibited\\n\\nsed -i \'/^-A INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -p ipv6-icmp -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -i lo -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -d fe80::\\\\/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -j REJECT --reject-with icmp6-adm-prohibited$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A FORWARD -j REJECT --reject-with icmp6-adm-prohibited$/d\' /etc/sysconfig/ip6tables\"}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(157,'2026-06-12 08:26:13',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(158,'2026-06-12 08:26:13',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (159,'2026-06-12 08:26:13',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Chrony time service deployment using ansible, this YAML file creates the interface between the HOT template and the ansible role that actually installs and configure chronyd.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"NtpServer\": {\"default\": \"pool.ntp.org\", \"description\": \"NTP servers list. Defaulted to a set of pool.ntp.org servers in order to have a sane default for Pacemaker deployments when not configuring this parameter by default.\", \"type\": \"comma_delimited_list\"}, \"NtpPool\": {\"default\": [], \"description\": \"NTP pool list.  Defaults to [], so only NtpServer is used by default.\", \"type\": \"comma_delimited_list\"}, \"ChronyGlobalServerOptions\": {\"default\": \"\", \"description\": \"Default server options for the configured NTP servers in chrony.conf. If this is specified, NtpIburstEnable, MaxPoll, and MinPoll are ignored.\", \"type\": \"string\"}, \"ChronyGlobalPoolOptions\": {\"default\": \"\", \"description\": \"Default pool options for the configured NTP pools in chrony.conf. If this is specified, NtpIburstEnable, MaxPoll, and MinPoll are ignored.\", \"type\": \"string\"}, \"NtpIburstEnable\": {\"default\": true, \"description\": \"Specifies whether to enable the iburst option for every NTP peer. If iburst is enabled, when the ntp server is unreachable ntp will send a burst of eight packages instead of one. This is designed to speed up the initial syncrhonization.\", \"type\": \"boolean\"}, \"MaxPoll\": {\"description\": \"Specify maximum poll interval of upstream servers for NTP messages, in seconds to the power of two. The maximum poll interval defaults to 10 (1,024 s). Allowed values are 4 to 17.\", \"type\": \"number\", \"default\": 10, \"constraints\": [{\"range\": {\"min\": 4, \"max\": 17}}]}, \"MinPoll\": {\"description\": \"Specify minimum poll interval of upstream servers for NTP messages, in seconds to the power of two. The minimum poll interval defaults to 6 (64 s). Allowed values are 4 to 17.\", \"type\": \"number\", \"default\": 6, \"constraints\": [{\"range\": {\"min\": 4, \"max\": 17}}]}, \"EnablePackageInstall\": {\"default\": true, \"description\": \"Set to true to enable package installation at deploy time\", \"type\": \"boolean\"}, \"ChronyAclRules\": {\"default\": [\"deny all\"], \"description\": \"Access Control List of NTP clients.  By default no clients are permitted.\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"chrony_global_server_settings_is_empty\": {\"equals\": [{\"get_param\": \"ChronyGlobalServerOptions\"}, \"\"]}, \"chrony_global_pool_settings_is_empty\": {\"equals\": [{\"get_param\": \"ChronyGlobalPoolOptions\"}, \"\"]}, \"ntp_iburst\": {\"equals\": [{\"get_param\": \"NtpIburstEnable\"}, true]}}, \"outputs\": {\"role_data\": {\"description\": \"Role chrony using composable timesync services.\", \"value\": {\"service_name\": \"chrony\", \"firewall_rules\": {\"105 ntp\": {\"dport\": 123, \"proto\": \"udp\"}}, \"host_prep_tasks\": [{\"name\": \"Check for NTP service\", \"shell\": \"systemctl is-active ntpd.service || systemctl is-enabled ntpd.service\", \"failed_when\": false, \"become\": true, \"register\": \"ntp_service_check\"}, {\"name\": \"Disable NTP before configuring Chrony\", \"service\": {\"name\": \"ntpd\", \"state\": \"stopped\", \"enabled\": false}, \"when\": [\"ntp_service_check.rc is defined\", \"ntp_service_check.rc == 0\"]}, {\"name\": \"Install, Configure and Run Chrony\", \"include_role\": {\"name\": \"chrony\"}}, {\"name\": \"Force NTP sync\", \"command\": \"chronyc makestep\"}, {\"name\": \"Ensure system is NTP time synced\", \"command\": \"chronyc waitsync 30\"}], \"ansible_group_vars\": {\"chrony_role_action\": \"all\", \"chrony_ntp_servers\": {\"get_param\": \"NtpServer\"}, \"chrony_ntp_pools\": {\"get_param\": \"NtpPool\"}, \"chrony_global_server_settings\": {\"if\": [\"chrony_global_server_settings_is_empty\", {\"str_replace\": {\"template\": \"IBURST minpoll MINPOLL maxpoll MAXPOLL\", \"params\": {\"IBURST\": {\"if\": [\"ntp_iburst\", \"iburst\", \"\"]}, \"MINPOLL\": {\"get_param\": \"MinPoll\"}, \"MAXPOLL\": {\"get_param\": \"MaxPoll\"}}}}, {\"get_param\": \"ChronyGlobalServerOptions\"}]}, \"chrony_global_pool_settings\": {\"if\": [\"chrony_global_pool_settings_is_empty\", {\"str_replace\": {\"template\": \"IBURST minpoll MINPOLL maxpoll MAXPOLL\", \"params\": {\"IBURST\": {\"if\": [\"ntp_iburst\", \"iburst\", \"\"]}, \"MINPOLL\": {\"get_param\": \"MinPoll\"}, \"MAXPOLL\": {\"get_param\": \"MaxPoll\"}}}}, {\"get_param\": \"ChronyGlobalPoolOptions\"}]}, \"chrony_manage_package\": {\"get_param\": \"EnablePackageInstall\"}, \"chrony_acl_rules\": {\"get_param\": \"ChronyAclRules\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(160,'2026-06-12 08:26:13',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"TripleO Package installation settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnablePackageInstall\": {\"default\": true, \"description\": \"Set to true to enable package installation at deploy time\", \"type\": \"boolean\"}, \"UpgradeLeappEnabled\": {\"description\": \"Use Leapp for operating system upgrade\", \"type\": \"boolean\", \"default\": false}, \"UpgradeLeappDebug\": {\"description\": \"Print debugging output when running Leapp\", \"type\": \"boolean\", \"default\": false}, \"UpgradeLeappDevelSkip\": {\"description\": \"Skip Leapp checks by setting env variables when running Leapp in\\ndevelopment/testing. For example, LEAPP_DEVEL_SKIP_RHSM=1.\\n\", \"type\": \"string\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeLeappCommandOptions\": {\"description\": \"In case or using UpgradeLeappDevelSkip with LEAPP_NO_RHSM=1 user\\ncan specify --enablerepo <repo1> --enablerepo <repo2> options for\\nleapp to use these repositories for the upgrade process.\\n\", \"type\": \"string\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeLeappRebootTimeout\": {\"description\": \"Timeout (seconds) for the OS upgrade phase via Leapp\", \"type\": \"number\", \"default\": 3600}, \"UpgradeLeappPostRebootDelay\": {\"description\": \"Maximum (seconds) to wait for machine to reboot and respond to a test\\ncommand.\\n\", \"type\": \"number\", \"default\": 120}, \"UpgradeLeappToRemove\": {\"default\": [], \"description\": \"List of packages to remove during Leapp upgrade.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"UpgradeLeappToInstall\": {\"default\": [], \"description\": \"List of packages to install after Leapp upgrade.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"LeappUnloadKernelDrivers\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"List of modules to unload from the system due to being incompatible\\nwith the next RHEL version. If not being unloaded Leapp will\\ninhibit the upgrade.\\n\"}, \"LeappActorsToRemove\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"List of actors to remove from the leapp process to prevent them\\nfrom inhibiting the upgrade.\\n\"}, \"LeappRepoInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\ninitialize the Leapp process. E.g. a repository switch.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"LeappInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\napply any necessary workarounds to get Leapp working.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NICsPrefixesToUdev\": {\"default\": [], \"description\": \"List of NIC prefixes to hardcode into udev in order to prevent\\nrenaming.\\n\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"LeappPreRebootCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\napply any necessary workarounds before rebooting into Leapp.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"LeappPostRebootCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\napply any necessary workarounds after rebooting from Leapp.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\ninitialize the upgrade process. E.g. a repository switch.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeInitCommonCommand\": {\"type\": \"string\", \"description\": \"Common commands required by the upgrades process. This should not\\nnormally be modified by the operator and is set and unset in the\\nmajor-upgrade-composable-steps.yaml and major-upgrade-converge.yaml\\nenvironment files.\\n\", \"default\": \"\"}, \"SkipPackageUpdate\": {\"default\": false, \"description\": \"Set to true to skip the update all packages\", \"type\": \"boolean\"}, \"SkipRhelEnforcement\": {\"default\": false, \"description\": \"Whether to avoid or not RHEL/OSP policies enforcement on Red Hat. Mainly for CI purpose.  It shouldn\'t matter on other distributions where it\'s disabled in the role. Set to true to skip the enforcement.\", \"type\": \"boolean\"}, \"DnfStreams\": {\"default\": [], \"description\": \"List of streams to be configured before updating packages. Each list element contains a dictionary with the following values defined module[mandatory], stream[mandatory], distribution_version[mandatory] and profile[optional]. If the profile is not specified \'common\' will be used instead.\", \"type\": \"json\", \"tags\": [\"role_specific\"]}, \"BaseTripleoPackages\": {\"default\": [], \"description\": \"List of packages to install.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"ContainerImageRegistryLogin\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Flag to enable container registry login actions during the deployment. Setting this to true will cause login calls to be performed during the deployment.\"}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"dnf_module_list\": \"DnfStreams\", \"upgrade_leapp_devel_skip\": \"UpgradeLeappDevelSkip\", \"upgrade_leapp_command_options\": \"UpgradeLeappCommandOptions\", \"upgrade_leapp_to_remove\": \"UpgradeLeappToRemove\", \"upgrade_leapp_to_install\": \"UpgradeLeappToInstall\", \"leapp_repo_init_command\": \"LeappRepoInitCommand\", \"leapp_init_command\": \"LeappInitCommand\", \"nics_prefixes_to_keep\": \"NICsPrefixesToUdev\", \"upgrade_leapp_modules_to_unload\": \"LeappUnloadKernelDrivers\", \"upgrade_leapp_actors_to_remove\": \"LeappActorsToRemove\", \"upgrade_init_command\": \"UpgradeInitCommand\", \"base_tripleo_packages\": \"BaseTripleoPackages\", \"leapp_pre_reboot_command\": \"LeappPreRebootCommand\", \"leapp_post_reboot_command\": \"LeappPostRebootCommand\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"DnfStreams\": {\"get_param\": \"DnfStreams\"}, \"UpgradeLeappDevelSkip\": {\"get_param\": \"UpgradeLeappDevelSkip\"}, \"UpgradeLeappCommandOptions\": {\"get_param\": \"UpgradeLeappCommandOptions\"}, \"UpgradeLeappToRemove\": {\"get_param\": \"UpgradeLeappToRemove\"}, \"UpgradeLeappToInstall\": {\"get_param\": \"UpgradeLeappToInstall\"}, \"LeappUnloadKernelDrivers\": {\"get_param\": \"LeappUnloadKernelDrivers\"}, \"LeappPreRebootCommand\": {\"get_param\": \"LeappPreRebootCommand\"}, \"LeappPostRebootCommand\": {\"get_param\": \"LeappPostRebootCommand\"}, \"LeappActorsToRemove\": {\"get_param\": \"LeappActorsToRemove\"}, \"UpgradeInitCommand\": {\"get_param\": \"UpgradeInitCommand\"}, \"LeappRepoInitCommand\": {\"get_param\": \"LeappRepoInitCommand\"}, \"LeappInitCommand\": {\"get_param\": \"LeappInitCommand\"}, \"NICsPrefixesToUdev\": {\"get_param\": \"NICsPrefixesToUdev\"}, \"BaseTripleoPackages\": {\"get_param\": \"BaseTripleoPackages\"}}}]}}}, \"Podman\": {\"type\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"conditions\": {\"podman_requires_login\": {\"equals\": [{\"get_param\": \"ContainerImageRegistryLogin\"}, true]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the TripleO package settings\", \"value\": {\"service_name\": \"tripleo_packages\", \"config_settings\": {\"tripleo::packages::enable_install\": {\"get_param\": \"EnablePackageInstall\"}}, \"step_config\": \"include ::tripleo::packages\\n\", \"upgrade_tasks\": {\"list_concat\": [[{\"name\": \"Gather missing facts\", \"setup\": {\"gather_subset\": [\"!all\", \"!min\", \"distribution\"]}, \"tags\": [\"always\"]}, {\"name\": \"Set leapp facts\", \"set_fact\": {\"upgrade_leapp_enabled\": \"{{ _upgradeLeappEnabled | bool and\\n   ansible_facts[\'distribution\'] == \'RedHat\' and\\n   ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\') }}\", \"upgrade_leapp_debug\": {\"get_param\": \"UpgradeLeappDebug\"}, \"upgrade_leapp_devel_skip\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_devel_skip\"]}, \"upgrade_leapp_command_options\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_command_options\"]}, \"upgrade_leapp_reboot_timeout\": {\"get_param\": \"UpgradeLeappRebootTimeout\"}, \"upgrade_leapp_post_reboot_delay\": {\"get_param\": \"UpgradeLeappPostRebootDelay\"}}, \"vars\": {\"_upgradeLeappEnabled\": {\"get_param\": \"UpgradeLeappEnabled\"}}, \"tags\": [\"always\"]}, {\"name\": \"system_upgrade_prepare step 3\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Run LeappRepoInitCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"leapp_repo_init_command\"]}]]}}, {\"name\": \"Remove firewalld bindings\", \"package\": {\"name\": \"python3-firewall\", \"state\": \"absent\"}}, {\"name\": \"install leapp\", \"package\": {\"name\": \"leapp-repository-openstack\", \"state\": \"latest\"}}, {\"name\": \"Run LeappInitCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"leapp_init_command\"]}]]}}, {\"name\": \"Remove vdo\", \"package\": {\"name\": \"vdo\", \"state\": \"absent\"}}, {\"name\": \"add packages into Leapp\'s to_remove file\", \"vars\": {\"pkg_to_remove\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_to_remove\"]}}, \"lineinfile\": {\"path\": \"/etc/leapp/transaction/to_remove\", \"line\": \"{{ item }}\"}, \"loop\": \"{{ pkg_to_remove }}\"}, {\"name\": \"add packages into Leapp\'s to_install file\", \"vars\": {\"pkg_to_install\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_to_install\"]}}, \"lineinfile\": {\"path\": \"/etc/leapp/transaction/to_install\", \"line\": \"{{ item }}\"}, \"loop\": \"{{ pkg_to_install }}\"}, {\"name\": \"check sshd_config file\", \"stat\": {\"path\": \"/etc/ssh/sshd_config\"}, \"register\": \"sshd_config_result\"}, {\"name\": \"add PermitRootLogin option for leapp\", \"lineinfile\": {\"path\": \"/etc/ssh/sshd_config\", \"regexp\": \"^(# *)?PermitRootLogin\", \"line\": \"PermitRootLogin without-password\"}}, {\"name\": \"Remove paunch-services\", \"package\": {\"name\": \"paunch-services\", \"state\": \"absent\"}}, {\"name\": \"tripleo_container_manage reconfiguration\", \"import_role\": {\"name\": \"tripleo_container_manage\", \"tasks_from\": \"shutdown.yml\"}}]}, {\"name\": \"system_upgrade_prepare step 4\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"when\": [\"step|int == 4\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Delete the kernel modules in Leapp database (device_driver_deprecation_data.json)\", \"vars\": {\"modules_to_unload\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_modules_to_unload\"]}}, \"shell\": \"set -o pipefail && jq \'. | del(.data[] | select(.driver_name == \\\"{{ item }}\\\"))\' /etc/leapp/files/device_driver_deprecation_data.json > /etc/leapp/files/device_driver_deprecation_data.json_modified && mv /etc/leapp/files/device_driver_deprecation_data.json_modified /etc/leapp/files/device_driver_deprecation_data.json\\n\", \"loop\": \"{{ modules_to_unload }}\"}, {\"name\": \"Remove leapp actors to prevent them inhibiting the upgrade\", \"vars\": {\"actors_to_remove\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_actors_to_remove\"]}}, \"command\": {\"cmd\": \"find /usr/share/leapp-repository/repositories/ -name {{ item }} -type d -print -exec rm -rf \\\"{}\\\" +\"}, \"loop\": \"{{ actors_to_remove }}\"}, {\"name\": \"set leapp required answers\", \"shell\": \"leapp answer --add --section check_vdo.confirm=True\\n\"}, {\"name\": \"Replace EFI grub.cfg with redirect to /boot/grub2/grub.cfg\", \"import_role\": {\"name\": \"tripleo_kernel\", \"tasks_from\": \"efigrub.yml\"}}, {\"name\": \"Keep nics with prefix in NICsPrefixesToUdev from renaming\", \"vars\": {\"nics_prefixes_to_keep\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nics_prefixes_to_keep\"]}}, \"shell\": \"ip -j link show | \\\\ jq -r --arg prefix \\\"{{ item }}\\\" \'.[] |\\n  select((.ifname | startswith($prefix)) and\\n  (.ifname | test(\\\"^.*v[0-9]*$\\\") | not) and\\n  (.ifname | test(\\\"^.*_[0-9]*$\\\") | not) and\\n  (.ifname | test(\\\"^.*\\\\\\\\..*$\\\") | not)) |\\n  if .permaddr? then .address=.permaddr else . end |\\n  \\\"SUBSYSTEM==\\\\\\\"net\\\\\\\",ACTION==\\\\\\\"add\\\\\\\",DRIVERS==\\\\\\\"?*\\\\\\\",\\\" + \\\"NAME=\\\\\\\"\\\" + .ifname +\\\"\\\\\\\" ,ATTR{address}==\\\\\\\"\\\" + .address + \\\"\\\\\\\"\\\"\' >> /etc/udev/rules.d/70-rhosp-persistent-net.rules\\n\", \"loop\": \"{{ nics_prefixes_to_keep|list }}\"}, {\"name\": \"run leapp upgrade (download packages)\", \"shell\": \"{% if upgrade_leapp_devel_skip|default(false) %}{{ upgrade_leapp_devel_skip }}{% endif %} leapp upgrade {% if upgrade_leapp_debug|default(true) %}--debug{% endif %} {% if upgrade_leapp_command_options|default(false) %}{{ upgrade_leapp_command_options }}{% endif %}\\n\", \"when\": \"upgrade_leapp_enabled\"}]}, {\"name\": \"system_upgrade_run step 4\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_reboot\"], \"when\": [\"step|int == 4\", \"upgrade_leapp_enabled\", \"\'Undercloud\' not in group_names\"], \"block\": [{\"name\": \"Run LeappPreRebootCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"leapp_pre_reboot_command\"]}]]}}, {\"name\": \"Check that nova_libvirt is running\", \"shell\": \"podman ps --filter name=^nova_virtlogd$ --format \\\"{% raw %}{{ .Image }}{% endraw %}\\\"\\n\", \"register\": \"is_virtlogd_image_running\"}, {\"name\": \"Remove systemd files to disable them\", \"file\": {\"path\": \"/etc/systemd/system/{{ item }}\", \"state\": \"absent\"}, \"with_items\": [\"tripleo_nova_libvirt.service\", \"tripleo_nova_virtlogd_wrapper.service\", \"tripleo_nova_libvirt.target\"], \"when\": \"is_virtlogd_image_running.stdout != \'\'\"}, {\"name\": \"reboot to perform the upgrade\", \"reboot\": {\"reboot_timeout\": \"{{upgrade_leapp_reboot_timeout}}\", \"test_command\": \"source /etc/os-release; [ \\\"${VERSION_ID%.*}\\\" -ge \\\"8\\\" ] && systemctl is-system-running | grep -qE \\\"running|degraded\\\" || exit 1\", \"post_reboot_delay\": \"{{ upgrade_leapp_post_reboot_delay }}\"}}, {\"name\": \"Set selinux back to enforcing after leapp reboot\", \"selinux\": {\"policy\": \"targeted\", \"state\": \"enforcing\"}}, {\"name\": \"Run LeappPostRebootCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"leapp_post_reboot_command\"]}]]}}]}, {\"name\": \"Host packages setup step0\", \"tags\": \"setup_packages\", \"when\": \"step|int == 0\", \"block\": [{\"name\": \"Package and repo update tasks\", \"block\": [{\"name\": \"Run UpgradeInitCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", \"if [[ -f /etc/resolv.conf.save ]] ; then rm /etc/resolv.conf.save; fi\\n\\n\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_init_command\"]}]]}}, {\"name\": \"Run UpgradeInitCommonCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", {\"get_param\": \"UpgradeInitCommonCommand\"}]]}}, {\"name\": \"Ensure DNF modules have the right stream\", \"vars\": {\"dnf_module_list\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"dnf_module_list\"]}}, \"dnf\": {\"name\": \"@{{ item.module }}:{{ item.stream }}/{{ item.profile|default(\'common\') }}\", \"state\": \"present\"}, \"loop\": \"{{ dnf_module_list|list }}\", \"when\": [\"dnf_module_list|length > 0\", \"item.distribution_version is defined\", \"ansible_facts[\'distribution_major_version\'] is version(item.distribution_version, \'==\')\"]}, {\"name\": \"Ensure TripleO prerequisite packages are installed\", \"package\": {\"name\": [\"jq\", \"lvm2\", \"openstack-selinux\", \"os-net-config\", \"puppet-tripleo\", \"python3-heat-agent*\", \"rsync\"], \"state\": \"present\"}, \"when\": \"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\"}, {\"name\": \"Ensure TripleO prerequisite packages are installed and use role based heat variable to provide specific list of packages\", \"vars\": {\"base_tripleo_packages\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"base_tripleo_packages\"]}}, \"package\": {\"name\": \"{{ base_tripleo_packages }}\", \"state\": \"present\"}, \"when\": [\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\", \"base_tripleo_packages|length > 0\"]}, {\"name\": \"WA for 2240185 - If the image is schema 1 and lacks signatures than add empty signatures\", \"shell\": \"for manifest_file in `find /var/lib/containers/storage/overlay-images/ -name \'manifest\'`\\ndo\\n    cat <<< $( jq  \'if .schemaVersion == 1 then if has(\\\"signatures\\\") then . else .signatures=[] end else . end\' $manifest_file ) > $manifest_file\\ndone\\n\", \"when\": \"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\"}]}, {\"name\": \"check if libvirt is installed\", \"command\": \"/usr/bin/rpm -q libvirt-daemon\", \"failed_when\": false, \"register\": \"libvirt_installed\", \"check_mode\": false}, {\"name\": \"make sure libvirt services are disabled and masked\", \"service\": {\"name\": \"{{ item }}\", \"state\": \"stopped\", \"enabled\": false, \"masked\": true, \"daemon_reload\": true}, \"loop\": [\"libvirtd.service\", \"virtlogd.socket\"], \"when\": [\"libvirt_installed.rc == 0\"]}]}, {\"name\": \"Host packages setup step2\", \"tags\": \"setup_packages\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Special treatment for OpenvSwitch\", \"tripleo_ovs_upgrade\": null, \"register\": \"ovs_upgrade\"}, {\"name\": \"Always ensure the openvswitch service is enabled and running after upgrades\", \"service\": {\"name\": \"openvswitch\", \"enabled\": true, \"state\": \"started\"}, \"when\": [\"ovs_upgrade.changed|bool\"]}]}, {\"name\": \"Host packages setup step3\", \"tags\": \"setup_packages\", \"when\": \"step|int == 3\", \"block\": [{\"name\": \"Check for os-net-config upgrade\", \"shell\": \"yum check-upgrade | awk \'/os-net-config/{print}\'\", \"register\": \"os_net_config_need_upgrade\"}, {\"name\": \"Check that os-net-config has legacy configuration\", \"stat\": {\"path\": \"/etc/os-net-config/config.json\", \"get_attributes\": false, \"get_checksum\": false, \"get_mime\": false}, \"register\": \"stat_config_json\"}, {\"name\": \"Check that os-net-config has new configuration\", \"stat\": {\"path\": \"/etc/os-net-config/config.yaml\", \"get_attributes\": false, \"get_checksum\": false, \"get_mime\": false}, \"register\": \"stat_config_yaml\"}, {\"name\": \"Slurp the os-net-config config.json\", \"slurp\": {\"src\": \"/etc/os-net-config/config.json\"}, \"register\": \"os_config_json\", \"when\": [\"stat_config_json.stat.exists\", \"not stat_config_yaml.stat.exists\"]}, {\"name\": \"Write updated /etc/os-net-config/config.yaml\", \"copy\": {\"content\": \"{{ os_config_json.content | b64decode | from_json | to_yaml }}\", \"dest\": \"/etc/os-net-config/config.yaml\"}, \"when\": [\"stat_config_json.stat.exists\", \"not stat_config_yaml.stat.exists\"]}, {\"name\": \"Remove legacy os-net-config configuration\", \"command\": \"mv /etc/os-net-config/config.json /etc/os-net-config/deprecated_config.json\", \"when\": [\"stat_config_json.stat.exists\"]}, {\"block\": [{\"name\": \"Upgrade os-net-config\", \"package\": \"name=os-net-config state=latest\"}, {\"name\": \"take new os-net-config parameters into account now\", \"command\": \"os-net-config --no-activate -c /etc/os-net-config/config.yaml -v --detailed-exit-codes\", \"register\": \"os_net_config_upgrade\", \"failed_when\": \"os_net_config_upgrade.rc not in [0,2]\", \"changed_when\": \"os_net_config_upgrade.rc == 2\"}], \"when\": [\"os_net_config_need_upgrade.stdout\", \"stat_config_yaml.stat.exists or stat_config_json.stat.exists\"]}, {\"name\": \"Update all packages\", \"when\": [\"not skip_package_update|bool\"], \"yum\": {\"name\": \"*\", \"state\": \"latest\", \"exclude\": \"ansible-core\"}, \"vars\": {\"skip_package_update\": {\"get_param\": \"SkipPackageUpdate\"}}}, {\"name\": \"Check whether openvswitch exits\", \"command\": \"systemctl status openvswitch.service\", \"register\": \"ovs_service\", \"ignore_errors\": true}, {\"name\": \"Always ensure the openvswitch service is enabled and running after upgrades rhbz#2329821\", \"service\": {\"name\": \"openvswitch\", \"enabled\": true, \"state\": \"started\"}, \"when\": [\"ovs_service.stderr != \\\"Unit openvswitch.service could not be found.\\\"\"]}]}], {\"if\": [\"podman_requires_login\", {\"get_attr\": [\"Podman\", \"role_data\", \"workaround_upgrade_tasks\"]}, []]}]}, \"external_upgrade_tasks\": [{\"name\": \"Clean up upgrade artifacts\", \"when\": \"step|int == 1\", \"tags\": [\"never\", \"system_upgrade_cleanup\"], \"block\": [{\"name\": \"cleanup tripleo_persist\", \"include_role\": {\"name\": \"tripleo_persist\", \"tasks_from\": \"cleanup.yml\"}}]}], \"update_tasks\": [{\"name\": \"Enforce RHOSP rules regarding subscription.\", \"include_role\": {\"name\": \"tripleo_redhat_enforce\"}, \"vars\": {\"skip_rhel_enforcement\": {\"get_param\": \"SkipRhelEnforcement\"}}, \"when\": [\"step|int == 0\", \"ansible_facts[\'distribution\'] == \'RedHat\'\", \"not (skip_rhel_enforcement | bool)\"]}, {\"name\": \"Ensure DNF modules have the right stream enabled\", \"vars\": {\"dnf_module_list\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"dnf_module_list\"]}}, \"tripleo_dnf_stream\": {\"name\": \"{{ item.module }}:{{ item.stream }}\", \"state\": \"enabled\"}, \"loop\": \"{{ dnf_module_list|list }}\", \"when\": [\"step|int == 0\", \"dnf_module_list|length > 0\", \"item.distribution_version is defined\", \"ansible_facts[\'distribution_major_version\'] is version(item.distribution_version, \'==\')\"]}, {\"name\": \"Check for existing yum.pid\", \"stat\": \"path=/run/yum.pid\", \"register\": \"yum_pid_file\", \"when\": \"step|int == 0 or step|int == 3\"}, {\"name\": \"Exit if existing yum process\", \"fail\": \"msg=\\\"ERROR existing yum.pid detected - can\'t continue! Please ensure there is no other package update process for the duration of the minor update worfklow. Exiting.\\\"\", \"when\": \"(step|int == 0 or step|int == 3) and yum_pid_file.stat.exists\"}, {\"name\": \"Special treatment for OpenvSwitch\", \"tripleo_ovs_upgrade\": null, \"when\": [\"step|int == 2\"], \"register\": \"ovs_upgrade\"}, {\"name\": \"Always ensure the openvswitch service is enabled and running after upgrades\", \"service\": {\"name\": \"openvswitch\", \"enabled\": true, \"state\": \"started\"}, \"when\": [\"step|int == 2\", \"ovs_upgrade.changed|bool\"]}, {\"name\": \"Update packages and EFI grub.cfg\", \"when\": [\"step|int == 3\", \"not skip_package_update|bool\"], \"block\": [{\"name\": \"Update all packages\", \"yum\": {\"name\": \"*\", \"state\": \"latest\", \"exclude\": \"ansible-core\"}}, {\"name\": \"Replace EFI grub.cfg with redirect to /boot/grub2/grub.cfg\", \"import_role\": {\"name\": \"tripleo_kernel\", \"tasks_from\": \"efigrub.yml\"}}], \"vars\": {\"skip_package_update\": {\"get_param\": \"SkipPackageUpdate\"}}}, {\"name\": \"Ensure openvswitch is running after update\", \"when\": \"step|int == 3\", \"service\": {\"name\": \"openvswitch\", \"enabled\": true, \"state\": \"started\"}, \"ignore_errors\": true}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(161,'2026-06-12 08:26:14',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configures podman on the host\\n\", \"parameters\": {\"DockerInsecureRegistryAddress\": {\"description\": \"Optional. The IP Address and Port of an insecure docker namespace that will be configured in /etc/sysconfig/docker. The value can be multiple addresses separated by commas.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerImageRegistryLogin\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Flag to enable container registry login actions during the deployment. Setting this to true will cause login calls to be performed during the deployment.\"}, \"ContainerImageRegistryCredentials\": {\"type\": \"json\", \"hidden\": true, \"default\": {}, \"description\": \"Mapping of image registry hosts to login credentials. Must be in the following example format\\n\\n  docker.io:\\n    username: pa55word\\n  \'192.0.2.1:8787\':\\n    registry_username: password\\n\"}, \"ContainerDefaultPidsLimit\": {\"type\": \"number\", \"default\": 4096, \"description\": \"Setting to configure the default pids_limit in /etc/container/container.conf. This is supported starting with podman 2.0.x\"}, \"ContainerDefaultEventsLogger\": {\"type\": \"string\", \"default\": \"journald\", \"description\": \"Setting to configure where podman logs its events. Uses journald by default as that will rotate data stored in tmpfs.\", \"constraints\": [{\"allowed_values\": [\"journald\", \"file\", \"none\"]}]}, \"SystemdDropInDependencies\": {\"default\": true, \"description\": \"tell the tripleo_container_manage to inject additional ordering dependencies for the systemd scopes associated to podman containers.\", \"type\": \"boolean\"}, \"deployment_source_hosts\": {\"default\": \"Undercloud\", \"type\": \"string\", \"description\": \"Host or hostgroup that runs the deployment\"}}, \"conditions\": {\"insecure_registry_is_empty\": {\"equals\": [{\"get_param\": \"DockerInsecureRegistryAddress\"}, []]}, \"systemd_drop_in_dependencies_enabled\": {\"get_param\": \"SystemdDropInDependencies\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the podman service\", \"value\": {\"service_name\": \"podman\", \"config_settings\": {}, \"step_config\": \"\", \"host_prep_tasks\": [{\"name\": \"Install and configure Podman\", \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}, {\"if\": [\"systemd_drop_in_dependencies_enabled\", [{\"name\": \"Configure tripleo_container_manage to generate systemd drop-in dependencies\", \"copy\": {\"dest\": \"/etc/sysconfig/podman_drop_in\", \"content\": \"This file makes tripleo_container_manage generate additional systemd\\ndependencies for containers that have special\\nstart/stop ordering constraints. It ensures that\\nthose constraints are enforced on reboot/shutdown.\\n\"}}], [{\"name\": \"Configure tripleo_container_manage to not generate drop-in dependencies\", \"file\": {\"path\": \"/etc/sysconfig/podman_drop_in\", \"state\": \"absent\"}}]]}], \"deploy_steps_tasks\": [{\"when\": [\"(step|int) == 1\"], \"block\": [{\"name\": \"Pre-fetch all the containers\", \"become\": true, \"containers.podman.podman_image\": {\"name\": \"{{ prefetch_image }}\", \"validate_certs\": false, \"force\": true}, \"register\": \"result\", \"until\": \"result is succeeded\", \"retries\": 5, \"delay\": 5, \"loop_control\": {\"loop_var\": \"prefetch_image\"}, \"loop\": \"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\"}]}], \"service_config_settings\": {}, \"workaround_upgrade_tasks\": [{\"name\": \"Configure Podman registry\", \"when\": [\"step|int == 0\"], \"tags\": [\"setup_packages\"], \"block\": [{\"name\": \"Make sure the Undercloud hostname is included in /etc/hosts\", \"when\": [\"undercloud_hosts_entries is defined\"], \"lineinfile\": {\"dest\": \"/etc/hosts\", \"line\": \"{{ undercloud_hosts_entries | join(\'\') }}\", \"state\": \"present\"}}]}, {\"name\": \"Run podman install\", \"tags\": [\"system_upgrade\", \"system_upgrade_run\", \"setup_packages\"], \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}, {\"name\": \"Comment infra_image in container.conf\", \"lineinfile\": {\"dest\": \"/usr/share/containers/containers.conf\", \"regexp\": \"(?i)^(infra_image.*)\", \"line\": \"#\\\\1\", \"backrefs\": true, \"state\": \"present\"}, \"tags\": [\"setup_packages\"], \"when\": [\"step|int == 0\"]}], \"upgrade_tasks\": [{\"name\": \"Configure Podman registry\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Make sure the Undercloud hostname is included in /etc/hosts\", \"when\": [\"undercloud_hosts_entries is defined\"], \"lineinfile\": {\"dest\": \"/etc/hosts\", \"line\": \"{{ undercloud_hosts_entries | join(\'\') }}\", \"state\": \"present\"}}]}, {\"name\": \"Run podman install\", \"tags\": [\"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}], \"update_tasks\": [{\"name\": \"Force pre-fetch of container images\", \"when\": [\"(step|int) == 5\"], \"block\": [{\"name\": \"Pre-fetch all the containers\", \"become\": true, \"containers.podman.podman_image\": {\"name\": \"{{ prefetch_image }}\", \"validate_certs\": false, \"force\": true}, \"register\": \"result\", \"until\": \"result is succeeded\", \"retries\": 5, \"delay\": 5, \"loop_control\": {\"loop_var\": \"prefetch_image\"}, \"loop\": \"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\"}]}], \"post_upgrade_tasks\": [{\"name\": \"Purge Podman\", \"when\": [\"(step | int) == 3\", \"container_cli == \'podman\'\", \"deployment_source_hosts not in group_names\"], \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_purge.yml\"}, \"vars\": {\"deployment_source_hosts\": {\"get_param\": \"deployment_source_hosts\"}}}], \"post_update_tasks\": [{\"name\": \"Purge Podman\", \"when\": [\"(step | int) == 3\", \"container_cli == \'podman\'\", \"deployment_source_hosts not in group_names\"], \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_purge.yml\"}, \"vars\": {\"deployment_source_hosts\": {\"get_param\": \"deployment_source_hosts\"}}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(162,'2026-06-12 08:26:14',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Nova base service. Shared for all Nova services.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"NovaPassword\": {\"description\": \"The password for the nova service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"1Ii49H1EfmLUfEWsgfy9vla3q\"}, \"NeutronPassword\": {\"description\": \"The password for the neutron service and db account, used by neutron agents.\", \"type\": \"string\", \"hidden\": true, \"default\": \"qnvMdngIoyiS9ntQpzmg868ob\"}, \"PlacementPassword\": {\"description\": \"The password for the Placement service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\"}, \"PlacementAPIInterface\": {\"type\": \"string\", \"description\": \"Endpoint interface to be used for the placement API.\\n\", \"default\": \"internal\"}, \"NovaOVSBridge\": {\"default\": \"br-int\", \"description\": \"Name of integration bridge used by Open vSwitch\", \"type\": \"string\"}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"NovaDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Nova services.\", \"type\": \"boolean\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"EnableConfigPurge\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Remove configuration that is not generated by TripleO. Used to avoid configuration remnants after upgrades.\\n\"}, \"UpgradeLevelNovaCompute\": {\"type\": \"string\", \"description\": \"Nova Compute upgrade level\", \"default\": \"\"}, \"NovaOVSDBConnection\": {\"type\": \"string\", \"description\": \"OVS DB connection string to used by Nova\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaSyncPowerStateInterval\": {\"type\": \"number\", \"description\": \"Interval to sync power states between the database and the hypervisor. Set to -1 to disable. Setting this to 0 will run at the default rate(60) defined in oslo.service.\", \"default\": 600}, \"RpcUseSSL\": {\"default\": false, \"description\": \"Messaging client subscriber parameter to specify an SSL connection to the messaging host.\\n\", \"type\": \"string\"}, \"NovaAdditionalCell\": {\"default\": true, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"NovaCrossAZAttach\": {\"default\": true, \"description\": \"Whether instances can attach cinder volumes from a different availability zone.\", \"type\": \"boolean\"}, \"MemcachedTLS\": {\"default\": false, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"conditions\": {\"compute_upgrade_level_set\": {\"not\": {\"equals\": [{\"get_param\": \"UpgradeLevelNovaCompute\"}, \"\"]}}, \"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"nova::ovsdb_connection\": \"NovaOVSDBConnection\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NovaOVSDBConnection\": {\"get_param\": \"NovaOVSDBConnection\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova base service.\", \"value\": {\"service_name\": \"nova_base\", \"config_settings\": {\"map_merge\": [{\"nova::my_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}}}, \"nova::rabbit_use_ssl\": {\"get_param\": \"RpcUseSSL\"}, \"nova::keystone::service_user::send_service_user_token\": true, \"nova::keystone::service_user::project_name\": \"service\", \"nova::keystone::service_user::password\": {\"get_param\": \"NovaPassword\"}, \"nova::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::placement::project_name\": \"service\", \"nova::placement::password\": {\"get_param\": \"PlacementPassword\"}, \"nova::placement::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::placement::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::placement::valid_interfaces\": {\"get_param\": \"PlacementAPIInterface\"}, \"nova::os_region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::logging::debug\": {\"if\": [{\"get_param\": \"NovaDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"nova::purge_config\": {\"get_param\": \"EnableConfigPurge\"}, \"nova::network::neutron::project_name\": \"service\", \"nova::network::neutron::username\": \"neutron\", \"nova::network::neutron::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::dhcp_domain\": \"\", \"nova::network::neutron::password\": {\"get_param\": \"NeutronPassword\"}, \"nova::network::neutron::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"nova::network::neutron::valid_interfaces\": \"internal\", \"nova::glance::valid_interfaces\": \"internal\", \"nova::rabbit_heartbeat_timeout_threshold\": 60, \"nova::cinder_catalog_info\": \"volumev3:cinderv3:internalURL\", \"nova::host\": \"%{hiera(\'fqdn_canonical\')}\", \"nova::notify_on_state_change\": \"vm_and_task_state\", \"nova::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"nova::notification_format\": \"unversioned\", \"nova::network::neutron::auth_type\": \"v3password\", \"nova::db::database_db_max_retries\": -1, \"nova::db::database_max_retries\": -1, \"nova::network::neutron::ovs_bridge\": {\"get_param\": \"NovaOVSBridge\"}, \"nova::compute::sync_power_state_interval\": {\"get_param\": \"NovaSyncPowerStateInterval\"}, \"nova_is_additional_cell\": {\"get_param\": \"NovaAdditionalCell\"}, \"nova::cross_az_attach\": {\"get_param\": \"NovaCrossAZAttach\"}, \"nova::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"nova::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}, \"nova::cache::backend\": {\"if\": [\"tls_cache_enabled\", \"dogpile.cache.pymemcache\", \"dogpile.cache.memcached\"]}, \"nova::rabbit_heartbeat_in_pthread\": false, \"nova::upgrade_level_compute\": {\"if\": [\"compute_upgrade_level_set\", {\"get_param\": \"UpgradeLevelNovaCompute\"}]}}, {\"get_attr\": [\"RoleParametersValue\", \"value\"]}]}, \"service_config_settings\": {\"rabbitmq\": {\"nova::rabbit_use_ssl\": {\"get_param\": \"RpcUseSSL\"}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(163,'2026-06-12 08:26:15',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configure tuned\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"TunedCustomProfile\": {\"default\": \"\", \"description\": \"The definition of a new tuned profile in INI format which will be named after the TunedProfileName and applied to the host. E.g. if TunedProfileName is \'my_profile\', it creates the file \'/etc/tuned/my_profile/tuned.conf\' on host whose content is the value of TunedCustomProfile, e.g. \\\"[main]\\\\n include=throughput-performance\\\\n[sysctl]\\\\nvm.dirty_ratio=10\\\"\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"TunedProfileName\": {\"default\": \"throughput-performance\", \"description\": \"Tuned Profile to apply to the host\", \"type\": \"string\", \"tags\": [\"role_specific\"]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"tuned_profile\": \"TunedProfileName\", \"tuned_custom_profile\": \"TunedCustomProfile\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"TunedProfileName\": {\"get_param\": \"TunedProfileName\"}, \"TunedCustomProfile\": {\"get_param\": \"TunedCustomProfile\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for tuned\", \"value\": {\"service_name\": \"tuned\", \"host_prep_tasks\": [{\"include_role\": {\"name\": \"tuned\"}}], \"ansible_group_vars\": {\"tuned_profile\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"tuned_profile\"]}, \"tuned_custom_profile\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"tuned_custom_profile\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(164,'2026-06-12 08:26:15',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(165,'2026-06-12 08:26:15',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Neutron base service. Shared for all Neutron agents.\\n\", \"parameters\": {\"DatabaseSyncTimeout\": {\"default\": 900, \"description\": \"DB Sync Timeout default\", \"type\": \"number\"}, \"NeutronDhcpAgentsPerNetwork\": {\"type\": \"number\", \"default\": 0, \"description\": \"The number of neutron dhcp agents to schedule per network\"}, \"DhcpAgentNotification\": {\"default\": false, \"description\": \"Whether or not to enable DHCP agent notifications.\", \"type\": \"boolean\"}, \"NeutronDnsDomain\": {\"type\": \"string\", \"default\": \"openstacklocal\", \"description\": \"Domain to use for building the hostnames.\"}, \"NeutronCorePlugin\": {\"default\": \"ml2\", \"description\": \"The core plugin for Neutron. The value should be the entrypoint to be loaded\\nfrom neutron.core_plugins namespace.\\n\", \"type\": \"string\"}, \"NeutronServicePlugins\": {\"default\": \"qos,ovn-router,trunk,segments,port_forwarding,log\", \"description\": \"Comma-separated list of service plugin entrypoints to be loaded from the\\nneutron.service_plugins namespace.\\n\", \"type\": \"comma_delimited_list\"}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"NeutronDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Neutron services.\", \"type\": \"boolean\"}, \"EnableConfigPurge\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Remove configuration that is not generated by TripleO. Used to avoid configuration remnants after upgrades.\\n\"}, \"NeutronGlobalPhysnetMtu\": {\"type\": \"number\", \"default\": 1350, \"description\": \"MTU of the underlying physical network. Neutron uses this value to\\ncalculate MTU for all virtual network components. For flat and VLAN\\nnetworks, neutron uses this value without modification. For overlay\\nnetworks such as VXLAN, neutron automatically subtracts the overlay\\nprotocol overhead from this value.\\n(If this is not changed TenantNetPhysnetMtu will be used.)\\n\"}, \"TenantNetPhysnetMtu\": {\"type\": \"number\", \"default\": 1500, \"description\": \"MTU of the underlying physical network. Neutron uses this value to\\ncalculate MTU for all virtual network components. For flat and VLAN\\nnetworks, neutron uses this value without modification. For overlay\\nnetworks such as VXLAN, neutron automatically subtracts the overlay\\nprotocol overhead from this value.\\n(The mtu setting of the Tenant network in network_data.yaml\\ncontrol\'s this parameter.)\\n\"}, \"NeutronDBSyncExtraParams\": {\"default\": \"\", \"description\": \"String of extra command line parameters to append to the neutron-db-manage\\nupgrade head command.\\n\", \"type\": \"string\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"EnableVLANTransparency\": {\"default\": false, \"description\": \"If True, then allow plugins that support it to create VLAN transparent networks.\\n\", \"type\": \"boolean\"}, \"NeutronGlobalReportInterval\": {\"default\": 300, \"description\": \"Seconds between nodes reporting state to server; should be less than NeutronAgentDownTime, best if it is half or less than NeutronAgentDownTime.\\n\", \"type\": \"number\"}}, \"conditions\": {\"dhcp_agents_zero\": {\"equals\": [{\"get_param\": \"NeutronDhcpAgentsPerNetwork\"}, 0]}, \"global_physnet_mtu_unset\": {\"equals\": [{\"get_param\": \"NeutronGlobalPhysnetMtu\"}, 0]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Neutron base service.\", \"value\": {\"service_name\": \"neutron_base\", \"config_settings\": {\"map_merge\": [{\"neutron::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"neutron::core_plugin\": {\"get_param\": \"NeutronCorePlugin\"}, \"neutron::service_plugins\": {\"get_param\": \"NeutronServicePlugins\"}, \"neutron::report_interval\": {\"get_param\": \"NeutronGlobalReportInterval\"}, \"neutron::logging::debug\": {\"if\": [{\"get_param\": \"NeutronDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"neutron::purge_config\": {\"get_param\": \"EnableConfigPurge\"}, \"neutron::allow_overlapping_ips\": true, \"neutron::dhcp_agent_notification\": {\"get_param\": \"DhcpAgentNotification\"}, \"neutron::dns_domain\": {\"get_param\": \"NeutronDnsDomain\"}, \"neutron::rabbit_heartbeat_timeout_threshold\": 60, \"neutron::host\": \"%{hiera(\'fqdn_canonical\')}\", \"neutron::db::database_db_max_retries\": -1, \"neutron::db::database_max_retries\": -1, \"neutron::db::sync::db_sync_timeout\": {\"get_param\": \"DatabaseSyncTimeout\"}, \"neutron::global_physnet_mtu\": {\"if\": [\"global_physnet_mtu_unset\", {\"get_param\": \"TenantNetPhysnetMtu\"}, {\"get_param\": \"NeutronGlobalPhysnetMtu\"}]}, \"neutron::db::sync::extra_params\": {\"get_param\": \"NeutronDBSyncExtraParams\"}, \"neutron::vlan_transparent\": {\"get_param\": \"EnableVLANTransparency\"}, \"neutron::rabbit_heartbeat_in_pthread\": false}, {\"if\": [\"dhcp_agents_zero\", {}, {\"tripleo::profile::base::neutron::dhcp_agents_per_network\": {\"get_param\": \"NeutronDhcpAgentsPerNetwork\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(166,'2026-06-12 08:26:16',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Template for nova\'s logging to files\\n\", \"parameters\": {\"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerNovaImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"NovaServiceName\": {\"description\": \"service name\", \"type\": \"string\"}, \"DeployIdentifier\": {\"default\": 1781252715, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}}, \"resources\": {\"InitLogContainerName\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"str_replace\": {\"template\": \"nova_SERVICE_init_log\", \"params\": {\"SERVICE\": {\"get_param\": \"NovaServiceName\"}}}}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerNovaImage\": \"ContainerNovaImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerNovaImage\": {\"get_param\": \"ContainerNovaImage\"}}}]}}}}, \"outputs\": {\"cmd_extra_args\": {\"description\": \"Extra command line arguments for running the service in the container.\", \"value\": \"\"}, \"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/nova:/var/log/nova\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {\"map_replace\": [{\"CONTAINERNAME\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/nova:/var/log/nova:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R nova:nova /var/log/nova\"], \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}, {\"keys\": {\"CONTAINERNAME\": {\"get_attr\": [\"InitLogContainerName\", \"value\"]}}}]}}}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"setype\": \"{{ item.setype }}\", \"state\": \"directory\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/nova\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ContainerNovaImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"NovaServiceName\": \"vncproxy\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (167,'2026-06-12 08:26:19',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Containerized rsyslogd service for purposes of centralized log collection of OpenStack services\' logs.\\n\", \"parameters\": {\"ContainerRsyslogImage\": {\"description\": \"The container image to use for container\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\"}, \"ContainerRsyslogConfigImage\": {\"description\": \"The container image to use for the rsyslog config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"RsyslogReopenOnTruncate\": {\"default\": true, \"description\": \"Rsyslog imfile reopenOnTruncate parameter\", \"type\": \"boolean\"}, \"RsyslogElasticsearchSetting\": {\"default\": {}, \"description\": \"Configuration for rsyslog-elasticsearch plugin\", \"type\": \"json\"}, \"RsyslogElasticsearchTlsCACert\": {\"default\": \"\", \"description\": \"Contains content of the CA cert for the CA that issued Elasticsearch server cert.\", \"type\": \"string\"}, \"RsyslogElasticsearchTlsClientCert\": {\"default\": \"\", \"description\": \"Contains content of the client cert for doing client cert auth against Elasticsearch.\", \"type\": \"string\"}, \"RsyslogElasticsearchTlsClientKey\": {\"default\": \"\", \"description\": \"Contains content of the private key corresponding to the cert RsyslogElasticsearchTlsClientCert.\", \"type\": \"string\"}, \"CloudName\": {\"default\": \"multicell.ooo.test\", \"description\": \"The DNS name of this cloud. E.g. ci-overcloud.tripleo.org\", \"type\": \"string\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"RsyslogAmqp1Setting\": {\"default\": {}, \"description\": \"Configuration for rsyslog-omamqp1 plugin\", \"type\": \"json\"}, \"RsyslogAmqp1Local\": {\"default\": true, \"description\": \"Set to false to disable prefilling host connection value to local QDR in RsyslogAmqp1Setting.\", \"type\": \"boolean\"}, \"MetricsQdrPort\": {\"default\": 5666, \"description\": \"Service name or port number on which the qdrouterd will accept connections.\", \"type\": \"number\"}, \"RsyslogMaxMessageSize\": {\"default\": \"32k\", \"description\": \"Maximum supported message size (both for sending and receiving) for rsyslogd.\", \"type\": \"string\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerRsyslogImage\": \"ContainerRsyslogImage\", \"ContainerRsyslogConfigImage\": \"ContainerRsyslogConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerRsyslogImage\": {\"get_param\": \"ContainerRsyslogImage\"}, \"ContainerRsyslogConfigImage\": {\"get_param\": \"ContainerRsyslogConfigImage\"}}}]}}}}, \"conditions\": {\"use_tls\": {\"not\": {\"and\": [{\"equals\": [{\"get_param\": \"RsyslogElasticsearchTlsCACert\"}, \"\"]}, {\"equals\": [{\"get_param\": \"RsyslogElasticsearchTlsClientCert\"}, \"\"]}, {\"equals\": [{\"get_param\": \"RsyslogElasticsearchTlsClientKey\"}, \"\"]}]}}, \"use_elasticsearch\": {\"not\": {\"equals\": [{\"get_param\": \"RsyslogElasticsearchSetting\"}, {}]}}, \"use_amqp1\": {\"not\": {\"equals\": [{\"get_param\": \"RsyslogAmqp1Setting\"}, {}]}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the rsyslog role.\", \"value\": {\"service_name\": \"rsyslog\", \"config_settings\": {\"map_merge\": [{\"rsyslog::server::global_config\": {\"WorkDirectory\": {\"type\": \"legacy\", \"target\": \"00_rsyslog.conf\", \"value\": \"/var/lib/rsyslog\"}, \"MaxMessageSize\": {\"type\": \"legacy\", \"target\": \"00_rsyslog.conf\", \"value\": {\"get_param\": \"RsyslogMaxMessageSize\"}}}, \"rsyslog::confdir\": \"/etc/rsyslog.d\", \"rsyslog::package_name\": \"rsyslog\", \"rsyslog::package_version\": \"installed\", \"rsyslog::manage_package\": true, \"rsyslog::manage_confdir\": true, \"rsyslog::purge_config_files\": true, \"rsyslog::override_default_config\": true, \"rsyslog::config_file\": \"/etc/rsyslog.conf\", \"rsyslog::manage_service\": true, \"rsyslog::service_name\": \"rsyslog\", \"rsyslog::service_status\": \"running\", \"rsyslog::service_enabled\": true, \"rsyslog::external_service\": false, \"rsyslog::use_upstream_repo\": false, \"rsyslog::feature_packages\": [\"rsyslog-elasticsearch\", \"rsyslog-mmnormalize\"], \"rsyslog::global_config_priority\": 10, \"rsyslog::module_load_priority\": 20, \"rsyslog::input_priority\": 30, \"rsyslog::main_queue_priority\": 40, \"rsyslog::parser_priority\": 45, \"rsyslog::template_priority\": 50, \"rsyslog::filter_priority\": 55, \"rsyslog::action_priority\": 60, \"rsyslog::ruleset_priority\": 65, \"rsyslog::lookup_table_priority\": 70, \"rsyslog::legacy_config_priority\": 80, \"rsyslog::custom_priority\": 90, \"rsyslog::target_file\": \"50_openstack_logs.conf\", \"rsyslog::server::modules\": {\"imfile\": {}, \"omelasticsearch\": {}, \"omamqp1\": {}}, \"rsyslog::server::templates\": {\"rsyslog-node-index\": {\"type\": \"list\", \"list_descriptions\": [{\"constant\": {\"value\": \"%{hiera(\'fqdn_canonical\')}-\"}}, {\"property\": {\"name\": \"timereported\", \"dateFormat\": \"year\"}}, {\"constant\": {\"value\": \".\"}}, {\"property\": {\"name\": \"timereported\", \"dateFormat\": \"month\"}}, {\"constant\": {\"value\": \".\"}}, {\"property\": {\"name\": \"timereported\", \"dateFormat\": \"day\"}}]}, \"rsyslog-record\": {\"type\": \"list\", \"options\": {\"jsonf\": \"on\"}, \"list_descriptions\": [{\"property\": {\"outname\": \"@timestamp\", \"name\": \"timereported\", \"dateFormat\": \"rfc3339\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"host\", \"name\": \"hostname\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"severity\", \"name\": \"syslogseverity\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"facility\", \"name\": \"syslogfacility-text\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"tag\", \"name\": \"syslogtag\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"source\", \"name\": \"app-name\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"message\", \"name\": \"msg\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"file\", \"name\": \"$!metadata!filename\", \"format\": \"jsonf\"}}, {\"constant\": {\"outname\": \"cloud\", \"value\": {\"get_param\": \"CloudName\"}, \"format\": \"jsonf\"}}, {\"constant\": {\"outname\": \"region\", \"value\": {\"get_param\": \"KeystoneRegion\"}, \"format\": \"jsonf\"}}]}}}, {\"if\": [\"use_elasticsearch\", {\"tripleo::profile::base::logging::rsyslog::elasticsearch\": {\"map_merge\": [{\"get_param\": \"RsyslogElasticsearchSetting\"}, {\"template\": \"rsyslog-record\", \"searchIndex\": \"rsyslog-node-index\", \"dynSearchIndex\": \"on\", \"errorfile\": \"/var/log/rsyslog/omelasticsearch.log\"}]}}, {}]}, {\"if\": [\"use_amqp1\", {\"tripleo::profile::base::logging::rsyslog::amqp1\": {\"map_merge\": [{\"get_param\": \"RsyslogAmqp1Setting\"}, {\"template\": \"rsyslog-record\"}, {\"if\": [{\"get_param\": \"RsyslogAmqp1Local\"}, {\"host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}:$PORT\", \"params\": {\"$PORT\": {\"get_param\": \"MetricsQdrPort\"}, \"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}}]}]}}, {}]}, {\"if\": [{\"get_param\": \"RsyslogReopenOnTruncate\"}, {\"tripleo::profile::base::logging::rsyslog::reopen_on_truncate\": \"on\"}, {}]}, {\"if\": [\"use_tls\", {\"tripleo::profile::base::logging::rsyslog::elasticsearch_tls_ca_cert\": {\"get_param\": \"RsyslogElasticsearchTlsCACert\"}, \"tripleo::profile::base::logging::rsyslog::elasticsearch_tls_client_cert\": {\"get_param\": \"RsyslogElasticsearchTlsClientCert\"}, \"tripleo::profile::base::logging::rsyslog::elasticsearch_tls_client_key\": {\"get_param\": \"RsyslogElasticsearchTlsClientKey\"}}]}]}, \"puppet_config\": {\"config_volume\": \"rsyslog\", \"puppet_tags\": \"rsyslog::generate_concat,concat::fragment\", \"step_config\": \"include tripleo::profile::base::logging::rsyslog\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRsyslogConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/rsyslog.json\": {\"command\": \"/usr/sbin/rsyslogd -n -iNONE\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/lib/rsyslog\", \"owner\": \"root:root\", \"recurse\": true}, {\"path\": \"/var/log/rsyslog\", \"owner\": \"root:root\", \"recurse\": true}]}}, \"docker_config\": {\"step_3\": {\"rsyslog\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRsyslogImage\"]}, \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"restart\": \"always\", \"security_opt\": [\"label=disable\"], \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/rsyslog.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/rsyslog:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers:/var/log/containers:ro\", \"/var/log/containers/rsyslog:/var/log/rsyslog:rw,z\", \"/var/log:/var/log/host:ro\", \"/var/lib/rsyslog.container:/var/lib/rsyslog:rw,z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent logs directory for rsyslog\", \"file\": {\"path\": \"/var/log/containers/rsyslog\", \"state\": \"directory\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}}, {\"name\": \"create persistent state directory for rsyslog\", \"file\": {\"path\": \"/var/lib/rsyslog.container\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(168,'2026-06-12 08:26:20',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(169,'2026-06-12 08:26:22',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Composable Timezone service\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"TimeZone\": {\"default\": \"UTC\", \"description\": \"The timezone to be set on the overcloud.\", \"type\": \"string\"}}, \"outputs\": {\"role_data\": {\"description\": \"Timezone role using composable services.\", \"value\": {\"service_name\": \"timezone\", \"host_prep_tasks\": [{\"name\": \"Run timezone role\", \"include_role\": {\"name\": \"tripleo_timezone\"}, \"vars\": {\"tripleo_timezone\": {\"get_param\": \"TimeZone\"}}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(171,'2026-06-12 08:26:23',NULL,'{\"heat_template_version\": \"2015-04-30\", \"resources\": {\"0\": {\"type\": \"OS::TripleO::Compute\", \"properties\": {\"CloudDomain\": \"ooo.test\", \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"Hostname\": \"cell1-compute-0\", \"NodeIndex\": \"0\", \"ComputeSchedulerHints\": {}, \"ServiceNames\": [\"boot_params_service\", \"ca_certs\", \"collectd\", \"ceilometer_agent_compute\", \"ceilometer_agent_ipmi\", \"iscsid\", \"kernel\", \"metrics_qdr\", \"mysql_client\", \"nova_compute\", \"nova_libvirt\", \"nova_libvirt_guests\", \"nova_migration_target\", \"logrotate_crond\", \"podman\", \"rsyslog\", \"snmp\", \"sshd\", \"chrony\", \"timezone\", \"tripleo_firewall\", \"tripleo_packages\", \"tuned\", \"ovn_controller\", \"ovn_metadata\"], \"OVNBridgeMappings\": [\"datacentre:br-ex\"], \"DeploymentServerBlacklistDict\": {}, \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"UserData\": \"e6c7f922-11d5-4ad5-b28d-5383f2775679\"}}}, \"outputs\": {\"attributes, nova_server_resource\": {\"value\": {\"0\": {\"get_attr\": [\"0\", \"nova_server_resource\"]}}}, \"storage_ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"storage_ip_address\"]}]}, \"blacklist_ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"blacklist_ip_address\"]}]}, \"internal_api_ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"internal_api_ip_address\"]}]}, \"blacklist_hostname\": {\"value\": [{\"get_attr\": [\"0\", \"blacklist_hostname\"]}]}, \"hostname_map\": {\"value\": [{\"get_attr\": [\"0\", \"hostname_map\"]}]}, \"tenant_ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"tenant_ip_address\"]}]}, \"nova_server_resource\": {\"value\": [{\"get_attr\": [\"0\", \"nova_server_resource\"]}]}, \"ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"ip_address\"]}]}, \"hostname\": {\"value\": [{\"get_attr\": [\"0\", \"hostname\"]}]}, \"hosts_entry\": {\"value\": [{\"get_attr\": [\"0\", \"hosts_entry\"]}]}, \"ansible_host_vars_map\": {\"value\": [{\"get_attr\": [\"0\", \"ansible_host_vars_map\"]}]}, \"refs_map\": {\"value\": {\"0\": {\"get_resource\": \"0\"}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(172,'2026-06-12 08:26:24',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Compute node configured by Puppet\", \"parameters\": {\"OvercloudComputeFlavor\": {\"description\": \"Flavor for the Compute node.\", \"default\": \"baremetal\", \"type\": \"string\"}, \"NovaImage\": {\"type\": \"string\", \"default\": \"overcloud-full\", \"description\": \"DEPRECATED Use ComputeImage instead\"}, \"ComputeImage\": {\"type\": \"string\", \"default\": \"overcloud-full\", \"description\": \"The disk image file to use for the role.\"}, \"ImageUpdatePolicy\": {\"default\": \"REBUILD_PRESERVE_EPHEMERAL\", \"description\": \"What policy to use when reconstructing instances. REBUILD for rebuilds, REBUILD_PRESERVE_EPHEMERAL to preserve /mnt.\", \"type\": \"string\"}, \"KeyName\": {\"description\": \"Name of an existing Nova key pair to enable SSH access to the instances\", \"type\": \"string\", \"default\": \"default\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"UpdateIdentifier\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Setting to a previously unused value during stack-update will trigger package update on all nodes\\n\"}, \"Hostname\": {\"type\": \"string\", \"default\": \"\"}, \"HostnameMap\": {\"type\": \"json\", \"default\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"description\": \"Optional mapping to override hostnames\"}, \"ComputeIPs\": {\"default\": {}, \"type\": \"json\"}, \"NovaComputeIPs\": {\"default\": {}, \"description\": \"DEPRECATED - use ComputeIPs instead\", \"type\": \"json\"}, \"SoftwareConfigTransport\": {\"default\": \"POLL_SERVER_HEAT\", \"description\": \"How the server should receive the metadata required for software configuration.\\n\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"POLL_SERVER_CFN\", \"POLL_SERVER_HEAT\", \"POLL_TEMP_URL\", \"ZAQAR_MESSAGE\"]}]}, \"CloudDomain\": {\"default\": \"ooo.test\", \"type\": \"string\", \"description\": \"The DNS domain used for the hosts. This must match the overcloud_domain_name configured on the undercloud.\\n\"}, \"ComputeServerMetadata\": {\"default\": {}, \"description\": \"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API. This option is role-specific and is merged with the values given to the ServerMetadata parameter.\\n\", \"type\": \"json\"}, \"NovaComputeServerMetadata\": {\"default\": {}, \"description\": \"DEPRECATED - use ComputeServerMetadata instead\", \"type\": \"json\"}, \"ServerMetadata\": {\"default\": {}, \"description\": \"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API. This applies to all roles and is merged with a role-specific metadata parameter.\\n\", \"type\": \"json\"}, \"ComputeSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"NodeIndex\": {\"type\": \"number\", \"default\": 0}, \"ServiceNames\": {\"type\": \"comma_delimited_list\", \"default\": []}, \"MonitoringSubscriptions\": {\"type\": \"comma_delimited_list\", \"default\": []}, \"ServiceMetadataSettings\": {\"type\": \"json\", \"default\": {}}, \"OVNBridgeMappings\": {\"type\": \"comma_delimited_list\", \"default\": []}, \"ConfigCommand\": {\"type\": \"string\", \"description\": \"Command which will be run whenever configuration data changes\", \"default\": \"os-refresh-config --timeout 14400\"}, \"ConfigCollectSplay\": {\"type\": \"number\", \"default\": 30, \"description\": \"Maximum amount of time to possibly to delay configuration collection\\npolling. Defaults to 30 seconds. Set to 0 to disable it which will cause\\nthe configuration collection to occur as soon as the collection process\\nstarts.  This setting is used to prevent the configuration collection\\nprocesses from polling all at the exact same time.\\n\"}, \"UpgradeInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\ninitialize the upgrade process. E.g. a repository switch.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeInitCommonCommand\": {\"type\": \"string\", \"description\": \"Common commands required by the upgrades process. This should not\\nnormally be modified by the operator and is set and unset in the\\nmajor-upgrade-composable-steps.yaml and major-upgrade-converge.yaml\\nenvironment files.\\n\", \"default\": \"\"}, \"DeploymentServerBlacklistDict\": {\"default\": {}, \"type\": \"json\", \"description\": \"Map of server hostnames to blacklist from any triggered deployments. If the value is 1, the server will be blacklisted. This parameter is generated from the parent template.\\n\"}, \"RoleParameters\": {\"type\": \"json\", \"description\": \"Parameters specific to the role\", \"default\": {}}, \"ComputeControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ServerDeletionPolicy\": {\"description\": \"Whether to retain or delete servers on deletion of the stack\", \"type\": \"string\", \"default\": \"delete\", \"constraints\": [{\"allowed_values\": [\"delete\", \"retain\"]}]}, \"UserData\": {\"type\": \"string\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"Do not use deprecated params, they will be removed.\", \"parameters\": [\"NovaImage\", \"NovaComputeServerMetadata\", \"NovaComputeIPs\"]}], \"conditions\": {\"server_blacklisted\": {\"or\": [{\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": \"Hostname\"}]}, 1]}, {\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": [\"HostnameMap\", {\"get_param\": \"Hostname\"}]}]}, 1]}]}, \"server_not_blacklisted\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": \"Hostname\"}]}, 1]}}, {\"not\": {\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": [\"HostnameMap\", {\"get_param\": \"Hostname\"}]}]}, 1]}}]}, \"deprecated_param_image_set\": {\"not\": {\"equals\": [{\"get_param\": \"NovaImage\"}, \"overcloud-full\"]}}, \"ctlplane_fixed_ip_set\": {\"or\": [{\"not\": {\"equals\": [{\"get_param\": [\"ComputeIPs\", \"ctlplane\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, {\"not\": {\"equals\": [{\"get_param\": [\"NovaComputeIPs\", \"ctlplane\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, false]}, \"Compute_Storage_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"ComputeIPs\", \"storage\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, \"Compute_InternalApi_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"ComputeIPs\", \"internal_api\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, \"Compute_Tenant_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"ComputeIPs\", \"tenant\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}}, \"resources\": {\"NovaCompute\": {\"type\": \"OS::TripleO::ComputeServer\", \"deletion_policy\": {\"get_param\": \"ServerDeletionPolicy\"}, \"properties\": {\"image\": {\"if\": [\"deprecated_param_image_set\", {\"get_param\": \"NovaImage\"}, {\"get_param\": \"ComputeImage\"}]}, \"image_update_policy\": {\"get_param\": \"ImageUpdatePolicy\"}, \"flavor\": {\"get_param\": \"OvercloudComputeFlavor\"}, \"key_name\": {\"get_param\": \"KeyName\"}, \"networks\": [{\"if\": [\"ctlplane_fixed_ip_set\", {\"network\": \"ctlplane\", \"subnet\": {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"fixed_ip\": {\"yaql\": {\"expression\": \"$.data.where(not isEmpty($)).first()\", \"data\": [{\"get_param\": [\"ComputeIPs\", \"ctlplane\", {\"get_param\": \"NodeIndex\"}]}, {\"get_param\": [\"NovaComputeIPs\", \"ctlplane\", {\"get_param\": \"NodeIndex\"}]}]}}}, {\"network\": \"ctlplane\", \"subnet\": {\"get_param\": \"ComputeControlPlaneSubnet\"}}]}], \"user_data_format\": \"SOFTWARE_CONFIG\", \"user_data\": {\"get_param\": \"UserData\"}, \"name\": {\"yaql\": {\"expression\": \"$.data.hostname_map.get($.data.hostname, $.data.hostname).toLower()\", \"data\": {\"hostname\": {\"get_param\": \"Hostname\"}, \"hostname_map\": {\"get_param\": \"HostnameMap\"}}}}, \"software_config_transport\": {\"get_param\": \"SoftwareConfigTransport\"}, \"metadata\": {\"map_merge\": [{\"get_param\": \"ServerMetadata\"}, {\"get_param\": \"NovaComputeServerMetadata\"}, {\"get_param\": \"ComputeServerMetadata\"}, {\"get_param\": \"ServiceMetadataSettings\"}]}, \"scheduler_hints\": {\"get_param\": \"ComputeSchedulerHints\"}}}, \"StoragePort\": {\"type\": \"OS::TripleO::Compute::Ports::StoragePort\", \"properties\": {\"PortName\": {\"list_join\": [\"_\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"Storage\"]]}, \"DnsName\": {\"get_attr\": [\"NovaCompute\", \"name\"]}, \"ControlPlaneIP\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"FixedIPs\": {\"if\": [\"Compute_Storage_fixed_ip_set\", [{\"ip_address\": {\"get_param\": [\"ComputeIPs\", \"storage\", {\"get_param\": \"NodeIndex\"}]}}], [{\"subnet\": \"storage_subnet\"}]]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"NovaCompute\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"IPPool\": {\"map_merge\": [{\"get_param\": \"NovaComputeIPs\"}, {\"get_param\": \"ComputeIPs\"}]}, \"NodeIndex\": {\"get_param\": \"NodeIndex\"}, \"Role\": \"Compute\"}}, \"InternalApiPort\": {\"type\": \"OS::TripleO::Compute::Ports::InternalApiPort\", \"properties\": {\"PortName\": {\"list_join\": [\"_\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"InternalApi\"]]}, \"DnsName\": {\"get_attr\": [\"NovaCompute\", \"name\"]}, \"ControlPlaneIP\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"FixedIPs\": {\"if\": [\"Compute_InternalApi_fixed_ip_set\", [{\"ip_address\": {\"get_param\": [\"ComputeIPs\", \"internal_api\", {\"get_param\": \"NodeIndex\"}]}}], [{\"subnet\": \"internal_api_subnet\"}]]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"NovaCompute\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"IPPool\": {\"map_merge\": [{\"get_param\": \"NovaComputeIPs\"}, {\"get_param\": \"ComputeIPs\"}]}, \"NodeIndex\": {\"get_param\": \"NodeIndex\"}, \"Role\": \"Compute\"}}, \"TenantPort\": {\"type\": \"OS::TripleO::Compute::Ports::TenantPort\", \"properties\": {\"PortName\": {\"list_join\": [\"_\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"Tenant\"]]}, \"DnsName\": {\"get_attr\": [\"NovaCompute\", \"name\"]}, \"ControlPlaneIP\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"FixedIPs\": {\"if\": [\"Compute_Tenant_fixed_ip_set\", [{\"ip_address\": {\"get_param\": [\"ComputeIPs\", \"tenant\", {\"get_param\": \"NodeIndex\"}]}}], [{\"subnet\": \"tenant_subnet\"}]]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"NovaCompute\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"IPPool\": {\"map_merge\": [{\"get_param\": \"NovaComputeIPs\"}, {\"get_param\": \"ComputeIPs\"}]}, \"NodeIndex\": {\"get_param\": \"NodeIndex\"}, \"Role\": \"Compute\"}}, \"NetIpMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpMap\", \"properties\": {\"ControlPlaneIp\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"NovaCompute\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"StorageIp\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageIpSubnet\": {\"get_attr\": [\"StoragePort\", \"ip_subnet\"]}, \"StorageIpUri\": {\"get_attr\": [\"StoragePort\", \"ip_address_uri\"]}, \"InternalApiIp\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiIpSubnet\": {\"get_attr\": [\"InternalApiPort\", \"ip_subnet\"]}, \"InternalApiIpUri\": {\"get_attr\": [\"InternalApiPort\", \"ip_address_uri\"]}, \"TenantIp\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantIpSubnet\": {\"get_attr\": [\"TenantPort\", \"ip_subnet\"]}, \"TenantIpUri\": {\"get_attr\": [\"TenantPort\", \"ip_address_uri\"]}}}, \"NetHostMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"storage\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"storage\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"storage\"]]}}, \"internal_api\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"internalapi\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"internalapi\"]]}}, \"tenant\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"tenant\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"tenant\"]]}}, \"ctlplane\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"ctlplane\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"ctlplane\"]]}}, \"canonical\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, {\"get_param\": \"CloudDomain\"}]]}, \"short\": [{\"get_attr\": [\"NovaCompute\", \"name\"]}]}}}}, \"PreNetworkConfig\": {\"type\": \"OS::TripleO::Compute::PreNetworkConfig\", \"condition\": \"server_not_blacklisted\", \"properties\": {\"server\": {\"get_resource\": \"NovaCompute\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"ServiceNames\": {\"get_param\": \"ServiceNames\"}, \"deployment_actions\": {\"get_attr\": [\"DeploymentActions\", \"value\"]}}}, \"NodeTLSCAData\": {\"type\": \"OS::TripleO::NodeTLSCAData\", \"properties\": {\"server\": {\"get_resource\": \"NovaCompute\"}}}, \"ComputeExtraConfigPre\": {\"type\": \"OS::TripleO::ComputeExtraConfigPre\", \"condition\": \"server_not_blacklisted\", \"properties\": {\"server\": {\"get_resource\": \"NovaCompute\"}}}, \"NodeExtraConfig\": {\"depends_on\": [\"ComputeExtraConfigPre\", \"NodeTLSCAData\"], \"type\": \"OS::TripleO::NodeExtraConfig\", \"condition\": \"server_not_blacklisted\", \"properties\": {\"server\": {\"get_resource\": \"NovaCompute\"}}}, \"DeploymentActions\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"if\": [\"server_not_blacklisted\", [\"CREATE\", \"UPDATE\"], []]}}}, \"NovaComputeAnsibleHostVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"fqdn_storage\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"fqdn\"]}, \"fqdn_internal_api\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"fqdn\"]}, \"fqdn_tenant\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"fqdn\"]}, \"fqdn_ctlplane\": {\"get_attr\": [\"NetHostMap\", \"value\", \"ctlplane\", \"fqdn\"]}, \"fqdn_canonical\": {\"get_attr\": [\"NetHostMap\", \"value\", \"canonical\", \"fqdn\"]}, \"hostname_resolve_network\": {\"get_param\": [\"ServiceNetMap\", \"ComputeHostnameResolveNetwork\"]}}}}}, \"outputs\": {\"ansible_host_vars_map\": {\"description\": \"Map of Ansible variables specific per host.\\nThis map is used to construct the AnsibleHostVarsMap output for the\\nansible vars per host in config-download.\\n\", \"value\": {\"map_replace\": [{\"host\": {\"get_attr\": [\"NovaComputeAnsibleHostVars\", \"value\"]}}, {\"keys\": {\"host\": {\"get_attr\": [\"NovaCompute\", \"name\"]}}}]}}, \"ip_address\": {\"description\": \"IP address of the server in the ctlplane network\", \"value\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}}, \"blacklist_ip_address\": {\"description\": \"IP address of the server if the server is blacklisted, otherwise this output will be an empty string\", \"value\": {\"if\": [\"server_blacklisted\", {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"\"]}}, \"blacklist_hostname\": {\"description\": \"Hostname of the server if the server is blacklisted, otherwise this output will be an empty string\", \"value\": {\"if\": [\"server_blacklisted\", {\"get_attr\": [\"NovaCompute\", \"name\"]}, \"\"]}}, \"hostname\": {\"description\": \"Hostname of the server\", \"value\": {\"get_attr\": [\"NovaCompute\", \"name\"]}}, \"hostname_map\": {\"description\": \"Mapping of network names to hostnames\", \"value\": {\"storage\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"fqdn\"]}, \"internal_api\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"fqdn\"]}, \"tenant\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"fqdn\"]}, \"ctlplane\": {\"get_attr\": [\"NetHostMap\", \"value\", \"ctlplane\", \"fqdn\"]}, \"canonical\": {\"get_attr\": [\"NetHostMap\", \"value\", \"canonical\", \"fqdn\"]}}}, \"hosts_entry\": {\"value\": [{\"str_replace\": {\"template\": \"PRIMARYIP PRIMARYHOST.DOMAIN PRIMARYHOST\", \"params\": {\"PRIMARYIP\": {\"get_attr\": [\"NetIpMap\", \"net_ip_map\", {\"get_param\": [\"ServiceNetMap\", \"ComputeHostnameResolveNetwork\"]}]}, \"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"PRIMARYHOST\": {\"get_attr\": [\"NovaCompute\", \"name\"]}}}}, {\"str_replace\": {\"template\": \"StorageIP StorageHOST.DOMAIN StorageHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"StorageIP\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"short\"]}, \"InternalApiIP\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"short\"]}, \"TenantIP\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"short\"]}}}}, {\"str_replace\": {\"template\": \"InternalApiIP InternalApiHOST.DOMAIN InternalApiHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"StorageIP\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"short\"]}, \"InternalApiIP\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"short\"]}, \"TenantIP\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"short\"]}}}}, {\"str_replace\": {\"template\": \"TenantIP TenantHOST.DOMAIN TenantHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"StorageIP\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"short\"]}, \"InternalApiIP\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"short\"]}, \"TenantIP\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"short\"]}}}}, {\"str_replace\": {\"template\": \"CTLPLANEIP CTLPLANEHOST.DOMAIN CTLPLANEHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"CTLPLANEIP\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"CTLPLANEHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"ctlplane\", \"short\"]}}}}]}, \"nova_server_resource\": {\"description\": \"Heat resource handle for Compute server\", \"value\": {\"get_resource\": \"NovaCompute\"}, \"condition\": \"server_not_blacklisted\"}, \"deployed_server_port_map\": {\"description\": \"Map of Heat created hostname of the server to ip address. This is the\\nhostname before it has been mapped with the HostnameMap parameter, and\\nthe IP address from the ctlplane network. This map can be used to construct\\nthe DeployedServerPortMap parameter when using split-stack.\\n\", \"value\": {\"map_replace\": [{\"hostname\": {\"fixed_ips\": [{\"ip_address\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}}], \"subnets\": [{\"cidr\": {\"get_attr\": [\"NovaCompute\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}}]}}, {\"keys\": {\"hostname\": {\"list_join\": [\"-\", [{\"get_param\": \"Hostname\"}, \"ctlplane\"]]}}}]}}, \"storage_ip_address\": {\"description\": \"IP address of the server in the Storage network\", \"value\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}}, \"internal_api_ip_address\": {\"description\": \"IP address of the server in the InternalApi network\", \"value\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}}, \"tenant_ip_address\": {\"description\": \"IP address of the server in the Tenant network\", \"value\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"Hostname\": \"cell1-compute-0\", \"CloudDomain\": \"ooo.test\", \"ComputeSchedulerHints\": {}, \"NodeIndex\": 0, \"ServiceNames\": \"boot_params_service,ca_certs,collectd,ceilometer_agent_compute,ceilometer_agent_ipmi,iscsid,kernel,metrics_qdr,mysql_client,nova_compute,nova_libvirt,nova_libvirt_guests,nova_migration_target,logrotate_crond,podman,rsyslog,snmp,sshd,chrony,timezone,tripleo_firewall,tripleo_packages,tuned,ovn_controller,ovn_metadata\", \"OVNBridgeMappings\": \"datacentre:br-ex\", \"DeploymentServerBlacklistDict\": {}, \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"UserData\": \"e6c7f922-11d5-4ad5-b28d-5383f2775679\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(173,'2026-06-12 08:26:24',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\", \"default\": \"cell1\"}, \"image\": {\"type\": \"string\", \"default\": \"unused\"}, \"flavor\": {\"type\": \"string\", \"default\": \"unused\"}, \"key_name\": {\"type\": \"string\", \"default\": \"unused\", \"description\": \"Name of keypair to assign to servers\"}, \"security_groups\": {\"type\": \"json\", \"default\": []}, \"user_data_format\": {\"type\": \"string\"}, \"user_data\": {\"type\": \"string\", \"default\": \"\"}, \"name\": {\"type\": \"string\", \"default\": \"deployed-server\"}, \"image_update_policy\": {\"type\": \"string\", \"default\": \"\"}, \"networks\": {\"type\": \"comma_delimited_list\", \"default\": \"\"}, \"metadata\": {\"type\": \"json\", \"default\": {}}, \"software_config_transport\": {\"default\": \"POLL_SERVER_CFN\", \"type\": \"string\"}, \"scheduler_hints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"UpgradeInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\ninitialize the upgrade process. E.g. a repository switch.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeInitCommonCommand\": {\"type\": \"string\", \"description\": \"Common commands required by the upgrades process. This should not\\nnormally be modified by the operator and is set and unset in the\\nmajor-upgrade-composable-steps.yaml and major-upgrade-converge.yaml\\nenvironment files.\\n\", \"default\": \"\"}, \"ControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"The name of the undercloud Neutron control plane subnet\", \"type\": \"string\"}}, \"resources\": {\"deployed-server\": {\"type\": \"OS::Heat::DeployedServer\", \"properties\": {\"name\": {\"get_param\": \"name\"}, \"software_config_transport\": {\"get_param\": \"software_config_transport\"}}}, \"ControlPlanePort\": {\"type\": \"OS::TripleO::DeployedServer::ControlPlanePort\", \"properties\": {\"network\": \"ctlplane\", \"fixed_ips\": [{\"subnet\": {\"get_param\": \"ControlPlaneSubnet\"}}], \"name\": {\"list_join\": [\"-\", [{\"get_param\": \"name\"}, \"ctlplane\"]]}, \"replacement_policy\": \"AUTO\", \"tags\": [{\"str_replace\": {\"template\": \"tripleo_stack_name=$STACK_NAME\", \"params\": {\"$STACK_NAME\": {\"get_param\": \"RootStackName\"}}}}]}}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"deployed-server\"}}, \"networks\": {\"value\": {\"ctlplane\": [{\"get_attr\": [\"ControlPlanePort\", \"fixed_ips\", 0, \"ip_address\"]}]}}, \"addresses\": {\"value\": {\"ctlplane\": [{\"subnets\": {\"get_attr\": [\"ControlPlanePort\", \"subnets\"]}}]}}, \"name\": {\"value\": {\"get_param\": \"name\"}}, \"os_collect_config\": {\"value\": {\"get_attr\": [\"deployed-server\", \"os_collect_config\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"image\": \"overcloud-full\", \"flavor\": \"baremetal\", \"key_name\": \"default\", \"user_data_format\": \"SOFTWARE_CONFIG\", \"user_data\": \"e6c7f922-11d5-4ad5-b28d-5383f2775679\", \"name\": \"np0000071539\", \"image_update_policy\": \"REBUILD_PRESERVE_EPHEMERAL\", \"networks\": \".member.0.network=ctlplane,.member.0.subnet=ctlplane-subnet\", \"metadata\": {}, \"software_config_transport\": \"POLL_SERVER_HEAT\", \"scheduler_hints\": {}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(174,'2026-06-12 08:26:25',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \" A fake OS::Neutron::Port stack which outputs fixed_ips and subnets based on the input from the DeployedServerPortMap (set via parameter_defaults). This lookup requires the use of port naming conventions. In order for this to work with deployed-server the keys should be <hostname>-<network>. Example: parameter_defaults: DeployedServerPortMap: gatsby-ctlplane: fixed_ips: - ip_address: 127.0.0.1 subnets: - cidr: 127.0.0.0/24 network: tags: - 127.0.0.0/24\", \"parameters\": {\"name\": {\"default\": \"\", \"type\": \"string\"}, \"dns_name\": {\"default\": \"\", \"type\": \"string\"}, \"network\": {\"default\": \"\", \"type\": \"string\"}, \"fixed_ips\": {\"default\": \"\", \"type\": \"comma_delimited_list\"}, \"replacement_policy\": {\"default\": \"\", \"type\": \"string\"}, \"tags\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"DeployedServerPortMap\": {\"default\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"type\": \"json\"}, \"IsVirtualIP\": {\"default\": false, \"type\": \"boolean\"}, \"Role\": {\"description\": \"The TripleO Role Name\\n\", \"type\": \"string\", \"default\": \"\"}}, \"outputs\": {\"fixed_ips\": {\"value\": {\"get_param\": [\"DeployedServerPortMap\", {\"get_param\": \"name\"}, \"fixed_ips\"]}}, \"subnets\": {\"value\": {\"get_param\": [\"DeployedServerPortMap\", {\"get_param\": \"name\"}, \"subnets\"]}}, \"network\": {\"value\": {\"get_param\": [\"DeployedServerPortMap\", {\"get_param\": \"name\"}, \"network\"]}}, \"name\": {\"value\": {\"get_param\": \"name\"}}, \"status\": {\"value\": \"DOWN\"}, \"allowed_address_pairs\": {\"value\": {}}, \"device_id\": {\"value\": \"\"}, \"device_owner\": {\"value\": {\"get_param\": \"network\"}}, \"dns_assignment\": {\"value\": \"\"}, \"port_security_enabled\": {\"value\": false}, \"admin_state_up\": {\"value\": false}, \"security_groups\": {\"value\": {}}, \"network_id\": {\"value\": \"\"}, \"tenant_id\": {\"value\": \"\"}, \"qos_policy_id\": {\"value\": \"\"}, \"mac_address\": {\"value\": \"\"}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"name\": \"np0000071539-ctlplane\", \"network\": \"ctlplane\", \"fixed_ips\": \".member.0.subnet=ctlplane-subnet\", \"replacement_policy\": \"AUTO\", \"tags\": \"tripleo_stack_name=cell1\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(175,'2026-06-12 08:26:27',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed port on the Storage network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"NodePortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"type\": \"json\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"DefaultRoute\": {\"description\": \"Whether this interface is used for the default route\\n\", \"type\": \"boolean\", \"default\": false}, \"Role\": {\"description\": \"The TripleO Role Name\\n\", \"type\": \"string\", \"default\": \"\"}}, \"resources\": {\"StorageDeployedPort\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ip_address\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"storage\", \"ip_address\"]}, \"ip_address_uri\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"storage\", \"ip_address_uri\"]}, \"ip_subnet\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"storage\", \"ip_subnet\"]}}}}}, \"outputs\": {\"ip_address\": {\"description\": \"Storage network IP\", \"value\": {\"get_attr\": [\"StorageDeployedPort\", \"value\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"Storage network IP (with brackets for IPv6 URLs)\", \"value\": {\"get_attr\": [\"StorageDeployedPort\", \"value\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the Storage network IP\", \"value\": {\"get_attr\": [\"StorageDeployedPort\", \"value\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"np0000071539_Storage\", \"DnsName\": \"np0000071539\", \"ControlPlaneIP\": \"192.168.122.107\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"storage_subnet\\\"}]\", \"IPPool\": {}, \"NodeIndex\": 0, \"Role\": \"Compute\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(176,'2026-06-12 08:26:28',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed port on the Tenant network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"NodePortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"type\": \"json\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"DefaultRoute\": {\"description\": \"Whether this interface is used for the default route\\n\", \"type\": \"boolean\", \"default\": false}, \"Role\": {\"description\": \"The TripleO Role Name\\n\", \"type\": \"string\", \"default\": \"\"}}, \"resources\": {\"TenantDeployedPort\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ip_address\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"tenant\", \"ip_address\"]}, \"ip_address_uri\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"tenant\", \"ip_address_uri\"]}, \"ip_subnet\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"tenant\", \"ip_subnet\"]}}}}}, \"outputs\": {\"ip_address\": {\"description\": \"Tenant network IP\", \"value\": {\"get_attr\": [\"TenantDeployedPort\", \"value\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"Tenant network IP (with brackets for IPv6 URLs)\", \"value\": {\"get_attr\": [\"TenantDeployedPort\", \"value\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the Tenant network IP\", \"value\": {\"get_attr\": [\"TenantDeployedPort\", \"value\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"np0000071539_Tenant\", \"DnsName\": \"np0000071539\", \"ControlPlaneIP\": \"192.168.122.107\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"tenant_subnet\\\"}]\", \"IPPool\": {}, \"NodeIndex\": 0, \"Role\": \"Compute\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (177,'2026-06-12 08:26:28',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Noop Extra Pre-Deployment Config\", \"parameters\": {\"server\": {\"type\": \"string\"}}, \"outputs\": {\"deploy_stdout\": {\"value\": \"None\"}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"server\": \"9c74e5b3-24cc-4b92-a048-87963237f199\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(178,'2026-06-12 08:26:28',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed port on the InternalApi network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"NodePortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"type\": \"json\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"DefaultRoute\": {\"description\": \"Whether this interface is used for the default route\\n\", \"type\": \"boolean\", \"default\": false}, \"Role\": {\"description\": \"The TripleO Role Name\\n\", \"type\": \"string\", \"default\": \"\"}}, \"resources\": {\"InternalApiDeployedPort\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ip_address\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"internal_api\", \"ip_address\"]}, \"ip_address_uri\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"internal_api\", \"ip_address_uri\"]}, \"ip_subnet\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"internal_api\", \"ip_subnet\"]}}}}}, \"outputs\": {\"ip_address\": {\"description\": \"InternalApi network IP\", \"value\": {\"get_attr\": [\"InternalApiDeployedPort\", \"value\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"InternalApi network IP (with brackets for IPv6 URLs)\", \"value\": {\"get_attr\": [\"InternalApiDeployedPort\", \"value\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the InternalApi network IP\", \"value\": {\"get_attr\": [\"InternalApiDeployedPort\", \"value\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"np0000071539_InternalApi\", \"DnsName\": \"np0000071539\", \"ControlPlaneIP\": \"192.168.122.107\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"internal_api_subnet\\\"}]\", \"IPPool\": {}, \"NodeIndex\": 0, \"Role\": \"Compute\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(179,'2026-06-12 08:26:29',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Noop Extra Pre-Deployment Config\", \"parameters\": {\"server\": {\"type\": \"string\"}}, \"outputs\": {\"deploy_stdout\": {\"value\": \"None\"}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"server\": \"9c74e5b3-24cc-4b92-a048-87963237f199\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(180,'2026-06-12 08:26:29',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIp\": {\"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"StorageIp\": {\"default\": \"\", \"type\": \"string\"}, \"StorageIpSubnet\": {\"description\": \"IP address/subnet on the storage network\", \"default\": \"\", \"type\": \"string\"}, \"StorageIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIp\": {\"default\": \"\", \"type\": \"string\"}, \"StorageMgmtIpSubnet\": {\"description\": \"IP address/subnet on the storage_mgmt network\", \"default\": \"\", \"type\": \"string\"}, \"StorageMgmtIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIp\": {\"default\": \"\", \"type\": \"string\"}, \"InternalApiIpSubnet\": {\"description\": \"IP address/subnet on the internal_api network\", \"default\": \"\", \"type\": \"string\"}, \"InternalApiIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIp\": {\"default\": \"\", \"type\": \"string\"}, \"TenantIpSubnet\": {\"description\": \"IP address/subnet on the tenant network\", \"default\": \"\", \"type\": \"string\"}, \"TenantIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIp\": {\"default\": \"\", \"type\": \"string\"}, \"ExternalIpSubnet\": {\"description\": \"IP address/subnet on the external network\", \"default\": \"\", \"type\": \"string\"}, \"ExternalIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}}, \"resources\": {\"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"ctlplane\": {\"get_param\": \"ControlPlaneIp\"}, \"ctlplane_subnet\": {\"list_join\": [\"\", [{\"get_param\": \"ControlPlaneIp\"}, \"/\", {\"get_param\": \"ControlPlaneSubnetCidr\"}]]}, \"ctlplane_uri\": {\"str_replace\": {\"template\": {\"make_url\": {\"host\": {\"get_param\": \"ControlPlaneIp\"}}}, \"params\": {\"//\": \"\"}}}, \"storage\": {\"get_param\": \"StorageIp\"}, \"storage_subnet\": {\"get_param\": \"StorageIpSubnet\"}, \"storage_uri\": {\"get_param\": \"StorageIpUri\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIp\"}, \"storage_mgmt_subnet\": {\"get_param\": \"StorageMgmtIpSubnet\"}, \"storage_mgmt_uri\": {\"get_param\": \"StorageMgmtIpUri\"}, \"internal_api\": {\"get_param\": \"InternalApiIp\"}, \"internal_api_subnet\": {\"get_param\": \"InternalApiIpSubnet\"}, \"internal_api_uri\": {\"get_param\": \"InternalApiIpUri\"}, \"tenant\": {\"get_param\": \"TenantIp\"}, \"tenant_subnet\": {\"get_param\": \"TenantIpSubnet\"}, \"tenant_uri\": {\"get_param\": \"TenantIpUri\"}, \"external\": {\"get_param\": \"ExternalIp\"}, \"external_subnet\": {\"get_param\": \"ExternalIpSubnet\"}, \"external_uri\": {\"get_param\": \"ExternalIpUri\"}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"StorageNetName\"}}}}, \"storage_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"StorageNetName\"}}}}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"storage_mgmt_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"StorageMgmtNetName\"}}}}, \"storage_mgmt_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"StorageMgmtNetName\"}}}}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"internal_api_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"InternalApiNetName\"}}}}, \"internal_api_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"InternalApiNetName\"}}}}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"tenant_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"TenantNetName\"}}}}, \"tenant_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"TenantNetName\"}}}}, \"external\": {\"get_param\": \"ExternalNetName\"}, \"external_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"ExternalNetName\"}}}}, \"external_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"ExternalNetName\"}}}}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned IPs for a specific machine.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIp\": \"192.168.122.107\", \"ControlPlaneSubnetCidr\": \"24\", \"StorageIp\": \"172.18.0.107\", \"StorageIpSubnet\": \"172.18.0.0/24\", \"StorageIpUri\": \"172.18.0.107\", \"InternalApiIp\": \"172.17.0.107\", \"InternalApiIpSubnet\": \"172.17.0.0/24\", \"InternalApiIpUri\": \"172.17.0.107\", \"TenantIp\": \"172.19.0.107\", \"TenantIpSubnet\": \"172.19.0.0/24\", \"TenantIpUri\": \"172.19.0.107\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(182,'2026-06-12 08:26:32',NULL,'{\"heat_template_version\": \"2015-04-30\", \"resources\": {\"0\": {\"type\": \"OS::TripleO::CellController\", \"properties\": {\"CloudDomain\": \"ooo.test\", \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"Hostname\": \"cell1-controller-0\", \"NodeIndex\": \"0\", \"CellControllerSchedulerHints\": {}, \"ServiceNames\": [\"boot_params_service\", \"ca_certs\", \"clustercheck\", \"collectd\", \"container_image_prepare\", \"logrotate_crond\", \"haproxy\", \"iscsid\", \"kernel\", \"metrics_qdr\", \"mysql\", \"mysql_client\", \"nova_conductor\", \"nova_metadata\", \"nova_vnc_proxy\", \"oslo_messaging_rpc\", \"pacemaker\", \"podman\", \"rsyslog\", \"snmp\", \"sshd\", \"chrony\", \"timezone\", \"tripleo_firewall\", \"tripleo_packages\", \"tuned\"], \"DeploymentServerBlacklistDict\": {}, \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"UserData\": \"143aaca9-8b31-4027-a27f-38df24607525\"}}}, \"outputs\": {\"storage_mgmt_ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"storage_mgmt_ip_address\"]}]}, \"attributes, nova_server_resource\": {\"value\": {\"0\": {\"get_attr\": [\"0\", \"nova_server_resource\"]}}}, \"storage_ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"storage_ip_address\"]}]}, \"blacklist_ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"blacklist_ip_address\"]}]}, \"internal_api_ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"internal_api_ip_address\"]}]}, \"blacklist_hostname\": {\"value\": [{\"get_attr\": [\"0\", \"blacklist_hostname\"]}]}, \"hostname_map\": {\"value\": [{\"get_attr\": [\"0\", \"hostname_map\"]}]}, \"tenant_ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"tenant_ip_address\"]}]}, \"nova_server_resource\": {\"value\": [{\"get_attr\": [\"0\", \"nova_server_resource\"]}]}, \"ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"ip_address\"]}]}, \"hostname\": {\"value\": [{\"get_attr\": [\"0\", \"hostname\"]}]}, \"hosts_entry\": {\"value\": [{\"get_attr\": [\"0\", \"hosts_entry\"]}]}, \"ansible_host_vars_map\": {\"value\": [{\"get_attr\": [\"0\", \"ansible_host_vars_map\"]}]}, \"refs_map\": {\"value\": {\"0\": {\"get_resource\": \"0\"}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(183,'2026-06-12 08:26:32',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack CellController node configured by Puppet\", \"parameters\": {\"OvercloudControlFlavor\": {\"description\": \"DEPRECATED Use OvercloudCellControllerFlavor instead.\", \"default\": \"baremetal\", \"type\": \"string\"}, \"OvercloudCellControllerFlavor\": {\"description\": \"Flavor for the CellController node.\", \"default\": \"baremetal\", \"type\": \"string\"}, \"controllerImage\": {\"type\": \"string\", \"default\": \"overcloud-full\", \"description\": \"DEPRECATED Use CellControllerImage instead\"}, \"CellControllerImage\": {\"type\": \"string\", \"default\": \"overcloud-full\", \"description\": \"The disk image file to use for the role.\"}, \"ImageUpdatePolicy\": {\"default\": \"REBUILD_PRESERVE_EPHEMERAL\", \"description\": \"What policy to use when reconstructing instances. REBUILD for rebuilds, REBUILD_PRESERVE_EPHEMERAL to preserve /mnt.\", \"type\": \"string\"}, \"KeyName\": {\"description\": \"Name of an existing Nova key pair to enable SSH access to the instances\", \"type\": \"string\", \"default\": \"default\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"UpdateIdentifier\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Setting to a previously unused value during stack-update will trigger package update on all nodes\\n\"}, \"Hostname\": {\"type\": \"string\", \"default\": \"\"}, \"HostnameMap\": {\"type\": \"json\", \"default\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"description\": \"Optional mapping to override hostnames\"}, \"CellControllerIPs\": {\"default\": {}, \"type\": \"json\"}, \"SoftwareConfigTransport\": {\"default\": \"POLL_SERVER_HEAT\", \"description\": \"How the server should receive the metadata required for software configuration.\\n\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"POLL_SERVER_CFN\", \"POLL_SERVER_HEAT\", \"POLL_TEMP_URL\", \"ZAQAR_MESSAGE\"]}]}, \"CloudDomain\": {\"default\": \"ooo.test\", \"type\": \"string\", \"description\": \"The DNS domain used for the hosts. This must match the overcloud_domain_name configured on the undercloud.\\n\"}, \"CellControllerServerMetadata\": {\"default\": {}, \"description\": \"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API. This option is role-specific and is merged with the values given to the ServerMetadata parameter.\\n\", \"type\": \"json\"}, \"ServerMetadata\": {\"default\": {}, \"description\": \"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API. This applies to all roles and is merged with a role-specific metadata parameter.\\n\", \"type\": \"json\"}, \"CellControllerSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"NodeIndex\": {\"type\": \"number\", \"default\": 0}, \"ServiceNames\": {\"type\": \"comma_delimited_list\", \"default\": []}, \"MonitoringSubscriptions\": {\"type\": \"comma_delimited_list\", \"default\": []}, \"ServiceMetadataSettings\": {\"type\": \"json\", \"default\": {}}, \"OVNBridgeMappings\": {\"type\": \"comma_delimited_list\", \"default\": []}, \"ConfigCommand\": {\"type\": \"string\", \"description\": \"Command which will be run whenever configuration data changes\", \"default\": \"os-refresh-config --timeout 14400\"}, \"ConfigCollectSplay\": {\"type\": \"number\", \"default\": 30, \"description\": \"Maximum amount of time to possibly to delay configuration collection\\npolling. Defaults to 30 seconds. Set to 0 to disable it which will cause\\nthe configuration collection to occur as soon as the collection process\\nstarts.  This setting is used to prevent the configuration collection\\nprocesses from polling all at the exact same time.\\n\"}, \"UpgradeInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\ninitialize the upgrade process. E.g. a repository switch.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeInitCommonCommand\": {\"type\": \"string\", \"description\": \"Common commands required by the upgrades process. This should not\\nnormally be modified by the operator and is set and unset in the\\nmajor-upgrade-composable-steps.yaml and major-upgrade-converge.yaml\\nenvironment files.\\n\", \"default\": \"\"}, \"DeploymentServerBlacklistDict\": {\"default\": {}, \"type\": \"json\", \"description\": \"Map of server hostnames to blacklist from any triggered deployments. If the value is 1, the server will be blacklisted. This parameter is generated from the parent template.\\n\"}, \"RoleParameters\": {\"type\": \"json\", \"description\": \"Parameters specific to the role\", \"default\": {}}, \"CellControllerControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ServerDeletionPolicy\": {\"description\": \"Whether to retain or delete servers on deletion of the stack\", \"type\": \"string\", \"default\": \"delete\", \"constraints\": [{\"allowed_values\": [\"delete\", \"retain\"]}]}, \"UserData\": {\"type\": \"string\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"Do not use deprecated params, they will be removed.\", \"parameters\": [\"OvercloudControlFlavor\", \"controllerImage\"]}], \"conditions\": {\"server_blacklisted\": {\"or\": [{\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": \"Hostname\"}]}, 1]}, {\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": [\"HostnameMap\", {\"get_param\": \"Hostname\"}]}]}, 1]}]}, \"server_not_blacklisted\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": \"Hostname\"}]}, 1]}}, {\"not\": {\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": [\"HostnameMap\", {\"get_param\": \"Hostname\"}]}]}, 1]}}]}, \"deprecated_param_image_set\": {\"not\": {\"equals\": [{\"get_param\": \"controllerImage\"}, \"overcloud-full\"]}}, \"deprecated_param_flavor_set\": {\"not\": {\"equals\": [{\"get_param\": \"OvercloudControlFlavor\"}, \"baremetal\"]}}, \"ctlplane_fixed_ip_set\": {\"or\": [{\"not\": {\"equals\": [{\"get_param\": [\"CellControllerIPs\", \"ctlplane\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, false]}, \"CellController_Storage_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"CellControllerIPs\", \"storage\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, \"CellController_StorageMgmt_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"CellControllerIPs\", \"storage_mgmt\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, \"CellController_InternalApi_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"CellControllerIPs\", \"internal_api\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, \"CellController_Tenant_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"CellControllerIPs\", \"tenant\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}}, \"resources\": {\"CellController\": {\"type\": \"OS::TripleO::CellControllerServer\", \"deletion_policy\": {\"get_param\": \"ServerDeletionPolicy\"}, \"properties\": {\"image\": {\"if\": [\"deprecated_param_image_set\", {\"get_param\": \"controllerImage\"}, {\"get_param\": \"CellControllerImage\"}]}, \"image_update_policy\": {\"get_param\": \"ImageUpdatePolicy\"}, \"flavor\": {\"if\": [\"deprecated_param_flavor_set\", {\"get_param\": \"OvercloudControlFlavor\"}, {\"get_param\": \"OvercloudCellControllerFlavor\"}]}, \"key_name\": {\"get_param\": \"KeyName\"}, \"networks\": [{\"if\": [\"ctlplane_fixed_ip_set\", {\"network\": \"ctlplane\", \"subnet\": {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"fixed_ip\": {\"yaql\": {\"expression\": \"$.data.where(not isEmpty($)).first()\", \"data\": [{\"get_param\": [\"CellControllerIPs\", \"ctlplane\", {\"get_param\": \"NodeIndex\"}]}]}}}, {\"network\": \"ctlplane\", \"subnet\": {\"get_param\": \"CellControllerControlPlaneSubnet\"}}]}], \"user_data_format\": \"SOFTWARE_CONFIG\", \"user_data\": {\"get_param\": \"UserData\"}, \"name\": {\"yaql\": {\"expression\": \"$.data.hostname_map.get($.data.hostname, $.data.hostname).toLower()\", \"data\": {\"hostname\": {\"get_param\": \"Hostname\"}, \"hostname_map\": {\"get_param\": \"HostnameMap\"}}}}, \"software_config_transport\": {\"get_param\": \"SoftwareConfigTransport\"}, \"metadata\": {\"map_merge\": [{\"get_param\": \"ServerMetadata\"}, {\"get_param\": \"CellControllerServerMetadata\"}, {\"get_param\": \"ServiceMetadataSettings\"}]}, \"scheduler_hints\": {\"get_param\": \"CellControllerSchedulerHints\"}}}, \"StoragePort\": {\"type\": \"OS::TripleO::CellController::Ports::StoragePort\", \"properties\": {\"PortName\": {\"list_join\": [\"_\", [{\"get_attr\": [\"CellController\", \"name\"]}, \"Storage\"]]}, \"DnsName\": {\"get_attr\": [\"CellController\", \"name\"]}, \"ControlPlaneIP\": {\"get_attr\": [\"CellController\", \"networks\", \"ctlplane\", 0]}, \"FixedIPs\": {\"if\": [\"CellController_Storage_fixed_ip_set\", [{\"ip_address\": {\"get_param\": [\"CellControllerIPs\", \"storage\", {\"get_param\": \"NodeIndex\"}]}}], [{\"subnet\": \"storage_subnet\"}]]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"CellController\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"IPPool\": {\"map_merge\": [{\"get_param\": \"CellControllerIPs\"}]}, \"NodeIndex\": {\"get_param\": \"NodeIndex\"}, \"Role\": \"CellController\"}}, \"StorageMgmtPort\": {\"type\": \"OS::TripleO::CellController::Ports::StorageMgmtPort\", \"properties\": {\"PortName\": {\"list_join\": [\"_\", [{\"get_attr\": [\"CellController\", \"name\"]}, \"StorageMgmt\"]]}, \"DnsName\": {\"get_attr\": [\"CellController\", \"name\"]}, \"ControlPlaneIP\": {\"get_attr\": [\"CellController\", \"networks\", \"ctlplane\", 0]}, \"FixedIPs\": {\"if\": [\"CellController_StorageMgmt_fixed_ip_set\", [{\"ip_address\": {\"get_param\": [\"CellControllerIPs\", \"storage_mgmt\", {\"get_param\": \"NodeIndex\"}]}}], [{\"subnet\": \"storage_mgmt_subnet\"}]]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"CellController\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"IPPool\": {\"map_merge\": [{\"get_param\": \"CellControllerIPs\"}]}, \"NodeIndex\": {\"get_param\": \"NodeIndex\"}, \"Role\": \"CellController\"}}, \"InternalApiPort\": {\"type\": \"OS::TripleO::CellController::Ports::InternalApiPort\", \"properties\": {\"PortName\": {\"list_join\": [\"_\", [{\"get_attr\": [\"CellController\", \"name\"]}, \"InternalApi\"]]}, \"DnsName\": {\"get_attr\": [\"CellController\", \"name\"]}, \"ControlPlaneIP\": {\"get_attr\": [\"CellController\", \"networks\", \"ctlplane\", 0]}, \"FixedIPs\": {\"if\": [\"CellController_InternalApi_fixed_ip_set\", [{\"ip_address\": {\"get_param\": [\"CellControllerIPs\", \"internal_api\", {\"get_param\": \"NodeIndex\"}]}}], [{\"subnet\": \"internal_api_subnet\"}]]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"CellController\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"IPPool\": {\"map_merge\": [{\"get_param\": \"CellControllerIPs\"}]}, \"NodeIndex\": {\"get_param\": \"NodeIndex\"}, \"Role\": \"CellController\"}}, \"TenantPort\": {\"type\": \"OS::TripleO::CellController::Ports::TenantPort\", \"properties\": {\"PortName\": {\"list_join\": [\"_\", [{\"get_attr\": [\"CellController\", \"name\"]}, \"Tenant\"]]}, \"DnsName\": {\"get_attr\": [\"CellController\", \"name\"]}, \"ControlPlaneIP\": {\"get_attr\": [\"CellController\", \"networks\", \"ctlplane\", 0]}, \"FixedIPs\": {\"if\": [\"CellController_Tenant_fixed_ip_set\", [{\"ip_address\": {\"get_param\": [\"CellControllerIPs\", \"tenant\", {\"get_param\": \"NodeIndex\"}]}}], [{\"subnet\": \"tenant_subnet\"}]]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"CellController\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"IPPool\": {\"map_merge\": [{\"get_param\": \"CellControllerIPs\"}]}, \"NodeIndex\": {\"get_param\": \"NodeIndex\"}, \"Role\": \"CellController\"}}, \"NetIpMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpMap\", \"properties\": {\"ControlPlaneIp\": {\"get_attr\": [\"CellController\", \"networks\", \"ctlplane\", 0]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"CellController\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"StorageIp\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageIpSubnet\": {\"get_attr\": [\"StoragePort\", \"ip_subnet\"]}, \"StorageIpUri\": {\"get_attr\": [\"StoragePort\", \"ip_address_uri\"]}, \"StorageMgmtIp\": {\"get_attr\": [\"StorageMgmtPort\", \"ip_address\"]}, \"StorageMgmtIpSubnet\": {\"get_attr\": [\"StorageMgmtPort\", \"ip_subnet\"]}, \"StorageMgmtIpUri\": {\"get_attr\": [\"StorageMgmtPort\", \"ip_address_uri\"]}, \"InternalApiIp\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiIpSubnet\": {\"get_attr\": [\"InternalApiPort\", \"ip_subnet\"]}, \"InternalApiIpUri\": {\"get_attr\": [\"InternalApiPort\", \"ip_address_uri\"]}, \"TenantIp\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantIpSubnet\": {\"get_attr\": [\"TenantPort\", \"ip_subnet\"]}, \"TenantIpUri\": {\"get_attr\": [\"TenantPort\", \"ip_address_uri\"]}}}, \"NetHostMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"storage\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"CellController\", \"name\"]}, \"storage\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"CellController\", \"name\"]}, \"storage\"]]}}, \"storage_mgmt\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"CellController\", \"name\"]}, \"storagemgmt\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"CellController\", \"name\"]}, \"storagemgmt\"]]}}, \"internal_api\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"CellController\", \"name\"]}, \"internalapi\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"CellController\", \"name\"]}, \"internalapi\"]]}}, \"tenant\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"CellController\", \"name\"]}, \"tenant\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"CellController\", \"name\"]}, \"tenant\"]]}}, \"ctlplane\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"CellController\", \"name\"]}, \"ctlplane\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"CellController\", \"name\"]}, \"ctlplane\"]]}}, \"canonical\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"CellController\", \"name\"]}, {\"get_param\": \"CloudDomain\"}]]}, \"short\": [{\"get_attr\": [\"CellController\", \"name\"]}]}}}}, \"PreNetworkConfig\": {\"type\": \"OS::TripleO::CellController::PreNetworkConfig\", \"condition\": \"server_not_blacklisted\", \"properties\": {\"server\": {\"get_resource\": \"CellController\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"ServiceNames\": {\"get_param\": \"ServiceNames\"}, \"deployment_actions\": {\"get_attr\": [\"DeploymentActions\", \"value\"]}}}, \"NodeTLSCAData\": {\"type\": \"OS::TripleO::NodeTLSCAData\", \"properties\": {\"server\": {\"get_resource\": \"CellController\"}}}, \"CellControllerExtraConfigPre\": {\"type\": \"OS::TripleO::CellControllerExtraConfigPre\", \"condition\": \"server_not_blacklisted\", \"properties\": {\"server\": {\"get_resource\": \"CellController\"}}}, \"NodeExtraConfig\": {\"depends_on\": [\"CellControllerExtraConfigPre\", \"NodeTLSCAData\"], \"type\": \"OS::TripleO::NodeExtraConfig\", \"condition\": \"server_not_blacklisted\", \"properties\": {\"server\": {\"get_resource\": \"CellController\"}}}, \"DeploymentActions\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"if\": [\"server_not_blacklisted\", [\"CREATE\", \"UPDATE\"], []]}}}, \"CellControllerAnsibleHostVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"fqdn_storage\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"fqdn\"]}, \"fqdn_storage_mgmt\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage_mgmt\", \"fqdn\"]}, \"fqdn_internal_api\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"fqdn\"]}, \"fqdn_tenant\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"fqdn\"]}, \"fqdn_ctlplane\": {\"get_attr\": [\"NetHostMap\", \"value\", \"ctlplane\", \"fqdn\"]}, \"fqdn_canonical\": {\"get_attr\": [\"NetHostMap\", \"value\", \"canonical\", \"fqdn\"]}, \"hostname_resolve_network\": {\"get_param\": [\"ServiceNetMap\", \"CellControllerHostnameResolveNetwork\"]}}}}}, \"outputs\": {\"ansible_host_vars_map\": {\"description\": \"Map of Ansible variables specific per host.\\nThis map is used to construct the AnsibleHostVarsMap output for the\\nansible vars per host in config-download.\\n\", \"value\": {\"map_replace\": [{\"host\": {\"get_attr\": [\"CellControllerAnsibleHostVars\", \"value\"]}}, {\"keys\": {\"host\": {\"get_attr\": [\"CellController\", \"name\"]}}}]}}, \"ip_address\": {\"description\": \"IP address of the server in the ctlplane network\", \"value\": {\"get_attr\": [\"CellController\", \"networks\", \"ctlplane\", 0]}}, \"blacklist_ip_address\": {\"description\": \"IP address of the server if the server is blacklisted, otherwise this output will be an empty string\", \"value\": {\"if\": [\"server_blacklisted\", {\"get_attr\": [\"CellController\", \"networks\", \"ctlplane\", 0]}, \"\"]}}, \"blacklist_hostname\": {\"description\": \"Hostname of the server if the server is blacklisted, otherwise this output will be an empty string\", \"value\": {\"if\": [\"server_blacklisted\", {\"get_attr\": [\"CellController\", \"name\"]}, \"\"]}}, \"hostname\": {\"description\": \"Hostname of the server\", \"value\": {\"get_attr\": [\"CellController\", \"name\"]}}, \"hostname_map\": {\"description\": \"Mapping of network names to hostnames\", \"value\": {\"storage\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"fqdn\"]}, \"storage_mgmt\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage_mgmt\", \"fqdn\"]}, \"internal_api\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"fqdn\"]}, \"tenant\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"fqdn\"]}, \"ctlplane\": {\"get_attr\": [\"NetHostMap\", \"value\", \"ctlplane\", \"fqdn\"]}, \"canonical\": {\"get_attr\": [\"NetHostMap\", \"value\", \"canonical\", \"fqdn\"]}}}, \"hosts_entry\": {\"value\": [{\"str_replace\": {\"template\": \"PRIMARYIP PRIMARYHOST.DOMAIN PRIMARYHOST\", \"params\": {\"PRIMARYIP\": {\"get_attr\": [\"NetIpMap\", \"net_ip_map\", {\"get_param\": [\"ServiceNetMap\", \"CellControllerHostnameResolveNetwork\"]}]}, \"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"PRIMARYHOST\": {\"get_attr\": [\"CellController\", \"name\"]}}}}, {\"str_replace\": {\"template\": \"StorageIP StorageHOST.DOMAIN StorageHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"StorageIP\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"short\"]}, \"StorageMgmtIP\": {\"get_attr\": [\"StorageMgmtPort\", \"ip_address\"]}, \"StorageMgmtHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage_mgmt\", \"short\"]}, \"InternalApiIP\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"short\"]}, \"TenantIP\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"short\"]}}}}, {\"str_replace\": {\"template\": \"StorageMgmtIP StorageMgmtHOST.DOMAIN StorageMgmtHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"StorageIP\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"short\"]}, \"StorageMgmtIP\": {\"get_attr\": [\"StorageMgmtPort\", \"ip_address\"]}, \"StorageMgmtHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage_mgmt\", \"short\"]}, \"InternalApiIP\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"short\"]}, \"TenantIP\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"short\"]}}}}, {\"str_replace\": {\"template\": \"InternalApiIP InternalApiHOST.DOMAIN InternalApiHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"StorageIP\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"short\"]}, \"StorageMgmtIP\": {\"get_attr\": [\"StorageMgmtPort\", \"ip_address\"]}, \"StorageMgmtHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage_mgmt\", \"short\"]}, \"InternalApiIP\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"short\"]}, \"TenantIP\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"short\"]}}}}, {\"str_replace\": {\"template\": \"TenantIP TenantHOST.DOMAIN TenantHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"StorageIP\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"short\"]}, \"StorageMgmtIP\": {\"get_attr\": [\"StorageMgmtPort\", \"ip_address\"]}, \"StorageMgmtHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage_mgmt\", \"short\"]}, \"InternalApiIP\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"short\"]}, \"TenantIP\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"short\"]}}}}, {\"str_replace\": {\"template\": \"CTLPLANEIP CTLPLANEHOST.DOMAIN CTLPLANEHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"CTLPLANEIP\": {\"get_attr\": [\"CellController\", \"networks\", \"ctlplane\", 0]}, \"CTLPLANEHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"ctlplane\", \"short\"]}}}}]}, \"nova_server_resource\": {\"description\": \"Heat resource handle for CellController server\", \"value\": {\"get_resource\": \"CellController\"}, \"condition\": \"server_not_blacklisted\"}, \"deployed_server_port_map\": {\"description\": \"Map of Heat created hostname of the server to ip address. This is the\\nhostname before it has been mapped with the HostnameMap parameter, and\\nthe IP address from the ctlplane network. This map can be used to construct\\nthe DeployedServerPortMap parameter when using split-stack.\\n\", \"value\": {\"map_replace\": [{\"hostname\": {\"fixed_ips\": [{\"ip_address\": {\"get_attr\": [\"CellController\", \"networks\", \"ctlplane\", 0]}}], \"subnets\": [{\"cidr\": {\"get_attr\": [\"CellController\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}}]}}, {\"keys\": {\"hostname\": {\"list_join\": [\"-\", [{\"get_param\": \"Hostname\"}, \"ctlplane\"]]}}}]}}, \"storage_ip_address\": {\"description\": \"IP address of the server in the Storage network\", \"value\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}}, \"storage_mgmt_ip_address\": {\"description\": \"IP address of the server in the StorageMgmt network\", \"value\": {\"get_attr\": [\"StorageMgmtPort\", \"ip_address\"]}}, \"internal_api_ip_address\": {\"description\": \"IP address of the server in the InternalApi network\", \"value\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}}, \"tenant_ip_address\": {\"description\": \"IP address of the server in the Tenant network\", \"value\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"Hostname\": \"cell1-controller-0\", \"CloudDomain\": \"ooo.test\", \"CellControllerSchedulerHints\": {}, \"NodeIndex\": 0, \"ServiceNames\": \"boot_params_service,ca_certs,clustercheck,collectd,container_image_prepare,logrotate_crond,haproxy,iscsid,kernel,metrics_qdr,mysql,mysql_client,nova_conductor,nova_metadata,nova_vnc_proxy,oslo_messaging_rpc,pacemaker,podman,rsyslog,snmp,sshd,chrony,timezone,tripleo_firewall,tripleo_packages,tuned\", \"DeploymentServerBlacklistDict\": {}, \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"UserData\": \"143aaca9-8b31-4027-a27f-38df24607525\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(184,'2026-06-12 08:26:33',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": true, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"192.168.122.107\", \"StorageIpList\": \"172.18.0.107\", \"InternalApiIpList\": \"172.17.0.107\", \"TenantIpList\": \"172.19.0.107\", \"EnabledServices\": \"boot_params_service,ca_certs,collectd,ceilometer_agent_compute,ceilometer_agent_ipmi,iscsid,kernel,metrics_qdr,mysql_client,nova_compute,nova_libvirt,nova_libvirt_guests,nova_migration_target,logrotate_crond,podman,rsyslog,snmp,sshd,chrony,timezone,tripleo_firewall,tripleo_packages,tuned,ovn_controller,ovn_metadata\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"np0000071539\", \"NetworkHostnameMap\": {\"storage\": [\"np0000071539.storage.ooo.test\"], \"internal_api\": [\"np0000071539.internalapi.ooo.test\"], \"tenant\": [\"np0000071539.tenant.ooo.test\"], \"ctlplane\": [\"np0000071539.ctlplane.ooo.test\"], \"canonical\": [\"np0000071539.ooo.test\"]}, \"RoleNetworks\": \"ctlplane,storage,internal_api,tenant\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(185,'2026-06-12 08:26:34',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\", \"default\": \"cell1\"}, \"image\": {\"type\": \"string\", \"default\": \"unused\"}, \"flavor\": {\"type\": \"string\", \"default\": \"unused\"}, \"key_name\": {\"type\": \"string\", \"default\": \"unused\", \"description\": \"Name of keypair to assign to servers\"}, \"security_groups\": {\"type\": \"json\", \"default\": []}, \"user_data_format\": {\"type\": \"string\"}, \"user_data\": {\"type\": \"string\", \"default\": \"\"}, \"name\": {\"type\": \"string\", \"default\": \"deployed-server\"}, \"image_update_policy\": {\"type\": \"string\", \"default\": \"\"}, \"networks\": {\"type\": \"comma_delimited_list\", \"default\": \"\"}, \"metadata\": {\"type\": \"json\", \"default\": {}}, \"software_config_transport\": {\"default\": \"POLL_SERVER_CFN\", \"type\": \"string\"}, \"scheduler_hints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"UpgradeInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\ninitialize the upgrade process. E.g. a repository switch.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeInitCommonCommand\": {\"type\": \"string\", \"description\": \"Common commands required by the upgrades process. This should not\\nnormally be modified by the operator and is set and unset in the\\nmajor-upgrade-composable-steps.yaml and major-upgrade-converge.yaml\\nenvironment files.\\n\", \"default\": \"\"}, \"ControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"The name of the undercloud Neutron control plane subnet\", \"type\": \"string\"}}, \"resources\": {\"deployed-server\": {\"type\": \"OS::Heat::DeployedServer\", \"properties\": {\"name\": {\"get_param\": \"name\"}, \"software_config_transport\": {\"get_param\": \"software_config_transport\"}}}, \"ControlPlanePort\": {\"type\": \"OS::TripleO::DeployedServer::ControlPlanePort\", \"properties\": {\"network\": \"ctlplane\", \"fixed_ips\": [{\"subnet\": {\"get_param\": \"ControlPlaneSubnet\"}}], \"name\": {\"list_join\": [\"-\", [{\"get_param\": \"name\"}, \"ctlplane\"]]}, \"replacement_policy\": \"AUTO\", \"tags\": [{\"str_replace\": {\"template\": \"tripleo_stack_name=$STACK_NAME\", \"params\": {\"$STACK_NAME\": {\"get_param\": \"RootStackName\"}}}}]}}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"deployed-server\"}}, \"networks\": {\"value\": {\"ctlplane\": [{\"get_attr\": [\"ControlPlanePort\", \"fixed_ips\", 0, \"ip_address\"]}]}}, \"addresses\": {\"value\": {\"ctlplane\": [{\"subnets\": {\"get_attr\": [\"ControlPlanePort\", \"subnets\"]}}]}}, \"name\": {\"value\": {\"get_param\": \"name\"}}, \"os_collect_config\": {\"value\": {\"get_attr\": [\"deployed-server\", \"os_collect_config\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"image\": \"overcloud-full\", \"flavor\": \"baremetal\", \"key_name\": \"default\", \"user_data_format\": \"SOFTWARE_CONFIG\", \"user_data\": \"143aaca9-8b31-4027-a27f-38df24607525\", \"name\": \"np0000071538\", \"image_update_policy\": \"REBUILD_PRESERVE_EPHEMERAL\", \"networks\": \".member.0.network=ctlplane,.member.0.subnet=ctlplane-subnet\", \"metadata\": {}, \"software_config_transport\": \"POLL_SERVER_HEAT\", \"scheduler_hints\": {}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(186,'2026-06-12 08:26:35',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \" A fake OS::Neutron::Port stack which outputs fixed_ips and subnets based on the input from the DeployedServerPortMap (set via parameter_defaults). This lookup requires the use of port naming conventions. In order for this to work with deployed-server the keys should be <hostname>-<network>. Example: parameter_defaults: DeployedServerPortMap: gatsby-ctlplane: fixed_ips: - ip_address: 127.0.0.1 subnets: - cidr: 127.0.0.0/24 network: tags: - 127.0.0.0/24\", \"parameters\": {\"name\": {\"default\": \"\", \"type\": \"string\"}, \"dns_name\": {\"default\": \"\", \"type\": \"string\"}, \"network\": {\"default\": \"\", \"type\": \"string\"}, \"fixed_ips\": {\"default\": \"\", \"type\": \"comma_delimited_list\"}, \"replacement_policy\": {\"default\": \"\", \"type\": \"string\"}, \"tags\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"DeployedServerPortMap\": {\"default\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"type\": \"json\"}, \"IsVirtualIP\": {\"default\": false, \"type\": \"boolean\"}, \"Role\": {\"description\": \"The TripleO Role Name\\n\", \"type\": \"string\", \"default\": \"\"}}, \"outputs\": {\"fixed_ips\": {\"value\": {\"get_param\": [\"DeployedServerPortMap\", {\"get_param\": \"name\"}, \"fixed_ips\"]}}, \"subnets\": {\"value\": {\"get_param\": [\"DeployedServerPortMap\", {\"get_param\": \"name\"}, \"subnets\"]}}, \"network\": {\"value\": {\"get_param\": [\"DeployedServerPortMap\", {\"get_param\": \"name\"}, \"network\"]}}, \"name\": {\"value\": {\"get_param\": \"name\"}}, \"status\": {\"value\": \"DOWN\"}, \"allowed_address_pairs\": {\"value\": {}}, \"device_id\": {\"value\": \"\"}, \"device_owner\": {\"value\": {\"get_param\": \"network\"}}, \"dns_assignment\": {\"value\": \"\"}, \"port_security_enabled\": {\"value\": false}, \"admin_state_up\": {\"value\": false}, \"security_groups\": {\"value\": {}}, \"network_id\": {\"value\": \"\"}, \"tenant_id\": {\"value\": \"\"}, \"qos_policy_id\": {\"value\": \"\"}, \"mac_address\": {\"value\": \"\"}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"name\": \"np0000071538-ctlplane\", \"network\": \"ctlplane\", \"fixed_ips\": \".member.0.subnet=ctlplane-subnet\", \"replacement_policy\": \"AUTO\", \"tags\": \"tripleo_stack_name=cell1\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (187,'2026-06-12 08:26:37',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed port on the StorageMgmt network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"NodePortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"type\": \"json\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"DefaultRoute\": {\"description\": \"Whether this interface is used for the default route\\n\", \"type\": \"boolean\", \"default\": false}, \"Role\": {\"description\": \"The TripleO Role Name\\n\", \"type\": \"string\", \"default\": \"\"}}, \"resources\": {\"StorageMgmtDeployedPort\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ip_address\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"storage_mgmt\", \"ip_address\"]}, \"ip_address_uri\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"storage_mgmt\", \"ip_address_uri\"]}, \"ip_subnet\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"storage_mgmt\", \"ip_subnet\"]}}}}}, \"outputs\": {\"ip_address\": {\"description\": \"StorageMgmt network IP\", \"value\": {\"get_attr\": [\"StorageMgmtDeployedPort\", \"value\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"StorageMgmt network IP (with brackets for IPv6 URLs)\", \"value\": {\"get_attr\": [\"StorageMgmtDeployedPort\", \"value\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the StorageMgmt network IP\", \"value\": {\"get_attr\": [\"StorageMgmtDeployedPort\", \"value\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"np0000071538_StorageMgmt\", \"DnsName\": \"np0000071538\", \"ControlPlaneIP\": \"192.168.122.106\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"storage_mgmt_subnet\\\"}]\", \"IPPool\": {}, \"NodeIndex\": 0, \"Role\": \"CellController\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(188,'2026-06-12 08:26:37',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed port on the Tenant network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"NodePortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"type\": \"json\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"DefaultRoute\": {\"description\": \"Whether this interface is used for the default route\\n\", \"type\": \"boolean\", \"default\": false}, \"Role\": {\"description\": \"The TripleO Role Name\\n\", \"type\": \"string\", \"default\": \"\"}}, \"resources\": {\"TenantDeployedPort\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ip_address\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"tenant\", \"ip_address\"]}, \"ip_address_uri\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"tenant\", \"ip_address_uri\"]}, \"ip_subnet\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"tenant\", \"ip_subnet\"]}}}}}, \"outputs\": {\"ip_address\": {\"description\": \"Tenant network IP\", \"value\": {\"get_attr\": [\"TenantDeployedPort\", \"value\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"Tenant network IP (with brackets for IPv6 URLs)\", \"value\": {\"get_attr\": [\"TenantDeployedPort\", \"value\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the Tenant network IP\", \"value\": {\"get_attr\": [\"TenantDeployedPort\", \"value\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"np0000071538_Tenant\", \"DnsName\": \"np0000071538\", \"ControlPlaneIP\": \"192.168.122.106\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"tenant_subnet\\\"}]\", \"IPPool\": {}, \"NodeIndex\": 0, \"Role\": \"CellController\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(189,'2026-06-12 08:26:37',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Noop Extra Pre-Deployment Config\", \"parameters\": {\"server\": {\"type\": \"string\"}}, \"outputs\": {\"deploy_stdout\": {\"value\": \"None\"}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"server\": \"fdfd9831-4e7f-49b0-88e6-ee2bc9bc0add\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(190,'2026-06-12 08:26:37',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed port on the InternalApi network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"NodePortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"type\": \"json\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"DefaultRoute\": {\"description\": \"Whether this interface is used for the default route\\n\", \"type\": \"boolean\", \"default\": false}, \"Role\": {\"description\": \"The TripleO Role Name\\n\", \"type\": \"string\", \"default\": \"\"}}, \"resources\": {\"InternalApiDeployedPort\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ip_address\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"internal_api\", \"ip_address\"]}, \"ip_address_uri\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"internal_api\", \"ip_address_uri\"]}, \"ip_subnet\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"internal_api\", \"ip_subnet\"]}}}}}, \"outputs\": {\"ip_address\": {\"description\": \"InternalApi network IP\", \"value\": {\"get_attr\": [\"InternalApiDeployedPort\", \"value\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"InternalApi network IP (with brackets for IPv6 URLs)\", \"value\": {\"get_attr\": [\"InternalApiDeployedPort\", \"value\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the InternalApi network IP\", \"value\": {\"get_attr\": [\"InternalApiDeployedPort\", \"value\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"np0000071538_InternalApi\", \"DnsName\": \"np0000071538\", \"ControlPlaneIP\": \"192.168.122.106\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"internal_api_subnet\\\"}]\", \"IPPool\": {}, \"NodeIndex\": 0, \"Role\": \"CellController\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(191,'2026-06-12 08:26:37',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed port on the Storage network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"NodePortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"type\": \"json\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"DefaultRoute\": {\"description\": \"Whether this interface is used for the default route\\n\", \"type\": \"boolean\", \"default\": false}, \"Role\": {\"description\": \"The TripleO Role Name\\n\", \"type\": \"string\", \"default\": \"\"}}, \"resources\": {\"StorageDeployedPort\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ip_address\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"storage\", \"ip_address\"]}, \"ip_address_uri\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"storage\", \"ip_address_uri\"]}, \"ip_subnet\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"storage\", \"ip_subnet\"]}}}}}, \"outputs\": {\"ip_address\": {\"description\": \"Storage network IP\", \"value\": {\"get_attr\": [\"StorageDeployedPort\", \"value\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"Storage network IP (with brackets for IPv6 URLs)\", \"value\": {\"get_attr\": [\"StorageDeployedPort\", \"value\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the Storage network IP\", \"value\": {\"get_attr\": [\"StorageDeployedPort\", \"value\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"np0000071538_Storage\", \"DnsName\": \"np0000071538\", \"ControlPlaneIP\": \"192.168.122.106\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"storage_subnet\\\"}]\", \"IPPool\": {}, \"NodeIndex\": 0, \"Role\": \"CellController\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(192,'2026-06-12 08:26:38',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Noop Extra Pre-Deployment Config\", \"parameters\": {\"server\": {\"type\": \"string\"}}, \"outputs\": {\"deploy_stdout\": {\"value\": \"None\"}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"server\": \"fdfd9831-4e7f-49b0-88e6-ee2bc9bc0add\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(193,'2026-06-12 08:26:38',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIp\": {\"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"StorageIp\": {\"default\": \"\", \"type\": \"string\"}, \"StorageIpSubnet\": {\"description\": \"IP address/subnet on the storage network\", \"default\": \"\", \"type\": \"string\"}, \"StorageIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIp\": {\"default\": \"\", \"type\": \"string\"}, \"StorageMgmtIpSubnet\": {\"description\": \"IP address/subnet on the storage_mgmt network\", \"default\": \"\", \"type\": \"string\"}, \"StorageMgmtIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIp\": {\"default\": \"\", \"type\": \"string\"}, \"InternalApiIpSubnet\": {\"description\": \"IP address/subnet on the internal_api network\", \"default\": \"\", \"type\": \"string\"}, \"InternalApiIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIp\": {\"default\": \"\", \"type\": \"string\"}, \"TenantIpSubnet\": {\"description\": \"IP address/subnet on the tenant network\", \"default\": \"\", \"type\": \"string\"}, \"TenantIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIp\": {\"default\": \"\", \"type\": \"string\"}, \"ExternalIpSubnet\": {\"description\": \"IP address/subnet on the external network\", \"default\": \"\", \"type\": \"string\"}, \"ExternalIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}}, \"resources\": {\"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"ctlplane\": {\"get_param\": \"ControlPlaneIp\"}, \"ctlplane_subnet\": {\"list_join\": [\"\", [{\"get_param\": \"ControlPlaneIp\"}, \"/\", {\"get_param\": \"ControlPlaneSubnetCidr\"}]]}, \"ctlplane_uri\": {\"str_replace\": {\"template\": {\"make_url\": {\"host\": {\"get_param\": \"ControlPlaneIp\"}}}, \"params\": {\"//\": \"\"}}}, \"storage\": {\"get_param\": \"StorageIp\"}, \"storage_subnet\": {\"get_param\": \"StorageIpSubnet\"}, \"storage_uri\": {\"get_param\": \"StorageIpUri\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIp\"}, \"storage_mgmt_subnet\": {\"get_param\": \"StorageMgmtIpSubnet\"}, \"storage_mgmt_uri\": {\"get_param\": \"StorageMgmtIpUri\"}, \"internal_api\": {\"get_param\": \"InternalApiIp\"}, \"internal_api_subnet\": {\"get_param\": \"InternalApiIpSubnet\"}, \"internal_api_uri\": {\"get_param\": \"InternalApiIpUri\"}, \"tenant\": {\"get_param\": \"TenantIp\"}, \"tenant_subnet\": {\"get_param\": \"TenantIpSubnet\"}, \"tenant_uri\": {\"get_param\": \"TenantIpUri\"}, \"external\": {\"get_param\": \"ExternalIp\"}, \"external_subnet\": {\"get_param\": \"ExternalIpSubnet\"}, \"external_uri\": {\"get_param\": \"ExternalIpUri\"}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"StorageNetName\"}}}}, \"storage_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"StorageNetName\"}}}}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"storage_mgmt_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"StorageMgmtNetName\"}}}}, \"storage_mgmt_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"StorageMgmtNetName\"}}}}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"internal_api_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"InternalApiNetName\"}}}}, \"internal_api_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"InternalApiNetName\"}}}}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"tenant_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"TenantNetName\"}}}}, \"tenant_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"TenantNetName\"}}}}, \"external\": {\"get_param\": \"ExternalNetName\"}, \"external_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"ExternalNetName\"}}}}, \"external_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"ExternalNetName\"}}}}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned IPs for a specific machine.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIp\": \"192.168.122.106\", \"ControlPlaneSubnetCidr\": \"24\", \"StorageIp\": \"172.18.0.106\", \"StorageIpSubnet\": \"172.18.0.0/24\", \"StorageIpUri\": \"172.18.0.106\", \"StorageMgmtIp\": \"172.20.0.106\", \"StorageMgmtIpSubnet\": \"172.20.0.0/24\", \"StorageMgmtIpUri\": \"172.20.0.106\", \"InternalApiIp\": \"172.17.0.106\", \"InternalApiIpSubnet\": \"172.17.0.0/24\", \"InternalApiIpUri\": \"172.17.0.106\", \"TenantIp\": \"172.19.0.106\", \"TenantIpSubnet\": \"172.19.0.0/24\", \"TenantIpUri\": \"172.19.0.106\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(194,'2026-06-12 08:26:42',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": true, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"192.168.122.106\", \"StorageIpList\": \"172.18.0.106\", \"StorageMgmtIpList\": \"172.20.0.106\", \"InternalApiIpList\": \"172.17.0.106\", \"TenantIpList\": \"172.19.0.106\", \"EnabledServices\": \"boot_params_service,ca_certs,clustercheck,collectd,container_image_prepare,logrotate_crond,haproxy,iscsid,kernel,metrics_qdr,mysql,mysql_client,nova_conductor,nova_metadata,nova_vnc_proxy,oslo_messaging_rpc,pacemaker,podman,rsyslog,snmp,sshd,chrony,timezone,tripleo_firewall,tripleo_packages,tuned\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"np0000071538\", \"NetworkHostnameMap\": {\"storage\": [\"np0000071538.storage.ooo.test\"], \"storage_mgmt\": [\"np0000071538.storagemgmt.ooo.test\"], \"internal_api\": [\"np0000071538.internalapi.ooo.test\"], \"tenant\": [\"np0000071538.tenant.ooo.test\"], \"ctlplane\": [\"np0000071538.ctlplane.ooo.test\"], \"canonical\": [\"np0000071538.ooo.test\"]}, \"RoleNetworks\": \"ctlplane,storage,storage_mgmt,internal_api,tenant\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (195,'2026-06-12 08:26:42',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Post-deploy configuration steps via puppet for all roles, as defined in ../roles_data.yaml\\n\", \"parameters\": {\"servers\": {\"type\": \"json\", \"description\": \"Mapping of Role name e.g Controller to a list of servers\"}, \"role_data\": {\"type\": \"json\", \"description\": \"Mapping of Role name e.g Controller to the per-role data\"}, \"DeployIdentifier\": {\"default\": 1781252715, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"deployment_source_hosts\": {\"default\": \"Undercloud\", \"type\": \"string\", \"description\": \"Host or hostgroup that runs the deployment\"}, \"deployment_target_hosts\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Host or hostgroup that consists of the target systems for the deployment. Defaults to all hosts in the current Heat stack if not set.\\n\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ConfigDebug\": {\"default\": false, \"description\": \"Whether to run config management (e.g. Puppet) in debug mode.\", \"type\": \"boolean\"}, \"HideSensitiveLogs\": {\"default\": true, \"type\": \"boolean\", \"description\": \"Set it to false if you don\'t want to activate the no_log feature within ansible modules.\\n\"}, \"EnablePuppet\": {\"default\": true, \"description\": \"Whether to run the puppet (baremetal) deployment tasks.\", \"type\": \"boolean\"}, \"EnablePaunch\": {\"default\": false, \"description\": \"(DEPRECATED) Whether to run paunch during container deployment tasks.\\n\", \"type\": \"boolean\"}, \"DockerPuppetDebug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debug logging with Puppet Containers\"}, \"DockerPuppetProcessCount\": {\"type\": \"number\", \"default\": 6, \"description\": \"Number of concurrent processes to use when running container-puppet to generate config files.\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"DockerPuppetMountHostPuppet\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Whether containerized puppet executions use modules from the baremetal host. Defaults to true. Can be set to false to consume puppet modules from containers directly.\"}, \"ContainerLogStdoutPath\": {\"type\": \"string\", \"description\": \"Absolute path for container stdout output (Podman only)\", \"default\": \"/var/log/containers/stdouts\"}, \"ContainerHealthcheckDisabled\": {\"type\": \"boolean\", \"description\": \"Whether or not we disable the container healthcheck.\", \"default\": false}, \"SELinuxMode\": {\"default\": \"enforcing\", \"description\": \"Configures SELinux mode\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"enforcing\", \"permissive\", \"disabled\"]}]}, \"ControllerCount\": {\"description\": \"Number of Controller nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"CellControllerCount\": {\"description\": \"Number of CellController nodes to deploy\", \"type\": \"number\", \"default\": 1}, \"CellControllerComputeCount\": {\"description\": \"Number of CellControllerCompute nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"ComputeCount\": {\"description\": \"Number of Compute nodes to deploy\", \"type\": \"number\", \"default\": 1}, \"BlockStorageCount\": {\"description\": \"Number of BlockStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"ObjectStorageCount\": {\"description\": \"Number of ObjectStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"CephStorageCount\": {\"description\": \"Number of CephStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"NetworkerCount\": {\"description\": \"Number of Networker nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"ServiceNetMapLower\": {\"description\": \"Mapping of service name to network name\", \"type\": \"json\", \"default\": {}}, \"ValidateControllersIcmp\": {\"default\": true, \"description\": \"Validation to ensure that all controllers can be reached with ICMP\", \"type\": \"boolean\"}, \"ValidateGatewaysIcmp\": {\"default\": true, \"description\": \"Validation to ensure that all gateways can be reached with ICMP\", \"type\": \"boolean\"}, \"ValidateFqdn\": {\"default\": false, \"description\": \"Optional validation to ensure FQDN as set by Nova matches the name set in /etc/hosts.\", \"type\": \"boolean\"}, \"PingTestGatewayIPsMap\": {\"default\": {}, \"description\": \"A map of role name to list of gateway IP addresses for each network, used to ping test each gateway.\", \"type\": \"json\"}, \"PingTestIpsMap\": {\"default\": \"\", \"description\": \"A map of role name to a space separated list of IP addresses used to ping test each available network interface.\", \"type\": \"json\"}, \"NetworkSafeDefaults\": {\"default\": true, \"description\": \"Allow to enable/disable safe networking defaults if os-net-config would fail to run with the provided config.\", \"type\": \"boolean\"}, \"DeployArtifactURLs\": {\"default\": [], \"description\": \"A list of HTTP URLs containing deployment artifacts to be pulled. Currently supports tarballs and RPM packages.\", \"type\": \"comma_delimited_list\"}, \"DeployArtifactFILEs\": {\"default\": [], \"description\": \"A list of files containing deployment artifacts to be pushed. Currently supports tarballs and RPM packages.\", \"type\": \"comma_delimited_list\"}, \"HostsEntry\": {\"default\": [], \"type\": \"comma_delimited_list\", \"description\": \"A list of entries to be added to /etc/hosts on each node.\"}, \"AnsibleHostVarsMap\": {\"type\": \"json\", \"default\": {}}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ControlVirtualIP\": {\"type\": \"string\"}, \"EnabledNetworks\": {\"type\": \"comma_delimited_list\"}, \"NetVipMap\": {\"type\": \"json\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"CloudNames\": {\"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": false}, \"CloudDomain\": {\"default\": \"ooo.test\", \"type\": \"string\", \"description\": \"The DNS domain used for the hosts. This must match the overcloud_domain_name configured on the undercloud.\\n\"}, \"NovaAdditionalCell\": {\"default\": true, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"AllNodesExtraMapData\": {\"default\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"type\": \"json\", \"description\": \"Map of extra data (hieradata) to set on each node.\"}, \"UndercloudHostsEntries\": {\"default\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"], \"description\": \"List of undercloud hosts entries to be appended to /etc/hosts. The value is populated with the HEAT_HOSTS entries on the undercloud by tripleoclient when running deploy.\\n\", \"type\": \"comma_delimited_list\"}, \"ExtraHostsEntries\": {\"default\": [], \"description\": \"List of extra hosts entries to be appended to /etc/hosts\", \"type\": \"comma_delimited_list\"}, \"VipHostsEntries\": {\"default\": [], \"description\": \"List of VIP (virtual IP) hosts entries to be appended to /etc/hosts\", \"type\": \"comma_delimited_list\"}, \"KeystoneResourcesConfigs\": {\"description\": \"The keystone resources config.\", \"type\": \"json\", \"default\": {}}, \"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\", \"default\": \"cell1\"}, \"NetCidrMap\": {\"description\": \"Mapping of CIDRs to network name\", \"type\": \"json\", \"default\": {}}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"EnablePaunch\", \"ServiceNetMapLower\"]}], \"conditions\": {\"ControllerNonZero\": {\"not\": {\"equals\": [{\"get_param\": \"ControllerCount\"}, 0]}}, \"CellControllerNonZero\": {\"not\": {\"equals\": [{\"get_param\": \"CellControllerCount\"}, 0]}}, \"CellControllerComputeNonZero\": {\"not\": {\"equals\": [{\"get_param\": \"CellControllerComputeCount\"}, 0]}}, \"ComputeNonZero\": {\"not\": {\"equals\": [{\"get_param\": \"ComputeCount\"}, 0]}}, \"BlockStorageNonZero\": {\"not\": {\"equals\": [{\"get_param\": \"BlockStorageCount\"}, 0]}}, \"ObjectStorageNonZero\": {\"not\": {\"equals\": [{\"get_param\": \"ObjectStorageCount\"}, 0]}}, \"CephStorageNonZero\": {\"not\": {\"equals\": [{\"get_param\": \"CephStorageCount\"}, 0]}}, \"NetworkerNonZero\": {\"not\": {\"equals\": [{\"get_param\": \"NetworkerCount\"}, 0]}}}, \"resources\": {\"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"list_concat_unique\": [{\"if\": [\"ControllerNonZero\", {\"get_param\": [\"role_data\", \"Controller\", \"pre_deploy_step_tasks\"]}, []]}, {\"if\": [\"CellControllerNonZero\", {\"get_param\": [\"role_data\", \"CellController\", \"pre_deploy_step_tasks\"]}, []]}, {\"if\": [\"CellControllerComputeNonZero\", {\"get_param\": [\"role_data\", \"CellControllerCompute\", \"pre_deploy_step_tasks\"]}, []]}, {\"if\": [\"ComputeNonZero\", {\"get_param\": [\"role_data\", \"Compute\", \"pre_deploy_step_tasks\"]}, []]}, {\"if\": [\"BlockStorageNonZero\", {\"get_param\": [\"role_data\", \"BlockStorage\", \"pre_deploy_step_tasks\"]}, []]}, {\"if\": [\"ObjectStorageNonZero\", {\"get_param\": [\"role_data\", \"ObjectStorage\", \"pre_deploy_step_tasks\"]}, []]}, {\"if\": [\"CephStorageNonZero\", {\"get_param\": [\"role_data\", \"CephStorage\", \"pre_deploy_step_tasks\"]}, []]}, {\"if\": [\"NetworkerNonZero\", {\"get_param\": [\"role_data\", \"Networker\", \"pre_deploy_step_tasks\"]}, []]}]}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"list_concat_unique\": [{\"if\": [\"ControllerNonZero\", {\"get_param\": [\"role_data\", \"Controller\", \"external_deploy_tasks\"]}, []]}, {\"if\": [\"CellControllerNonZero\", {\"get_param\": [\"role_data\", \"CellController\", \"external_deploy_tasks\"]}, []]}, {\"if\": [\"CellControllerComputeNonZero\", {\"get_param\": [\"role_data\", \"CellControllerCompute\", \"external_deploy_tasks\"]}, []]}, {\"if\": [\"ComputeNonZero\", {\"get_param\": [\"role_data\", \"Compute\", \"external_deploy_tasks\"]}, []]}, {\"if\": [\"BlockStorageNonZero\", {\"get_param\": [\"role_data\", \"BlockStorage\", \"external_deploy_tasks\"]}, []]}, {\"if\": [\"ObjectStorageNonZero\", {\"get_param\": [\"role_data\", \"ObjectStorage\", \"external_deploy_tasks\"]}, []]}, {\"if\": [\"CephStorageNonZero\", {\"get_param\": [\"role_data\", \"CephStorage\", \"external_deploy_tasks\"]}, []]}, {\"if\": [\"NetworkerNonZero\", {\"get_param\": [\"role_data\", \"Networker\", \"external_deploy_tasks\"]}, []]}]}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"list_concat_unique\": [{\"if\": [\"ControllerNonZero\", {\"get_param\": [\"role_data\", \"Controller\", \"external_post_deploy_tasks\"]}, []]}, {\"if\": [\"CellControllerNonZero\", {\"get_param\": [\"role_data\", \"CellController\", \"external_post_deploy_tasks\"]}, []]}, {\"if\": [\"CellControllerComputeNonZero\", {\"get_param\": [\"role_data\", \"CellControllerCompute\", \"external_post_deploy_tasks\"]}, []]}, {\"if\": [\"ComputeNonZero\", {\"get_param\": [\"role_data\", \"Compute\", \"external_post_deploy_tasks\"]}, []]}, {\"if\": [\"BlockStorageNonZero\", {\"get_param\": [\"role_data\", \"BlockStorage\", \"external_post_deploy_tasks\"]}, []]}, {\"if\": [\"ObjectStorageNonZero\", {\"get_param\": [\"role_data\", \"ObjectStorage\", \"external_post_deploy_tasks\"]}, []]}, {\"if\": [\"CephStorageNonZero\", {\"get_param\": [\"role_data\", \"CephStorage\", \"external_post_deploy_tasks\"]}, []]}, {\"if\": [\"NetworkerNonZero\", {\"get_param\": [\"role_data\", \"Networker\", \"external_post_deploy_tasks\"]}, []]}]}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"list_concat_unique\": [{\"get_param\": [\"role_data\", \"Controller\", \"scale_tasks\"]}, {\"get_param\": [\"role_data\", \"CellController\", \"scale_tasks\"]}, {\"get_param\": [\"role_data\", \"CellControllerCompute\", \"scale_tasks\"]}, {\"get_param\": [\"role_data\", \"Compute\", \"scale_tasks\"]}, {\"get_param\": [\"role_data\", \"BlockStorage\", \"scale_tasks\"]}, {\"get_param\": [\"role_data\", \"ObjectStorage\", \"scale_tasks\"]}, {\"get_param\": [\"role_data\", \"CephStorage\", \"scale_tasks\"]}, {\"get_param\": [\"role_data\", \"Networker\", \"scale_tasks\"]}]}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"list_concat_unique\": [{\"if\": [\"ControllerNonZero\", {\"get_param\": [\"role_data\", \"Controller\", \"external_update_tasks\"]}, []]}, {\"if\": [\"CellControllerNonZero\", {\"get_param\": [\"role_data\", \"CellController\", \"external_update_tasks\"]}, []]}, {\"if\": [\"CellControllerComputeNonZero\", {\"get_param\": [\"role_data\", \"CellControllerCompute\", \"external_update_tasks\"]}, []]}, {\"if\": [\"ComputeNonZero\", {\"get_param\": [\"role_data\", \"Compute\", \"external_update_tasks\"]}, []]}, {\"if\": [\"BlockStorageNonZero\", {\"get_param\": [\"role_data\", \"BlockStorage\", \"external_update_tasks\"]}, []]}, {\"if\": [\"ObjectStorageNonZero\", {\"get_param\": [\"role_data\", \"ObjectStorage\", \"external_update_tasks\"]}, []]}, {\"if\": [\"CephStorageNonZero\", {\"get_param\": [\"role_data\", \"CephStorage\", \"external_update_tasks\"]}, []]}, {\"if\": [\"NetworkerNonZero\", {\"get_param\": [\"role_data\", \"Networker\", \"external_update_tasks\"]}, []]}]}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"list_concat_unique\": [{\"if\": [\"ControllerNonZero\", {\"get_param\": [\"role_data\", \"Controller\", \"external_upgrade_tasks\"]}, []]}, {\"if\": [\"CellControllerNonZero\", {\"get_param\": [\"role_data\", \"CellController\", \"external_upgrade_tasks\"]}, []]}, {\"if\": [\"CellControllerComputeNonZero\", {\"get_param\": [\"role_data\", \"CellControllerCompute\", \"external_upgrade_tasks\"]}, []]}, {\"if\": [\"ComputeNonZero\", {\"get_param\": [\"role_data\", \"Compute\", \"external_upgrade_tasks\"]}, []]}, {\"if\": [\"BlockStorageNonZero\", {\"get_param\": [\"role_data\", \"BlockStorage\", \"external_upgrade_tasks\"]}, []]}, {\"if\": [\"ObjectStorageNonZero\", {\"get_param\": [\"role_data\", \"ObjectStorage\", \"external_upgrade_tasks\"]}, []]}, {\"if\": [\"CephStorageNonZero\", {\"get_param\": [\"role_data\", \"CephStorage\", \"external_upgrade_tasks\"]}, []]}, {\"if\": [\"NetworkerNonZero\", {\"get_param\": [\"role_data\", \"Networker\", \"external_upgrade_tasks\"]}, []]}]}}}, \"BootstrapServerId\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"switch($.data = {} => \\\"no_bootstrap_server\\\", $.data != {} => $.data.items().orderBy($[0]).first()[1])\", \"data\": {\"get_param\": [\"servers\", \"CellControllerCompute\"]}}}}}, \"ControllerExtraConfigPost\": {\"condition\": \"ControllerNonZero\", \"type\": \"OS::TripleO::NodeExtraConfigPost\", \"properties\": {\"servers\": {\"get_param\": [\"servers\", \"Controller\"]}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}}}, \"ControllerPostConfig\": {\"condition\": \"ControllerNonZero\", \"type\": \"OS::TripleO::Tasks::ControllerPostConfig\", \"depends_on\": [\"ControllerExtraConfigPost\", \"CellControllerExtraConfigPost\", \"CellControllerComputeExtraConfigPost\", \"ComputeExtraConfigPost\", \"BlockStorageExtraConfigPost\", \"ObjectStorageExtraConfigPost\", \"CephStorageExtraConfigPost\", \"NetworkerExtraConfigPost\"], \"properties\": {\"servers\": {\"get_param\": \"servers\"}, \"input_values\": {\"deploy_identifier\": {\"get_param\": \"DeployIdentifier\"}}}}, \"CellControllerExtraConfigPost\": {\"condition\": \"CellControllerNonZero\", \"type\": \"OS::TripleO::NodeExtraConfigPost\", \"properties\": {\"servers\": {\"get_param\": [\"servers\", \"CellController\"]}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}}}, \"CellControllerPostConfig\": {\"condition\": \"CellControllerNonZero\", \"type\": \"OS::TripleO::Tasks::CellControllerPostConfig\", \"depends_on\": [\"ControllerExtraConfigPost\", \"CellControllerExtraConfigPost\", \"CellControllerComputeExtraConfigPost\", \"ComputeExtraConfigPost\", \"BlockStorageExtraConfigPost\", \"ObjectStorageExtraConfigPost\", \"CephStorageExtraConfigPost\", \"NetworkerExtraConfigPost\"], \"properties\": {\"servers\": {\"get_param\": \"servers\"}, \"input_values\": {\"deploy_identifier\": {\"get_param\": \"DeployIdentifier\"}}}}, \"CellControllerComputeExtraConfigPost\": {\"condition\": \"CellControllerComputeNonZero\", \"type\": \"OS::TripleO::NodeExtraConfigPost\", \"properties\": {\"servers\": {\"get_param\": [\"servers\", \"CellControllerCompute\"]}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}}}, \"CellControllerComputePostConfig\": {\"condition\": \"CellControllerComputeNonZero\", \"type\": \"OS::TripleO::Tasks::CellControllerComputePostConfig\", \"depends_on\": [\"ControllerExtraConfigPost\", \"CellControllerExtraConfigPost\", \"CellControllerComputeExtraConfigPost\", \"ComputeExtraConfigPost\", \"BlockStorageExtraConfigPost\", \"ObjectStorageExtraConfigPost\", \"CephStorageExtraConfigPost\", \"NetworkerExtraConfigPost\"], \"properties\": {\"servers\": {\"get_param\": \"servers\"}, \"input_values\": {\"deploy_identifier\": {\"get_param\": \"DeployIdentifier\"}}}}, \"ComputeExtraConfigPost\": {\"condition\": \"ComputeNonZero\", \"type\": \"OS::TripleO::NodeExtraConfigPost\", \"properties\": {\"servers\": {\"get_param\": [\"servers\", \"Compute\"]}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}}}, \"ComputePostConfig\": {\"condition\": \"ComputeNonZero\", \"type\": \"OS::TripleO::Tasks::ComputePostConfig\", \"depends_on\": [\"ControllerExtraConfigPost\", \"CellControllerExtraConfigPost\", \"CellControllerComputeExtraConfigPost\", \"ComputeExtraConfigPost\", \"BlockStorageExtraConfigPost\", \"ObjectStorageExtraConfigPost\", \"CephStorageExtraConfigPost\", \"NetworkerExtraConfigPost\"], \"properties\": {\"servers\": {\"get_param\": \"servers\"}, \"input_values\": {\"deploy_identifier\": {\"get_param\": \"DeployIdentifier\"}}}}, \"BlockStorageExtraConfigPost\": {\"condition\": \"BlockStorageNonZero\", \"type\": \"OS::TripleO::NodeExtraConfigPost\", \"properties\": {\"servers\": {\"get_param\": [\"servers\", \"BlockStorage\"]}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}}}, \"BlockStoragePostConfig\": {\"condition\": \"BlockStorageNonZero\", \"type\": \"OS::TripleO::Tasks::BlockStoragePostConfig\", \"depends_on\": [\"ControllerExtraConfigPost\", \"CellControllerExtraConfigPost\", \"CellControllerComputeExtraConfigPost\", \"ComputeExtraConfigPost\", \"BlockStorageExtraConfigPost\", \"ObjectStorageExtraConfigPost\", \"CephStorageExtraConfigPost\", \"NetworkerExtraConfigPost\"], \"properties\": {\"servers\": {\"get_param\": \"servers\"}, \"input_values\": {\"deploy_identifier\": {\"get_param\": \"DeployIdentifier\"}}}}, \"ObjectStorageExtraConfigPost\": {\"condition\": \"ObjectStorageNonZero\", \"type\": \"OS::TripleO::NodeExtraConfigPost\", \"properties\": {\"servers\": {\"get_param\": [\"servers\", \"ObjectStorage\"]}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}}}, \"ObjectStoragePostConfig\": {\"condition\": \"ObjectStorageNonZero\", \"type\": \"OS::TripleO::Tasks::ObjectStoragePostConfig\", \"depends_on\": [\"ControllerExtraConfigPost\", \"CellControllerExtraConfigPost\", \"CellControllerComputeExtraConfigPost\", \"ComputeExtraConfigPost\", \"BlockStorageExtraConfigPost\", \"ObjectStorageExtraConfigPost\", \"CephStorageExtraConfigPost\", \"NetworkerExtraConfigPost\"], \"properties\": {\"servers\": {\"get_param\": \"servers\"}, \"input_values\": {\"deploy_identifier\": {\"get_param\": \"DeployIdentifier\"}}}}, \"CephStorageExtraConfigPost\": {\"condition\": \"CephStorageNonZero\", \"type\": \"OS::TripleO::NodeExtraConfigPost\", \"properties\": {\"servers\": {\"get_param\": [\"servers\", \"CephStorage\"]}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}}}, \"CephStoragePostConfig\": {\"condition\": \"CephStorageNonZero\", \"type\": \"OS::TripleO::Tasks::CephStoragePostConfig\", \"depends_on\": [\"ControllerExtraConfigPost\", \"CellControllerExtraConfigPost\", \"CellControllerComputeExtraConfigPost\", \"ComputeExtraConfigPost\", \"BlockStorageExtraConfigPost\", \"ObjectStorageExtraConfigPost\", \"CephStorageExtraConfigPost\", \"NetworkerExtraConfigPost\"], \"properties\": {\"servers\": {\"get_param\": \"servers\"}, \"input_values\": {\"deploy_identifier\": {\"get_param\": \"DeployIdentifier\"}}}}, \"NetworkerExtraConfigPost\": {\"condition\": \"NetworkerNonZero\", \"type\": \"OS::TripleO::NodeExtraConfigPost\", \"properties\": {\"servers\": {\"get_param\": [\"servers\", \"Networker\"]}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}}}, \"NetworkerPostConfig\": {\"condition\": \"NetworkerNonZero\", \"type\": \"OS::TripleO::Tasks::NetworkerPostConfig\", \"depends_on\": [\"ControllerExtraConfigPost\", \"CellControllerExtraConfigPost\", \"CellControllerComputeExtraConfigPost\", \"ComputeExtraConfigPost\", \"BlockStorageExtraConfigPost\", \"ObjectStorageExtraConfigPost\", \"CephStorageExtraConfigPost\", \"NetworkerExtraConfigPost\"], \"properties\": {\"servers\": {\"get_param\": \"servers\"}, \"input_values\": {\"deploy_identifier\": {\"get_param\": \"DeployIdentifier\"}}}}}, \"outputs\": {\"RoleConfig\": {\"description\": \"Mapping of config data for all roles\", \"value\": {\"global_vars\": {\"deploy_steps_max\": 6, \"service_net_map\": {\"get_param\": \"ServiceNetMapLower\"}, \"validate_controllers_icmp\": {\"get_param\": \"ValidateControllersIcmp\"}, \"validate_gateways_icmp\": {\"get_param\": \"ValidateGatewaysIcmp\"}, \"validate_fqdn\": {\"get_param\": \"ValidateFqdn\"}, \"ping_test_gateway_ips\": {\"get_param\": \"PingTestGatewayIPsMap\"}, \"ping_test_ips\": {\"get_param\": \"PingTestIpsMap\"}, \"network_safe_defaults\": {\"get_param\": \"NetworkSafeDefaults\"}, \"deploy_artifact_urls\": {\"get_param\": \"DeployArtifactURLs\"}, \"deploy_artifact_files\": {\"get_param\": \"DeployArtifactFILEs\"}, \"hosts_entry\": {\"get_param\": \"HostsEntry\"}, \"primary_role_name\": \"CellControllerCompute\", \"deploy_identifier\": {\"get_param\": \"DeployIdentifier\"}, \"container_cli\": {\"get_param\": \"ContainerCli\"}, \"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"control_virtual_ip\": {\"get_param\": \"ControlVirtualIP\"}, \"enabled_networks\": {\"get_param\": \"EnabledNetworks\"}, \"net_vip_map\": {\"get_param\": \"NetVipMap\"}, \"nova_additional_cell\": {\"get_param\": \"NovaAdditionalCell\"}, \"hide_sensitive_logs\": {\"get_param\": \"HideSensitiveLogs\"}, \"storage_net_name\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt_net_name\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api_net_name\": {\"get_param\": \"InternalApiNetName\"}, \"tenant_net_name\": {\"get_param\": \"TenantNetName\"}, \"external_net_name\": {\"get_param\": \"ExternalNetName\"}, \"networks\": {\"Storage\": {\"name\": {\"get_param\": \"StorageNetName\"}, \"name_lower\": \"storage\"}, \"StorageMgmt\": {\"name\": {\"get_param\": \"StorageMgmtNetName\"}, \"name_lower\": \"storage_mgmt\"}, \"InternalApi\": {\"name\": {\"get_param\": \"InternalApiNetName\"}, \"name_lower\": \"internal_api\"}, \"Tenant\": {\"name\": {\"get_param\": \"TenantNetName\"}, \"name_lower\": \"tenant\"}, \"External\": {\"name\": {\"get_param\": \"ExternalNetName\"}, \"name_lower\": \"external\"}}, \"network_virtual_ips\": {\"ctlplane\": {\"ip_address\": {\"get_param\": [\"NetVipMap\", \"ctlplane\"]}, \"index\": 1}, \"storage\": {\"ip_address\": {\"get_param\": [\"NetVipMap\", {\"get_param\": \"StorageNetName\"}]}, \"index\": 2}, \"storage_mgmt\": {\"ip_address\": {\"get_param\": [\"NetVipMap\", {\"get_param\": \"StorageMgmtNetName\"}]}, \"index\": 3}, \"internal_api\": {\"ip_address\": {\"get_param\": [\"NetVipMap\", {\"get_param\": \"InternalApiNetName\"}]}, \"index\": 4}, \"external\": {\"ip_address\": {\"get_param\": [\"NetVipMap\", {\"get_param\": \"ExternalNetName\"}]}, \"index\": 5}}, \"cloud_names\": {\"get_param\": \"CloudNames\"}, \"enable_internal_tls\": {\"get_param\": \"EnableInternalTLS\"}, \"cloud_domain\": {\"get_param\": \"CloudDomain\"}, \"all_nodes_extra_map_data\": {\"get_param\": \"AllNodesExtraMapData\"}, \"undercloud_hosts_entries\": {\"get_param\": \"UndercloudHostsEntries\"}, \"extra_hosts_entries\": {\"get_param\": \"ExtraHostsEntries\"}, \"vip_hosts_entries\": {\"get_param\": \"VipHostsEntries\"}, \"keystone_resources\": {\"get_param\": \"KeystoneResourcesConfigs\"}, \"net_cidr_map\": {\"get_param\": \"NetCidrMap\"}}, \"common_deploy_steps_playbooks\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/deploy-steps-playbooks-common.yaml\"}, \"common_deploy_steps_tasks\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/deploy-steps-tasks.yaml\"}, \"common_container_config_scripts\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/common-container-config-scripts.yaml\"}, \"hiera_steps_tasks\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/hiera-steps-tasks.yaml\"}, \"deploy_steps_tasks_step_0\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/deploy-steps-tasks-step-0.yaml\"}, \"common_container_setup_tasks\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/common-container-setup-tasks.yaml\"}, \"common_deploy_steps_tasks_step_1\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/deploy-steps-tasks-step-1.yaml\"}, \"container_puppet_script\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/container-puppet.sh\"}, \"generate-config-tasks\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/generate-config-tasks.yaml\"}, \"host-container-puppet-tasks\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/host-container-puppet-tasks.yaml\"}, \"deploy_steps_0_playbook\": {\"str_replace\": {\"params\": {\"BOOTSTRAP_SERVER_ID\": {\"get_attr\": [\"BootstrapServerId\", \"value\"]}, \"DEPLOY_SOURCE_HOST\": {\"get_param\": \"deployment_source_hosts\"}, \"DEPLOY_TARGET_HOST\": {\"if\": [{\"equals\": [{\"get_param\": \"deployment_target_hosts\"}, \"\"]}, {\"get_param\": \"RootStackName\"}, {\"get_param\": \"deployment_target_hosts\"}]}, \"DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}, \"ENABLE_DEBUG\": {\"get_param\": \"ConfigDebug\"}, \"ENABLE_PUPPET\": {\"get_param\": \"EnablePuppet\"}, \"CONTAINER_CLI\": {\"get_param\": \"ContainerCli\"}, \"CONTAINER_LOG_STDOUT_PATH\": {\"get_param\": \"ContainerLogStdoutPath\"}, \"CONTAINER_HEALTHCHECK_DISABLED\": {\"get_param\": \"ContainerHealthcheckDisabled\"}, \"DOCKER_PUPPET_DEBUG\": {\"get_param\": \"DockerPuppetDebug\"}, \"DOCKER_PUPPET_PROCESS_COUNT\": {\"get_param\": \"DockerPuppetProcessCount\"}, \"DOCKER_PUPPET_MOUNT_HOST_PUPPET\": {\"get_param\": \"DockerPuppetMountHostPuppet\"}, \"SELINUX_MODE\": {\"get_param\": \"SELinuxMode\"}}, \"template\": \"- hosts: DEPLOY_SOURCE_HOST\\n  strategy: tripleo_free\\n  name: External deployment step 0\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  become: false\\n  vars:\\n    step: 0\\n    enable_debug: ENABLE_DEBUG\\n  tasks:\\n    - name: External deployment step 0\\n      delegate_to: localhost\\n      run_once: true\\n      debug:\\n        msg: Use --start-at-task \'External deployment step 0\' to resume from this task\\n    - include_tasks: \\\"external_deploy_steps_tasks_step0.yaml\\\"\\n      when:\\n        - playbook_dir ~ \'/external_deploy_steps_tasks_step0.yaml\' is exists\\n  tags:\\n    - external\\n    - external_deploy_steps\\n    - step0\\n\\n- import_playbook: common_deploy_steps_playbooks.yaml\\n  vars:\\n    deploy_source_host: \\\"DEPLOY_SOURCE_HOST\\\"\\n    deploy_target_host: \\\"DEPLOY_TARGET_HOST\\\"\\n\"}}, \"deploy_steps_selinux_playbook\": {\"str_replace\": {\"params\": {\"BOOTSTRAP_SERVER_ID\": {\"get_attr\": [\"BootstrapServerId\", \"value\"]}, \"DEPLOY_SOURCE_HOST\": {\"get_param\": \"deployment_source_hosts\"}, \"DEPLOY_TARGET_HOST\": {\"if\": [{\"equals\": [{\"get_param\": \"deployment_target_hosts\"}, \"\"]}, {\"get_param\": \"RootStackName\"}, {\"get_param\": \"deployment_target_hosts\"}]}, \"DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}, \"ENABLE_DEBUG\": {\"get_param\": \"ConfigDebug\"}, \"ENABLE_PUPPET\": {\"get_param\": \"EnablePuppet\"}, \"CONTAINER_CLI\": {\"get_param\": \"ContainerCli\"}, \"CONTAINER_LOG_STDOUT_PATH\": {\"get_param\": \"ContainerLogStdoutPath\"}, \"CONTAINER_HEALTHCHECK_DISABLED\": {\"get_param\": \"ContainerHealthcheckDisabled\"}, \"DOCKER_PUPPET_DEBUG\": {\"get_param\": \"DockerPuppetDebug\"}, \"DOCKER_PUPPET_PROCESS_COUNT\": {\"get_param\": \"DockerPuppetProcessCount\"}, \"DOCKER_PUPPET_MOUNT_HOST_PUPPET\": {\"get_param\": \"DockerPuppetMountHostPuppet\"}, \"SELINUX_MODE\": {\"get_param\": \"SELinuxMode\"}}, \"template\": \"- hosts: DEPLOY_TARGET_HOST\\n  strategy: tripleo_linear\\n  name: Manage SELinux\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  tasks:\\n    - name: Set selinux state\\n      become: true\\n      selinux:\\n        policy: targeted\\n        state: SELINUX_MODE\\n\\n- hosts: all\\n  strategy: tripleo_linear\\n  name: Generate /etc/hosts\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  tasks:\\n\\n    - name: Configure Hosts Entries\\n      include_role:\\n        name: tripleo_hosts_entries\\n      vars:\\n        tripleo_hosts_entries_undercloud_hosts_entries: \\\"{{ undercloud_hosts_entries }}\\\"\\n        tripleo_hosts_entries_extra_hosts_entries: \\\"{{ extra_hosts_entries }}\\\"\\n        tripleo_hosts_entries_vip_hosts_entries: \\\"{{ vip_hosts_entries }}\\\"\\n\"}}, \"deploy_steps_common_roles_playbook\": {\"str_replace\": {\"params\": {\"BOOTSTRAP_SERVER_ID\": {\"get_attr\": [\"BootstrapServerId\", \"value\"]}, \"DEPLOY_SOURCE_HOST\": {\"get_param\": \"deployment_source_hosts\"}, \"DEPLOY_TARGET_HOST\": {\"if\": [{\"equals\": [{\"get_param\": \"deployment_target_hosts\"}, \"\"]}, {\"get_param\": \"RootStackName\"}, {\"get_param\": \"deployment_target_hosts\"}]}, \"DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}, \"ENABLE_DEBUG\": {\"get_param\": \"ConfigDebug\"}, \"ENABLE_PUPPET\": {\"get_param\": \"EnablePuppet\"}, \"CONTAINER_CLI\": {\"get_param\": \"ContainerCli\"}, \"CONTAINER_LOG_STDOUT_PATH\": {\"get_param\": \"ContainerLogStdoutPath\"}, \"CONTAINER_HEALTHCHECK_DISABLED\": {\"get_param\": \"ContainerHealthcheckDisabled\"}, \"DOCKER_PUPPET_DEBUG\": {\"get_param\": \"DockerPuppetDebug\"}, \"DOCKER_PUPPET_PROCESS_COUNT\": {\"get_param\": \"DockerPuppetProcessCount\"}, \"DOCKER_PUPPET_MOUNT_HOST_PUPPET\": {\"get_param\": \"DockerPuppetMountHostPuppet\"}, \"SELINUX_MODE\": {\"get_param\": \"SELinuxMode\"}}, \"template\": \"- hosts: DEPLOY_TARGET_HOST\\n  strategy: tripleo_linear\\n  name: Common roles for TripleO servers\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  # pre_tasks run before any roles in a play, so we use it for the\\n  # named debug task for --start-at-task.\\n  pre_tasks:\\n    - name: Common roles for TripleO servers\\n      delegate_to: localhost\\n      run_once: true\\n      debug:\\n        msg: Use --start-at-task \'Common roles for TripleO servers\' to resume from this task\\n  tasks:\\n    - include_role:\\n        name: tripleo_bootstrap\\n    - include_role:\\n        name: tripleo_ssh_known_hosts\\n  tags:\\n    - common_roles\\n\"}}, \"deploy_steps_0_tasks_playbook\": {\"str_replace\": {\"params\": {\"BOOTSTRAP_SERVER_ID\": {\"get_attr\": [\"BootstrapServerId\", \"value\"]}, \"DEPLOY_SOURCE_HOST\": {\"get_param\": \"deployment_source_hosts\"}, \"DEPLOY_TARGET_HOST\": {\"if\": [{\"equals\": [{\"get_param\": \"deployment_target_hosts\"}, \"\"]}, {\"get_param\": \"RootStackName\"}, {\"get_param\": \"deployment_target_hosts\"}]}, \"DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}, \"ENABLE_DEBUG\": {\"get_param\": \"ConfigDebug\"}, \"ENABLE_PUPPET\": {\"get_param\": \"EnablePuppet\"}, \"CONTAINER_CLI\": {\"get_param\": \"ContainerCli\"}, \"CONTAINER_LOG_STDOUT_PATH\": {\"get_param\": \"ContainerLogStdoutPath\"}, \"CONTAINER_HEALTHCHECK_DISABLED\": {\"get_param\": \"ContainerHealthcheckDisabled\"}, \"DOCKER_PUPPET_DEBUG\": {\"get_param\": \"DockerPuppetDebug\"}, \"DOCKER_PUPPET_PROCESS_COUNT\": {\"get_param\": \"DockerPuppetProcessCount\"}, \"DOCKER_PUPPET_MOUNT_HOST_PUPPET\": {\"get_param\": \"DockerPuppetMountHostPuppet\"}, \"SELINUX_MODE\": {\"get_param\": \"SELinuxMode\"}}, \"template\": \"- hosts: CellControllerCompute:DEPLOY_TARGET_HOST\\n  strategy: tripleo_free\\n  name: Deploy step tasks for step 0\\n  become: true\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  vars:\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    step: 0\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    enable_puppet: ENABLE_PUPPET\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n  tasks:\\n    - import_tasks: deploy_steps_tasks_step_0.yaml\\n  tags:\\n    - overcloud\\n    - deploy_steps\\n    - step0\\n\"}}, \"deploy_steps_pre_network_playbook\": {\"str_replace\": {\"params\": {\"BOOTSTRAP_SERVER_ID\": {\"get_attr\": [\"BootstrapServerId\", \"value\"]}, \"DEPLOY_SOURCE_HOST\": {\"get_param\": \"deployment_source_hosts\"}, \"DEPLOY_TARGET_HOST\": {\"if\": [{\"equals\": [{\"get_param\": \"deployment_target_hosts\"}, \"\"]}, {\"get_param\": \"RootStackName\"}, {\"get_param\": \"deployment_target_hosts\"}]}, \"DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}, \"ENABLE_DEBUG\": {\"get_param\": \"ConfigDebug\"}, \"ENABLE_PUPPET\": {\"get_param\": \"EnablePuppet\"}, \"CONTAINER_CLI\": {\"get_param\": \"ContainerCli\"}, \"CONTAINER_LOG_STDOUT_PATH\": {\"get_param\": \"ContainerLogStdoutPath\"}, \"CONTAINER_HEALTHCHECK_DISABLED\": {\"get_param\": \"ContainerHealthcheckDisabled\"}, \"DOCKER_PUPPET_DEBUG\": {\"get_param\": \"DockerPuppetDebug\"}, \"DOCKER_PUPPET_PROCESS_COUNT\": {\"get_param\": \"DockerPuppetProcessCount\"}, \"DOCKER_PUPPET_MOUNT_HOST_PUPPET\": {\"get_param\": \"DockerPuppetMountHostPuppet\"}, \"SELINUX_MODE\": {\"get_param\": \"SELinuxMode\"}}, \"template\": \"- hosts: CellControllerCompute:DEPLOY_TARGET_HOST\\n  strategy: tripleo_free\\n  name: Server pre network steps\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  vars:\\n    deploy_source_host: \\\"DEPLOY_SOURCE_HOST\\\"\\n  tasks:\\n\\n    - name: Server pre-network deployments\\n      delegate_to: localhost\\n      run_once: true\\n      debug:\\n        msg: Use --start-at-task \'Server pre-network deployments\' to resume from this task\\n    - import_tasks: hiera_steps_tasks.yaml\\n    - include_tasks: deployments.yaml\\n      vars:\\n        force: false\\n      with_items: \\\"{{ hostvars[inventory_hostname][\'pre_network_\' ~ tripleo_role_name]|default([]) }}\\\"\\n\\n  tags:\\n    - overcloud\\n    - pre_deploy_steps\\n\"}}, \"deploy_steps_network_deployments_playbook\": {\"str_replace\": {\"params\": {\"BOOTSTRAP_SERVER_ID\": {\"get_attr\": [\"BootstrapServerId\", \"value\"]}, \"DEPLOY_SOURCE_HOST\": {\"get_param\": \"deployment_source_hosts\"}, \"DEPLOY_TARGET_HOST\": {\"if\": [{\"equals\": [{\"get_param\": \"deployment_target_hosts\"}, \"\"]}, {\"get_param\": \"RootStackName\"}, {\"get_param\": \"deployment_target_hosts\"}]}, \"DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}, \"ENABLE_DEBUG\": {\"get_param\": \"ConfigDebug\"}, \"ENABLE_PUPPET\": {\"get_param\": \"EnablePuppet\"}, \"CONTAINER_CLI\": {\"get_param\": \"ContainerCli\"}, \"CONTAINER_LOG_STDOUT_PATH\": {\"get_param\": \"ContainerLogStdoutPath\"}, \"CONTAINER_HEALTHCHECK_DISABLED\": {\"get_param\": \"ContainerHealthcheckDisabled\"}, \"DOCKER_PUPPET_DEBUG\": {\"get_param\": \"DockerPuppetDebug\"}, \"DOCKER_PUPPET_PROCESS_COUNT\": {\"get_param\": \"DockerPuppetProcessCount\"}, \"DOCKER_PUPPET_MOUNT_HOST_PUPPET\": {\"get_param\": \"DockerPuppetMountHostPuppet\"}, \"SELINUX_MODE\": {\"get_param\": \"SELinuxMode\"}}, \"template\": \"- hosts: CellControllerCompute:DEPLOY_TARGET_HOST\\n  strategy: tripleo_free\\n  name: Server network deployments\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  tasks:\\n\\n    - name: Network Configuration\\n      delegate_to: localhost\\n      run_once: true\\n      debug:\\n        msg: Use --start-at-task \'Network Configuration\' to resume from this task\\n    - name: Check NetworkConfig script existence\\n      delegate_to: localhost\\n      stat:\\n        path: \\\"{{ tripleo_role_name ~ \'/NetworkConfig\' }}\\\"\\n      register: NetworkConfig_stat\\n      when: not tripleo_network_config_with_ansible\\n    - name: Run Network Config\\n      import_role:\\n        name: tripleo_network_config\\n      vars:\\n        tripleo_network_config_script_path: \\\"{{ NetworkConfig_stat.stat.path }}\\\"\\n        tripleo_network_config_update: \\\"{{ network_config_update }}\\\"\\n        tripleo_network_config_nmstate: \\\"{{ use_nmstate }}\\\"\\n        tripleo_network_config_purge: \\\"{{ ifcfg_purge }}\\\"\\n        tripleo_network_config_async_timeout: \\\"{{ async_timeout | default(300) }}\\\"\\n        tripleo_network_config_async_poll: \\\"{{ async_poll | default(3) }}\\\"\\n        tripleo_network_config_hide_sensitive_logs: false\\n        tripleo_network_config_legacy_script: false\\n        tripleo_network_config_safe_defaults: \\\"{{ network_safe_defaults }}|bool\\\"\\n      when:\\n        - tripleo_network_config_with_ansible or NetworkConfig_stat.stat.exists\\n  tags:\\n    - overcloud\\n    - pre_deploy_steps\\n    - network_deploy_steps\\n\"}}, \"deploy_steps_network_validation_playbook\": {\"str_replace\": {\"params\": {\"BOOTSTRAP_SERVER_ID\": {\"get_attr\": [\"BootstrapServerId\", \"value\"]}, \"DEPLOY_SOURCE_HOST\": {\"get_param\": \"deployment_source_hosts\"}, \"DEPLOY_TARGET_HOST\": {\"if\": [{\"equals\": [{\"get_param\": \"deployment_target_hosts\"}, \"\"]}, {\"get_param\": \"RootStackName\"}, {\"get_param\": \"deployment_target_hosts\"}]}, \"DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}, \"ENABLE_DEBUG\": {\"get_param\": \"ConfigDebug\"}, \"ENABLE_PUPPET\": {\"get_param\": \"EnablePuppet\"}, \"CONTAINER_CLI\": {\"get_param\": \"ContainerCli\"}, \"CONTAINER_LOG_STDOUT_PATH\": {\"get_param\": \"ContainerLogStdoutPath\"}, \"CONTAINER_HEALTHCHECK_DISABLED\": {\"get_param\": \"ContainerHealthcheckDisabled\"}, \"DOCKER_PUPPET_DEBUG\": {\"get_param\": \"DockerPuppetDebug\"}, \"DOCKER_PUPPET_PROCESS_COUNT\": {\"get_param\": \"DockerPuppetProcessCount\"}, \"DOCKER_PUPPET_MOUNT_HOST_PUPPET\": {\"get_param\": \"DockerPuppetMountHostPuppet\"}, \"SELINUX_MODE\": {\"get_param\": \"SELinuxMode\"}}, \"template\": \"- hosts: CellControllerCompute:DEPLOY_TARGET_HOST\\n  strategy: tripleo_free\\n  name: Server network validation\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  tasks:\\n\\n    - name: Basic Network Validation\\n      include_role:\\n        name: tripleo_nodes_validation\\n      vars:\\n        tripleo_nodes_validation_validate_controllers_icmp: \\\"{{ validate_controllers_icmp }}\\\"\\n        tripleo_nodes_validation_validate_gateway_icmp: \\\"{{ validate_gateways_icmp }}\\\"\\n        tripleo_nodes_validation_validate_fqdn: \\\"{{ validate_fqdn }}\\\"\\n        tripleo_nodes_validation_ping_test_ips: \\\"{{ ping_test_ips.get(tripleo_role_name, \'\').split() | list | unique }}\\\"\\n        tripleo_nodes_validation_ping_test_gateway_ips: \\\"{{ ping_test_gateway_ips.get(tripleo_role_name, []) }}\\\"\\n  tags:\\n    - overcloud\\n    - pre_deploy_steps\\n    - network_deploy_steps\\n\"}}, \"deploy_steps_pre_deployment_playbook\": {\"str_replace\": {\"params\": {\"BOOTSTRAP_SERVER_ID\": {\"get_attr\": [\"BootstrapServerId\", \"value\"]}, \"DEPLOY_SOURCE_HOST\": {\"get_param\": \"deployment_source_hosts\"}, \"DEPLOY_TARGET_HOST\": {\"if\": [{\"equals\": [{\"get_param\": \"deployment_target_hosts\"}, \"\"]}, {\"get_param\": \"RootStackName\"}, {\"get_param\": \"deployment_target_hosts\"}]}, \"DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}, \"ENABLE_DEBUG\": {\"get_param\": \"ConfigDebug\"}, \"ENABLE_PUPPET\": {\"get_param\": \"EnablePuppet\"}, \"CONTAINER_CLI\": {\"get_param\": \"ContainerCli\"}, \"CONTAINER_LOG_STDOUT_PATH\": {\"get_param\": \"ContainerLogStdoutPath\"}, \"CONTAINER_HEALTHCHECK_DISABLED\": {\"get_param\": \"ContainerHealthcheckDisabled\"}, \"DOCKER_PUPPET_DEBUG\": {\"get_param\": \"DockerPuppetDebug\"}, \"DOCKER_PUPPET_PROCESS_COUNT\": {\"get_param\": \"DockerPuppetProcessCount\"}, \"DOCKER_PUPPET_MOUNT_HOST_PUPPET\": {\"get_param\": \"DockerPuppetMountHostPuppet\"}, \"SELINUX_MODE\": {\"get_param\": \"SELinuxMode\"}}, \"template\": \"- hosts: CellControllerCompute:DEPLOY_TARGET_HOST\\n  strategy: tripleo_free\\n  name: Server pre deployment steps\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  tasks:\\n    - name: Server pre deployments\\n      delegate_to: localhost\\n      run_once: true\\n      debug:\\n        msg: Use --start-at-task \'Server pre deployments\' to resume from this task\\n\\n    - import_tasks: hiera_steps_tasks.yaml\\n    - include_tasks: deployments.yaml\\n      vars:\\n        force: false\\n      with_items: \\\"{{ hostvars[inventory_hostname][\'pre_deployments_\' ~ tripleo_role_name]|default([]) }}\\\"\\n\\n  tags:\\n    - overcloud\\n    - pre_deploy_steps\\n\"}}, \"deploy_steps_host_prep_playbook\": {\"str_replace\": {\"params\": {\"BOOTSTRAP_SERVER_ID\": {\"get_attr\": [\"BootstrapServerId\", \"value\"]}, \"DEPLOY_SOURCE_HOST\": {\"get_param\": \"deployment_source_hosts\"}, \"DEPLOY_TARGET_HOST\": {\"if\": [{\"equals\": [{\"get_param\": \"deployment_target_hosts\"}, \"\"]}, {\"get_param\": \"RootStackName\"}, {\"get_param\": \"deployment_target_hosts\"}]}, \"DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}, \"ENABLE_DEBUG\": {\"get_param\": \"ConfigDebug\"}, \"ENABLE_PUPPET\": {\"get_param\": \"EnablePuppet\"}, \"CONTAINER_CLI\": {\"get_param\": \"ContainerCli\"}, \"CONTAINER_LOG_STDOUT_PATH\": {\"get_param\": \"ContainerLogStdoutPath\"}, \"CONTAINER_HEALTHCHECK_DISABLED\": {\"get_param\": \"ContainerHealthcheckDisabled\"}, \"DOCKER_PUPPET_DEBUG\": {\"get_param\": \"DockerPuppetDebug\"}, \"DOCKER_PUPPET_PROCESS_COUNT\": {\"get_param\": \"DockerPuppetProcessCount\"}, \"DOCKER_PUPPET_MOUNT_HOST_PUPPET\": {\"get_param\": \"DockerPuppetMountHostPuppet\"}, \"SELINUX_MODE\": {\"get_param\": \"SELinuxMode\"}}, \"template\": \"- hosts: CellControllerCompute:DEPLOY_TARGET_HOST\\n  strategy: tripleo_free\\n  name: Host prep steps\\n  become: true\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  vars:\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    enable_puppet: ENABLE_PUPPET\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n  tasks:\\n\\n    - name: Host prep steps\\n      delegate_to: localhost\\n      run_once: true\\n      debug:\\n        msg: Use --start-at-task \'Host prep steps\' to resume from this task\\n    - name: Deploy Artifacts\\n      tripleo_push_artifacts:\\n        artifact_urls: \\\"{{ deploy_artifact_urls | default([]) }}\\\"\\n        artifact_paths: \\\"{{ deploy_artifact_files | default([]) }}\\\"\\n      when:\\n        - ((deploy_artifact_urls | default([]) | length) > 0) or\\n          ((deploy_artifact_files | default([]) | length) > 0)\\n    - include_tasks: \\\"{{ _task_file_path }}\\\"\\n      vars:\\n        _task_file_path: \\\"{{ tripleo_role_name }}/host_prep_tasks.yaml\\\"\\n      when: \\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\"\\n  tags:\\n    - overcloud\\n    - host_prep_steps\\n\"}}, \"deploy_steps_container_setup_tasks_playbook\": {\"str_replace\": {\"params\": {\"BOOTSTRAP_SERVER_ID\": {\"get_attr\": [\"BootstrapServerId\", \"value\"]}, \"DEPLOY_SOURCE_HOST\": {\"get_param\": \"deployment_source_hosts\"}, \"DEPLOY_TARGET_HOST\": {\"if\": [{\"equals\": [{\"get_param\": \"deployment_target_hosts\"}, \"\"]}, {\"get_param\": \"RootStackName\"}, {\"get_param\": \"deployment_target_hosts\"}]}, \"DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}, \"ENABLE_DEBUG\": {\"get_param\": \"ConfigDebug\"}, \"ENABLE_PUPPET\": {\"get_param\": \"EnablePuppet\"}, \"CONTAINER_CLI\": {\"get_param\": \"ContainerCli\"}, \"CONTAINER_LOG_STDOUT_PATH\": {\"get_param\": \"ContainerLogStdoutPath\"}, \"CONTAINER_HEALTHCHECK_DISABLED\": {\"get_param\": \"ContainerHealthcheckDisabled\"}, \"DOCKER_PUPPET_DEBUG\": {\"get_param\": \"DockerPuppetDebug\"}, \"DOCKER_PUPPET_PROCESS_COUNT\": {\"get_param\": \"DockerPuppetProcessCount\"}, \"DOCKER_PUPPET_MOUNT_HOST_PUPPET\": {\"get_param\": \"DockerPuppetMountHostPuppet\"}, \"SELINUX_MODE\": {\"get_param\": \"SELinuxMode\"}}, \"template\": \"- hosts: CellControllerCompute:DEPLOY_TARGET_HOST\\n  strategy: tripleo_free\\n  name: Overcloud container setup tasks\\n  become: true\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  vars:\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    enable_puppet: ENABLE_PUPPET\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n  tasks:\\n    - name: Overcloud container setup tasks\\n      block:\\n        - name: Overcloud container setup tasks\\n          delegate_to: localhost\\n          run_once: true\\n          debug:\\n            msg: Use --start-at-task \'Overcloud container setup tasks\' to resume from this task\\n        - name: Write config data\\n          include_tasks: common_container_setup_tasks.yaml\\n          when:\\n            - (deploy_identifier is defined and deploy_identifier != \\\"\\\" and deploy_identifier is not none)\\n  tags:\\n    - overcloud\\n    - container_setup_tasks\\n\"}}, \"deploy_steps_pre_deployment_tasks_playbook\": {\"str_replace\": {\"params\": {\"BOOTSTRAP_SERVER_ID\": {\"get_attr\": [\"BootstrapServerId\", \"value\"]}, \"DEPLOY_SOURCE_HOST\": {\"get_param\": \"deployment_source_hosts\"}, \"DEPLOY_TARGET_HOST\": {\"if\": [{\"equals\": [{\"get_param\": \"deployment_target_hosts\"}, \"\"]}, {\"get_param\": \"RootStackName\"}, {\"get_param\": \"deployment_target_hosts\"}]}, \"DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}, \"ENABLE_DEBUG\": {\"get_param\": \"ConfigDebug\"}, \"ENABLE_PUPPET\": {\"get_param\": \"EnablePuppet\"}, \"CONTAINER_CLI\": {\"get_param\": \"ContainerCli\"}, \"CONTAINER_LOG_STDOUT_PATH\": {\"get_param\": \"ContainerLogStdoutPath\"}, \"CONTAINER_HEALTHCHECK_DISABLED\": {\"get_param\": \"ContainerHealthcheckDisabled\"}, \"DOCKER_PUPPET_DEBUG\": {\"get_param\": \"DockerPuppetDebug\"}, \"DOCKER_PUPPET_PROCESS_COUNT\": {\"get_param\": \"DockerPuppetProcessCount\"}, \"DOCKER_PUPPET_MOUNT_HOST_PUPPET\": {\"get_param\": \"DockerPuppetMountHostPuppet\"}, \"SELINUX_MODE\": {\"get_param\": \"SELinuxMode\"}}, \"template\": \"- hosts: CellControllerCompute:DEPLOY_TARGET_HOST\\n  strategy: tripleo_free\\n  name: Pre Deployment Step Tasks\\n  become: true\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  vars:\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    enable_puppet: ENABLE_PUPPET\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n  tasks:\\n\\n    - name: Pre Deployment Step Tasks\\n      delegate_to: localhost\\n      run_once: true\\n      debug:\\n        msg: Use --start-at-task \'Pre Deployment Step Tasks\' to resume from this task\\n    - include_tasks: \\\"{{ _task_file_path }}\\\"\\n      vars:\\n        _task_file_path: \\\"{{ tripleo_role_name }}/pre_deploy_step_tasks.yaml\\\"\\n      when: \\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\"\\n  tags:\\n    - overcloud\\n    - pre_deploy_steps_tasks\\n\"}}, \"deploy_steps_external_deployment_playbook\": {\"str_replace\": {\"params\": {\"BOOTSTRAP_SERVER_ID\": {\"get_attr\": [\"BootstrapServerId\", \"value\"]}, \"DEPLOY_SOURCE_HOST\": {\"get_param\": \"deployment_source_hosts\"}, \"DEPLOY_TARGET_HOST\": {\"if\": [{\"equals\": [{\"get_param\": \"deployment_target_hosts\"}, \"\"]}, {\"get_param\": \"RootStackName\"}, {\"get_param\": \"deployment_target_hosts\"}]}, \"DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}, \"ENABLE_DEBUG\": {\"get_param\": \"ConfigDebug\"}, \"ENABLE_PUPPET\": {\"get_param\": \"EnablePuppet\"}, \"CONTAINER_CLI\": {\"get_param\": \"ContainerCli\"}, \"CONTAINER_LOG_STDOUT_PATH\": {\"get_param\": \"ContainerLogStdoutPath\"}, \"CONTAINER_HEALTHCHECK_DISABLED\": {\"get_param\": \"ContainerHealthcheckDisabled\"}, \"DOCKER_PUPPET_DEBUG\": {\"get_param\": \"DockerPuppetDebug\"}, \"DOCKER_PUPPET_PROCESS_COUNT\": {\"get_param\": \"DockerPuppetProcessCount\"}, \"DOCKER_PUPPET_MOUNT_HOST_PUPPET\": {\"get_param\": \"DockerPuppetMountHostPuppet\"}, \"SELINUX_MODE\": {\"get_param\": \"SELinuxMode\"}}, \"template\": \"- hosts: DEPLOY_SOURCE_HOST\\n  strategy: tripleo_free\\n  name: External deployment step 1\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  become: false\\n  vars:\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    step: \'1\'\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    enable_puppet: ENABLE_PUPPET\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n  tasks:\\n    - name: External deployment step 1\\n      delegate_to: localhost\\n      run_once: true\\n      debug:\\n        msg: Use --start-at-task \'External deployment step 1\' to resume from this task\\n    - include_tasks: \\\"external_deploy_steps_tasks_step1.yaml\\\"\\n      when:\\n        - playbook_dir ~ \'/external_deploy_steps_tasks_step1.yaml\' is exists\\n  tags:\\n    - external\\n    - external_deploy_steps\\n    - step1\\n\\n- hosts: CellControllerCompute:DEPLOY_TARGET_HOST\\n  strategy: tripleo_free\\n  name: Deploy step tasks for 1\\n  become: true\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  vars:\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    step: \'1\'\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    enable_puppet: ENABLE_PUPPET\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n  tasks:\\n    - name: Deploy step tasks for 1\\n      delegate_to: localhost\\n      run_once: true\\n      debug:\\n        msg: Use --start-at-task \'Deploy step tasks for 1\' to resume from this task\\n    - name: Write the config_step hieradata for the deploy step 1 tasks\\n\\n      copy:\\n        content: \\\"{{ dict(step=step | int) | to_json }}\\\"\\n        dest: /etc/puppet/hieradata/config_step.json\\n        force: true\\n        mode: \'0600\'\\n\\n\\n    - name: Overcloud common bootstrap tasks for step 1\\n      block:\\n        - name: \\\"Check if /var/lib/tripleo-config/container-startup-config/step_1 already exists\\\"\\n          stat:\\n            path: \\\"/var/lib/tripleo-config/container-startup-config/step_1\\\"\\n          register: container_startup_configs_json_stat\\n        - name: Write config data at the start of step 1\\n          include_tasks: common_deploy_steps_tasks_step_1.yaml\\n          when:\\n            - ((deploy_identifier is defined and deploy_identifier != \\\"\\\" and deploy_identifier is not none) or\\n              not container_startup_configs_json_stat.stat.exists)\\n\\n\\n    - include_tasks: \\\"{{ _task_file_path }}\\\"\\n      vars:\\n        _task_file_path: \\\"{{ tripleo_role_name }}/deploy_steps_tasks_step{{ step }}.yaml\\\"\\n      when: \\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\"\\n\\n    - name: Overcloud common deploy step tasks 1\\n      block:\\n        - name: \\\"Check if /var/lib/tripleo-config/container-startup-config/step_1 already exists\\\"\\n          stat:\\n            path: \\\"/var/lib/tripleo-config/container-startup-config/step_1\\\"\\n          register: container_startup_configs_json_stat\\n        - include_tasks: common_deploy_steps_tasks.yaml\\n          when: (deploy_identifier is defined and deploy_identifier != \\\"\\\" and deploy_identifier is not none) or\\n                (container_startup_configs_json_stat is defined and not container_startup_configs_json_stat.stat.exists)\\n  tags:\\n    - overcloud\\n    - deploy_steps\\n    - step1\\n- hosts: DEPLOY_SOURCE_HOST\\n  strategy: tripleo_free\\n  name: External deployment step 2\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  become: false\\n  vars:\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    step: \'2\'\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    enable_puppet: ENABLE_PUPPET\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n  tasks:\\n    - name: External deployment step 2\\n      delegate_to: localhost\\n      run_once: true\\n      debug:\\n        msg: Use --start-at-task \'External deployment step 2\' to resume from this task\\n    - include_tasks: \\\"external_deploy_steps_tasks_step2.yaml\\\"\\n      when:\\n        - playbook_dir ~ \'/external_deploy_steps_tasks_step2.yaml\' is exists\\n  tags:\\n    - external\\n    - external_deploy_steps\\n    - step2\\n\\n- hosts: CellControllerCompute:DEPLOY_TARGET_HOST\\n  strategy: tripleo_free\\n  name: Deploy step tasks for 2\\n  become: true\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  vars:\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    step: \'2\'\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    enable_puppet: ENABLE_PUPPET\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n  tasks:\\n    - name: Deploy step tasks for 2\\n      delegate_to: localhost\\n      run_once: true\\n      debug:\\n        msg: Use --start-at-task \'Deploy step tasks for 2\' to resume from this task\\n    - name: Write the config_step hieradata for the deploy step 2 tasks\\n\\n      copy:\\n        content: \\\"{{ dict(step=step | int) | to_json }}\\\"\\n        dest: /etc/puppet/hieradata/config_step.json\\n        force: true\\n        mode: \'0600\'\\n\\n\\n\\n    - include_tasks: \\\"{{ _task_file_path }}\\\"\\n      vars:\\n        _task_file_path: \\\"{{ tripleo_role_name }}/deploy_steps_tasks_step{{ step }}.yaml\\\"\\n      when: \\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\"\\n\\n    - name: Overcloud common deploy step tasks 2\\n      block:\\n        - name: \\\"Check if /var/lib/tripleo-config/container-startup-config/step_2 already exists\\\"\\n          stat:\\n            path: \\\"/var/lib/tripleo-config/container-startup-config/step_2\\\"\\n          register: container_startup_configs_json_stat\\n        - include_tasks: common_deploy_steps_tasks.yaml\\n          when: (deploy_identifier is defined and deploy_identifier != \\\"\\\" and deploy_identifier is not none) or\\n                (container_startup_configs_json_stat is defined and not container_startup_configs_json_stat.stat.exists)\\n  tags:\\n    - overcloud\\n    - deploy_steps\\n    - step2\\n- hosts: DEPLOY_SOURCE_HOST\\n  strategy: tripleo_free\\n  name: External deployment step 3\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  become: false\\n  vars:\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    step: \'3\'\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    enable_puppet: ENABLE_PUPPET\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n  tasks:\\n    - name: External deployment step 3\\n      delegate_to: localhost\\n      run_once: true\\n      debug:\\n        msg: Use --start-at-task \'External deployment step 3\' to resume from this task\\n    - include_tasks: \\\"external_deploy_steps_tasks_step3.yaml\\\"\\n      when:\\n        - playbook_dir ~ \'/external_deploy_steps_tasks_step3.yaml\' is exists\\n  tags:\\n    - external\\n    - external_deploy_steps\\n    - step3\\n\\n- hosts: CellControllerCompute:DEPLOY_TARGET_HOST\\n  strategy: tripleo_free\\n  name: Deploy step tasks for 3\\n  become: true\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  vars:\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    step: \'3\'\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    enable_puppet: ENABLE_PUPPET\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n  tasks:\\n    - name: Deploy step tasks for 3\\n      delegate_to: localhost\\n      run_once: true\\n      debug:\\n        msg: Use --start-at-task \'Deploy step tasks for 3\' to resume from this task\\n    - name: Write the config_step hieradata for the deploy step 3 tasks\\n\\n      copy:\\n        content: \\\"{{ dict(step=step | int) | to_json }}\\\"\\n        dest: /etc/puppet/hieradata/config_step.json\\n        force: true\\n        mode: \'0600\'\\n\\n\\n\\n    - include_tasks: \\\"{{ _task_file_path }}\\\"\\n      vars:\\n        _task_file_path: \\\"{{ tripleo_role_name }}/deploy_steps_tasks_step{{ step }}.yaml\\\"\\n      when: \\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\"\\n\\n    - name: Overcloud common deploy step tasks 3\\n      block:\\n        - name: \\\"Check if /var/lib/tripleo-config/container-startup-config/step_3 already exists\\\"\\n          stat:\\n            path: \\\"/var/lib/tripleo-config/container-startup-config/step_3\\\"\\n          register: container_startup_configs_json_stat\\n        - include_tasks: common_deploy_steps_tasks.yaml\\n          when: (deploy_identifier is defined and deploy_identifier != \\\"\\\" and deploy_identifier is not none) or\\n                (container_startup_configs_json_stat is defined and not container_startup_configs_json_stat.stat.exists)\\n  tags:\\n    - overcloud\\n    - deploy_steps\\n    - step3\\n- hosts: DEPLOY_SOURCE_HOST\\n  strategy: tripleo_free\\n  name: External deployment step 4\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  become: false\\n  vars:\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    step: \'4\'\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    enable_puppet: ENABLE_PUPPET\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n  tasks:\\n    - name: External deployment step 4\\n      delegate_to: localhost\\n      run_once: true\\n      debug:\\n        msg: Use --start-at-task \'External deployment step 4\' to resume from this task\\n    - include_tasks: \\\"external_deploy_steps_tasks_step4.yaml\\\"\\n      when:\\n        - playbook_dir ~ \'/external_deploy_steps_tasks_step4.yaml\' is exists\\n  tags:\\n    - external\\n    - external_deploy_steps\\n    - step4\\n\\n- hosts: CellControllerCompute:DEPLOY_TARGET_HOST\\n  strategy: tripleo_free\\n  name: Deploy step tasks for 4\\n  become: true\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  vars:\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    step: \'4\'\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    enable_puppet: ENABLE_PUPPET\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n  tasks:\\n    - name: Deploy step tasks for 4\\n      delegate_to: localhost\\n      run_once: true\\n      debug:\\n        msg: Use --start-at-task \'Deploy step tasks for 4\' to resume from this task\\n    - name: Write the config_step hieradata for the deploy step 4 tasks\\n\\n      copy:\\n        content: \\\"{{ dict(step=step | int) | to_json }}\\\"\\n        dest: /etc/puppet/hieradata/config_step.json\\n        force: true\\n        mode: \'0600\'\\n\\n\\n\\n    - include_tasks: \\\"{{ _task_file_path }}\\\"\\n      vars:\\n        _task_file_path: \\\"{{ tripleo_role_name }}/deploy_steps_tasks_step{{ step }}.yaml\\\"\\n      when: \\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\"\\n\\n    - name: Overcloud common deploy step tasks 4\\n      block:\\n        - name: \\\"Check if /var/lib/tripleo-config/container-startup-config/step_4 already exists\\\"\\n          stat:\\n            path: \\\"/var/lib/tripleo-config/container-startup-config/step_4\\\"\\n          register: container_startup_configs_json_stat\\n        - include_tasks: common_deploy_steps_tasks.yaml\\n          when: (deploy_identifier is defined and deploy_identifier != \\\"\\\" and deploy_identifier is not none) or\\n                (container_startup_configs_json_stat is defined and not container_startup_configs_json_stat.stat.exists)\\n  tags:\\n    - overcloud\\n    - deploy_steps\\n    - step4\\n- hosts: DEPLOY_SOURCE_HOST\\n  strategy: tripleo_free\\n  name: External deployment step 5\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  become: false\\n  vars:\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    step: \'5\'\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    enable_puppet: ENABLE_PUPPET\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n  tasks:\\n    - name: External deployment step 5\\n      delegate_to: localhost\\n      run_once: true\\n      debug:\\n        msg: Use --start-at-task \'External deployment step 5\' to resume from this task\\n    - include_tasks: \\\"external_deploy_steps_tasks_step5.yaml\\\"\\n      when:\\n        - playbook_dir ~ \'/external_deploy_steps_tasks_step5.yaml\' is exists\\n  tags:\\n    - external\\n    - external_deploy_steps\\n    - step5\\n\\n- hosts: CellControllerCompute:DEPLOY_TARGET_HOST\\n  strategy: tripleo_free\\n  name: Deploy step tasks for 5\\n  become: true\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  vars:\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    step: \'5\'\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    enable_puppet: ENABLE_PUPPET\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n  tasks:\\n    - name: Deploy step tasks for 5\\n      delegate_to: localhost\\n      run_once: true\\n      debug:\\n        msg: Use --start-at-task \'Deploy step tasks for 5\' to resume from this task\\n    - name: Write the config_step hieradata for the deploy step 5 tasks\\n\\n      copy:\\n        content: \\\"{{ dict(step=step | int) | to_json }}\\\"\\n        dest: /etc/puppet/hieradata/config_step.json\\n        force: true\\n        mode: \'0600\'\\n\\n\\n\\n    - include_tasks: \\\"{{ _task_file_path }}\\\"\\n      vars:\\n        _task_file_path: \\\"{{ tripleo_role_name }}/deploy_steps_tasks_step{{ step }}.yaml\\\"\\n      when: \\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\"\\n\\n    - name: Overcloud common deploy step tasks 5\\n      block:\\n        - name: \\\"Check if /var/lib/tripleo-config/container-startup-config/step_5 already exists\\\"\\n          stat:\\n            path: \\\"/var/lib/tripleo-config/container-startup-config/step_5\\\"\\n          register: container_startup_configs_json_stat\\n        - include_tasks: common_deploy_steps_tasks.yaml\\n          when: (deploy_identifier is defined and deploy_identifier != \\\"\\\" and deploy_identifier is not none) or\\n                (container_startup_configs_json_stat is defined and not container_startup_configs_json_stat.stat.exists)\\n  tags:\\n    - overcloud\\n    - deploy_steps\\n    - step5\\n\"}}, \"deploy_steps_post_deployment_playbook\": {\"str_replace\": {\"params\": {\"BOOTSTRAP_SERVER_ID\": {\"get_attr\": [\"BootstrapServerId\", \"value\"]}, \"DEPLOY_SOURCE_HOST\": {\"get_param\": \"deployment_source_hosts\"}, \"DEPLOY_TARGET_HOST\": {\"if\": [{\"equals\": [{\"get_param\": \"deployment_target_hosts\"}, \"\"]}, {\"get_param\": \"RootStackName\"}, {\"get_param\": \"deployment_target_hosts\"}]}, \"DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}, \"ENABLE_DEBUG\": {\"get_param\": \"ConfigDebug\"}, \"ENABLE_PUPPET\": {\"get_param\": \"EnablePuppet\"}, \"CONTAINER_CLI\": {\"get_param\": \"ContainerCli\"}, \"CONTAINER_LOG_STDOUT_PATH\": {\"get_param\": \"ContainerLogStdoutPath\"}, \"CONTAINER_HEALTHCHECK_DISABLED\": {\"get_param\": \"ContainerHealthcheckDisabled\"}, \"DOCKER_PUPPET_DEBUG\": {\"get_param\": \"DockerPuppetDebug\"}, \"DOCKER_PUPPET_PROCESS_COUNT\": {\"get_param\": \"DockerPuppetProcessCount\"}, \"DOCKER_PUPPET_MOUNT_HOST_PUPPET\": {\"get_param\": \"DockerPuppetMountHostPuppet\"}, \"SELINUX_MODE\": {\"get_param\": \"SELinuxMode\"}}, \"template\": \"\\n- hosts: CellControllerCompute:DEPLOY_TARGET_HOST\\n  strategy: tripleo_free\\n  name: Server Post Deployments\\n  become: true\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  tasks:\\n    - name: Server Post Deployments\\n      delegate_to: localhost\\n      run_once: true\\n      debug:\\n        msg: Use --start-at-task \'Server Post Deployments\' to resume from this task\\n\\n    - include_tasks: deployments.yaml\\n      vars:\\n        force: false\\n      with_items: \\\"{{ hostvars[inventory_hostname][\'post_deployments_\' ~ tripleo_role_name]|default([]) }}\\\"\\n  tags:\\n    - overcloud\\n    - post_deploy_steps\\n\"}}, \"deploy_steps_post_deploy_tasks_playbook\": {\"str_replace\": {\"params\": {\"BOOTSTRAP_SERVER_ID\": {\"get_attr\": [\"BootstrapServerId\", \"value\"]}, \"DEPLOY_SOURCE_HOST\": {\"get_param\": \"deployment_source_hosts\"}, \"DEPLOY_TARGET_HOST\": {\"if\": [{\"equals\": [{\"get_param\": \"deployment_target_hosts\"}, \"\"]}, {\"get_param\": \"RootStackName\"}, {\"get_param\": \"deployment_target_hosts\"}]}, \"DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}, \"ENABLE_DEBUG\": {\"get_param\": \"ConfigDebug\"}, \"ENABLE_PUPPET\": {\"get_param\": \"EnablePuppet\"}, \"CONTAINER_CLI\": {\"get_param\": \"ContainerCli\"}, \"CONTAINER_LOG_STDOUT_PATH\": {\"get_param\": \"ContainerLogStdoutPath\"}, \"CONTAINER_HEALTHCHECK_DISABLED\": {\"get_param\": \"ContainerHealthcheckDisabled\"}, \"DOCKER_PUPPET_DEBUG\": {\"get_param\": \"DockerPuppetDebug\"}, \"DOCKER_PUPPET_PROCESS_COUNT\": {\"get_param\": \"DockerPuppetProcessCount\"}, \"DOCKER_PUPPET_MOUNT_HOST_PUPPET\": {\"get_param\": \"DockerPuppetMountHostPuppet\"}, \"SELINUX_MODE\": {\"get_param\": \"SELinuxMode\"}}, \"template\": \"- hosts: DEPLOY_SOURCE_HOST\\n  strategy: tripleo_linear\\n  name: External deployment Post Deploy tasks\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  become: false\\n  vars:\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    enable_puppet: ENABLE_PUPPET\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n  tasks:\\n    - name: External deployment Post Deploy tasks\\n      delegate_to: localhost\\n      run_once: true\\n      debug:\\n        msg: Use --start-at-task \'External deployment Post Deploy tasks\' to resume from this task\\n    - import_tasks: external_post_deploy_steps_tasks.yaml\\n  tags:\\n    - external\\n    - external_deploy_steps\\n    - external_post_deploy_steps\\n\"}}, \"deploy_steps_playbook\": {\"str_replace\": {\"params\": {\"BOOTSTRAP_SERVER_ID\": {\"get_attr\": [\"BootstrapServerId\", \"value\"]}, \"DEPLOY_SOURCE_HOST\": {\"get_param\": \"deployment_source_hosts\"}, \"DEPLOY_TARGET_HOST\": {\"if\": [{\"equals\": [{\"get_param\": \"deployment_target_hosts\"}, \"\"]}, {\"get_param\": \"RootStackName\"}, {\"get_param\": \"deployment_target_hosts\"}]}, \"DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}, \"ENABLE_DEBUG\": {\"get_param\": \"ConfigDebug\"}, \"ENABLE_PUPPET\": {\"get_param\": \"EnablePuppet\"}, \"CONTAINER_CLI\": {\"get_param\": \"ContainerCli\"}, \"CONTAINER_LOG_STDOUT_PATH\": {\"get_param\": \"ContainerLogStdoutPath\"}, \"CONTAINER_HEALTHCHECK_DISABLED\": {\"get_param\": \"ContainerHealthcheckDisabled\"}, \"DOCKER_PUPPET_DEBUG\": {\"get_param\": \"DockerPuppetDebug\"}, \"DOCKER_PUPPET_PROCESS_COUNT\": {\"get_param\": \"DockerPuppetProcessCount\"}, \"DOCKER_PUPPET_MOUNT_HOST_PUPPET\": {\"get_param\": \"DockerPuppetMountHostPuppet\"}, \"SELINUX_MODE\": {\"get_param\": \"SELinuxMode\"}}, \"template\": \"- import_playbook: deploy_steps_0_playbook.yaml\\n- import_playbook: deploy_steps_selinux_playbook.yaml\\n- import_playbook: deploy_steps_common_roles_playbook.yaml\\n- import_playbook: deploy_steps_0_tasks_playbook.yaml\\n- import_playbook: deploy_steps_pre_network_playbook.yaml\\n- import_playbook: deploy_steps_network_deployments_playbook.yaml\\n- import_playbook: deploy_steps_network_validation_playbook.yaml\\n- import_playbook: deploy_steps_pre_deployment_playbook.yaml\\n- import_playbook: deploy_steps_host_prep_playbook.yaml\\n- import_playbook: deploy_steps_container_setup_tasks_playbook.yaml\\n- import_playbook: deploy_steps_pre_deployment_tasks_playbook.yaml\\n- import_playbook: deploy_steps_external_deployment_playbook.yaml\\n- import_playbook: deploy_steps_post_deployment_playbook.yaml\\n- import_playbook: deploy_steps_post_deploy_tasks_playbook.yaml\\n\"}}, \"external_deploy_steps_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_steps_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"pre_deploy_step_tasks\": {\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, \"update_steps_playbook\": {\"str_replace\": {\"params\": {\"BOOTSTRAP_SERVER_ID\": {\"get_attr\": [\"BootstrapServerId\", \"value\"]}, \"DEPLOY_SOURCE_HOST\": {\"get_param\": \"deployment_source_hosts\"}, \"DEPLOY_TARGET_HOST\": {\"if\": [{\"equals\": [{\"get_param\": \"deployment_target_hosts\"}, \"\"]}, {\"get_param\": \"RootStackName\"}, {\"get_param\": \"deployment_target_hosts\"}]}, \"DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}, \"ENABLE_DEBUG\": {\"get_param\": \"ConfigDebug\"}, \"ENABLE_PUPPET\": {\"get_param\": \"EnablePuppet\"}, \"CONTAINER_CLI\": {\"get_param\": \"ContainerCli\"}, \"CONTAINER_LOG_STDOUT_PATH\": {\"get_param\": \"ContainerLogStdoutPath\"}, \"CONTAINER_HEALTHCHECK_DISABLED\": {\"get_param\": \"ContainerHealthcheckDisabled\"}, \"DOCKER_PUPPET_DEBUG\": {\"get_param\": \"DockerPuppetDebug\"}, \"DOCKER_PUPPET_PROCESS_COUNT\": {\"get_param\": \"DockerPuppetProcessCount\"}, \"DOCKER_PUPPET_MOUNT_HOST_PUPPET\": {\"get_param\": \"DockerPuppetMountHostPuppet\"}, \"SELINUX_MODE\": {\"get_param\": \"SELinuxMode\"}}, \"template\": \"- hosts: DEPLOY_TARGET_HOST\\n  strategy: tripleo_linear\\n  name: External update step 0\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  become: false\\n  vars:\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    step: 0\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    enable_puppet: ENABLE_PUPPET\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n  tasks:\\n    - import_tasks:\\n        file: external_update_steps_tasks.yaml\\n      delegate_to: localhost\\n      run_once: true\\n  tags:\\n    - step0\\n    - external\\n    - external_update_steps\\n- import_playbook: common_deploy_steps_playbooks.yaml\\n  vars:\\n    deploy_source_host: \\\"DEPLOY_SOURCE_HOST\\\"\\n    deploy_target_host: \\\"DEPLOY_TARGET_HOST\\\"\\n- hosts: Controller\\n  name: Run update\\n  become: true\\n  serial: \\\"{{ update_serial | default(1)}}\\\"\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  vars:\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    enable_puppet: ENABLE_PUPPET\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n    tripleo_minor_update: true\\n    tripleo_redhat_enforce: true\\n    \\n  tasks:\\n    - import_tasks: hiera_steps_tasks.yaml\\n    - import_tasks: common_container_config_scripts.yaml\\n    - name: Make sure container configuration is refreshed\\n      import_tasks: common_container_setup_tasks.yaml\\n    - import_tasks: \\\"Controller/update_tasks_step0.yaml\\\"\\n      vars:\\n        step: \\\"0\\\"\\n    - import_tasks: \\\"Controller/update_tasks_step1.yaml\\\"\\n      vars:\\n        step: \\\"1\\\"\\n    - import_tasks: \\\"Controller/update_tasks_step2.yaml\\\"\\n      vars:\\n        step: \\\"2\\\"\\n    - import_tasks: \\\"Controller/update_tasks_step3.yaml\\\"\\n      vars:\\n        step: \\\"3\\\"\\n    - import_tasks: \\\"Controller/update_tasks_step4.yaml\\\"\\n      vars:\\n        step: \\\"4\\\"\\n    - import_tasks: \\\"Controller/update_tasks_step5.yaml\\\"\\n      vars:\\n        step: \\\"5\\\"\\n\\n    - include_tasks: \\\"{{ _task_file_path }}\\\"\\n      vars:\\n        _task_file_path: \\\"{{ tripleo_role_name }}/host_prep_tasks.yaml\\\"\\n      when: \\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\"\\n\\n    - import_tasks: deploy_steps_tasks_step_0.yaml\\n      vars:\\n        step: 0\\n    - name: Write config data at the start of step 1\\n      import_tasks: common_deploy_steps_tasks_step_1.yaml\\n    - import_tasks: common_deploy_steps_tasks.yaml\\n      vars:\\n        step: \\\"1\\\"\\n    - import_tasks: common_deploy_steps_tasks.yaml\\n      vars:\\n        step: \\\"2\\\"\\n    - import_tasks: common_deploy_steps_tasks.yaml\\n      vars:\\n        step: \\\"3\\\"\\n    - import_tasks: common_deploy_steps_tasks.yaml\\n      vars:\\n        step: \\\"4\\\"\\n    - import_tasks: common_deploy_steps_tasks.yaml\\n      vars:\\n        step: \\\"5\\\"\\n    - import_tasks: \\\"Controller/post_update_tasks_step0.yaml\\\"\\n      vars:\\n        step: \\\"0\\\"\\n    - import_tasks: \\\"Controller/post_update_tasks_step1.yaml\\\"\\n      vars:\\n        step: \\\"1\\\"\\n    - import_tasks: \\\"Controller/post_update_tasks_step2.yaml\\\"\\n      vars:\\n        step: \\\"2\\\"\\n    - import_tasks: \\\"Controller/post_update_tasks_step3.yaml\\\"\\n      vars:\\n        step: \\\"3\\\"\\n- hosts: CellController\\n  name: Run update\\n  become: true\\n  serial: \\\"{{ update_serial | default(1)}}\\\"\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  vars:\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    enable_puppet: ENABLE_PUPPET\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n    tripleo_minor_update: true\\n    tripleo_redhat_enforce: true\\n    \\n  tasks:\\n    - import_tasks: hiera_steps_tasks.yaml\\n    - import_tasks: common_container_config_scripts.yaml\\n    - name: Make sure container configuration is refreshed\\n      import_tasks: common_container_setup_tasks.yaml\\n    - import_tasks: \\\"CellController/update_tasks_step0.yaml\\\"\\n      vars:\\n        step: \\\"0\\\"\\n    - import_tasks: \\\"CellController/update_tasks_step1.yaml\\\"\\n      vars:\\n        step: \\\"1\\\"\\n    - import_tasks: \\\"CellController/update_tasks_step2.yaml\\\"\\n      vars:\\n        step: \\\"2\\\"\\n    - import_tasks: \\\"CellController/update_tasks_step3.yaml\\\"\\n      vars:\\n        step: \\\"3\\\"\\n    - import_tasks: \\\"CellController/update_tasks_step4.yaml\\\"\\n      vars:\\n        step: \\\"4\\\"\\n    - import_tasks: \\\"CellController/update_tasks_step5.yaml\\\"\\n      vars:\\n        step: \\\"5\\\"\\n\\n    - include_tasks: \\\"{{ _task_file_path }}\\\"\\n      vars:\\n        _task_file_path: \\\"{{ tripleo_role_name }}/host_prep_tasks.yaml\\\"\\n      when: \\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\"\\n\\n    - import_tasks: deploy_steps_tasks_step_0.yaml\\n      vars:\\n        step: 0\\n    - name: Write config data at the start of step 1\\n      import_tasks: common_deploy_steps_tasks_step_1.yaml\\n    - import_tasks: common_deploy_steps_tasks.yaml\\n      vars:\\n        step: \\\"1\\\"\\n    - import_tasks: common_deploy_steps_tasks.yaml\\n      vars:\\n        step: \\\"2\\\"\\n    - import_tasks: common_deploy_steps_tasks.yaml\\n      vars:\\n        step: \\\"3\\\"\\n    - import_tasks: common_deploy_steps_tasks.yaml\\n      vars:\\n        step: \\\"4\\\"\\n    - import_tasks: common_deploy_steps_tasks.yaml\\n      vars:\\n        step: \\\"5\\\"\\n    - import_tasks: \\\"CellController/post_update_tasks_step0.yaml\\\"\\n      vars:\\n        step: \\\"0\\\"\\n    - import_tasks: \\\"CellController/post_update_tasks_step1.yaml\\\"\\n      vars:\\n        step: \\\"1\\\"\\n    - import_tasks: \\\"CellController/post_update_tasks_step2.yaml\\\"\\n      vars:\\n        step: \\\"2\\\"\\n    - import_tasks: \\\"CellController/post_update_tasks_step3.yaml\\\"\\n      vars:\\n        step: \\\"3\\\"\\n- hosts: CellControllerCompute\\n  name: Run update\\n  become: true\\n  serial: \\\"{{ update_serial | default(1)}}\\\"\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  vars:\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    enable_puppet: ENABLE_PUPPET\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n    tripleo_minor_update: true\\n    tripleo_redhat_enforce: true\\n    \\n  tasks:\\n    - import_tasks: hiera_steps_tasks.yaml\\n    - import_tasks: common_container_config_scripts.yaml\\n    - name: Make sure container configuration is refreshed\\n      import_tasks: common_container_setup_tasks.yaml\\n    - import_tasks: \\\"CellControllerCompute/update_tasks_step0.yaml\\\"\\n      vars:\\n        step: \\\"0\\\"\\n    - import_tasks: \\\"CellControllerCompute/update_tasks_step1.yaml\\\"\\n      vars:\\n        step: \\\"1\\\"\\n    - import_tasks: \\\"CellControllerCompute/update_tasks_step2.yaml\\\"\\n      vars:\\n        step: \\\"2\\\"\\n    - import_tasks: \\\"CellControllerCompute/update_tasks_step3.yaml\\\"\\n      vars:\\n        step: \\\"3\\\"\\n    - import_tasks: \\\"CellControllerCompute/update_tasks_step4.yaml\\\"\\n      vars:\\n        step: \\\"4\\\"\\n    - import_tasks: \\\"CellControllerCompute/update_tasks_step5.yaml\\\"\\n      vars:\\n        step: \\\"5\\\"\\n\\n    - include_tasks: \\\"{{ _task_file_path }}\\\"\\n      vars:\\n        _task_file_path: \\\"{{ tripleo_role_name }}/host_prep_tasks.yaml\\\"\\n      when: \\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\"\\n\\n    - import_tasks: deploy_steps_tasks_step_0.yaml\\n      vars:\\n        step: 0\\n    - name: Write config data at the start of step 1\\n      import_tasks: common_deploy_steps_tasks_step_1.yaml\\n    - import_tasks: common_deploy_steps_tasks.yaml\\n      vars:\\n        step: \\\"1\\\"\\n    - import_tasks: common_deploy_steps_tasks.yaml\\n      vars:\\n        step: \\\"2\\\"\\n    - import_tasks: common_deploy_steps_tasks.yaml\\n      vars:\\n        step: \\\"3\\\"\\n    - import_tasks: common_deploy_steps_tasks.yaml\\n      vars:\\n        step: \\\"4\\\"\\n    - import_tasks: common_deploy_steps_tasks.yaml\\n      vars:\\n        step: \\\"5\\\"\\n    - import_tasks: \\\"CellControllerCompute/post_update_tasks_step0.yaml\\\"\\n      vars:\\n        step: \\\"0\\\"\\n    - import_tasks: \\\"CellControllerCompute/post_update_tasks_step1.yaml\\\"\\n      vars:\\n        step: \\\"1\\\"\\n    - import_tasks: \\\"CellControllerCompute/post_update_tasks_step2.yaml\\\"\\n      vars:\\n        step: \\\"2\\\"\\n    - import_tasks: \\\"CellControllerCompute/post_update_tasks_step3.yaml\\\"\\n      vars:\\n        step: \\\"3\\\"\\n- hosts: Compute\\n  name: Run update\\n  become: true\\n  serial: \\\"{{ update_serial | default(25)}}\\\"\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  vars:\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    enable_puppet: ENABLE_PUPPET\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n    tripleo_minor_update: true\\n    tripleo_redhat_enforce: true\\n    \\n  tasks:\\n    - import_tasks: hiera_steps_tasks.yaml\\n    - import_tasks: common_container_config_scripts.yaml\\n    - name: Make sure container configuration is refreshed\\n      import_tasks: common_container_setup_tasks.yaml\\n    - import_tasks: \\\"Compute/update_tasks_step0.yaml\\\"\\n      vars:\\n        step: \\\"0\\\"\\n    - import_tasks: \\\"Compute/update_tasks_step1.yaml\\\"\\n      vars:\\n        step: \\\"1\\\"\\n    - import_tasks: \\\"Compute/update_tasks_step2.yaml\\\"\\n      vars:\\n        step: \\\"2\\\"\\n    - import_tasks: \\\"Compute/update_tasks_step3.yaml\\\"\\n      vars:\\n        step: \\\"3\\\"\\n    - import_tasks: \\\"Compute/update_tasks_step4.yaml\\\"\\n      vars:\\n        step: \\\"4\\\"\\n    - import_tasks: \\\"Compute/update_tasks_step5.yaml\\\"\\n      vars:\\n        step: \\\"5\\\"\\n\\n    - include_tasks: \\\"{{ _task_file_path }}\\\"\\n      vars:\\n        _task_file_path: \\\"{{ tripleo_role_name }}/host_prep_tasks.yaml\\\"\\n      when: \\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\"\\n\\n    - import_tasks: deploy_steps_tasks_step_0.yaml\\n      vars:\\n        step: 0\\n    - name: Write config data at the start of step 1\\n      import_tasks: common_deploy_steps_tasks_step_1.yaml\\n    - import_tasks: common_deploy_steps_tasks.yaml\\n      vars:\\n        step: \\\"1\\\"\\n    - import_tasks: common_deploy_steps_tasks.yaml\\n      vars:\\n        step: \\\"2\\\"\\n    - import_tasks: common_deploy_steps_tasks.yaml\\n      vars:\\n        step: \\\"3\\\"\\n    - import_tasks: common_deploy_steps_tasks.yaml\\n      vars:\\n        step: \\\"4\\\"\\n    - import_tasks: common_deploy_steps_tasks.yaml\\n      vars:\\n        step: \\\"5\\\"\\n    - import_tasks: \\\"Compute/post_update_tasks_step0.yaml\\\"\\n      vars:\\n        step: \\\"0\\\"\\n    - import_tasks: \\\"Compute/post_update_tasks_step1.yaml\\\"\\n      vars:\\n        step: \\\"1\\\"\\n    - import_tasks: \\\"Compute/post_update_tasks_step2.yaml\\\"\\n      vars:\\n        step: \\\"2\\\"\\n    - import_tasks: \\\"Compute/post_update_tasks_step3.yaml\\\"\\n      vars:\\n        step: \\\"3\\\"\\n- hosts: BlockStorage\\n  name: Run update\\n  become: true\\n  serial: \\\"{{ update_serial | default(25)}}\\\"\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  vars:\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    enable_puppet: ENABLE_PUPPET\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n    tripleo_minor_update: true\\n    tripleo_redhat_enforce: true\\n    \\n  tasks:\\n    - import_tasks: hiera_steps_tasks.yaml\\n    - import_tasks: common_container_config_scripts.yaml\\n    - name: Make sure container configuration is refreshed\\n      import_tasks: common_container_setup_tasks.yaml\\n    - import_tasks: \\\"BlockStorage/update_tasks_step0.yaml\\\"\\n      vars:\\n        step: \\\"0\\\"\\n    - import_tasks: \\\"BlockStorage/update_tasks_step1.yaml\\\"\\n      vars:\\n        step: \\\"1\\\"\\n    - import_tasks: \\\"BlockStorage/update_tasks_step2.yaml\\\"\\n      vars:\\n        step: \\\"2\\\"\\n    - import_tasks: \\\"BlockStorage/update_tasks_step3.yaml\\\"\\n      vars:\\n        step: \\\"3\\\"\\n    - import_tasks: \\\"BlockStorage/update_tasks_step4.yaml\\\"\\n      vars:\\n        step: \\\"4\\\"\\n    - import_tasks: \\\"BlockStorage/update_tasks_step5.yaml\\\"\\n      vars:\\n        step: \\\"5\\\"\\n\\n    - include_tasks: \\\"{{ _task_file_path }}\\\"\\n      vars:\\n        _task_file_path: \\\"{{ tripleo_role_name }}/host_prep_tasks.yaml\\\"\\n      when: \\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\"\\n\\n    - import_tasks: deploy_steps_tasks_step_0.yaml\\n      vars:\\n        step: 0\\n    - name: Write config data at the start of step 1\\n      import_tasks: common_deploy_steps_tasks_step_1.yaml\\n    - import_tasks: common_deploy_steps_tasks.yaml\\n      vars:\\n        step: \\\"1\\\"\\n    - import_tasks: common_deploy_steps_tasks.yaml\\n      vars:\\n        step: \\\"2\\\"\\n    - import_tasks: common_deploy_steps_tasks.yaml\\n      vars:\\n        step: \\\"3\\\"\\n    - import_tasks: common_deploy_steps_tasks.yaml\\n      vars:\\n        step: \\\"4\\\"\\n    - import_tasks: common_deploy_steps_tasks.yaml\\n      vars:\\n        step: \\\"5\\\"\\n    - import_tasks: \\\"BlockStorage/post_update_tasks_step0.yaml\\\"\\n      vars:\\n        step: \\\"0\\\"\\n    - import_tasks: \\\"BlockStorage/post_update_tasks_step1.yaml\\\"\\n      vars:\\n        step: \\\"1\\\"\\n    - import_tasks: \\\"BlockStorage/post_update_tasks_step2.yaml\\\"\\n      vars:\\n        step: \\\"2\\\"\\n    - import_tasks: \\\"BlockStorage/post_update_tasks_step3.yaml\\\"\\n      vars:\\n        step: \\\"3\\\"\\n- hosts: ObjectStorage\\n  name: Run update\\n  become: true\\n  serial: \\\"{{ update_serial | default(1)}}\\\"\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  vars:\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    enable_puppet: ENABLE_PUPPET\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n    tripleo_minor_update: true\\n    tripleo_redhat_enforce: true\\n    \\n  tasks:\\n    - import_tasks: hiera_steps_tasks.yaml\\n    - import_tasks: common_container_config_scripts.yaml\\n    - name: Make sure container configuration is refreshed\\n      import_tasks: common_container_setup_tasks.yaml\\n    - import_tasks: \\\"ObjectStorage/update_tasks_step0.yaml\\\"\\n      vars:\\n        step: \\\"0\\\"\\n    - import_tasks: \\\"ObjectStorage/update_tasks_step1.yaml\\\"\\n      vars:\\n        step: \\\"1\\\"\\n    - import_tasks: \\\"ObjectStorage/update_tasks_step2.yaml\\\"\\n      vars:\\n        step: \\\"2\\\"\\n    - import_tasks: \\\"ObjectStorage/update_tasks_step3.yaml\\\"\\n      vars:\\n        step: \\\"3\\\"\\n    - import_tasks: \\\"ObjectStorage/update_tasks_step4.yaml\\\"\\n      vars:\\n        step: \\\"4\\\"\\n    - import_tasks: \\\"ObjectStorage/update_tasks_step5.yaml\\\"\\n      vars:\\n        step: \\\"5\\\"\\n\\n    - include_tasks: \\\"{{ _task_file_path }}\\\"\\n      vars:\\n        _task_file_path: \\\"{{ tripleo_role_name }}/host_prep_tasks.yaml\\\"\\n      when: \\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\"\\n\\n    - import_tasks: deploy_steps_tasks_step_0.yaml\\n      vars:\\n        step: 0\\n    - name: Write config data at the start of step 1\\n      import_tasks: common_deploy_steps_tasks_step_1.yaml\\n    - import_tasks: common_deploy_steps_tasks.yaml\\n      vars:\\n        step: \\\"1\\\"\\n    - import_tasks: common_deploy_steps_tasks.yaml\\n      vars:\\n        step: \\\"2\\\"\\n    - import_tasks: common_deploy_steps_tasks.yaml\\n      vars:\\n        step: \\\"3\\\"\\n    - import_tasks: common_deploy_steps_tasks.yaml\\n      vars:\\n        step: \\\"4\\\"\\n    - import_tasks: common_deploy_steps_tasks.yaml\\n      vars:\\n        step: \\\"5\\\"\\n    - import_tasks: \\\"ObjectStorage/post_update_tasks_step0.yaml\\\"\\n      vars:\\n        step: \\\"0\\\"\\n    - import_tasks: \\\"ObjectStorage/post_update_tasks_step1.yaml\\\"\\n      vars:\\n        step: \\\"1\\\"\\n    - import_tasks: \\\"ObjectStorage/post_update_tasks_step2.yaml\\\"\\n      vars:\\n        step: \\\"2\\\"\\n    - import_tasks: \\\"ObjectStorage/post_update_tasks_step3.yaml\\\"\\n      vars:\\n        step: \\\"3\\\"\\n- hosts: CephStorage\\n  name: Run update\\n  become: true\\n  serial: \\\"{{ update_serial | default(1)}}\\\"\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  vars:\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    enable_puppet: ENABLE_PUPPET\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n    tripleo_minor_update: true\\n    tripleo_redhat_enforce: False\\n    \\n  tasks:\\n    - import_tasks: hiera_steps_tasks.yaml\\n    - import_tasks: common_container_config_scripts.yaml\\n    - name: Make sure container configuration is refreshed\\n      import_tasks: common_container_setup_tasks.yaml\\n    - import_tasks: \\\"CephStorage/update_tasks_step0.yaml\\\"\\n      vars:\\n        step: \\\"0\\\"\\n    - import_tasks: \\\"CephStorage/update_tasks_step1.yaml\\\"\\n      vars:\\n        step: \\\"1\\\"\\n    - import_tasks: \\\"CephStorage/update_tasks_step2.yaml\\\"\\n      vars:\\n        step: \\\"2\\\"\\n    - import_tasks: \\\"CephStorage/update_tasks_step3.yaml\\\"\\n      vars:\\n        step: \\\"3\\\"\\n    - import_tasks: \\\"CephStorage/update_tasks_step4.yaml\\\"\\n      vars:\\n        step: \\\"4\\\"\\n    - import_tasks: \\\"CephStorage/update_tasks_step5.yaml\\\"\\n      vars:\\n        step: \\\"5\\\"\\n\\n    - include_tasks: \\\"{{ _task_file_path }}\\\"\\n      vars:\\n        _task_file_path: \\\"{{ tripleo_role_name }}/host_prep_tasks.yaml\\\"\\n      when: \\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\"\\n\\n    - import_tasks: deploy_steps_tasks_step_0.yaml\\n      vars:\\n        step: 0\\n    - name: Write config data at the start of step 1\\n      import_tasks: common_deploy_steps_tasks_step_1.yaml\\n    - import_tasks: common_deploy_steps_tasks.yaml\\n      vars:\\n        step: \\\"1\\\"\\n    - import_tasks: common_deploy_steps_tasks.yaml\\n      vars:\\n        step: \\\"2\\\"\\n    - import_tasks: common_deploy_steps_tasks.yaml\\n      vars:\\n        step: \\\"3\\\"\\n    - import_tasks: common_deploy_steps_tasks.yaml\\n      vars:\\n        step: \\\"4\\\"\\n    - import_tasks: common_deploy_steps_tasks.yaml\\n      vars:\\n        step: \\\"5\\\"\\n    - import_tasks: \\\"CephStorage/post_update_tasks_step0.yaml\\\"\\n      vars:\\n        step: \\\"0\\\"\\n    - import_tasks: \\\"CephStorage/post_update_tasks_step1.yaml\\\"\\n      vars:\\n        step: \\\"1\\\"\\n    - import_tasks: \\\"CephStorage/post_update_tasks_step2.yaml\\\"\\n      vars:\\n        step: \\\"2\\\"\\n    - import_tasks: \\\"CephStorage/post_update_tasks_step3.yaml\\\"\\n      vars:\\n        step: \\\"3\\\"\\n- hosts: Networker\\n  name: Run update\\n  become: true\\n  serial: \\\"{{ update_serial | default(1)}}\\\"\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  vars:\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    enable_puppet: ENABLE_PUPPET\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n    tripleo_minor_update: true\\n    tripleo_redhat_enforce: true\\n    \\n  tasks:\\n    - import_tasks: hiera_steps_tasks.yaml\\n    - import_tasks: common_container_config_scripts.yaml\\n    - name: Make sure container configuration is refreshed\\n      import_tasks: common_container_setup_tasks.yaml\\n    - import_tasks: \\\"Networker/update_tasks_step0.yaml\\\"\\n      vars:\\n        step: \\\"0\\\"\\n    - import_tasks: \\\"Networker/update_tasks_step1.yaml\\\"\\n      vars:\\n        step: \\\"1\\\"\\n    - import_tasks: \\\"Networker/update_tasks_step2.yaml\\\"\\n      vars:\\n        step: \\\"2\\\"\\n    - import_tasks: \\\"Networker/update_tasks_step3.yaml\\\"\\n      vars:\\n        step: \\\"3\\\"\\n    - import_tasks: \\\"Networker/update_tasks_step4.yaml\\\"\\n      vars:\\n        step: \\\"4\\\"\\n    - import_tasks: \\\"Networker/update_tasks_step5.yaml\\\"\\n      vars:\\n        step: \\\"5\\\"\\n\\n    - include_tasks: \\\"{{ _task_file_path }}\\\"\\n      vars:\\n        _task_file_path: \\\"{{ tripleo_role_name }}/host_prep_tasks.yaml\\\"\\n      when: \\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\"\\n\\n    - import_tasks: deploy_steps_tasks_step_0.yaml\\n      vars:\\n        step: 0\\n    - name: Write config data at the start of step 1\\n      import_tasks: common_deploy_steps_tasks_step_1.yaml\\n    - import_tasks: common_deploy_steps_tasks.yaml\\n      vars:\\n        step: \\\"1\\\"\\n    - import_tasks: common_deploy_steps_tasks.yaml\\n      vars:\\n        step: \\\"2\\\"\\n    - import_tasks: common_deploy_steps_tasks.yaml\\n      vars:\\n        step: \\\"3\\\"\\n    - import_tasks: common_deploy_steps_tasks.yaml\\n      vars:\\n        step: \\\"4\\\"\\n    - import_tasks: common_deploy_steps_tasks.yaml\\n      vars:\\n        step: \\\"5\\\"\\n    - import_tasks: \\\"Networker/post_update_tasks_step0.yaml\\\"\\n      vars:\\n        step: \\\"0\\\"\\n    - import_tasks: \\\"Networker/post_update_tasks_step1.yaml\\\"\\n      vars:\\n        step: \\\"1\\\"\\n    - import_tasks: \\\"Networker/post_update_tasks_step2.yaml\\\"\\n      vars:\\n        step: \\\"2\\\"\\n    - import_tasks: \\\"Networker/post_update_tasks_step3.yaml\\\"\\n      vars:\\n        step: \\\"3\\\"\\n\"}}, \"external_update_steps_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_update_steps_playbook\": {\"str_replace\": {\"params\": {\"BOOTSTRAP_SERVER_ID\": {\"get_attr\": [\"BootstrapServerId\", \"value\"]}, \"DEPLOY_SOURCE_HOST\": {\"get_param\": \"deployment_source_hosts\"}, \"DEPLOY_TARGET_HOST\": {\"if\": [{\"equals\": [{\"get_param\": \"deployment_target_hosts\"}, \"\"]}, {\"get_param\": \"RootStackName\"}, {\"get_param\": \"deployment_target_hosts\"}]}, \"DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}, \"ENABLE_DEBUG\": {\"get_param\": \"ConfigDebug\"}, \"ENABLE_PUPPET\": {\"get_param\": \"EnablePuppet\"}, \"CONTAINER_CLI\": {\"get_param\": \"ContainerCli\"}, \"CONTAINER_LOG_STDOUT_PATH\": {\"get_param\": \"ContainerLogStdoutPath\"}, \"CONTAINER_HEALTHCHECK_DISABLED\": {\"get_param\": \"ContainerHealthcheckDisabled\"}, \"DOCKER_PUPPET_DEBUG\": {\"get_param\": \"DockerPuppetDebug\"}, \"DOCKER_PUPPET_PROCESS_COUNT\": {\"get_param\": \"DockerPuppetProcessCount\"}, \"DOCKER_PUPPET_MOUNT_HOST_PUPPET\": {\"get_param\": \"DockerPuppetMountHostPuppet\"}, \"SELINUX_MODE\": {\"get_param\": \"SELinuxMode\"}}, \"template\": \"- hosts: DEPLOY_SOURCE_HOST\\n  name: External update step 0\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  become: false\\n  vars:\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    step: 0\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    enable_puppet: ENABLE_PUPPET\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n  tasks:\\n    - import_tasks: external_update_steps_tasks.yaml\\n  tags:\\n    - step0\\n    - external\\n    - external_update_steps\\n- import_playbook: common_deploy_steps_playbooks.yaml\\n  vars:\\n    deploy_source_host: \\\"DEPLOY_SOURCE_HOST\\\"\\n    deploy_target_host: \\\"DEPLOY_TARGET_HOST\\\"\\n- hosts: DEPLOY_SOURCE_HOST\\n  name: External update step 1\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  become: false\\n  vars:\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    step: \'1\'\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    enable_puppet: ENABLE_PUPPET\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n  tasks:\\n    - import_tasks: external_update_steps_tasks.yaml\\n  tags:\\n    - step1\\n    - external\\n    - external_update_steps\\n- hosts: DEPLOY_SOURCE_HOST\\n  name: External update step 2\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  become: false\\n  vars:\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    step: \'2\'\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    enable_puppet: ENABLE_PUPPET\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n  tasks:\\n    - import_tasks: external_update_steps_tasks.yaml\\n  tags:\\n    - step2\\n    - external\\n    - external_update_steps\\n# putting both update and deploy tasks in the same\\n# playbook allows influencing the deploy tasks by\\n# variables \\\"exported\\\" from update tasks\\n- hosts: DEPLOY_SOURCE_HOST\\n  name: External deploy step 1\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  become: false\\n  vars:\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    step: \'1\'\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    enable_puppet: ENABLE_PUPPET\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n  tasks:\\n    - import_tasks: external_deploy_steps_tasks.yaml\\n  tags:\\n    - external\\n    - external_deploy_steps\\n    - step1\\n# putting both update and deploy tasks in the same\\n# playbook allows influencing the deploy tasks by\\n# variables \\\"exported\\\" from update tasks\\n- hosts: DEPLOY_SOURCE_HOST\\n  name: External deploy step 2\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  become: false\\n  vars:\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    step: \'2\'\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    enable_puppet: ENABLE_PUPPET\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n  tasks:\\n    - import_tasks: external_deploy_steps_tasks.yaml\\n  tags:\\n    - external\\n    - external_deploy_steps\\n    - step2\\n# putting both update and deploy tasks in the same\\n# playbook allows influencing the deploy tasks by\\n# variables \\\"exported\\\" from update tasks\\n- hosts: DEPLOY_SOURCE_HOST\\n  name: External deploy step 3\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  become: false\\n  vars:\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    step: \'3\'\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    enable_puppet: ENABLE_PUPPET\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n  tasks:\\n    - import_tasks: external_deploy_steps_tasks.yaml\\n  tags:\\n    - external\\n    - external_deploy_steps\\n    - step3\\n# putting both update and deploy tasks in the same\\n# playbook allows influencing the deploy tasks by\\n# variables \\\"exported\\\" from update tasks\\n- hosts: DEPLOY_SOURCE_HOST\\n  name: External deploy step 4\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  become: false\\n  vars:\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    step: \'4\'\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    enable_puppet: ENABLE_PUPPET\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n  tasks:\\n    - import_tasks: external_deploy_steps_tasks.yaml\\n  tags:\\n    - external\\n    - external_deploy_steps\\n    - step4\\n# putting both update and deploy tasks in the same\\n# playbook allows influencing the deploy tasks by\\n# variables \\\"exported\\\" from update tasks\\n- hosts: DEPLOY_SOURCE_HOST\\n  name: External deploy step 5\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  become: false\\n  vars:\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    step: \'5\'\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    enable_puppet: ENABLE_PUPPET\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n  tasks:\\n    - import_tasks: external_deploy_steps_tasks.yaml\\n  tags:\\n    - external\\n    - external_deploy_steps\\n    - step5\\n\"}}, \"pre_upgrade_rolling_steps_tasks\": \"\\n- include_tasks: \\\"{{ _task_file_path }}\\\"\\n  vars:\\n    _task_file_path: \\\"{{ tripleo_role_name }}/pre_upgrade_rolling_tasks.yaml\\\"\\n  when: \\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\"\\n  tags:\\n    - always\\n\", \"pre_upgrade_rolling_steps_playbook\": {\"str_replace\": {\"params\": {\"BOOTSTRAP_SERVER_ID\": {\"get_attr\": [\"BootstrapServerId\", \"value\"]}, \"DEPLOY_SOURCE_HOST\": {\"get_param\": \"deployment_source_hosts\"}, \"DEPLOY_TARGET_HOST\": {\"if\": [{\"equals\": [{\"get_param\": \"deployment_target_hosts\"}, \"\"]}, {\"get_param\": \"RootStackName\"}, {\"get_param\": \"deployment_target_hosts\"}]}, \"DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}, \"ENABLE_DEBUG\": {\"get_param\": \"ConfigDebug\"}, \"ENABLE_PUPPET\": {\"get_param\": \"EnablePuppet\"}, \"CONTAINER_CLI\": {\"get_param\": \"ContainerCli\"}, \"CONTAINER_LOG_STDOUT_PATH\": {\"get_param\": \"ContainerLogStdoutPath\"}, \"CONTAINER_HEALTHCHECK_DISABLED\": {\"get_param\": \"ContainerHealthcheckDisabled\"}, \"DOCKER_PUPPET_DEBUG\": {\"get_param\": \"DockerPuppetDebug\"}, \"DOCKER_PUPPET_PROCESS_COUNT\": {\"get_param\": \"DockerPuppetProcessCount\"}, \"DOCKER_PUPPET_MOUNT_HOST_PUPPET\": {\"get_param\": \"DockerPuppetMountHostPuppet\"}, \"SELINUX_MODE\": {\"get_param\": \"SELinuxMode\"}}, \"template\": \"- import_playbook: common_deploy_steps_playbooks.yaml\\n  vars:\\n    deploy_source_host: \\\"DEPLOY_SOURCE_HOST:Controller\\\"\\n    deploy_target_host: \\\"DEPLOY_TARGET_HOST\\\"\\n- hosts: Controller\\n  name: Run pre-upgrade rolling tasks\\n  serial:  1\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  tasks:\\n    - include_tasks: pre_upgrade_rolling_steps_tasks.yaml\\n      with_sequence: start=0 end=0\\n      loop_control:\\n        loop_var: step\\n- import_playbook: common_deploy_steps_playbooks.yaml\\n  vars:\\n    deploy_source_host: \\\"DEPLOY_SOURCE_HOST:CellController\\\"\\n    deploy_target_host: \\\"DEPLOY_TARGET_HOST\\\"\\n- hosts: CellController\\n  name: Run pre-upgrade rolling tasks\\n  serial:  1\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  tasks:\\n    - include_tasks: pre_upgrade_rolling_steps_tasks.yaml\\n      with_sequence: start=0 end=0\\n      loop_control:\\n        loop_var: step\\n- import_playbook: common_deploy_steps_playbooks.yaml\\n  vars:\\n    deploy_source_host: \\\"DEPLOY_SOURCE_HOST:CellControllerCompute\\\"\\n    deploy_target_host: \\\"DEPLOY_TARGET_HOST\\\"\\n- hosts: CellControllerCompute\\n  name: Run pre-upgrade rolling tasks\\n  serial:  1\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  tasks:\\n    - include_tasks: pre_upgrade_rolling_steps_tasks.yaml\\n      with_sequence: start=0 end=0\\n      loop_control:\\n        loop_var: step\\n- import_playbook: common_deploy_steps_playbooks.yaml\\n  vars:\\n    deploy_source_host: \\\"DEPLOY_SOURCE_HOST:Compute\\\"\\n    deploy_target_host: \\\"DEPLOY_TARGET_HOST\\\"\\n- hosts: Compute\\n  name: Run pre-upgrade rolling tasks\\n  serial:  1\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  tasks:\\n    - include_tasks: pre_upgrade_rolling_steps_tasks.yaml\\n      with_sequence: start=0 end=0\\n      loop_control:\\n        loop_var: step\\n- import_playbook: common_deploy_steps_playbooks.yaml\\n  vars:\\n    deploy_source_host: \\\"DEPLOY_SOURCE_HOST:BlockStorage\\\"\\n    deploy_target_host: \\\"DEPLOY_TARGET_HOST\\\"\\n- hosts: BlockStorage\\n  name: Run pre-upgrade rolling tasks\\n  serial:  1\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  tasks:\\n    - include_tasks: pre_upgrade_rolling_steps_tasks.yaml\\n      with_sequence: start=0 end=0\\n      loop_control:\\n        loop_var: step\\n- import_playbook: common_deploy_steps_playbooks.yaml\\n  vars:\\n    deploy_source_host: \\\"DEPLOY_SOURCE_HOST:ObjectStorage\\\"\\n    deploy_target_host: \\\"DEPLOY_TARGET_HOST\\\"\\n- hosts: ObjectStorage\\n  name: Run pre-upgrade rolling tasks\\n  serial:  1\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  tasks:\\n    - include_tasks: pre_upgrade_rolling_steps_tasks.yaml\\n      with_sequence: start=0 end=0\\n      loop_control:\\n        loop_var: step\\n- import_playbook: common_deploy_steps_playbooks.yaml\\n  vars:\\n    deploy_source_host: \\\"DEPLOY_SOURCE_HOST:CephStorage\\\"\\n    deploy_target_host: \\\"DEPLOY_TARGET_HOST\\\"\\n- hosts: CephStorage\\n  name: Run pre-upgrade rolling tasks\\n  serial:  1\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  tasks:\\n    - include_tasks: pre_upgrade_rolling_steps_tasks.yaml\\n      with_sequence: start=0 end=0\\n      loop_control:\\n        loop_var: step\\n- import_playbook: common_deploy_steps_playbooks.yaml\\n  vars:\\n    deploy_source_host: \\\"DEPLOY_SOURCE_HOST:Networker\\\"\\n    deploy_target_host: \\\"DEPLOY_TARGET_HOST\\\"\\n- hosts: Networker\\n  name: Run pre-upgrade rolling tasks\\n  serial:  1\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  tasks:\\n    - include_tasks: pre_upgrade_rolling_steps_tasks.yaml\\n      with_sequence: start=0 end=0\\n      loop_control:\\n        loop_var: step\\n\"}}, \"upgrade_steps_playbook\": {\"str_replace\": {\"params\": {\"BOOTSTRAP_SERVER_ID\": {\"get_attr\": [\"BootstrapServerId\", \"value\"]}, \"DEPLOY_SOURCE_HOST\": {\"get_param\": \"deployment_source_hosts\"}, \"DEPLOY_TARGET_HOST\": {\"if\": [{\"equals\": [{\"get_param\": \"deployment_target_hosts\"}, \"\"]}, {\"get_param\": \"RootStackName\"}, {\"get_param\": \"deployment_target_hosts\"}]}, \"DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}, \"ENABLE_DEBUG\": {\"get_param\": \"ConfigDebug\"}, \"ENABLE_PUPPET\": {\"get_param\": \"EnablePuppet\"}, \"CONTAINER_CLI\": {\"get_param\": \"ContainerCli\"}, \"CONTAINER_LOG_STDOUT_PATH\": {\"get_param\": \"ContainerLogStdoutPath\"}, \"CONTAINER_HEALTHCHECK_DISABLED\": {\"get_param\": \"ContainerHealthcheckDisabled\"}, \"DOCKER_PUPPET_DEBUG\": {\"get_param\": \"DockerPuppetDebug\"}, \"DOCKER_PUPPET_PROCESS_COUNT\": {\"get_param\": \"DockerPuppetProcessCount\"}, \"DOCKER_PUPPET_MOUNT_HOST_PUPPET\": {\"get_param\": \"DockerPuppetMountHostPuppet\"}, \"SELINUX_MODE\": {\"get_param\": \"SELinuxMode\"}}, \"template\": \"- import_playbook: common_deploy_steps_playbooks.yaml\\n  vars:\\n    deploy_source_host: \\\"DEPLOY_SOURCE_HOST\\\"\\n    deploy_target_host: \\\"DEPLOY_TARGET_HOST\\\"\\n- hosts: DEPLOY_TARGET_HOST\\n  strategy: tripleo_free\\n  name: Upgrade tasks for step 0\\n  become: true\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  vars:\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    step: \'0\'\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n  tasks:\\n\\n    - include_tasks: \\\"{{ _task_file_path }}\\\"\\n      vars:\\n        _task_file_path: \\\"{{ tripleo_role_name }}/upgrade_tasks_step{{ step }}.yaml\\\"\\n      when: \\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\"\\n      tags:\\n        - always\\n\\n  tags:\\n    - upgrade_steps\\n    - upgrade_step0\\n- hosts: DEPLOY_TARGET_HOST\\n  strategy: tripleo_free\\n  name: Upgrade tasks for step 1\\n  become: true\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  vars:\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    step: \'1\'\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n  tasks:\\n\\n    - include_tasks: \\\"{{ _task_file_path }}\\\"\\n      vars:\\n        _task_file_path: \\\"{{ tripleo_role_name }}/upgrade_tasks_step{{ step }}.yaml\\\"\\n      when: \\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\"\\n      tags:\\n        - always\\n\\n  tags:\\n    - upgrade_steps\\n    - upgrade_step1\\n- hosts: DEPLOY_TARGET_HOST\\n  strategy: tripleo_free\\n  name: Upgrade tasks for step 2\\n  become: true\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  vars:\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    step: \'2\'\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n  tasks:\\n\\n    - include_tasks: \\\"{{ _task_file_path }}\\\"\\n      vars:\\n        _task_file_path: \\\"{{ tripleo_role_name }}/upgrade_tasks_step{{ step }}.yaml\\\"\\n      when: \\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\"\\n      tags:\\n        - always\\n\\n  tags:\\n    - upgrade_steps\\n    - upgrade_step2\\n- hosts: DEPLOY_TARGET_HOST\\n  strategy: tripleo_free\\n  name: Upgrade tasks for step 3\\n  become: true\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  vars:\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    step: \'3\'\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n  tasks:\\n\\n    - include_tasks: \\\"{{ _task_file_path }}\\\"\\n      vars:\\n        _task_file_path: \\\"{{ tripleo_role_name }}/upgrade_tasks_step{{ step }}.yaml\\\"\\n      when: \\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\"\\n      tags:\\n        - always\\n\\n  tags:\\n    - upgrade_steps\\n    - upgrade_step3\\n- hosts: DEPLOY_TARGET_HOST\\n  strategy: tripleo_free\\n  name: Upgrade tasks for step 4\\n  become: true\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  vars:\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    step: \'4\'\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n  tasks:\\n\\n    - include_tasks: \\\"{{ _task_file_path }}\\\"\\n      vars:\\n        _task_file_path: \\\"{{ tripleo_role_name }}/upgrade_tasks_step{{ step }}.yaml\\\"\\n      when: \\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\"\\n      tags:\\n        - always\\n\\n  tags:\\n    - upgrade_steps\\n    - upgrade_step4\\n- hosts: DEPLOY_TARGET_HOST\\n  strategy: tripleo_free\\n  name: Upgrade tasks for step 5\\n  become: true\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  vars:\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    step: \'5\'\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n  tasks:\\n\\n    - include_tasks: \\\"{{ _task_file_path }}\\\"\\n      vars:\\n        _task_file_path: \\\"{{ tripleo_role_name }}/upgrade_tasks_step{{ step }}.yaml\\\"\\n      when: \\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\"\\n      tags:\\n        - always\\n\\n  tags:\\n    - upgrade_steps\\n    - upgrade_step5\\n\"}}, \"post_upgrade_steps_tasks\": \"\\n- include_tasks: \\\"{{ _task_file_path }}\\\"\\n  vars:\\n    _task_file_path: \\\"{{ tripleo_role_name }}/post_upgrade_tasks.yaml\\\"\\n  when: \\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\"\\n  tags:\\n    - always\\n\", \"post_upgrade_steps_playbook\": {\"str_replace\": {\"params\": {\"BOOTSTRAP_SERVER_ID\": {\"get_attr\": [\"BootstrapServerId\", \"value\"]}, \"DEPLOY_SOURCE_HOST\": {\"get_param\": \"deployment_source_hosts\"}, \"DEPLOY_TARGET_HOST\": {\"if\": [{\"equals\": [{\"get_param\": \"deployment_target_hosts\"}, \"\"]}, {\"get_param\": \"RootStackName\"}, {\"get_param\": \"deployment_target_hosts\"}]}, \"DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}, \"ENABLE_DEBUG\": {\"get_param\": \"ConfigDebug\"}, \"ENABLE_PUPPET\": {\"get_param\": \"EnablePuppet\"}, \"CONTAINER_CLI\": {\"get_param\": \"ContainerCli\"}, \"CONTAINER_LOG_STDOUT_PATH\": {\"get_param\": \"ContainerLogStdoutPath\"}, \"CONTAINER_HEALTHCHECK_DISABLED\": {\"get_param\": \"ContainerHealthcheckDisabled\"}, \"DOCKER_PUPPET_DEBUG\": {\"get_param\": \"DockerPuppetDebug\"}, \"DOCKER_PUPPET_PROCESS_COUNT\": {\"get_param\": \"DockerPuppetProcessCount\"}, \"DOCKER_PUPPET_MOUNT_HOST_PUPPET\": {\"get_param\": \"DockerPuppetMountHostPuppet\"}, \"SELINUX_MODE\": {\"get_param\": \"SELinuxMode\"}}, \"template\": \"- import_playbook: common_deploy_steps_playbooks.yaml\\n  vars:\\n    deploy_source_host: \\\"DEPLOY_SOURCE_HOST\\\"\\n    deploy_target_host: \\\"DEPLOY_TARGET_HOST\\\"\\n- hosts: DEPLOY_TARGET_HOST\\n  strategy: tripleo_free\\n  any_errors_fatal: yes\\n  tasks:\\n    - include_tasks: post_upgrade_steps_tasks.yaml\\n      with_sequence: start=0 end=3\\n      vars:\\n        bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n        deploy_identifier: DEPLOY_IDENTIFIER\\n        enable_debug: ENABLE_DEBUG\\n        enable_puppet: ENABLE_PUPPET\\n        container_cli: CONTAINER_CLI\\n        container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n        container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n        docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n        docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n        docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n      loop_control:\\n        loop_var: step\\n\"}}, \"external_upgrade_steps_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"external_upgrade_steps_playbook\": {\"str_replace\": {\"params\": {\"BOOTSTRAP_SERVER_ID\": {\"get_attr\": [\"BootstrapServerId\", \"value\"]}, \"DEPLOY_SOURCE_HOST\": {\"get_param\": \"deployment_source_hosts\"}, \"DEPLOY_TARGET_HOST\": {\"if\": [{\"equals\": [{\"get_param\": \"deployment_target_hosts\"}, \"\"]}, {\"get_param\": \"RootStackName\"}, {\"get_param\": \"deployment_target_hosts\"}]}, \"DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}, \"ENABLE_DEBUG\": {\"get_param\": \"ConfigDebug\"}, \"ENABLE_PUPPET\": {\"get_param\": \"EnablePuppet\"}, \"CONTAINER_CLI\": {\"get_param\": \"ContainerCli\"}, \"CONTAINER_LOG_STDOUT_PATH\": {\"get_param\": \"ContainerLogStdoutPath\"}, \"CONTAINER_HEALTHCHECK_DISABLED\": {\"get_param\": \"ContainerHealthcheckDisabled\"}, \"DOCKER_PUPPET_DEBUG\": {\"get_param\": \"DockerPuppetDebug\"}, \"DOCKER_PUPPET_PROCESS_COUNT\": {\"get_param\": \"DockerPuppetProcessCount\"}, \"DOCKER_PUPPET_MOUNT_HOST_PUPPET\": {\"get_param\": \"DockerPuppetMountHostPuppet\"}, \"SELINUX_MODE\": {\"get_param\": \"SELinuxMode\"}}, \"template\": \"- import_playbook: common_deploy_steps_playbooks.yaml\\n  vars:\\n    deploy_source_host: \\\"DEPLOY_SOURCE_HOST\\\"\\n    deploy_target_host: \\\"DEPLOY_TARGET_HOST\\\"\\n- hosts: DEPLOY_SOURCE_HOST\\n  strategy: tripleo_free\\n  name: External upgrade step 0\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  become: false\\n  vars:\\n    # Explicit ansible_python_interpreter to allow connecting\\n    # to different OS releases (EL7/8) while using delegate_to.\\n    ansible_python_interpreter: /usr/libexec/platform-python\\n    step: \'0\'\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    enable_puppet: ENABLE_PUPPET\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n  tasks:\\n    - import_tasks: external_upgrade_steps_tasks.yaml\\n  tags:\\n    - step0\\n    - external\\n    - external_upgrade_steps\\n- hosts: DEPLOY_SOURCE_HOST\\n  strategy: tripleo_free\\n  name: External upgrade step 1\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  become: false\\n  vars:\\n    # Explicit ansible_python_interpreter to allow connecting\\n    # to different OS releases (EL7/8) while using delegate_to.\\n    ansible_python_interpreter: /usr/libexec/platform-python\\n    step: \'1\'\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    enable_puppet: ENABLE_PUPPET\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n  tasks:\\n    - import_tasks: external_upgrade_steps_tasks.yaml\\n  tags:\\n    - step1\\n    - external\\n    - external_upgrade_steps\\n- hosts: DEPLOY_SOURCE_HOST\\n  strategy: tripleo_free\\n  name: External upgrade step 2\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  become: false\\n  vars:\\n    # Explicit ansible_python_interpreter to allow connecting\\n    # to different OS releases (EL7/8) while using delegate_to.\\n    ansible_python_interpreter: /usr/libexec/platform-python\\n    step: \'2\'\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    enable_puppet: ENABLE_PUPPET\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n  tasks:\\n    - import_tasks: external_upgrade_steps_tasks.yaml\\n  tags:\\n    - step2\\n    - external\\n    - external_upgrade_steps\\n# putting both upgrade and deploy tasks in the same\\n# playbook allows influencing the deploy tasks by\\n# variables \\\"exported\\\" from upgrade tasks\\n- hosts: DEPLOY_SOURCE_HOST\\n  name: External deploy step 1\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  become: false\\n  vars:\\n    # Explicit ansible_python_interpreter to allow connecting\\n    # to different OS releases (EL7/8) while using delegate_to.\\n    ansible_python_interpreter: /usr/libexec/platform-python\\n    step: \'1\'\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    enable_puppet: ENABLE_PUPPET\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n  tasks:\\n    - import_tasks: external_deploy_steps_tasks.yaml\\n  tags:\\n    - step1\\n    - external\\n    - external_deploy_steps\\n# putting both upgrade and deploy tasks in the same\\n# playbook allows influencing the deploy tasks by\\n# variables \\\"exported\\\" from upgrade tasks\\n- hosts: DEPLOY_SOURCE_HOST\\n  name: External deploy step 2\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  become: false\\n  vars:\\n    # Explicit ansible_python_interpreter to allow connecting\\n    # to different OS releases (EL7/8) while using delegate_to.\\n    ansible_python_interpreter: /usr/libexec/platform-python\\n    step: \'2\'\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    enable_puppet: ENABLE_PUPPET\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n  tasks:\\n    - import_tasks: external_deploy_steps_tasks.yaml\\n  tags:\\n    - step2\\n    - external\\n    - external_deploy_steps\\n# putting both upgrade and deploy tasks in the same\\n# playbook allows influencing the deploy tasks by\\n# variables \\\"exported\\\" from upgrade tasks\\n- hosts: DEPLOY_SOURCE_HOST\\n  name: External deploy step 3\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  become: false\\n  vars:\\n    # Explicit ansible_python_interpreter to allow connecting\\n    # to different OS releases (EL7/8) while using delegate_to.\\n    ansible_python_interpreter: /usr/libexec/platform-python\\n    step: \'3\'\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    enable_puppet: ENABLE_PUPPET\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n  tasks:\\n    - import_tasks: external_deploy_steps_tasks.yaml\\n  tags:\\n    - step3\\n    - external\\n    - external_deploy_steps\\n# putting both upgrade and deploy tasks in the same\\n# playbook allows influencing the deploy tasks by\\n# variables \\\"exported\\\" from upgrade tasks\\n- hosts: DEPLOY_SOURCE_HOST\\n  name: External deploy step 4\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  become: false\\n  vars:\\n    # Explicit ansible_python_interpreter to allow connecting\\n    # to different OS releases (EL7/8) while using delegate_to.\\n    ansible_python_interpreter: /usr/libexec/platform-python\\n    step: \'4\'\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    enable_puppet: ENABLE_PUPPET\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n  tasks:\\n    - import_tasks: external_deploy_steps_tasks.yaml\\n  tags:\\n    - step4\\n    - external\\n    - external_deploy_steps\\n# putting both upgrade and deploy tasks in the same\\n# playbook allows influencing the deploy tasks by\\n# variables \\\"exported\\\" from upgrade tasks\\n- hosts: DEPLOY_SOURCE_HOST\\n  name: External deploy step 5\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: yes\\n  become: false\\n  vars:\\n    # Explicit ansible_python_interpreter to allow connecting\\n    # to different OS releases (EL7/8) while using delegate_to.\\n    ansible_python_interpreter: /usr/libexec/platform-python\\n    step: \'5\'\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    enable_puppet: ENABLE_PUPPET\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n  tasks:\\n    - import_tasks: external_deploy_steps_tasks.yaml\\n  tags:\\n    - step5\\n    - external\\n    - external_deploy_steps\\n\"}}, \"scale_steps_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"scale_playbook\": {\"str_replace\": {\"params\": {\"BOOTSTRAP_SERVER_ID\": {\"get_attr\": [\"BootstrapServerId\", \"value\"]}, \"DEPLOY_SOURCE_HOST\": {\"get_param\": \"deployment_source_hosts\"}, \"DEPLOY_TARGET_HOST\": {\"if\": [{\"equals\": [{\"get_param\": \"deployment_target_hosts\"}, \"\"]}, {\"get_param\": \"RootStackName\"}, {\"get_param\": \"deployment_target_hosts\"}]}, \"DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}, \"ENABLE_DEBUG\": {\"get_param\": \"ConfigDebug\"}, \"ENABLE_PUPPET\": {\"get_param\": \"EnablePuppet\"}, \"CONTAINER_CLI\": {\"get_param\": \"ContainerCli\"}, \"CONTAINER_LOG_STDOUT_PATH\": {\"get_param\": \"ContainerLogStdoutPath\"}, \"CONTAINER_HEALTHCHECK_DISABLED\": {\"get_param\": \"ContainerHealthcheckDisabled\"}, \"DOCKER_PUPPET_DEBUG\": {\"get_param\": \"DockerPuppetDebug\"}, \"DOCKER_PUPPET_PROCESS_COUNT\": {\"get_param\": \"DockerPuppetProcessCount\"}, \"DOCKER_PUPPET_MOUNT_HOST_PUPPET\": {\"get_param\": \"DockerPuppetMountHostPuppet\"}, \"SELINUX_MODE\": {\"get_param\": \"SELinuxMode\"}}, \"template\": \"# Collect the facts from the overcloud nodes but ignore unreachable\\n# nodes in the case of a dead node which needs to be part of the\\n# scale-down operation.\\n- import_playbook: common_deploy_steps_playbooks.yaml\\n  vars:\\n    deploy_source_host: \\\"DEPLOY_SOURCE_HOST\\\"\\n    deploy_target_host: \\\"DEPLOY_TARGET_HOST\\\"\\n\\n- hosts: DEPLOY_TARGET_HOST\\n  name: Scaling\\n  # NOTE(cloudnull): This is set to true explicitly so that we have up-to-date facts\\n  #                  on all DEPLOY_TARGET_HOST when performing a scaling operation.\\n  #                  Without up-to-date facts, we\'re creating a potential failure\\n  #                  scenario.\\n  gather_facts: true\\n  ignore_unreachable: true\\n  become: false\\n  vars:\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\n    deploy_identifier: DEPLOY_IDENTIFIER\\n    enable_debug: ENABLE_DEBUG\\n    enable_puppet: ENABLE_PUPPET\\n    container_cli: CONTAINER_CLI\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\n  tasks:\\n    # Only run the scale tasks on the nodes that are alive.\\n    # We expect the tasks to work on the nodes that are alive.\\n    # If a task is allowed to fail, it needs to be configured at\\n    # the task definition level but not here.\\n    - include_tasks: scale_steps_tasks.yaml\\n      with_sequence: start=1 end=1\\n      loop_control:\\n        loop_var: step\\n      tags: always\\n      # we use ansible_facts[\'hostname\'] to determine if the host is alive\\n      # or not.\\n      when: ansible_facts[\'hostname\'] is defined\\n    # We don\'t want to run the scale tasks on dead nodes, to allow\\n    # the operator to scale down the cloud no matter the state of\\n    # the servers.\\n    # However, we notify the operator if the node wasn\'t reachable.\\n    # Using fail and not debug module to make it more visible\\n    # in the logs.\\n    - fail:\\n        msg: \\\"Node is unreachable. No scale tasks will be run.\\\"\\n      ignore_errors: True\\n      tags: always\\n      # we use ansible_facts[\'hostname\'] to determine if the host is alive\\n      # or not.\\n      when: ansible_facts[\'hostname\'] is not defined\\n  tags:\\n    - scale\\n\"}}, \"post_update_steps_tasks\": \"\\n- include_tasks: \\\"{{ _task_file_path }}\\\"\\n  vars:\\n    _task_file_path: \\\"{{ tripleo_role_name }}/post_update_tasks.yaml\\\"\\n  when: \\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\"\\n  tags:\\n    - always\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"servers\": {\"Controller\": {}, \"CellController\": {\"0\": \"fdfd9831-4e7f-49b0-88e6-ee2bc9bc0add\"}, \"CellControllerCompute\": {}, \"Compute\": {\"0\": \"9c74e5b3-24cc-4b92-a048-87963237f199\"}, \"BlockStorage\": {}, \"ObjectStorage\": {}, \"CephStorage\": {}, \"Networker\": {}}, \"role_data\": {\"Controller\": {\"service_names\": [], \"monitoring_subscriptions\": [], \"config_settings\": {}, \"global_config_settings\": {}, \"service_config_settings\": {}, \"step_config\": \"\", \"deploy_steps_tasks\": [], \"external_deploy_tasks\": [], \"external_post_deploy_tasks\": [], \"external_update_tasks\": [], \"external_upgrade_tasks\": [], \"scale_tasks\": [], \"pre_upgrade_rolling_tasks\": [], \"upgrade_tasks\": [], \"post_upgrade_tasks\": [], \"update_tasks\": [], \"post_update_tasks\": [], \"upgrade_batch_tasks\": [], \"service_metadata_settings\": null, \"ansible_group_vars\": {\"ansible_async_dir\": \"/tmp/.ansible_async\"}, \"keystone_resources\": {}, \"firewall_rules\": {}, \"firewall_frontend_rules\": {}, \"firewall_ssl_frontend_rules\": {}, \"firewall_edge_frontend_rules\": {}, \"firewall_edge_ssl_frontend_rules\": null, \"puppet_config\": [], \"kolla_config\": {}, \"docker_config\": {}, \"container_config_scripts\": {}, \"container_puppet_tasks\": {}, \"host_prep_tasks\": [], \"pre_deploy_step_tasks\": []}, \"CellController\": {\"service_names\": [\"boot_params_service\", \"ca_certs\", \"clustercheck\", \"collectd\", \"container_image_prepare\", \"logrotate_crond\", \"haproxy\", \"iscsid\", \"kernel\", \"metrics_qdr\", \"mysql\", \"mysql_client\", \"nova_conductor\", \"nova_metadata\", \"nova_vnc_proxy\", \"oslo_messaging_rpc\", \"pacemaker\", \"podman\", \"rsyslog\", \"snmp\", \"sshd\", \"chrony\", \"timezone\", \"tripleo_firewall\", \"tripleo_packages\", \"tuned\"], \"monitoring_subscriptions\": [\"overcloud-haproxy\", \"overcloud-qdr\", \"overcloud-nova-conductor\", \"overcloud-nova-metadata\", \"overcloud-pacemaker\"], \"config_settings\": {\"tripleo::trusted_cas::ca_map\": {}, \"mysql::server::package_name\": \"mariadb-galera-server\", \"mysql::server::manage_config_file\": true, \"mysql_ipv6\": false, \"mysql_max_connections\": 4096, \"mysql::server::root_password\": \"lewodgEGks\", \"mysql_clustercheck_password\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"enable_galera\": true, \"mysql_auth_ed25519\": false, \"mysql_bind_host\": \"%{hiera(\'internal_api\')}\", \"tripleo::profile::base::database::mysql::bind_address\": \"%{hiera(\'fqdn_internal_api\')}\", \"tripleo::profile::base::database::mysql::client_bind_address\": \"%{hiera(\'internal_api\')}\", \"tripleo::profile::base::database::mysql::generate_dropin_file_limit\": true, \"innodb_buffer_pool_size\": \"128M\", \"tripleo::profile::pacemaker::database::mysql::bind_address\": \"%{hiera(\'fqdn_internal_api\')}\", \"tripleo::profile::pacemaker::database::mysql::gmcast_listen_addr\": \"%{hiera(\'internal_api\')}\", \"tripleo::profile::pacemaker::database::mysql::ca_file\": \"/etc/ipa/ca.crt\", \"tripleo::profile::pacemaker::database::mysql_bundle::mysql_docker_image\": \"cluster.common.tag/mariadb:pcmklatest\", \"tripleo::profile::pacemaker::database::mysql_bundle::control_port\": 3123, \"tripleo::profile::pacemaker::database::mysql_bundle::container_backend\": \"podman\", \"tripleo::profile::pacemaker::database::mysql_bundle::bind_address\": \"%{hiera(\'fqdn_internal_api\')}\", \"tripleo::profile::pacemaker::database::mysql_bundle::sst_method\": \"rsync\", \"tripleo::profile::pacemaker::database::mysql_bundle::mariabackup_user\": \"mariabackup\", \"tripleo::profile::pacemaker::database::mysql_bundle::mariabackup_password\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"tripleo::profile::pacemaker::database::mysql_bundle::force_ocf\": true, \"tripleo::profile::pacemaker::database::mysql_bundle::gcomm_cipher\": \"AES128-SHA256\", \"tripleo::profile::pacemaker::clustercheck::bind_address\": \"%{hiera(\'internal_api\')}\", \"tripleo::profile::base::metrics::collectd::enable_file_logging\": true, \"collectd::plugin::logfile::log_file\": \"/var/log/collectd/collectd.log\", \"collectd::manage_repo\": false, \"collectd::purge\": true, \"collectd::recurse\": true, \"collectd::purge_config\": true, \"collectd::minimum_version\": \"5.7\", \"collectd::interval\": 120, \"collectd::plugin::unixsock::socketgroup\": \"root\", \"collectd::plugin::unixsock::socketfile\": \"/run/collectd-socket\", \"collectd::plugin::unixsock::deletesocket\": true, \"collectd::plugin::cpu::reportbycpu\": true, \"collectd::plugin::cpu::reportbystate\": true, \"collectd::plugin::cpu::reportnumcpu\": false, \"collectd::plugin::cpu::valuespercentage\": true, \"collectd::plugin::df::ignoreselected\": true, \"collectd::plugin::df::reportbydevice\": true, \"collectd::plugin::df::fstypes\": [\"xfs\"], \"collectd::plugin::load::reportrelative\": true, \"collectd::plugin::virt::connection\": \"qemu:///system\", \"collectd::plugin::virt::extra_stats\": \"pcpu cpu_util vcpu memory disk disk_err disk_allocation disk_capacity disk_physical domain_state job_stats_background perf\", \"collectd::plugin::virt::hostname_format\": \"hostname\", \"tripleo.collectd.plugins.collectd\": [\"cpu\", \"df\", \"disk\", \"hugepages\", \"interface\", \"load\", \"memory\", \"unixsock\", \"uptime\"], \"tripleo::profile::base::metrics::collectd::amqp_transport_name\": \"metrics\", \"tripleo::profile::base::metrics::collectd::amqp_address\": \"collectd\", \"tripleo::profile::base::metrics::collectd::amqp_instances\": {}, \"tripleo::profile::base::metrics::collectd::amqp_retry_delay\": 1, \"tripleo::profile::base::metrics::collectd::amqp_host\": \"%{hiera(\'internal_api\')}\", \"tripleo::profile::base::metrics::collectd::amqp_port\": 5666, \"tripleo::profile::base::metrics::collectd::amqp_user\": \"guest\", \"tripleo::profile::base::metrics::collectd::amqp_password\": \"guest\", \"tripleo::profile::base::logging::logrotate::maxsize\": \"10M\", \"tripleo::profile::base::logging::logrotate::rotation\": \"daily\", \"tripleo::profile::base::logging::logrotate::rotate\": \"14\", \"tripleo::profile::base::logging::logrotate::purge_after_days\": \"14\", \"tripleo::profile::base::logging::logrotate::dateext\": false, \"tripleo::haproxy::haproxy_service_manage\": false, \"tripleo::haproxy::haproxy_log_address\": \"/dev/log\", \"tripleo::haproxy::haproxy_log_facility\": \"local0\", \"tripleo::haproxy::haproxy_stats_user\": \"admin\", \"tripleo::haproxy::haproxy_stats_password\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"tripleo::haproxy::haproxy_stats_bind_address\": \"%{hiera(\'ctlplane\')}\", \"tripleo::haproxy::redis_password\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"tripleo::haproxy::crl_file\": null, \"tripleo::haproxy::haproxy_stats\": true, \"enable_load_balancer\": true, \"tripleo::profile::base::haproxy::certificates_specs\": {}, \"tripleo::haproxy::mysql_clustercheck\": true, \"haproxy_docker\": true, \"tripleo::profile::pacemaker::haproxy_bundle::container_backend\": \"podman\", \"tripleo::profile::pacemaker::haproxy_bundle::tls_mapping\": [], \"tripleo::profile::pacemaker::haproxy_bundle::tls_mapping_init_bundle\": [], \"tripleo::profile::pacemaker::haproxy_bundle::internal_certs_directory\": \"/etc/pki/tls/certs/haproxy\", \"tripleo::profile::pacemaker::haproxy_bundle::internal_keys_directory\": \"/etc/pki/tls/private/haproxy\", \"tripleo::profile::pacemaker::haproxy_bundle::haproxy_docker_image\": \"cluster.common.tag/haproxy:pcmklatest\", \"tripleo::profile::base::iscsid::chap_algs\": \"SHA3-256,SHA256,SHA1,MD5\", \"tripleo::profile::base::metrics::qdr::listener_addr\": \"%{hiera(\'internal_api\')}\", \"tripleo::haproxy::metrics_qdr\": false, \"tripleo::profile::base::metrics::qdr::listener_port\": 5666, \"tripleo::profile::base::metrics::qdr::username\": \"guest\", \"tripleo::profile::base::metrics::qdr::password\": \"guest\", \"tripleo::profile::base::metrics::qdr::connectors\": [], \"tripleo::profile::base::metrics::qdr::addresses\": [{\"prefix\": \"collectd\", \"distribution\": \"multicast\"}, {\"prefix\": \"ceilometer/metering.sample\", \"distribution\": \"multicast\"}, {\"prefix\": \"ceilometer/event.sample\", \"distribution\": \"multicast\"}], \"tripleo::profile::base::metrics::qdr::autolink_addresses\": [], \"tripleo::profile::base::metrics::qdr::listener_require_ssl\": false, \"tripleo::profile::base::metrics::qdr::listener_require_encrypt\": false, \"tripleo::profile::base::metrics::qdr::listener_sasl_mech\": \"ANONYMOUS\", \"tripleo::profile::base::metrics::qdr::listener_ssl_cert_db\": \"/etc/ipa/ca.crt\", \"tripleo::profile::base::metrics::qdr::listener_ssl_cert_file\": \"/etc/pki/tls/certs/metrics_qdr.crt\", \"tripleo::profile::base::metrics::qdr::listener_ssl_key_file\": \"/etc/pki/tls/private/metrics_qdr.key\", \"tripleo::profile::base::metrics::qdr::listener_ssl_pw_file\": \"\", \"tripleo::profile::base::metrics::qdr::listener_ssl_password\": \"\", \"tripleo::profile::base::metrics::qdr::listener_trusted_certs\": \"\", \"qdr::log_enable\": \"info+\", \"qdr::log_output\": \"/var/log/qdrouterd/metrics_qdr.log\", \"qdr::listener_auth_peer\": false, \"tripleo::profile::base::metrics::qdr::ssl_profiles\": [{\"name\": \"sslProfile\"}], \"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": \"%{hiera(\'internal_api\')}\", \"tripleo::profile::base::database::mysql::client::enable_ssl\": false, \"tripleo::profile::base::database::mysql::client::ssl_ca\": \"/etc/ipa/ca.crt\", \"nova::my_ip\": \"%{hiera(\'internal_api\')}\", \"nova::rabbit_use_ssl\": \"False\", \"nova::keystone::service_user::send_service_user_token\": true, \"nova::keystone::service_user::project_name\": \"service\", \"nova::keystone::service_user::password\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"nova::keystone::service_user::auth_url\": \"http://172.17.0.130:5000\", \"nova::keystone::service_user::region_name\": \"regionOne\", \"nova::placement::project_name\": \"service\", \"nova::placement::password\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"nova::placement::auth_url\": \"http://172.17.0.130:5000\", \"nova::placement::region_name\": \"regionOne\", \"nova::placement::valid_interfaces\": \"internal\", \"nova::os_region_name\": \"regionOne\", \"nova::logging::debug\": true, \"nova::purge_config\": false, \"nova::network::neutron::project_name\": \"service\", \"nova::network::neutron::username\": \"neutron\", \"nova::network::neutron::region_name\": \"regionOne\", \"nova::dhcp_domain\": \"\", \"nova::network::neutron::password\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"nova::network::neutron::auth_url\": \"http://172.17.0.130:5000/v3\", \"nova::network::neutron::valid_interfaces\": \"internal\", \"nova::glance::valid_interfaces\": \"internal\", \"nova::rabbit_heartbeat_timeout_threshold\": 60, \"nova::cinder_catalog_info\": \"volumev3:cinderv3:internalURL\", \"nova::host\": \"%{hiera(\'fqdn_canonical\')}\", \"nova::notify_on_state_change\": \"vm_and_task_state\", \"nova::notification_driver\": [\"noop\"], \"nova::notification_format\": \"unversioned\", \"nova::network::neutron::auth_type\": \"v3password\", \"nova::db::database_db_max_retries\": -1, \"nova::db::database_max_retries\": -1, \"nova::network::neutron::ovs_bridge\": \"br-int\", \"nova::compute::sync_power_state_interval\": 600, \"nova_is_additional_cell\": true, \"nova::cross_az_attach\": true, \"nova::cache::enabled\": true, \"nova::cache::tls_enabled\": false, \"nova::cache::backend\": \"dogpile.cache.memcached\", \"nova::rabbit_heartbeat_in_pthread\": false, \"nova::ovsdb_connection\": \"\", \"nova::api_database_connection\": \"mysql+pymysql://nova_api:1Ii49H1EfmLUfEWsgfy9vla3q@172.17.0.130/nova_api?read_default_file=/etc/my.cnf.d/tripleo.cnf&read_default_group=tripleo\", \"nova::database_connection\": \"mysql+pymysql://nova:1Ii49H1EfmLUfEWsgfy9vla3q@172.17.0.133/nova?read_default_file=/etc/my.cnf.d/tripleo.cnf&read_default_group=tripleo\", \"nova::conductor::workers\": 1, \"apache::ip\": \"%{hiera(\'internal_api\')}\", \"apache::default_vhost\": false, \"apache::trace_enable\": \"Off\", \"apache::server_signature\": \"Off\", \"apache::server_tokens\": \"Prod\", \"apache::timeout\": 90, \"apache::default_mods\": false, \"apache::mod::prefork::maxrequestworkers\": 100, \"apache::mod::prefork::serverlimit\": 100, \"apache::mod::remoteip::proxy_ips\": [\"172.17.0.0/24\"], \"apache::mod::alias::icons_options\": \"None\", \"nova::keystone::authtoken::project_name\": \"service\", \"nova::keystone::authtoken::password\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"nova::keystone::authtoken::www_authenticate_uri\": \"http://172.21.0.80:5000\", \"nova::keystone::authtoken::auth_url\": \"http://172.17.0.130:5000\", \"nova::keystone::authtoken::region_name\": \"regionOne\", \"nova::keystone::authtoken::interface\": \"internal\", \"nova::keystone::authtoken::memcache_use_advanced_pool\": true, \"nova::wsgi::apache_metadata::api_port\": \"8775\", \"nova::wsgi::apache_metadata::ssl\": false, \"nova::metadata::local_metadata_per_cell\": true, \"nova::wsgi::apache_metadata::bind_host\": \"%{hiera(\'internal_api\')}\", \"nova::wsgi::apache_metadata::servername\": \"%{hiera(\'fqdn_internal_api\')}\", \"nova::wsgi::apache_metadata::workers\": 1, \"nova::metadata::neutron_metadata_proxy_shared_secret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"nova::vncproxy::enabled\": true, \"nova::vncproxy::common::vncproxy_protocol\": \"http\", \"nova::vncproxy::common::vncproxy_host\": \"172.21.0.83\", \"nova::vncproxy::common::vncproxy_port\": \"6080\", \"nova::vncproxy::host\": \"%{hiera(\'internal_api\')}\", \"rabbitmq::file_limit\": 65536, \"rabbitmq::default_user\": \"guest\", \"rabbitmq::default_pass\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"rabbit_ipv6\": false, \"rabbitmq::delete_guest_user\": false, \"rabbitmq::wipe_db_on_cookie_change\": true, \"rabbitmq::port\": 5672, \"rabbitmq::loopback_users\": [], \"rabbitmq::tcp_backlog\": 4096, \"rabbitmq::repos_ensure\": false, \"rabbitmq::tcp_keepalive\": true, \"rabbitmq_environment\": {\"LANG\": \"en_US.UTF-8\", \"LC_ALL\": \"en_US.UTF-8\", \"NODE_PORT\": \"\", \"NODE_IP_ADDRESS\": \"\", \"RABBITMQ_NODENAME\": \"rabbit@%{hiera(\'fqdn_internal_api\')}\", \"RABBITMQ_USE_LONGNAME\": \"true\", \"RABBITMQ_CTL_DIST_PORT_MIN\": \"25673\", \"RABBITMQ_CTL_DIST_PORT_MAX\": \"25683\", \"export ERL_EPMD_ADDRESS\": \"%{hiera(\'rabbitmq::interface\')}\"}, \"tripleo::profile::base::rabbitmq::additional_erl_args\": \"\'+sbwt none +sbwtdcpu none +sbwtdio none\'\", \"rabbitmq_kernel_variables\": {\"inet_dist_listen_min\": \"25672\", \"inet_dist_listen_max\": \"25672\", \"net_ticktime\": 15}, \"rabbitmq_config_variables\": {\"cluster_partition_handling\": \"ignore\", \"queue_master_locator\": \"<<\\\"min-masters\\\">>\"}, \"rabbitmq::config_additional_variables\": {\"lager\": \"[{crash_log_count, 0}, { crash_log_date, \\\"\\\"}, { crash_log_size, 0 }]\"}, \"rabbitmq::erlang_cookie\": \"2ljqdppvti5CXNoMTl6c\", \"rabbitmq::interface\": \"%{hiera(\'internal_api\')}\", \"rabbitmq::nr_ha_queues\": 0, \"rabbitmq::ssl\": false, \"rabbitmq::ssl_erl_dist\": false, \"rabbitmq::ssl_port\": 5672, \"rabbitmq::ssl_depth\": 1, \"rabbitmq::ssl_only\": false, \"rabbitmq::ssl_interface\": \"%{hiera(\'internal_api\')}\", \"tripleo::profile::base::rabbitmq::enable_internal_tls\": false, \"tripleo::profile::base::rabbitmq::fips_mode\": false, \"rabbitmq::collect_statistics_interval\": 30000, \"rabbitmq::admin_enable\": false, \"rabbitmq::management_enable\": true, \"rabbitmq::use_config_file_for_plugins\": true, \"rabbitmq::management_ip_address\": \"127.0.0.1\", \"rabbitmq::management_port\": 15672, \"rabbitmq::config_management_variables\": {\"rates_mode\": \"none\"}, \"rabbitmq::ssl_cacert\": \"/etc/ipa/ca.crt\", \"rabbitmq::ssl_management_cacert\": \"/etc/ipa/ca.crt\", \"rabbitmq::service_manage\": false, \"tripleo::profile::pacemaker::rabbitmq_bundle::rabbitmq_docker_image\": \"cluster.common.tag/rabbitmq:pcmklatest\", \"tripleo::profile::pacemaker::rabbitmq_bundle::control_port\": 3122, \"tripleo::profile::pacemaker::rabbitmq_bundle::container_backend\": \"podman\", \"tripleo::profile::pacemaker::rabbitmq_bundle::force_ocf\": true, \"pacemaker::corosync::cluster_name\": \"tripleo_cluster\", \"pacemaker::corosync::manage_fw\": false, \"pacemaker::resource_defaults::defaults\": {\"resource-stickiness\": {\"value\": \"INFINITY\"}}, \"corosync_token_timeout\": 10000, \"pacemaker::corosync::settle_tries\": 360, \"pacemaker::resource::bundle::deep_compare\": true, \"pacemaker::resource::ip::deep_compare\": true, \"pacemaker::resource::ocf::deep_compare\": true, \"corosync_ipv6\": false, \"tripleo::fencing::config\": {}, \"tripleo::fencing::deep_compare\": true, \"enable_fencing\": false, \"hacluster_pwd\": \"NvleZPciNHzWAChh\", \"tripleo::profile::base::pacemaker::remote_authkey\": \" \", \"tripleo::profile::base::pacemaker::pcsd_bind_addr\": \"%{hiera(\'internal_api\')}\", \"tripleo::profile::base::pacemaker::resource_op_defaults\": {\"bundle\": {\"name\": \"timeout\", \"value\": \"120s\"}}, \"rsyslog::server::global_config\": {\"WorkDirectory\": {\"type\": \"legacy\", \"target\": \"00_rsyslog.conf\", \"value\": \"/var/lib/rsyslog\"}, \"MaxMessageSize\": {\"type\": \"legacy\", \"target\": \"00_rsyslog.conf\", \"value\": \"32k\"}}, \"rsyslog::confdir\": \"/etc/rsyslog.d\", \"rsyslog::package_name\": \"rsyslog\", \"rsyslog::package_version\": \"installed\", \"rsyslog::manage_package\": true, \"rsyslog::manage_confdir\": true, \"rsyslog::purge_config_files\": true, \"rsyslog::override_default_config\": true, \"rsyslog::config_file\": \"/etc/rsyslog.conf\", \"rsyslog::manage_service\": true, \"rsyslog::service_name\": \"rsyslog\", \"rsyslog::service_status\": \"running\", \"rsyslog::service_enabled\": true, \"rsyslog::external_service\": false, \"rsyslog::use_upstream_repo\": false, \"rsyslog::feature_packages\": [\"rsyslog-elasticsearch\", \"rsyslog-mmnormalize\"], \"rsyslog::global_config_priority\": 10, \"rsyslog::module_load_priority\": 20, \"rsyslog::input_priority\": 30, \"rsyslog::main_queue_priority\": 40, \"rsyslog::parser_priority\": 45, \"rsyslog::template_priority\": 50, \"rsyslog::filter_priority\": 55, \"rsyslog::action_priority\": 60, \"rsyslog::ruleset_priority\": 65, \"rsyslog::lookup_table_priority\": 70, \"rsyslog::legacy_config_priority\": 80, \"rsyslog::custom_priority\": 90, \"rsyslog::target_file\": \"50_openstack_logs.conf\", \"rsyslog::server::modules\": {\"imfile\": {}, \"omelasticsearch\": {}, \"omamqp1\": {}}, \"rsyslog::server::templates\": {\"rsyslog-node-index\": {\"type\": \"list\", \"list_descriptions\": [{\"constant\": {\"value\": \"%{hiera(\'fqdn_canonical\')}-\"}}, {\"property\": {\"name\": \"timereported\", \"dateFormat\": \"year\"}}, {\"constant\": {\"value\": \".\"}}, {\"property\": {\"name\": \"timereported\", \"dateFormat\": \"month\"}}, {\"constant\": {\"value\": \".\"}}, {\"property\": {\"name\": \"timereported\", \"dateFormat\": \"day\"}}]}, \"rsyslog-record\": {\"type\": \"list\", \"options\": {\"jsonf\": \"on\"}, \"list_descriptions\": [{\"property\": {\"outname\": \"@timestamp\", \"name\": \"timereported\", \"dateFormat\": \"rfc3339\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"host\", \"name\": \"hostname\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"severity\", \"name\": \"syslogseverity\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"facility\", \"name\": \"syslogfacility-text\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"tag\", \"name\": \"syslogtag\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"source\", \"name\": \"app-name\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"message\", \"name\": \"msg\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"file\", \"name\": \"$!metadata!filename\", \"format\": \"jsonf\"}}, {\"constant\": {\"outname\": \"cloud\", \"value\": \"multicell.ooo.test\", \"format\": \"jsonf\"}}, {\"constant\": {\"outname\": \"region\", \"value\": \"regionOne\", \"format\": \"jsonf\"}}]}}, \"tripleo::profile::base::logging::rsyslog::reopen_on_truncate\": \"on\", \"tripleo::profile::base::snmp::snmpd_user\": \"ro_snmp_user\", \"tripleo::profile::base::snmp::snmpd_password\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"snmp::agentaddress\": [\"udp:161\", \"udp6:[::1]:161\"], \"snmp::snmpd_options\": \"-LS0-5d\", \"tripleo::firewall::manage_firewall\": false, \"tripleo::firewall::purge_firewall_rules\": false, \"tripleo::packages::enable_install\": true}, \"global_config_settings\": {\"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_port\": 5672}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_collectd\": [{\"tag\": \"collectd\", \"file\": \"/var/log/containers/collectd/collectd.log\"}], \"tripleo_logging_sources_haproxy\": [{\"tag\": \"openstack.haproxy\", \"file\": \"/var/log/containers/haproxy/haproxy.log\", \"startmsg.regex\": \"^[a-zA-Z]{3} [ 123][0-9] [:0-9]{8}\"}], \"tripleo_logging_sources_metrics_qdr\": [{\"tag\": \"openstack.nova.consoleauth\", \"file\": \"/var/log/containers/metrics_qdr/metrics_qdr.log\", \"startmsg.regex\": \"^[0-9]{4}-[0-9]{2}-[0-9]{2} [0-9]{2}:[0-9]{2}:[0-9]{2}(.[0-9]+ \\\\\\\\+[0-9]+)? [A-Z]+ \\\\\\\\([a-z]+\\\\\\\\) \"}], \"tripleo_logging_sources_nova_conductor\": [{\"tag\": \"openstack.nova.conductor\", \"file\": \"/var/log/containers/nova/nova-conductor.log\"}], \"tripleo_logging_sources_nova_metadata\": [{\"tag\": \"openstack.nova.api.metadata\", \"file\": \"/var/log/containers/nova/nova-metadata-api.log\"}], \"tripleo_logging_sources_nova_vnc_proxy\": [{\"tag\": \"openstack.nova.vncproxy\", \"file\": \"/var/log/containers/nova/nova-novncproxy.log\"}], \"tripleo_logging_sources_pacemaker\": [{\"tag\": \"system.pacemaker\", \"file\": \"/var/log/host/pacemaker/pacemaker.log\", \"startmsg.regex\": \"^[a-zA-Z]{3} [0-9]{2} [:0-9]{8}\"}]}, \"rabbitmq\": {\"get_attr\": [\"NovaBase\", \"role_data\", \"service_config_settings\"], \"rabbitmq\": null}, \"mysql\": {\"nova::db::mysql_api::password\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"nova::db::mysql_api::user\": \"nova_api\", \"nova::db::mysql_api::host\": \"%\", \"nova::db::mysql_api::dbname\": \"nova_api\", \"nova::db::mysql::password\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"nova::db::mysql::user\": \"nova\", \"nova::db::mysql::host\": \"%\", \"nova::db::mysql::dbname\": \"nova\"}}, \"step_config\": \"include tripleo::trusted_cas\\ninclude tripleo::profile::base::database::mysql::client\\ninclude tripleo::profile::base::pacemaker\\n\\n\\ninclude tripleo::profile::base::snmp\\n\\ninclude ::tripleo::packages\\n\", \"deploy_steps_tasks\": [{\"name\": \"Configure tuned before reboot\", \"when\": \"step|int == 0\", \"include_role\": {\"name\": \"tuned\"}, \"vars\": {\"tuned_profile\": \"throughput-performance\", \"tuned_isolated_cores\": \"\"}}, {\"name\": \"Configure kernel args and reboot\", \"when\": \"step|int == 0\", \"include_role\": {\"name\": \"tripleo_kernel\", \"tasks_from\": \"kernelargs.yml\"}, \"vars\": {\"tripleo_kernel_args\": \"\", \"tripleo_kernel_hugepages\": {}, \"tripleo_kernel_hugepages_remove\": false, \"tripleo_kernel_defer_reboot\": false, \"tripleo_kernel_reboot_timeout\": 900}}, {\"name\": \"set enable_sensubility fact\", \"set_fact\": {\"enable_sensubility\": false}}, {\"name\": \"create podman socket for sensubility purposes\", \"block\": [{\"name\": \"create podman socket and appropriate systemd service\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_service\"}, \"vars\": {\"tripleo_podman_socket_path\": \"/var/lib/tripleo-podman/collectd/podman.sock\"}}, {\"name\": \"create systemd service for ensuring socket file ACL contains collectd\", \"become\": true, \"ansible.builtin.copy\": {\"content\": \"[Unit]\\nDescription=ACL setting for /var/lib/tripleo-podman/collectd/podman.sock\\nRequires=tripleo_collectd.service\\nAfter=tripleo_podman.service\\nAfter=tripleo_collectd.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/usr/bin/podman exec -it collectd setfacl -m m:rwx /run/podman/podman.sock\\nExecStart=/usr/bin/podman exec -it collectd setfacl -R -m u:collectd:rwx /run/podman\\nExecStart=/usr/bin/podman exec -it collectd setfacl -d -m u:collectd:rwx /run/podman\\n\\n[Install]\\nWantedBy=multi-user.target\\n\", \"dest\": \"/etc/systemd/system/tripleo_podman_collectd_acl.service\", \"mode\": 420}}, {\"name\": \"enable podman.sock ACL service\", \"ansible.builtin.service\": {\"name\": \"tripleo_podman_collectd_acl.service\", \"enabled\": true}}, {\"name\": \"create directory for downloads of users\' scripts\", \"file\": {\"path\": \"/var/lib/container-user-scripts\", \"state\": \"directory\", \"setype\": \"container_file_t\", \"mode\": \"0755\"}}, {\"name\": \"download exec scripts\", \"ansible.builtin.get_url\": {\"url\": \"{{ item.source }}\", \"checksum\": \"{{ item.checksum }}\", \"dest\": \"/var/lib/container-user-scripts/{{ item.name }}\", \"mode\": \"0755\"}, \"with_items\": []}], \"when\": [\"enable_sensubility|bool\", \"step|int == 1\"]}, {\"name\": \"configure tmpwatch on the host\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Push script\", \"copy\": {\"dest\": \"/usr/local/sbin/containers-tmpwatch\", \"owner\": \"root\", \"group\": \"root\", \"mode\": 493, \"content\": \"#!/bin/sh\\ntmpwatch --nodirs \\\\\\n  -X \\\"/var/log/containers/*/*log\\\" \\\\\\n  -X \\\"/var/log/containers/*/*/*log\\\" \\\\\\n  -X \\\"/var/log/containers/*/*err\\\" \\\\\\n  {{ LogrotatePurgeAfterDays|int +1 }}d \\\\\\n  /var/log/containers/ 2>&1 | logger -t container-tmpwatch\\n\"}, \"vars\": {\"LogrotatePurgeAfterDays\": \"14\"}}, {\"name\": \"Insert cronjob in root crontab\", \"cron\": {\"name\": \"Remove old logs\", \"special_time\": \"daily\", \"user\": \"root\", \"job\": \"/usr/local/sbin/containers-tmpwatch\"}}]}, {\"name\": \"Configure rsyslog for HAproxy container managed by Pacemaker\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Check if rsyslog exists\", \"shell\": \"systemctl is-active rsyslog\", \"register\": \"rsyslog_config\"}, {\"when\": [\"rsyslog_config is changed\", \"rsyslog_config.rc == 0\"], \"block\": [{\"name\": \"Forward logging to haproxy.log file\", \"blockinfile\": {\"content\": \"if $syslogfacility-text == \'{{facility}}\' and $programname == \'haproxy\' then -/var/log/containers/haproxy/haproxy.log\\n& stop\\n\", \"create\": true, \"path\": \"/etc/rsyslog.d/openstack-haproxy.conf\"}, \"vars\": {\"facility\": \"local0\"}, \"register\": \"logconfig\"}, {\"name\": \"restart rsyslog service after logging conf change\", \"service\": {\"name\": \"rsyslog\", \"state\": \"restarted\"}, \"when\": \"logconfig is changed\"}]}]}, {\"name\": \"HAproxy tag container image for pacemaker\", \"when\": \"step|int == 1\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"container_image_latest\": \"cluster.common.tag/haproxy:pcmklatest\"}}, {\"name\": \"HAproxy HA Wrappers Step\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"HAproxy puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"haproxy\", \"tripleo_ha_wrapper_resource_name\": \"haproxy-bundle\", \"tripleo_ha_wrapper_bundle_name\": \"haproxy-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"haproxy\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::haproxy_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": false, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}]}, {\"name\": \"Run lvmfilter role\", \"include_role\": {\"name\": \"tripleo_lvmfilter\"}, \"when\": [\"step|int == 1\"]}, {\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"metrics_qdr\", \"dns\": \"{{fqdn_internal_api}}\", \"principal\": \"metrics_qdr/{{fqdn_internal_api}}@{{idm_realm}}\", \"run_after\": \"container_name=$({{container_cli}} ps --format=\\\\{\\\\{.Names\\\\}\\\\} | grep metrics_qdr)\\nservice_crt=\\\"/etc/pki/tls/certs/metrics_qdr.crt\\\"\\nservice_key=\\\"/etc/pki/tls/private/metrics_qdr.key\\n# Copy the new cert from the mount-point to the real path\\n{{container_cli}} exec \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_crt\\\" \\\"$service_crt\\\"\\n# Copy the new key from the mount-point to the real path\\n{{container_cli}} exec \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_key\\\" \\\"$service_key\\\"\\n# Set appropriate permissions\\n{{container_cli}} exec \\\"$container_name\\\" chown qdrouterd:qdrouterd \\\"$service_crt\\\"\\n{{container_cli}} exec \\\"$container_name\\\" chown qdrouterd:qdrouterd \\\"$service_key\\\"\\n# Trigger a container restart to read the new certificate\\n{{container_cli}} restart \\\"$container_name\\\"\\n\", \"key_size\": \"2048\", \"ca\": \"ipa\"}]}}]}, {\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"mysql\", \"dns\": [\"{{fqdn_internal_api}}\", \"{{cloud_names.cloud_name_internal_api}}\"], \"principal\": \"mysql/{{fqdn_internal_api}}@{{idm_realm}}\", \"key_size\": \"2048\", \"ca\": \"ipa\"}]}}]}, {\"name\": \"MySQL tag container image for pacemaker\", \"when\": \"step|int == 1\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"container_image_latest\": \"cluster.common.tag/mariadb:pcmklatest\"}}, {\"name\": \"MySQL HA Wrappers Step\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Mysql puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"mysql\", \"tripleo_ha_wrapper_resource_name\": \"galera\", \"tripleo_ha_wrapper_bundle_name\": \"galera-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Master\", \"tripleo_ha_wrapper_puppet_config_volume\": \"mysql\", \"tripleo_ha_wrapper_puppet_execute\": \"[\\\"Mysql_datadir\\\", \\\"Mysql_user\\\", \\\"Mysql_database\\\", \\\"Mysql_grant\\\", \\\"Mysql_plugin\\\"].each |String $val| { noop_resource($val) }; include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::database::mysql_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": false, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}]}, {\"name\": \"validate nova-conductor container state\", \"containers.podman.podman_container_info\": {\"name\": \"nova_conductor\"}, \"register\": \"nova_conductor_infos\", \"failed_when\": [\"nova_conductor_infos.containers.0.Healthcheck.Status is defined\", \"\'healthy\' not in nova_conductor_infos.containers.0.Healthcheck.Status\"], \"retries\": 10, \"delay\": 30, \"tags\": [\"opendev-validation\", \"opendev-validation-nova\"], \"when\": [\"container_cli == \'podman\'\", \"not container_healthcheck_disabled\", \"step|int == 5\"]}, {\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/tls/certs/httpd\", \"/etc/pki/tls/private/httpd\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"httpd-ctlplane\", \"dns\": \"{{ fqdn_ctlplane }}\", \"principal\": \"HTTP/{{ fqdn_ctlplane }}@{{ idm_realm }}\", \"run_after\": \"cp /etc/pki/tls/certs/httpd-ctlplane.crt /etc/pki/tls/certs/httpd/httpd-ctlplane.crt\\ncp /etc/pki/tls/private/httpd-ctlplane.key /etc/pki/tls/private/httpd/httpd-ctlplane.key\\npkill -USR1 httpd\\n\", \"key_size\": \"2048\", \"ca\": \"ipa\"}, {\"name\": \"httpd-storage\", \"dns\": \"{{ fqdn_storage }}\", \"principal\": \"HTTP/{{ fqdn_storage }}@{{ idm_realm }}\", \"run_after\": \"cp /etc/pki/tls/certs/httpd-storage.crt /etc/pki/tls/certs/httpd/httpd-storage.crt\\ncp /etc/pki/tls/private/httpd-storage.key /etc/pki/tls/private/httpd/httpd-storage.key\\npkill -USR1 httpd\\n\", \"key_size\": \"2048\", \"ca\": \"ipa\"}, {\"name\": \"httpd-storage_mgmt\", \"dns\": \"{{ fqdn_storage_mgmt }}\", \"principal\": \"HTTP/{{ fqdn_storage_mgmt }}@{{ idm_realm }}\", \"run_after\": \"cp /etc/pki/tls/certs/httpd-storage_mgmt.crt /etc/pki/tls/certs/httpd/httpd-storage_mgmt.crt\\ncp /etc/pki/tls/private/httpd-storage_mgmt.key /etc/pki/tls/private/httpd/httpd-storage_mgmt.key\\npkill -USR1 httpd\\n\", \"key_size\": \"2048\", \"ca\": \"ipa\"}, {\"name\": \"httpd-internal_api\", \"dns\": \"{{ fqdn_internal_api }}\", \"principal\": \"HTTP/{{ fqdn_internal_api }}@{{ idm_realm }}\", \"run_after\": \"cp /etc/pki/tls/certs/httpd-internal_api.crt /etc/pki/tls/certs/httpd/httpd-internal_api.crt\\ncp /etc/pki/tls/private/httpd-internal_api.key /etc/pki/tls/private/httpd/httpd-internal_api.key\\npkill -USR1 httpd\\n\", \"key_size\": \"2048\", \"ca\": \"ipa\"}]}}]}, {\"name\": \"validate nova-metadata container state\", \"containers.podman.podman_container_info\": {\"name\": \"nova_metadata\"}, \"register\": \"nova_metadata_infos\", \"failed_when\": [\"nova_metadata_infos.containers.0.Healthcheck.Status is defined\", \"\'healthy\' not in nova_metadata_infos.containers.0.Healthcheck.Status\"], \"retries\": 10, \"delay\": 30, \"tags\": [\"opendev-validation\", \"opendev-validation-nova\"], \"when\": [\"container_cli == \'podman\'\", \"not container_healthcheck_disabled\", \"step|int == 5\"]}, {\"name\": \"validate nova-vnc-proxy container state\", \"containers.podman.podman_container_info\": {\"name\": \"nova_vnc_proxy\"}, \"register\": \"nova_vnc_proxy_infos\", \"failed_when\": [\"nova_vnc_proxy_infos.containers.0.Healthcheck.Status is defined\", \"\'healthy\' not in nova_vnc_proxy_infos.containers.0.Healthcheck.Status\"], \"retries\": 10, \"delay\": 30, \"tags\": [\"opendev-validation\", \"opendev-validation-nova\"], \"when\": [\"container_cli == \'podman\'\", \"not container_healthcheck_disabled\", \"step|int == 5\"]}, {\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"rabbitmq\", \"dns\": \"{{fqdn_internal_api}}\", \"principal\": \"rabbitmq/{{fqdn_internal_api}}@{{idm_realm}}\", \"run_after\": \"container_name=$({{container_cli}} ps --format=\\\\{\\\\{.Names\\\\}\\\\} | grep -w -E \'rabbitmq(-bundle-.*-[0-9]+)?\')\\nservice_crt=\\\"/etc/pki/tls/certs/rabbitmq.crt\\\"\\nservice_key=\\\"/etc/pki/tls/private/rabbitmq.key\\\"\\nif echo \\\"$container_name\\\" | grep -q \\\"^rabbitmq-bundle\\\"; then\\n  # lp#1917868: Do not use podman cp with HA containers as they get\\n  # frozen temporarily and that can make pacemaker operation fail.\\n  tar -c \\\"$service_crt\\\" \\\"$service_key\\\" | {{container_cli}} exec -i \\\"$container_name\\\" tar -C / -xv\\n  # no need to update the mount point, because pacemaker\\n  # recreates the container when it\'s restarted\\nelse\\n  # Refresh the cert at the mount-point\\n  {{container_cli}} cp $service_crt \\\"$container_name:/var/lib/kolla/config_files/src-tls/$service_crt\\\"\\n  # Refresh the key at the mount-point\\n  {{container_cli}} cp $service_key \\\"$container_name:/var/lib/kolla/config_files/src-tls/$service_key\\\"\\n  # Copy the new cert from the mount-point to the real path\\n  {{container_cli}} exec -u root \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_crt\\\" \\\"$service_crt\\\"\\n  # Copy the new key from the mount-point to the real path\\n  {{container_cli}} exec -u root \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_key\\\" \\\"$service_key\\\"\\nfi\\n# Set appropriate permissions\\n{{container_cli}} exec -u root \\\"$container_name\\\" chown rabbitmq:rabbitmq \\\"$service_crt\\\"\\n{{container_cli}} exec -u root \\\"$container_name\\\" chown rabbitmq:rabbitmq \\\"$service_key\\\"\\n# Trigger a pem cache clear in RabbitMQ to read the new certificates\\n{{container_cli}} exec \\\"$container_name\\\" rabbitmqctl eval \\\"ssl:clear_pem_cache().\\\"\\n\", \"key_size\": \"2048\", \"ca\": \"ipa\"}]}}]}, {\"name\": \"RabbitMQ tag container image for pacemaker\", \"when\": \"step|int == 1\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"container_image_latest\": \"cluster.common.tag/rabbitmq:pcmklatest\"}}, {\"name\": \"RabbitMQ RPC HA Wrappers Step\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Rabbitmq rpc puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"oslo_messaging_rpc\", \"tripleo_ha_wrapper_resource_name\": \"rabbitmq\", \"tripleo_ha_wrapper_bundle_name\": \"rabbitmq-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"rabbitmq\", \"tripleo_ha_wrapper_puppet_execute\": \"[\\\"Rabbitmq_policy\\\", \\\"Rabbitmq_user\\\"].each |String $val| { noop_resource($val) }; include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::rabbitmq_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": false, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}]}, {\"when\": [\"(step|int) == 1\"], \"block\": [{\"name\": \"Pre-fetch all the containers\", \"become\": true, \"containers.podman.podman_image\": {\"name\": \"{{ prefetch_image }}\", \"validate_certs\": false, \"force\": true}, \"register\": \"result\", \"until\": \"result is succeeded\", \"retries\": 5, \"delay\": 5, \"loop_control\": {\"loop_var\": \"prefetch_image\"}, \"loop\": \"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\"}]}], \"external_deploy_tasks\": [{\"name\": \"Run tripleo-container-image-prepare role\", \"import_role\": {\"name\": \"tripleo_container_image_prepare\"}, \"vars\": {\"tripleo_container_image_prepare_log_file\": \"/var/log/tripleo-container-image-prepare.log\", \"tripleo_container_image_prepare_debug\": true, \"tripleo_container_image_prepare_roles\": [{\"name\": \"Controller\", \"description\": \"Controller role that has all the controler services loaded and handles\\\\nDatabase, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\", \"external_bridge\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BarbicanApi\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\", \"OS::TripleO::Services::BarbicanBackendDogtag\", \"OS::TripleO::Services::BarbicanBackendKmip\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::CephGrafana\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CephNfs\", \"OS::TripleO::Services::CephRbdMirror\", \"OS::TripleO::Services::CephRgw\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackendDellSc\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\", \"OS::TripleO::Services::CinderBackendDellEMCSc\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\", \"OS::TripleO::Services::CinderBackendNetApp\", \"OS::TripleO::Services::CinderBackendPure\", \"OS::TripleO::Services::CinderBackendScaleIO\", \"OS::TripleO::Services::CinderBackendNVMeOF\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::DesignateApi\", \"OS::TripleO::Services::DesignateCentral\", \"OS::TripleO::Services::DesignateProducer\", \"OS::TripleO::Services::DesignateWorker\", \"OS::TripleO::Services::DesignateMDNS\", \"OS::TripleO::Services::DesignateSink\", \"OS::TripleO::Services::DesignateBind\", \"OS::TripleO::Services::Etcd\", \"OS::TripleO::Services::ExternalSwiftProxy\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::IronicApi\", \"OS::TripleO::Services::IronicConductor\", \"OS::TripleO::Services::IronicInspector\", \"OS::TripleO::Services::IronicPxe\", \"OS::TripleO::Services::IronicNeutronAgent\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaBackendFlashBlade\", \"OS::TripleO::Services::ManilaBackendIsilon\", \"OS::TripleO::Services::ManilaBackendNetapp\", \"OS::TripleO::Services::ManilaBackendPowerMax\", \"OS::TripleO::Services::ManilaBackendUnity\", \"OS::TripleO::Services::ManilaBackendVNX\", \"OS::TripleO::Services::ManilaBackendVMAX\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronBgpVpnApi\", \"OS::TripleO::Services::NeutronSfcApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NeutronDhcpAgent\", \"OS::TripleO::Services::NeutronL2gwAgent\", \"OS::TripleO::Services::NeutronL2gwApi\", \"OS::TripleO::Services::NeutronL3Agent\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NeutronOvsAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NeutronAgentsIBConfig\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaIronic\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OctaviaApi\", \"OS::TripleO::Services::OctaviaDeploymentConfig\", \"OS::TripleO::Services::OctaviaHealthManager\", \"OS::TripleO::Services::OctaviaHousekeeping\", \"OS::TripleO::Services::OctaviaWorker\", \"OS::TripleO::Services::OpenStackClients\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftDispersion\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Unbound\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"CellController\", \"description\": \"Controller role that has the cell controler specific\\\\nservices and handles Database, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Ptp\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"CellControllerCompute\", \"description\": \"Controller and Compute AIO role that has compute and cell controler specific\\\\nservices loaded and handles Database, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\", \"external_bridge\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-compute-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\", \"OS::TripleO::Services::ComputeNeutronL3Agent\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NovaAZConfig\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Ptp\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"Compute\", \"description\": \"Basic Compute Node role\\\\n\", \"CountDefault\": 1, \"tags\": [\"compute\", \"external_bridge\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-novacompute-%index%\", \"RoleParametersDefault\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"uses_deprecated_params\": true, \"deprecated_param_image\": \"NovaImage\", \"deprecated_param_extraconfig\": \"NovaComputeExtraConfig\", \"deprecated_param_metadata\": \"NovaComputeServerMetadata\", \"deprecated_param_scheduler_hints\": \"NovaComputeSchedulerHints\", \"deprecated_param_ips\": \"NovaComputeIPs\", \"deprecated_server_resource_name\": \"NovaCompute\", \"deprecated_nic_config_name\": \"compute.yaml\", \"update_serial\": 25, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\", \"OS::TripleO::Services::ComputeNeutronL3Agent\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NovaAZConfig\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"]}, {\"name\": \"BlockStorage\", \"description\": \"Cinder Block Storage node role\\\\n\", \"tags\": [\"storage\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": false, \"deprecated_nic_config_name\": \"cinder-storage.yaml\", \"update_serial\": 25, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BlockStorageCinderVolume\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}, {\"name\": \"ObjectStorage\", \"description\": \"Swift Object Storage node role\\\\n\", \"tags\": [\"storage\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": true, \"deprecated_param_metadata\": \"SwiftStorageServerMetadata\", \"deprecated_param_ips\": \"SwiftStorageIPs\", \"deprecated_param_image\": \"SwiftStorageImage\", \"deprecated_param_flavor\": \"OvercloudSwiftStorageFlavor\", \"deprecated_nic_config_name\": \"swift-storage.yaml\", \"deprecated_server_resource_name\": \"SwiftStorage\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Ptp\"]}, {\"name\": \"CephStorage\", \"description\": \"Ceph OSD Storage node role\\\\n\", \"tags\": [\"ceph\", \"storage\"], \"networks\": {\"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": false, \"HostnameFormatDefault\": \"%stackname%-cephstorage-%index%\", \"deprecated_nic_config_name\": \"ceph-storage.yaml\", \"update_serial\": 1, \"rhsm_enforce\": false, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}, {\"name\": \"Networker\", \"description\": \"Standalone networking role to run Neutron agents on their own.\\\\n\", \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"tags\": [\"external_bridge\"], \"HostnameFormatDefault\": \"%stackname%-networker-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::IronicNeutronAgent\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronDhcpAgent\", \"OS::TripleO::Services::NeutronL2gwAgent\", \"OS::TripleO::Services::NeutronL3Agent\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NeutronOvsAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OctaviaDeploymentConfig\", \"OS::TripleO::Services::OctaviaHealthManager\", \"OS::TripleO::Services::OctaviaHousekeeping\", \"OS::TripleO::Services::OctaviaWorker\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}], \"tripleo_container_image_prepare_content\": {\"parameter_defaults\": {\"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"DockerInsecureRegistryAddress\": [], \"NeutronMechanismDrivers\": [\"ovn\"], \"DockerRegistryMirror\": \"\", \"ContainerImageRegistryCredentials\": {}, \"AdditionalArchitectures\": [], \"ControllerContainerImagePrepare\": {}, \"ControllerServices\": [], \"ControllerCount\": 0, \"CellControllerContainerImagePrepare\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerCount\": 1, \"CellControllerComputeContainerImagePrepare\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeCount\": 0, \"ComputeContainerImagePrepare\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeCount\": 1, \"BlockStorageContainerImagePrepare\": {}, \"BlockStorageServices\": [], \"BlockStorageCount\": 0, \"ObjectStorageContainerImagePrepare\": {}, \"ObjectStorageServices\": [], \"ObjectStorageCount\": 0, \"CephStorageContainerImagePrepare\": {}, \"CephStorageServices\": [], \"CephStorageCount\": 0, \"NetworkerContainerImagePrepare\": {}, \"NetworkerServices\": [], \"NetworkerCount\": 0}}}, \"when\": [\"(step | int) == 1\"]}], \"external_post_deploy_tasks\": [], \"external_update_tasks\": [{\"when\": \"step|int == 1\", \"tags\": \"ha_image_update\", \"block\": [{\"block\": [{\"name\": \"Get haproxy image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_haproxy_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'haproxy-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container haproxy image\", \"set_fact\": {\"haproxy_image\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"haproxy_image_latest\": \"cluster.common.tag/haproxy:pcmklatest\", \"pcmk_haproxy_image\": \"{{xmllint_pcmk_haproxy_image.stdout}}\"}}], \"delegate_to\": \"{{ (groups[\\\"haproxy\\\"] | difference(groups[\\\"excluded_overcloud\\\"]))[0] }}\"}, {\"name\": \"haproxy temporary pacemaker container tag in case of image switch\", \"become\": true, \"import_role\": {\"name\": \"tripleo_ha_image_update\"}, \"vars\": {\"tripleo_ha_image_update_node_names\": \"{{ groups[\\\"haproxy\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) }}\", \"tripleo_ha_image_update_bundle\": \"haproxy-bundle\", \"tripleo_ha_image_update_new_image\": \"{{haproxy_image_latest}}\", \"tripleo_ha_image_update_old_image\": \"{{pcmk_haproxy_image}}\"}, \"when\": [\"(pcmk_haproxy_image != \\\"\\\")\", \"(pcmk_haproxy_image != haproxy_image_latest)\"]}]}, {\"when\": \"step|int == 1\", \"tags\": \"ha_image_update\", \"block\": [{\"block\": [{\"name\": \"Get galera image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_galera_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'galera-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container galera image\", \"set_fact\": {\"galera_image\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"galera_image_latest\": \"cluster.common.tag/mariadb:pcmklatest\", \"pcmk_galera_image\": \"{{xmllint_pcmk_galera_image.stdout}}\"}}], \"delegate_to\": \"{{ (groups[\\\"mysql\\\"] | difference(groups[\\\"excluded_overcloud\\\"]))[0] }}\"}, {\"name\": \"MySQL temporary pacemaker container tag in case of image switch\", \"become\": true, \"import_role\": {\"name\": \"tripleo_ha_image_update\"}, \"vars\": {\"tripleo_ha_image_update_node_names\": \"{{ groups[\\\"mysql\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) }}\", \"tripleo_ha_image_update_bundle\": \"galera-bundle\", \"tripleo_ha_image_update_new_image\": \"{{galera_image_latest}}\", \"tripleo_ha_image_update_old_image\": \"{{pcmk_galera_image}}\"}, \"when\": [\"(pcmk_galera_image != \\\"\\\")\", \"(pcmk_galera_image != galera_image_latest)\"]}]}, {\"when\": \"step|int == 1\", \"block\": [{\"name\": \"Set facts for running online DB migrations\", \"set_fact\": {\"is_additional_cell\": true}, \"tags\": [\"online_upgrade\", \"online_upgrade_nova\"]}, {\"name\": \"Online data migration for Nova\", \"when\": \"not is_additional_cell|bool\", \"command\": \"{{ container_cli }} exec nova_conductor nova-manage db online_data_migrations\", \"delegate_to\": \"{{ (groups[\'nova_conductor\'] | difference(groups[\'excluded_overcloud\']))[0] }}\", \"become\": true, \"tags\": [\"online_upgrade\", \"online_upgrade_nova\"]}]}, {\"when\": \"step|int == 1\", \"tags\": \"ha_image_update\", \"block\": [{\"block\": [{\"name\": \"Get rabbitmq image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_rabbitmq_rpc_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'rabbitmq-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container rabbitmq image\", \"set_fact\": {\"rabbitmq_rpc_image\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"rabbitmq_rpc_image_latest\": \"cluster.common.tag/rabbitmq:pcmklatest\", \"pcmk_rabbitmq_rpc_image\": \"{{xmllint_pcmk_rabbitmq_rpc_image.stdout}}\"}}], \"delegate_to\": \"{{ (groups[\\\"oslo_messaging_rpc\\\"] | difference(groups[\\\"excluded_overcloud\\\"]))[0] }}\"}, {\"name\": \"rabbitmq temporary pacemaker container tag in case of image switch\", \"become\": true, \"import_role\": {\"name\": \"tripleo_ha_image_update\"}, \"vars\": {\"tripleo_ha_image_update_node_names\": \"{{ groups[\\\"oslo_messaging_rpc\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) }}\", \"tripleo_ha_image_update_bundle\": \"rabbitmq-bundle\", \"tripleo_ha_image_update_new_image\": \"{{rabbitmq_rpc_image_latest}}\", \"tripleo_ha_image_update_old_image\": \"{{pcmk_rabbitmq_rpc_image}}\"}, \"when\": [\"(pcmk_rabbitmq_rpc_image != \\\"\\\")\", \"(pcmk_rabbitmq_rpc_image != rabbitmq_rpc_image_latest)\"]}]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop clustercheck container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"clustercheck\"], \"tripleo_delegate_to\": \"{{ groups[\'clustercheck\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}, {\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop logrotate container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"logrotate_crond\"], \"tripleo_delegate_to\": \"{{ groups[\'logrotate_crond\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}, {\"vars\": {\"mysql_upgrade_transfer\": true}, \"when\": [\"step|int == 2\", \"mysql_upgrade_transfer\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\"], \"block\": [{\"name\": \"Transfer mysql data\", \"include_role\": {\"name\": \"tripleo_transfer\"}, \"vars\": {\"tripleo_transfer_src_dir\": \"/var/lib/mysql\", \"tripleo_transfer_src_host\": \"{{hostvars[groups[\'overcloud\'][0]][\'mysql_short_node_names\'][1]}}\", \"tripleo_transfer_dest_dir\": \"/var/lib/mysql\", \"tripleo_transfer_dest_host\": \"{{hostvars[groups[\'overcloud\'][0]][\'mysql_short_bootstrap_node_name\']}}\", \"tripleo_transfer_flag_file\": \"/var/lib/tripleo/transfer-flags/var-lib-mysql\", \"tripleo_transfer_sync_options\": \"--whole-file --ignore-times --inplace --archive --delete\", \"tripleo_transfer_include\": [\"/ibdata*\", \"/ib_lru_dump\", \"/ib_logfile[0-9]*\", \"/undo*\", \"/*/\"], \"tripleo_transfer_exclude\": \"/*\"}}]}, {\"when\": \"step|int == 1\", \"block\": [{\"name\": \"Set facts for running online DB migrations\", \"set_fact\": {\"is_additional_cell\": true}, \"tags\": [\"online_upgrade\", \"online_upgrade_nova\"]}, {\"name\": \"Online data migration for Nova\", \"when\": \"not is_additional_cell|bool\", \"command\": \"{{ container_cli }} exec nova_conductor nova-manage db online_data_migrations\", \"delegate_to\": \"{{ (groups[\'nova_conductor\'] | difference(groups[\'excluded_overcloud\']))[0] }}\", \"become\": true, \"tags\": [\"online_upgrade\", \"online_upgrade_nova\"]}]}, {\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop nova conductor container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"nova_conductor\"], \"tripleo_delegate_to\": \"{{ groups[\'nova_conductor\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}, {\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop nova metadata container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"nova_metadata\"], \"tripleo_delegate_to\": \"{{ groups[\'nova_metadata\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}, {\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop nova vnc proxy container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"nova_vnc_proxy\"], \"tripleo_delegate_to\": \"{{ groups[\'nova_vnc_proxy\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}, {\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_stop_services\", \"system_upgrade_transfer_data\"], \"block\": [{\"name\": \"Stop cluster\", \"become\": true, \"shell\": \"set -eu\\nFILE=/usr/sbin/pcs\\nif test -f \\\"$FILE\\\"; then\\n  /usr/sbin/pcs cluster stop --force\\nfi\\n\", \"delegate_to\": \"{{ item }}\", \"with_items\": \"{{ groups[\'pacemaker\'] | difference(groups[\'excluded_overcloud\']) }}\"}]}, {\"name\": \"Clean up upgrade artifacts\", \"when\": \"step|int == 1\", \"tags\": [\"never\", \"system_upgrade_cleanup\"], \"block\": [{\"name\": \"cleanup tripleo_persist\", \"include_role\": {\"name\": \"tripleo_persist\", \"tasks_from\": \"cleanup.yml\"}}]}], \"scale_tasks\": [{\"when\": [\"step|int == 1\", \"container_cli == \'podman\'\", \"\\\"pacemaker_remote\\\" in enabled_services|list\", \"inventory_hostname_short in compute_instanceha_short_node_names\"], \"tags\": \"down\", \"become\": true, \"block\": [{\"name\": \"Getting Nova compute hostname\", \"command\": \"crm_node -n\", \"register\": \"nova_compute_hostname\"}, {\"name\": \"Check if pacemaker_short_bootstrap_node_name is a defined variable\", \"when\": \"pacemaker_short_bootstrap_node_name is not defined\", \"fail\": {\"msg\": \"Cannot delegate pacemaker cleanup to the bootstrap node. Please delete the resources manually.\"}, \"ignore_errors\": true}, {\"name\": \"Clean up Pacemaker remote and STONITH resources for Compute node\", \"when\": [\"nova_compute_hostname.stdout in compute_instanceha_short_node_names\", \"pacemaker_short_bootstrap_node_name is defined\"], \"block\": [{\"name\": \"List STONITH resource for the Compute node\", \"command\": \"stonith_admin -l {{ nova_compute_hostname.stdout }}\", \"register\": \"stonith_service_results\", \"delegate_to\": \"{{ pacemaker_short_bootstrap_node_name }}\"}, {\"name\": \"Disable the STONITH resources for the Compute node\", \"command\": \"pcs stonith disable \\\"{{ item }}\\\"\", \"loop\": \"{{ stonith_service_results.stdout | regex_findall(\'^(stonith-fence(?!_compute-fence-nova).*)\', multiline=True)}}\", \"delegate_to\": \"{{ pacemaker_short_bootstrap_node_name }}\", \"register\": \"disable_output\", \"failed_when\": \"disable_output.rc != 0\", \"retries\": 3, \"delay\": 5, \"until\": \"disable_output.rc == 0\"}, {\"name\": \"Delete the STONITH resources for the Compute node\", \"command\": \"pcs stonith delete \\\"{{ item }}\\\"\", \"loop\": \"{{ stonith_service_results.stdout | regex_findall(\'^(stonith-fence(?!_compute-fence-nova).*)\', multiline=True)}}\", \"delegate_to\": \"{{ pacemaker_short_bootstrap_node_name }}\", \"register\": \"delete_output\", \"failed_when\": \"delete_output.rc != 0\", \"retries\": 3, \"delay\": 5, \"until\": \"delete_output.rc == 0\"}, {\"name\": \"Clear the stonith level hierarchy for the Compute node target\", \"command\": \"pcs stonith level clear target {{ nova_compute_hostname.stdout }}\", \"delegate_to\": \"{{ pacemaker_short_bootstrap_node_name }}\"}, {\"name\": \"Delete Compute node from cluster\", \"command\": \"pcs cluster node remove-remote {{ nova_compute_hostname.stdout }}\", \"delegate_to\": \"{{ pacemaker_short_bootstrap_node_name }}\"}, {\"name\": \"Remove compute node in pcmk_host_list parameter from stonith-fence_compute-fence-nova\", \"command\": \"crm_resource --set-parameter=pcmk_host_list -r stonith-fence_compute-fence-nova -v \\\"{{ pacemaker_remote_short_node_names | reject(\'search\', nova_compute_hostname.stdout) | join(\',\') }}\\\"\", \"delegate_to\": \"{{ pacemaker_short_bootstrap_node_name }}\"}]}]}], \"pre_upgrade_rolling_tasks\": [], \"upgrade_tasks\": [{\"name\": \"upgrade prepare for leapp to align kernel arg shortcommings in leapp\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"fix grub entries to have name start with GRUB_\", \"replace\": {\"path\": \"/etc/default/grub\", \"regexp\": \"^(TRIPLEO_HEAT_TEMPLATE_KERNEL_ARGS)(.*)\", \"replace\": \"GRUB_\\\\1\\\\2\"}}, {\"name\": \"fix grub entries in append statement\", \"replace\": {\"path\": \"/etc/default/grub\", \"regexp\": \"(.*){(TRIPLEO_HEAT_TEMPLATE_KERNEL_ARGS)}(.*)\", \"replace\": \"\\\\1{GRUB_\\\\2}\\\\3\"}}]}, {\"name\": \"remove rsyslog configuration for podman healthcheck log\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_rsyslog_cleanup\"}}, {\"name\": \"Force pull image collectd\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 3\"], \"containers.podman.podman_image\": {\"name\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"force\": true}}, {\"name\": \"UBI8 to UBI9 switch of collectd\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 5\"], \"block\": [{\"name\": \"Update collectd to UBI9\", \"tripleo_container_manage\": {\"config_dir\": \"/var/lib/tripleo-config/container-startup-config/step_3\", \"config_patterns\": \"collectd.json\", \"config_id\": [\"tripleo_step3\"], \"log_base_path\": \"{{ container_log_stdout_path }}\", \"debug\": \"{{ enable_debug | bool }}\", \"config_overrides\": {\"collectd\": {\"image\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\"}}}}]}, {\"name\": \"Ensure old cron.daily is absent\", \"when\": \"step|int == 1\", \"file\": {\"path\": \"/etc/cron.daily/containers-tmpwatch\", \"state\": \"absent\"}}, {\"name\": \"Tear-down non-HA haproxy container\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Remove non-HA haproxy container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"haproxy\"]}}]}, {\"name\": \"Prepare switch of haproxy image name\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Get haproxy image id currently used by pacemaker\", \"shell\": \"pcs resource config haproxy-bundle | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\", \"register\": \"haproxy_image_current_res\", \"failed_when\": false}, {\"name\": \"Image facts for haproxy\", \"set_fact\": {\"haproxy_image_latest\": \"cluster.common.tag/haproxy:pcmklatest\", \"haproxy_image_current\": \"{{haproxy_image_current_res.stdout}}\"}}, {\"name\": \"Temporarily tag the current haproxy image id with the upgraded image name\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{haproxy_image_current}}\", \"container_image_latest\": \"{{haproxy_image_latest}}\", \"pull_image\": false}, \"when\": [\"haproxy_image_current != \'\'\", \"haproxy_image_current != haproxy_image_latest\"]}, {\"name\": \"Create haproxy retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/haproxy_needs_retag\", \"state\": \"touch\"}, \"when\": [\"haproxy_image_current != \'\'\", \"haproxy_image_current != haproxy_image_latest\"]}]}, {\"name\": \"Update haproxy pcs resource bundle for new container image\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Set upgrade haproxy facts\", \"set_fact\": {\"is_haproxy_bootstrap_node\": \"{{haproxy_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\"}}, {\"name\": \"Check for haproxy retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/haproxy_needs_retag\"}, \"register\": \"haproxy_retag_state_file\"}]}, {\"name\": \"Update haproxy pcs resource bundle for new container image\", \"when\": [\"step|int == 1\", \"is_haproxy_bootstrap_node|bool\", \"haproxy_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the haproxy cluster resource before container upgrade\", \"pacemaker_resource\": {\"resource\": \"haproxy-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Expose HAProxy stats socket on the host and mount TLS cert if needed\", \"block\": [{\"name\": \"Check haproxy stats socket configuration in pacemaker\", \"command\": \"cibadmin --query --xpath \\\"//storage-mapping[@id=\'haproxy-var-lib\']\\\"\", \"failed_when\": false, \"register\": \"haproxy_stats_exposed\"}, {\"name\": \"Check haproxy public certificate configuration in pacemaker\", \"command\": \"cibadmin --query --xpath \\\"//storage-mapping[@id=\'haproxy-cert\']\\\"\", \"failed_when\": false, \"register\": \"haproxy_cert_mounted\"}, {\"name\": \"Add a bind mount for stats socket in the haproxy bundle\", \"command\": \"pcs resource bundle update haproxy-bundle storage-map add id=haproxy-var-lib source-dir=/var/lib/haproxy target-dir=/var/lib/haproxy options=rw\", \"when\": \"haproxy_stats_exposed.rc == 6\"}, {\"name\": \"Set HAProxy public cert volume mount fact\", \"set_fact\": {\"haproxy_public_cert_path\": \"/etc/pki/tls/private/overcloud_endpoint.pem\", \"haproxy_public_tls_enabled\": false}}, {\"name\": \"Add a bind mount for public certificate in the haproxy bundle\", \"command\": \"pcs resource bundle update haproxy-bundle storage-map add id=haproxy-cert source-dir={{ haproxy_public_cert_path }} target-dir=/var/lib/kolla/config_files/src-tls/{{ haproxy_public_cert_path }} options=ro\", \"when\": [\"haproxy_cert_mounted.rc == 6\", \"haproxy_public_tls_enabled|bool\"]}]}, {\"name\": \"Update the haproxy bundle to use the new container image name\", \"command\": \"pcs resource bundle update haproxy-bundle container image={{haproxy_image_latest}}\"}, {\"name\": \"Enable the haproxy cluster resource\", \"pacemaker_resource\": {\"resource\": \"haproxy-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Remove haproxy retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/haproxy_needs_retag\", \"state\": \"absent\"}}]}, {\"name\": \"Retag the pacemaker image if containerized\", \"when\": [\"step|int == 3\"], \"block\": [{\"block\": [{\"name\": \"Get haproxy image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_haproxy_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'haproxy-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container haproxy image\", \"set_fact\": {\"haproxy_image\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"haproxy_image_latest\": \"cluster.common.tag/haproxy:pcmklatest\", \"pcmk_haproxy_image\": \"{{xmllint_pcmk_haproxy_image.stdout}}\"}}]}, {\"block\": [{\"name\": \"Retag pcmklatest to latest haproxy image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{haproxy_image}}\", \"container_image_latest\": \"{{haproxy_image_latest}}\"}}]}, {\"name\": \"Ensure config works for the new config\", \"shell\": \"set -o pipefail\\nawk -i inplace -v INPLACE_SUFFIX=.bak \'/  rsprep/ {print \\\"  http-response replace-header Location \\\" $3\\\" \\\"$5; next;}; {print} \' /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg\"}]}, {\"name\": \"Tear-down non-HA mysql container\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"stat mysql container\", \"command\": \"podman container exists mysql\", \"failed_when\": false, \"changed_when\": false, \"register\": \"stat_mysql_container\"}, {\"name\": \"Create clustercheck user and permissions\", \"command\": {\"argv\": \"{{ mysql_exec_data | container_exec_cmd }}\"}, \"changed_when\": true, \"when\": [\"stat_mysql_container.rc == 0\"], \"vars\": {\"mysql_exec_data\": {\"environment\": {\"CLUSTERCHECK_PASSWORD\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\"}, \"command\": [\"mysql\", \"/bin/sh\", \"-c\", \"mysql -e \\\"CREATE USER IF NOT EXISTS \'clustercheck\'@\'localhost\' IDENTIFIED BY \'${CLUSTERCHECK_PASSWORD}\'; GRANT PROCESS ON *.* TO \'clustercheck\'@\'localhost\' WITH GRANT OPTION;\\\"\"]}}}, {\"name\": \"Remove non-HA mysql container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"mysql\"]}}]}, {\"name\": \"set mysql container name fact\", \"when\": [\"step|int == 1\"], \"set_fact\": {\"mysql_container_name\": \"galera-bundle\"}}, {\"name\": \"Drop unused OpenStack DB users\", \"when\": [\"step|int == 1\", \"mysql_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower\"], \"block\": [{\"name\": \"mysql container id\", \"command\": \"podman ps -q --filter name={{ mysql_container_name }} --filter status=running\", \"register\": \"mysql_container_id\"}, {\"name\": \"set mysql container id fact\", \"set_fact\": {\"mysql_container\": \"{{ mysql_container_id.stdout }}\"}}, {\"name\": \"Mysql script to drop unused DB users\", \"when\": \"( mysql_container | length ) > 0\", \"block\": [{\"name\": \"Get the list of all OpenStack DB users\", \"shell\": \"jq -r \'to_entries[] | select(.key|endswith(\\\"::db::mysql::user\\\")) | .value\' /etc/puppet/hieradata/service_configs.json\", \"register\": \"openstack_db_users\"}, {\"name\": \"List all DB users that match the DB users to be dropped\", \"shell\": \"for u in {{ openstack_db_users.stdout_lines | join(\' \') }}; do podman exec -u root -it \\\"{{ mysql_container }}\\\" mysql -sNe \\\"select concat(\'\\\\`\',user,\'\\\\`@\\\\`\',host,\'\\\\`\') from mysql.user where user = \'$u\' and host != \'%\';\\\"; done\", \"register\": \"mysql_db_users\"}, {\"name\": \"resulting DB users to be dropped\", \"debug\": {\"msg\": \"{{ mysql_db_users.stdout_lines }}\"}}, {\"name\": \"Drop all unneeded Openstack DB users\", \"shell\": \"podman exec -u root -it \\\"{{ mysql_container }}\\\" mysql -sNe \'drop user {{ item }};\'\", \"loop\": \"{{ mysql_db_users.stdout_lines }}\"}]}]}, {\"vars\": {\"mysql_upgrade_persist\": false}, \"when\": [\"step|int == 3\", \"mysql_upgrade_persist\"], \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"block\": [{\"name\": \"Persist mysql data\", \"include_role\": {\"name\": \"tripleo_persist\", \"tasks_from\": \"persist.yml\"}, \"vars\": {\"tripleo_persist_dir\": \"/var/lib/mysql\"}}]}, {\"vars\": {\"mysql_upgrade_persist\": false}, \"when\": [\"step|int == 5\", \"mysql_upgrade_persist\"], \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\"], \"block\": [{\"name\": \"Restore mysql data\", \"include_role\": {\"name\": \"tripleo_persist\", \"tasks_from\": \"restore.yml\"}, \"vars\": {\"tripleo_persist_dir\": \"/var/lib/mysql\"}}]}, {\"name\": \"Prepare switch of galera image name\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Get galera image id currently used by pacemaker\", \"shell\": \"pcs resource config galera-bundle | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\", \"register\": \"galera_image_current_res\", \"failed_when\": false}, {\"name\": \"Image facts for galera\", \"set_fact\": {\"galera_image_latest\": \"cluster.common.tag/mariadb:pcmklatest\", \"galera_image_current\": \"{{galera_image_current_res.stdout}}\"}}, {\"name\": \"Temporarily tag the current galera image id with the upgraded image name\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{galera_image_current}}\", \"container_image_latest\": \"{{galera_image_latest}}\", \"pull_image\": false}, \"when\": [\"galera_image_current != \'\'\", \"galera_image_current != galera_image_latest\"]}, {\"name\": \"Create galera retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/galera_needs_retag\", \"state\": \"touch\"}, \"when\": [\"galera_image_current != \'\'\", \"galera_image_current != galera_image_latest\"]}]}, {\"name\": \"Update galera pcs resource bundle for new container image - check\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"set is_mysql_bootstrap_node fact\", \"tags\": \"common\", \"set_fact\": \"is_mysql_bootstrap_node={{mysql_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\"}, {\"name\": \"Check for galera retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/galera_needs_retag\"}, \"register\": \"galera_retag_state_file\"}]}, {\"name\": \"Update galera pcs resource bundle for new container image\", \"when\": [\"step|int == 1\", \"is_mysql_bootstrap_node|bool\", \"galera_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the galera cluster resource before container upgrade\", \"pacemaker_resource\": {\"resource\": \"galera-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Move Mysql logging to /var/log/containers\", \"block\": [{\"name\": \"Check Mysql logging configuration in pacemaker\", \"command\": \"cibadmin --query --xpath \\\"//storage-mapping[@id=\'mysql-log\']\\\"\", \"failed_when\": false, \"register\": \"mysql_logs_moved\"}, {\"name\": \"Change Mysql logging configuration in pacemaker\", \"when\": \"mysql_logs_moved.rc == 6\", \"block\": [{\"name\": \"Add a bind mount for logging in the galera bundle\", \"command\": \"pcs resource bundle update galera-bundle storage-map add id=mysql-log source-dir=/var/log/containers/mysql target-dir=/var/log/mysql options=rw\"}, {\"name\": \"Reconfigure Mysql log file in the galera resource agent\", \"command\": \"pcs resource update galera log=/var/log/mysql/mysqld.log\"}]}]}, {\"name\": \"Update the galera bundle to use the new container image name\", \"command\": \"pcs resource bundle update galera-bundle container image={{galera_image_latest}}\"}, {\"name\": \"Enable the galera cluster resource\", \"pacemaker_resource\": {\"resource\": \"galera-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}]}, {\"name\": \"Upgrade galera in step3\", \"when\": [\"step|int == 3\"], \"block\": [{\"name\": \"Bind mounts for temporary container\", \"set_fact\": {\"mysql_upgrade_db_bind_mounts\": [\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\", \"/etc/puppet:/etc/puppet:ro\", \"/var/lib/kolla/config_files/mysql.json:/var/lib/kolla/config_files/config.json:rw,z\", \"/var/lib/config-data/puppet-generated/mysql:/var/lib/kolla/config_files/src:ro,z\", \"/var/lib/mysql:/var/lib/mysql:rw,z\", \"/var/log/containers/mysql:/var/log/mysql:rw,z\"]}}, {\"name\": \"Check if Galera needs upgrade\", \"shell\": \"{{ container_cli }} run --rm --log-driver=k8s-file --log-opt path=/var/log/containers/mysql/db-upgrade.log \\\\ -u root --net=host -e \\\"KOLLA_CONFIG_STRATEGY=COPY_ALWAYS\\\" -v {{ mysql_upgrade_db_bind_mounts | join(\' -v \')}} \\\"cluster.common.tag/mariadb:pcmklatest\\\" /bin/bash -ecx \\\"$UPGRADE_SCRIPT\\\"\", \"environment\": {\"UPGRADE_SCRIPT\": \"kolla_set_configs\\nupgraded_ver=$(cat /var/lib/mysql/mysql_upgrade_info 2>/dev/null || true)\\nmysql_ver=$(mysql --version | awk -F\'[ ,]*\' \'{print $5}\')\\nif [ \\\"${upgraded_ver}\\\" = \\\"${mysql_ver}\\\" ]; then\\n    echo \\\"mysql already upgraded\\\"\\nelse\\n    echo \\\"${upgraded_ver} VS ${mysql_ver}\\\"\\nfi\\n\"}, \"register\": \"mysql_upgrade_needed\"}, {\"name\": \"Set fact upgrade_mysql\", \"set_fact\": {\"upgrade_mysql\": \"{{ (mysql_upgrade_needed.stdout != \\\"mysql already upgraded\\\") | bool }}\"}}, {\"debug\": {\"msg\": \"MYSQL check - {{ mysql_upgrade_needed.stdout }} - Upgrade needed: {{ upgrade_mysql }}\"}}, {\"name\": \"Disable the galera cluster resource before container upgrade\", \"when\": [\"upgrade_mysql|bool\"], \"pacemaker_resource\": {\"resource\": \"galera-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"block\": [{\"name\": \"Get galera image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_galera_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'galera-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container galera image\", \"set_fact\": {\"galera_image\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"galera_image_latest\": \"cluster.common.tag/mariadb:pcmklatest\", \"pcmk_galera_image\": \"{{xmllint_pcmk_galera_image.stdout}}\"}}]}, {\"name\": \"Check for galera retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/galera_needs_retag\"}, \"register\": \"galera_retag_state_file\"}, {\"name\": \"Retag the pacemaker image if containerized\", \"when\": [\"galera_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Retag pcmklatest to latest galera image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{galera_image}}\", \"container_image_latest\": \"{{galera_image_latest}}\"}}]}, {\"name\": \"Remove galera retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/galera_needs_retag\", \"state\": \"absent\"}}, {\"name\": \"Mysql upgrade script\", \"when\": [\"upgrade_mysql|bool\"], \"set_fact\": {\"mysql_upgrade_script\": \"kolla_set_configs\\nif mysqladmin ping --silent; then exit 0; fi\\nupgraded_ver=$(cat /var/lib/mysql/mysql_upgrade_info 2>/dev/null || true)\\nmysql_ver=$(mysql --version | awk -F\'[ ,]*\' \'{print $5}\')\\nif [ \\\"${upgraded_ver}\\\" = \\\"${mysql_ver}\\\" ]; then\\n    echo \\\"mysql already upgraded\\\"\\n    exit 0\\nfi\\nchown -R mysql:mysql /var/lib/mysql\\nchown -R mysql:mysql /var/log/mysql\\nmysqld_safe --user=mysql --wsrep-provider=none --skip-networking --wsrep-on=off --log-error=/var/log/mysql/mysqld-upgrade.log &\\n\\n#!/usr/bin/bash\\n\\nset -e\\n\\n# Wait until we know the mysql server is up and responding\\ntimeout ${DB_MAX_TIMEOUT:-60} /bin/bash -c \'until mysqladmin -uroot ping 2>/dev/null; do sleep 1; done\'\\n\\n# After an upgrade, make sure that the running mysql had a chance to\\n# update its data table on disk.\\nmysql_upgrade\\n\\n# Upgrade to 10.3: the default table row format changed from COMPACT\\n# to DYNAMIC, so upgrade the existing tables.\\ncompact_tables=$(mysql -se \'SELECT CONCAT(\\\"`\\\",TABLE_SCHEMA,\\\"`.`\\\",TABLE_NAME,\\\"`\\\") FROM information_schema.tables WHERE ENGINE = \\\"InnoDB\\\" and ROW_FORMAT = \\\"Compact\\\";\');\\nfor i in $compact_tables; do echo converting row format of table $i; mysql -e \\\"ALTER TABLE $i ROW_FORMAT=DYNAMIC;\\\"; done;\\n\\nmysqladmin shutdown\"}}, {\"name\": \"Upgrade Mysql database from a temporary container\", \"when\": [\"upgrade_mysql|bool\"], \"shell\": \"{{ container_cli }} run --rm --log-driver=k8s-file --log-opt path=/var/log/containers/mysql/db-upgrade.log \\\\ -u root --net=host -e \\\"KOLLA_CONFIG_STRATEGY=COPY_ALWAYS\\\" -v {{ mysql_upgrade_db_bind_mounts | join(\' -v \')}} \\\"cluster.common.tag/mariadb:pcmklatest\\\" /bin/bash -ecx \\\"$UPGRADE_SCRIPT\\\"\", \"environment\": {\"UPGRADE_SCRIPT\": \"{{ mysql_upgrade_script }}\"}}, {\"name\": \"Enable the galera cluster resource\", \"when\": [\"upgrade_mysql|bool\"], \"pacemaker_resource\": {\"resource\": \"galera-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}]}, {\"name\": \"Tear-down non-HA rabbitmq container\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Remove non-HA rabbitmq container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"rabbitmq\"]}}]}, {\"name\": \"Prepare switch of rabbitmq image name\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Get rabbitmq image id currently used by pacemaker\", \"shell\": \"pcs resource config rabbitmq-bundle | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\", \"register\": \"rabbitmq_rpc_image_current_res\", \"failed_when\": false}, {\"name\": \"Image facts for rabbitmq\", \"set_fact\": {\"rabbitmq_rpc_image_latest\": \"cluster.common.tag/rabbitmq:pcmklatest\", \"rabbitmq_rpc_image_current\": \"{{rabbitmq_rpc_image_current_res.stdout}}\"}}, {\"name\": \"Temporarily tag the current rabbitmq image id with the upgraded image name\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{rabbitmq_rpc_image_current}}\", \"container_image_latest\": \"{{rabbitmq_rpc_image_latest}}\", \"pull_image\": false}, \"when\": [\"rabbitmq_rpc_image_current != \'\'\", \"rabbitmq_rpc_image_current != rabbitmq_rpc_image_latest\"]}, {\"name\": \"Create rabbitmq_rpc retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/rabbitmq_rpc_needs_retag\", \"state\": \"touch\"}, \"when\": [\"rabbitmq_rpc_image_current != \'\'\", \"rabbitmq_rpc_image_current != rabbitmq_rpc_image_latest\"]}]}, {\"name\": \"Update rabbitmq-bundle pcs resource bundle for new container image\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"set is_rpc_rabbitmq_bootstrap_node fact\", \"set_fact\": \"is_rpc_rabbitmq_bootstrap_node={{oslo_messaging_rpc_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\"}, {\"name\": \"Check for rabbitmq_rpc retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/rabbitmq_rpc_needs_retag\"}, \"register\": \"rabbitmq_rpc_retag_state_file\"}]}, {\"name\": \"Update rabbitmq-bundle pcs resource bundle for new container image\", \"when\": [\"step|int == 1\", \"is_rpc_rabbitmq_bootstrap_node|bool\", \"rabbitmq_rpc_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the rabbitmq cluster resource before container upgrade\", \"pacemaker_resource\": {\"resource\": \"rabbitmq-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Check rabbitmq logging configuration in pacemaker\", \"command\": \"cibadmin --query --xpath \\\"//storage-mapping[@id=\'rabbitmq-log\']\\\"\", \"failed_when\": false, \"register\": \"rabbitmq_logs_moved\"}, {\"name\": \"Add a bind mount for logging in the rabbitmq bundle\", \"when\": \"rabbitmq_logs_moved.rc == 6\", \"command\": \"pcs resource bundle update rabbitmq-bundle storage-map add id=rabbitmq-log source-dir=/var/log/containers/rabbitmq target-dir=/var/log/rabbitmq options=rw\"}, {\"name\": \"Update the rabbitmq bundle to use the new container image name\", \"command\": \"pcs resource bundle update rabbitmq-bundle container image={{rabbitmq_rpc_image_latest}}\"}, {\"name\": \"Enable the rabbitmq cluster resource\", \"pacemaker_resource\": {\"resource\": \"rabbitmq-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}]}, {\"name\": \"Check for rabbitmq_rpc retag statefile\", \"when\": [\"step|int == 3\"], \"stat\": {\"path\": \"/var/lib/tripleo/rabbitmq_rpc_needs_retag\"}, \"register\": \"rabbitmq_rpc_retag_state_file\"}, {\"name\": \"Retag rabbitmq-bundle container image\", \"when\": [\"step|int == 3\", \"rabbitmq_rpc_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the rabbitmq cluster resource before container upgrade\", \"pacemaker_resource\": {\"resource\": \"rabbitmq-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Retag the pacemaker image if containerized\", \"block\": [{\"block\": [{\"name\": \"Get rabbitmq image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_rabbitmq_rpc_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'rabbitmq-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container rabbitmq image\", \"set_fact\": {\"rabbitmq_rpc_image\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"rabbitmq_rpc_image_latest\": \"cluster.common.tag/rabbitmq:pcmklatest\", \"pcmk_rabbitmq_rpc_image\": \"{{xmllint_pcmk_rabbitmq_rpc_image.stdout}}\"}}]}, {\"block\": [{\"name\": \"Retag pcmklatest to latest rabbitmq image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{rabbitmq_rpc_image}}\", \"container_image_latest\": \"{{rabbitmq_rpc_image_latest}}\"}}]}]}, {\"name\": \"Enable the rabbitmq cluster resource\", \"pacemaker_resource\": {\"resource\": \"rabbitmq-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Remove rabbitmq_rpc retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/rabbitmq_rpc_needs_retag\", \"state\": \"absent\"}}]}, {\"name\": \"Ensure redis is removed\", \"when\": [\"step|int == 5\", \"\\\"redis\\\" not in enabled_services|list\", \"{{ (pacemaker_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower)|bool}}\"], \"become\": true, \"shell\": \"if crm_resource -r redis-bundle -q &>/dev/null; then\\n   pcs resource delete redis-bundle || true\\n   pcs resource delete ip-$(hiera redis_vip) || true\\nfi\\n\"}, {\"name\": \"Clean up cluster node cache\", \"when\": [\"step|int == 5\", \"\\\"redis\\\" not in enabled_services|list\", \"{{ (pacemaker_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower)|bool}}\"], \"become\": true, \"shell\": \"pcs cluster node clear redis-bundle-0\\npcs cluster node clear redis-bundle-1\\npcs cluster node clear redis-bundle-2\\ncrm_attribute --name redis_REPL_INFO --delete\\n\"}, {\"name\": \"Clean up redis attribute\", \"when\": [\"step|int == 5\", \"\\\"redis\\\" not in enabled_services|list\", \"{{ (pacemaker_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower)|bool}}\"], \"become\": true, \"shell\": \"pcs node attribute \\\"{{ item }}\\\" redis-role= || true\\n\", \"loop\": \"{{ pacemaker_short_node_names }}\"}, {\"name\": \"Configure Podman registry\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Make sure the Undercloud hostname is included in /etc/hosts\", \"when\": [\"undercloud_hosts_entries is defined\"], \"lineinfile\": {\"dest\": \"/etc/hosts\", \"line\": \"{{ undercloud_hosts_entries | join(\'\') }}\", \"state\": \"present\"}}]}, {\"name\": \"Run podman install\", \"tags\": [\"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": [], \"container_registry_login\": false, \"container_registry_logins\": {}, \"container_registry_logins_json\": {}, \"container_default_pids_limit\": 4096, \"container_events_logger_mechanism\": \"journald\"}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}, {\"when\": \"step|int == 0\", \"block\": [{\"name\": \"Check if snmpd is enabled\", \"command\": \"systemctl is-enabled --quiet snmpd\", \"failed_when\": false, \"register\": \"snmpd_enabled_result\"}, {\"name\": \"Set fact snmpd_enabled\", \"set_fact\": {\"snmpd_enabled\": \"{{ snmpd_enabled_result.rc == 0 }}\"}}]}, {\"name\": \"Stop snmp service\", \"when\": [\"step|int == 1\", \"snmpd_enabled|bool\"], \"service\": \"name=snmpd state=stopped\"}, {\"name\": \"Cleanup tripleo-iptables services\", \"when\": [\"(step | int) == 1\"], \"block\": [{\"name\": \"Disable tripleo-iptables.service\", \"systemd\": {\"name\": \"tripleo-iptables.service\", \"state\": \"stopped\", \"enabled\": false}, \"register\": \"systemd_tripleo_iptables\", \"failed_when\": false}, {\"name\": \"Cleanup tripleo-iptables.services\", \"file\": {\"path\": \"/etc/systemd/system/tripleo-iptables.service\", \"state\": \"absent\"}}, {\"name\": \"Disable tripleo-ip6tables.service\", \"systemd\": {\"name\": \"tripleo-ip6tables.service\", \"state\": \"stopped\", \"enabled\": false}, \"register\": \"systemd_tripleo_ip6tables\", \"failed_when\": false}, {\"name\": \"Cleanup tripleo-ip6tables.services\", \"file\": {\"path\": \"/etc/systemd/system/tripleo-ip6tables.service\", \"state\": \"absent\"}}, {\"name\": \"Reload systemd\", \"systemd\": {\"daemon_reload\": true}, \"when\": [\"(systemd_tripleo_iptables is changed or systemd_tripleo_ip6tables is changed)\"]}]}, {\"when\": [\"(step | int) == 3\"], \"block\": [{\"name\": \"blank ipv6 rule before activating ipv6 firewall.\", \"shell\": \"cat /etc/sysconfig/ip6tables > /etc/sysconfig/ip6tables.n-o-upgrade; cat</dev/null>/etc/sysconfig/ip6tables\", \"args\": {\"creates\": \"/etc/sysconfig/ip6tables.n-o-upgrade\"}}, {\"name\": \"cleanup unmanaged rules pushed by iptables-services\", \"shell\": \"iptables -C INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT &>/dev/null && \\\\\\n  iptables -D INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT\\niptables -C INPUT -p icmp -j ACCEPT &>/dev/null && \\\\\\n  iptables -D INPUT -p icmp -j ACCEPT\\niptables -C INPUT -i lo -j ACCEPT &>/dev/null && \\\\\\n  iptables -D INPUT -i lo -j ACCEPT\\niptables -C INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT &>/dev/null && \\\\\\n  iptables -D INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT\\niptables -C INPUT -j REJECT --reject-with icmp-host-prohibited &>/dev/null && \\\\\\n  iptables -D INPUT -j REJECT --reject-with icmp-host-prohibited\\niptables -C FORWARD -j REJECT --reject-with icmp-host-prohibited &>/dev/null && \\\\\\n  iptables -D FORWARD -j REJECT --reject-with icmp-host-prohibited\\n\\nsed -i \'/^-A INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A INPUT -p icmp -j ACCEPT$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A INPUT -i lo -j ACCEPT$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A INPUT -j REJECT --reject-with icmp-host-prohibited$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A FORWARD -j REJECT --reject-with icmp-host-prohibited$/d\' /etc/sysconfig/iptables\\n\\nip6tables -C INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT\\nip6tables -C INPUT -p ipv6-icmp -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -p ipv6-icmp -j ACCEPT\\nip6tables -C INPUT -i lo -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -i lo -j ACCEPT\\nip6tables -C INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT\\nip6tables -C INPUT -d fe80::/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -d fe80::/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT\\nip6tables -C INPUT -j REJECT --reject-with icmp6-adm-prohibited &>/dev/null && \\\\\\n  ip6tables -D INPUT -j REJECT --reject-with icmp6-adm-prohibited\\nip6tables -C FORWARD -j REJECT --reject-with icmp6-adm-prohibited &>/dev/null && \\\\\\n  ip6tables -D FORWARD -j REJECT --reject-with icmp6-adm-prohibited\\n\\nsed -i \'/^-A INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -p ipv6-icmp -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -i lo -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -d fe80::\\\\/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -j REJECT --reject-with icmp6-adm-prohibited$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A FORWARD -j REJECT --reject-with icmp6-adm-prohibited$/d\' /etc/sysconfig/ip6tables\"}]}, {\"name\": \"Gather missing facts\", \"setup\": {\"gather_subset\": [\"!all\", \"!min\", \"distribution\"]}, \"tags\": [\"always\"]}, {\"name\": \"Set leapp facts\", \"set_fact\": {\"upgrade_leapp_enabled\": \"{{ _upgradeLeappEnabled | bool and\\n   ansible_facts[\'distribution\'] == \'RedHat\' and\\n   ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\') }}\", \"upgrade_leapp_debug\": false, \"upgrade_leapp_devel_skip\": \"\", \"upgrade_leapp_command_options\": \"\", \"upgrade_leapp_reboot_timeout\": 3600, \"upgrade_leapp_post_reboot_delay\": 120}, \"vars\": {\"_upgradeLeappEnabled\": false}, \"tags\": [\"always\"]}, {\"name\": \"system_upgrade_prepare step 3\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Run LeappRepoInitCommand\", \"shell\": \"#!/bin/bash\\n\\n\"}, {\"name\": \"Remove firewalld bindings\", \"package\": {\"name\": \"python3-firewall\", \"state\": \"absent\"}}, {\"name\": \"install leapp\", \"package\": {\"name\": \"leapp-repository-openstack\", \"state\": \"latest\"}}, {\"name\": \"Run LeappInitCommand\", \"shell\": \"#!/bin/bash\\n\\n\"}, {\"name\": \"Remove vdo\", \"package\": {\"name\": \"vdo\", \"state\": \"absent\"}}, {\"name\": \"add packages into Leapp\'s to_remove file\", \"vars\": {\"pkg_to_remove\": []}, \"lineinfile\": {\"path\": \"/etc/leapp/transaction/to_remove\", \"line\": \"{{ item }}\"}, \"loop\": \"{{ pkg_to_remove }}\"}, {\"name\": \"add packages into Leapp\'s to_install file\", \"vars\": {\"pkg_to_install\": []}, \"lineinfile\": {\"path\": \"/etc/leapp/transaction/to_install\", \"line\": \"{{ item }}\"}, \"loop\": \"{{ pkg_to_install }}\"}, {\"name\": \"check sshd_config file\", \"stat\": {\"path\": \"/etc/ssh/sshd_config\"}, \"register\": \"sshd_config_result\"}, {\"name\": \"add PermitRootLogin option for leapp\", \"lineinfile\": {\"path\": \"/etc/ssh/sshd_config\", \"regexp\": \"^(# *)?PermitRootLogin\", \"line\": \"PermitRootLogin without-password\"}}, {\"name\": \"Remove paunch-services\", \"package\": {\"name\": \"paunch-services\", \"state\": \"absent\"}}, {\"name\": \"tripleo_container_manage reconfiguration\", \"import_role\": {\"name\": \"tripleo_container_manage\", \"tasks_from\": \"shutdown.yml\"}}]}, {\"name\": \"system_upgrade_prepare step 4\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"when\": [\"step|int == 4\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Delete the kernel modules in Leapp database (device_driver_deprecation_data.json)\", \"vars\": {\"modules_to_unload\": []}, \"shell\": \"set -o pipefail && jq \'. | del(.data[] | select(.driver_name == \\\"{{ item }}\\\"))\' /etc/leapp/files/device_driver_deprecation_data.json > /etc/leapp/files/device_driver_deprecation_data.json_modified && mv /etc/leapp/files/device_driver_deprecation_data.json_modified /etc/leapp/files/device_driver_deprecation_data.json\\n\", \"loop\": \"{{ modules_to_unload }}\"}, {\"name\": \"Remove leapp actors to prevent them inhibiting the upgrade\", \"vars\": {\"actors_to_remove\": []}, \"command\": {\"cmd\": \"find /usr/share/leapp-repository/repositories/ -name {{ item }} -type d -print -exec rm -rf \\\"{}\\\" +\"}, \"loop\": \"{{ actors_to_remove }}\"}, {\"name\": \"set leapp required answers\", \"shell\": \"leapp answer --add --section check_vdo.confirm=True\\n\"}, {\"name\": \"Replace EFI grub.cfg with redirect to /boot/grub2/grub.cfg\", \"import_role\": {\"name\": \"tripleo_kernel\", \"tasks_from\": \"efigrub.yml\"}}, {\"name\": \"Keep nics with prefix in NICsPrefixesToUdev from renaming\", \"vars\": {\"nics_prefixes_to_keep\": []}, \"shell\": \"ip -j link show | \\\\ jq -r --arg prefix \\\"{{ item }}\\\" \'.[] |\\n  select((.ifname | startswith($prefix)) and\\n  (.ifname | test(\\\"^.*v[0-9]*$\\\") | not) and\\n  (.ifname | test(\\\"^.*_[0-9]*$\\\") | not) and\\n  (.ifname | test(\\\"^.*\\\\\\\\..*$\\\") | not)) |\\n  if .permaddr? then .address=.permaddr else . end |\\n  \\\"SUBSYSTEM==\\\\\\\"net\\\\\\\",ACTION==\\\\\\\"add\\\\\\\",DRIVERS==\\\\\\\"?*\\\\\\\",\\\" + \\\"NAME=\\\\\\\"\\\" + .ifname +\\\"\\\\\\\" ,ATTR{address}==\\\\\\\"\\\" + .address + \\\"\\\\\\\"\\\"\' >> /etc/udev/rules.d/70-rhosp-persistent-net.rules\\n\", \"loop\": \"{{ nics_prefixes_to_keep|list }}\"}, {\"name\": \"run leapp upgrade (download packages)\", \"shell\": \"{% if upgrade_leapp_devel_skip|default(false) %}{{ upgrade_leapp_devel_skip }}{% endif %} leapp upgrade {% if upgrade_leapp_debug|default(true) %}--debug{% endif %} {% if upgrade_leapp_command_options|default(false) %}{{ upgrade_leapp_command_options }}{% endif %}\\n\", \"when\": \"upgrade_leapp_enabled\"}]}, {\"name\": \"system_upgrade_run step 4\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_reboot\"], \"when\": [\"step|int == 4\", \"upgrade_leapp_enabled\", \"\'Undercloud\' not in group_names\"], \"block\": [{\"name\": \"Run LeappPreRebootCommand\", \"shell\": \"#!/bin/bash\\n\\n\"}, {\"name\": \"Check that nova_libvirt is running\", \"shell\": \"podman ps --filter name=^nova_virtlogd$ --format \\\"{% raw %}{{ .Image }}{% endraw %}\\\"\\n\", \"register\": \"is_virtlogd_image_running\"}, {\"name\": \"Remove systemd files to disable them\", \"file\": {\"path\": \"/etc/systemd/system/{{ item }}\", \"state\": \"absent\"}, \"with_items\": [\"tripleo_nova_libvirt.service\", \"tripleo_nova_virtlogd_wrapper.service\", \"tripleo_nova_libvirt.target\"], \"when\": \"is_virtlogd_image_running.stdout != \'\'\"}, {\"name\": \"reboot to perform the upgrade\", \"reboot\": {\"reboot_timeout\": \"{{upgrade_leapp_reboot_timeout}}\", \"test_command\": \"source /etc/os-release; [ \\\"${VERSION_ID%.*}\\\" -ge \\\"8\\\" ] && systemctl is-system-running | grep -qE \\\"running|degraded\\\" || exit 1\", \"post_reboot_delay\": \"{{ upgrade_leapp_post_reboot_delay }}\"}}, {\"name\": \"Set selinux back to enforcing after leapp reboot\", \"selinux\": {\"policy\": \"targeted\", \"state\": \"enforcing\"}}, {\"name\": \"Run LeappPostRebootCommand\", \"shell\": \"#!/bin/bash\\n\\n\"}]}, {\"name\": \"Host packages setup step0\", \"tags\": \"setup_packages\", \"when\": \"step|int == 0\", \"block\": [{\"name\": \"Package and repo update tasks\", \"block\": [{\"name\": \"Run UpgradeInitCommand\", \"shell\": \"#!/bin/bash\\n\\nif [[ -f /etc/resolv.conf.save ]] ; then rm /etc/resolv.conf.save; fi\\n\\n\"}, {\"name\": \"Run UpgradeInitCommonCommand\", \"shell\": \"#!/bin/bash\\n\\n\"}, {\"name\": \"Ensure DNF modules have the right stream\", \"vars\": {\"dnf_module_list\": []}, \"dnf\": {\"name\": \"@{{ item.module }}:{{ item.stream }}/{{ item.profile|default(\'common\') }}\", \"state\": \"present\"}, \"loop\": \"{{ dnf_module_list|list }}\", \"when\": [\"dnf_module_list|length > 0\", \"item.distribution_version is defined\", \"ansible_facts[\'distribution_major_version\'] is version(item.distribution_version, \'==\')\"]}, {\"name\": \"Ensure TripleO prerequisite packages are installed\", \"package\": {\"name\": [\"jq\", \"lvm2\", \"openstack-selinux\", \"os-net-config\", \"puppet-tripleo\", \"python3-heat-agent*\", \"rsync\"], \"state\": \"present\"}, \"when\": \"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\"}, {\"name\": \"Ensure TripleO prerequisite packages are installed and use role based heat variable to provide specific list of packages\", \"vars\": {\"base_tripleo_packages\": []}, \"package\": {\"name\": \"{{ base_tripleo_packages }}\", \"state\": \"present\"}, \"when\": [\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\", \"base_tripleo_packages|length > 0\"]}, {\"name\": \"WA for 2240185 - If the image is schema 1 and lacks signatures than add empty signatures\", \"shell\": \"for manifest_file in `find /var/lib/containers/storage/overlay-images/ -name \'manifest\'`\\ndo\\n    cat <<< $( jq  \'if .schemaVersion == 1 then if has(\\\"signatures\\\") then . else .signatures=[] end else . end\' $manifest_file ) > $manifest_file\\ndone\\n\", \"when\": \"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\"}]}, {\"name\": \"check if libvirt is installed\", \"command\": \"/usr/bin/rpm -q libvirt-daemon\", \"failed_when\": false, \"register\": \"libvirt_installed\", \"check_mode\": false}, {\"name\": \"make sure libvirt services are disabled and masked\", \"service\": {\"name\": \"{{ item }}\", \"state\": \"stopped\", \"enabled\": false, \"masked\": true, \"daemon_reload\": true}, \"loop\": [\"libvirtd.service\", \"virtlogd.socket\"], \"when\": [\"libvirt_installed.rc == 0\"]}]}, {\"name\": \"Host packages setup step2\", \"tags\": \"setup_packages\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Special treatment for OpenvSwitch\", \"tripleo_ovs_upgrade\": null, \"register\": \"ovs_upgrade\"}, {\"name\": \"Always ensure the openvswitch service is enabled and running after upgrades\", \"service\": {\"name\": \"openvswitch\", \"enabled\": true, \"state\": \"started\"}, \"when\": [\"ovs_upgrade.changed|bool\"]}]}, {\"name\": \"Host packages setup step3\", \"tags\": \"setup_packages\", \"when\": \"step|int == 3\", \"block\": [{\"name\": \"Check for os-net-config upgrade\", \"shell\": \"yum check-upgrade | awk \'/os-net-config/{print}\'\", \"register\": \"os_net_config_need_upgrade\"}, {\"name\": \"Check that os-net-config has legacy configuration\", \"stat\": {\"path\": \"/etc/os-net-config/config.json\", \"get_attributes\": false, \"get_checksum\": false, \"get_mime\": false}, \"register\": \"stat_config_json\"}, {\"name\": \"Check that os-net-config has new configuration\", \"stat\": {\"path\": \"/etc/os-net-config/config.yaml\", \"get_attributes\": false, \"get_checksum\": false, \"get_mime\": false}, \"register\": \"stat_config_yaml\"}, {\"name\": \"Slurp the os-net-config config.json\", \"slurp\": {\"src\": \"/etc/os-net-config/config.json\"}, \"register\": \"os_config_json\", \"when\": [\"stat_config_json.stat.exists\", \"not stat_config_yaml.stat.exists\"]}, {\"name\": \"Write updated /etc/os-net-config/config.yaml\", \"copy\": {\"content\": \"{{ os_config_json.content | b64decode | from_json | to_yaml }}\", \"dest\": \"/etc/os-net-config/config.yaml\"}, \"when\": [\"stat_config_json.stat.exists\", \"not stat_config_yaml.stat.exists\"]}, {\"name\": \"Remove legacy os-net-config configuration\", \"command\": \"mv /etc/os-net-config/config.json /etc/os-net-config/deprecated_config.json\", \"when\": [\"stat_config_json.stat.exists\"]}, {\"block\": [{\"name\": \"Upgrade os-net-config\", \"package\": \"name=os-net-config state=latest\"}, {\"name\": \"take new os-net-config parameters into account now\", \"command\": \"os-net-config --no-activate -c /etc/os-net-config/config.yaml -v --detailed-exit-codes\", \"register\": \"os_net_config_upgrade\", \"failed_when\": \"os_net_config_upgrade.rc not in [0,2]\", \"changed_when\": \"os_net_config_upgrade.rc == 2\"}], \"when\": [\"os_net_config_need_upgrade.stdout\", \"stat_config_yaml.stat.exists or stat_config_json.stat.exists\"]}, {\"name\": \"Update all packages\", \"when\": [\"not skip_package_update|bool\"], \"yum\": {\"name\": \"*\", \"state\": \"latest\", \"exclude\": \"ansible-core\"}, \"vars\": {\"skip_package_update\": false}}, {\"name\": \"Check whether openvswitch exits\", \"command\": \"systemctl status openvswitch.service\", \"register\": \"ovs_service\", \"ignore_errors\": true}, {\"name\": \"Always ensure the openvswitch service is enabled and running after upgrades rhbz#2329821\", \"service\": {\"name\": \"openvswitch\", \"enabled\": true, \"state\": \"started\"}, \"when\": [\"ovs_service.stderr != \\\"Unit openvswitch.service could not be found.\\\"\"]}]}], \"post_upgrade_tasks\": [{\"when\": [\"step|int == 3\"], \"become\": true, \"environment\": {\"OS_CLOUD\": \"overcloud\"}, \"block\": [{\"name\": \"Get nova-consoleauth service ID\", \"command\": \"openstack compute service list --service nova-consoleauth --column ID  --column Host --format yaml\", \"register\": \"nova_compute_service_result\", \"check_mode\": false, \"run_once\": true, \"changed_when\": false, \"failed_when\": false, \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\"}, {\"name\": \"Deleting nova-consoleauth\", \"command\": \"openstack compute service delete {{ item.ID }}\", \"loop\": \"{{ nova_compute_service_result.stdout | from_yaml | default([]) }}\", \"run_once\": true, \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"failed_when\": false}]}, {\"name\": \"Purge Podman\", \"when\": [\"(step | int) == 3\", \"container_cli == \'podman\'\", \"deployment_source_hosts not in group_names\"], \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_purge.yml\"}, \"vars\": {\"deployment_source_hosts\": \"Undercloud\"}}], \"update_tasks\": [{\"name\": \"remove rsyslog configuration for podman healthcheck log\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_rsyslog_cleanup\"}}, {\"name\": \"Ensure old cron.daily is absent\", \"when\": \"step|int == 1\", \"file\": {\"path\": \"/etc/cron.daily/containers-tmpwatch\", \"state\": \"absent\"}}, {\"block\": [{\"name\": \"Get haproxy image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_haproxy_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'haproxy-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container haproxy image\", \"set_fact\": {\"haproxy_image\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"haproxy_image_latest\": \"cluster.common.tag/haproxy:pcmklatest\", \"pcmk_haproxy_image\": \"{{xmllint_pcmk_haproxy_image.stdout}}\"}}], \"when\": \"(step|int == 0 or step|int == 2)\"}, {\"name\": \"Check for update of haproxy container image name\", \"when\": \"step|int == 0\", \"assert\": {\"that\": \"pcmk_haproxy_image == haproxy_image_latest\", \"fail_msg\": \"haproxy image change detected, run overcloud external-update --tags ha_image_update first\"}}, {\"name\": \"Tear-down non-HA haproxy container\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Remove non-HA haproxy container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"haproxy\"]}}]}, {\"name\": \"Set HAProxy upgrade facts\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"set is_haproxy_bootstrap_node fact\", \"tags\": \"common\", \"set_fact\": \"is_haproxy_bootstrap_node={{haproxy_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\", \"when\": [\"haproxy_short_bootstrap_node_name|default(false)\"]}]}, {\"name\": \"Mount TLS cert if needed\", \"when\": [\"step|int == 1\", \"is_haproxy_bootstrap_node\"], \"block\": [{\"name\": \"Check haproxy public certificate configuration in pacemaker\", \"command\": \"cibadmin --query --xpath \\\"//storage-mapping[@id=\'haproxy-cert\']\\\"\", \"failed_when\": false, \"register\": \"haproxy_cert_mounted\"}, {\"name\": \"Disable the haproxy cluster resource\", \"pacemaker_resource\": {\"resource\": \"haproxy-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\", \"when\": \"haproxy_cert_mounted.rc == 6\"}, {\"name\": \"Set HAProxy public cert volume mount fact\", \"set_fact\": {\"haproxy_public_cert_path\": \"/etc/pki/tls/private/overcloud_endpoint.pem\", \"haproxy_public_tls_enabled\": false}}, {\"name\": \"Add a bind mount for public certificate in the haproxy bundle\", \"command\": \"pcs resource bundle update haproxy-bundle storage-map add id=haproxy-cert source-dir={{ haproxy_public_cert_path }} target-dir=/var/lib/kolla/config_files/src-tls/{{ haproxy_public_cert_path }} options=ro\", \"when\": \"haproxy_cert_mounted.rc == 6 and haproxy_public_tls_enabled|bool\"}, {\"name\": \"Enable the haproxy cluster resource\", \"pacemaker_resource\": {\"resource\": \"haproxy-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\", \"when\": \"haproxy_cert_mounted.rc == 6\"}]}, {\"name\": \"Haproxy fetch and retag container image for pacemaker\", \"tags\": \"haproxy_syn_block\", \"when\": [\"step|int == 2\"], \"block\": [{\"name\": \"Retag pcmklatest to latest haproxy image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{haproxy_image}}\", \"container_image_latest\": \"{{haproxy_image_latest}}\"}}]}, {\"name\": \"Move virtual IPs to another node before stopping pacemaker\", \"when\": [\"step|int == 1\", \"hostvars[inventory_hostname][\\\"haproxy_node_names\\\"]|default([])|length > 1\"], \"shell\": \"CLUSTER_NODE=$(crm_node -n)\\necho \\\"Retrieving all the VIPs which are hosted on this node\\\"\\nVIPS_TO_MOVE=$(crm_mon --as-xml | xmllint --xpath \'//resource[@resource_agent=\\\"ocf:heartbeat:IPaddr2\\\" and @role = \\\"Started\\\" and @managed = \\\"true\\\" and ./node[@name = \\\"\'${CLUSTER_NODE}\'\\\"]]/@id\' - | sed -e \'s/id=//g\' -e \'s/\\\"//g\')\\nfor v in ${VIPS_TO_MOVE}; do\\n    echo \\\"Moving VIP $v on another node\\\"\\n    pcs resource ban $v ${CLUSTER_NODE} --wait=300\\ndone\\necho \\\"Removing the location constraints that were created to move the VIPs\\\"\\nfor v in ${VIPS_TO_MOVE}; do\\n    echo \\\"Removing location ban for VIP $v\\\"\\n    ban_id=$(cibadmin --query | xmllint --xpath \'string(//rsc_location[@rsc=\\\"\'${v}\'\\\" and @node=\\\"\'${CLUSTER_NODE}\'\\\" and @score=\\\"-INFINITY\\\"]/@id)\' -)\\n    if [ -n \\\"$ban_id\\\" ]; then\\n        pcs constraint remove ${ban_id}\\n    else\\n        echo \\\"Could not retrieve and clear location constraint for VIP $v\\\" 2>&1\\n    fi\\ndone\\n\"}, {\"name\": \"Wait for 10s to settle connections on new VIPs\", \"wait_for\": {\"timeout\": 10}, \"when\": [\"step|int == 1\", \"hostvars[inventory_hostname][\\\"haproxy_node_names\\\"]|default([])|length > 1\"]}, {\"name\": \"Block local INPUT SYN packets on the backends except mysql\", \"tags\": \"haproxy_syn_block\", \"when\": [\"step|int == 1\"], \"shell\": \"# server controller-0.storage.redhat.local 172.17.3.93:8080 check fall 5 inter 2000 rise 2\\n# server controller-0.internalapi.redhat.local fd00:fd00:fd00:2000::176:9292 check fall 5 inter 2000 rise 2\\nset -o pipefail\\nsource /etc/os-release; test  \\\"${VERSION_ID%*}\\\" = \\\"9.0\\\" && exit 0\\ngrep {{ ansible_facts[\\\"hostname\\\"]|lower }} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg  | grep -v \\\":3306 \\\" | \\\\\\nawk \'{print $3}\' | \\\\\\nwhile read BACKEND; do\\n    IP=${BACKEND%:*}\\n    PORT=${BACKEND#\\\"$IP:\\\"}\\n    if [[ $IP =~ .*:.* ]]\\n      then PROTOCOL=\\\"ip6\\\"\\n      else PROTOCOL=\\\"ip\\\"\\n    fi\\necho \\\"insert rule $PROTOCOL filter INPUT $PROTOCOL daddr $IP tcp dport $PORT tcp flags syn / fin,syn,rst,ack meta time\\\"\\ndone | xargs -i nft {} $(date +%s)-$(date -d\'+20 minutes\' +%s) counter drop comment \\\"{{ ansible_facts[\\\"hostname\\\"]|lower }}_haproxy_drop\\\"\\n\"}, {\"name\": \"Generate block for other nodes OUTPUT SYN packets on the backends except mysql\", \"tags\": \"haproxy_syn_block\", \"when\": [\"step|int == 1\"], \"shell\": \"set -o pipefail\\nsource /etc/os-release; test  \\\"${VERSION_ID%*}\\\" = \\\"9.0\\\" && exit 0\\ngrep {{ ansible_facts[\\\"hostname\\\"]|lower }} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg  | grep -v \\\":3306 \\\" | \\\\\\nawk \'{print $3}\' | \\\\\\nwhile read BACKEND; do\\n    IP=${BACKEND%:*}\\n    PORT=${BACKEND#\\\"$IP:\\\"}\\n    if [[ $IP =~ .*:.* ]]\\n      then PROTOCOL=\\\"ip6\\\"\\n      else PROTOCOL=\\\"ip\\\"\\n    fi\\n echo \\\"nft insert rule $PROTOCOL \\\\$TABLE OUTPUT $PROTOCOL daddr $IP tcp dport $PORT tcp flags syn / fin,syn,rst,ack meta time $(date +%s)-$(date -d\'+20 minutes\' +%s) counter drop comment \\\\\\\"{{ ansible_facts[\\\"hostname\\\"]|lower }}_haproxy_drop\\\\\\\" \\\"\\ndone\\n\", \"register\": \"haproxy_iptables_block\"}, {\"name\": \"Block OUTPUT SYN packets to this node on other haproxy nodes\", \"tags\": \"haproxy_syn_block\", \"delegate_to\": \"{{ item }}\", \"when\": [\"step|int == 1\"], \"shell\": \"set -o pipefail\\ngrep {{ ansible_facts[\\\"hostname\\\"]|lower }} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg | head -n 1 \\\\\\nawk \'{print $3}\' | while read BACKEND; do\\n    IP=${BACKEND%:*}\\n    if [[ $IP =~ .*:.* ]]\\n      then PROTOCOL=\\\"ip6\\\"\\n      else PROTOCOL=\\\"ip\\\"\\n    fi\\ndone\\nTABLE=$(nft list tables | grep -q \\\"$PROTOCOL raw\\\" && echo raw || echo filter )\\necho \\\"{{ haproxy_iptables_block.stdout}}\\\" | while read i; do bash -c \\\"$i\\\"; done\\n\", \"loop\": \"{{ groups[\\\"haproxy\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) | difference(ansible_facts[\\\"hostname\\\"]|lower) }}\"}, {\"block\": [{\"name\": \"Get galera image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_galera_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'galera-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container galera image\", \"set_fact\": {\"galera_image\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"galera_image_latest\": \"cluster.common.tag/mariadb:pcmklatest\", \"pcmk_galera_image\": \"{{xmllint_pcmk_galera_image.stdout}}\"}}], \"when\": \"(step|int == 0 or step|int == 2)\"}, {\"name\": \"Check for update of galera container image name\", \"when\": \"step|int == 0\", \"assert\": {\"that\": \"pcmk_galera_image == galera_image_latest\", \"fail_msg\": \"galera image change detected, run overcloud external-update --tags ha_image_update first\"}}, {\"name\": \"Tear-down non-HA mysql container\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"stat mysql container\", \"command\": \"podman container exists mysql\", \"failed_when\": false, \"changed_when\": false, \"register\": \"stat_mysql_container\"}, {\"name\": \"Create clustercheck user and permissions\", \"command\": {\"argv\": \"{{ mysql_exec_data | container_exec_cmd }}\"}, \"changed_when\": true, \"when\": [\"stat_mysql_container.rc == 0\"], \"vars\": {\"mysql_exec_data\": {\"environment\": {\"CLUSTERCHECK_PASSWORD\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\"}, \"command\": [\"mysql\", \"/bin/sh\", \"-c\", \"mysql -e \\\"CREATE USER IF NOT EXISTS \'clustercheck\'@\'localhost\' IDENTIFIED BY \'${CLUSTERCHECK_PASSWORD}\'; GRANT PROCESS ON *.* TO \'clustercheck\'@\'localhost\' WITH GRANT OPTION;\\\"\"]}}}, {\"name\": \"Remove non-HA mysql container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"mysql\"]}}]}, {\"name\": \"Mariadb fetch and retag container image for pacemaker\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Retag pcmklatest to latest galera image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{galera_image}}\", \"container_image_latest\": \"{{galera_image_latest}}\"}}]}, {\"name\": \"Ensure mariadb-server is not installed on the host\", \"when\": \"step|int == 2\", \"yum\": {\"name\": \"mariadb-server*\", \"state\": \"absent\"}}, {\"block\": [{\"name\": \"Get rabbitmq image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_rabbitmq_rpc_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'rabbitmq-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container rabbitmq image\", \"set_fact\": {\"rabbitmq_rpc_image\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"rabbitmq_rpc_image_latest\": \"cluster.common.tag/rabbitmq:pcmklatest\", \"pcmk_rabbitmq_rpc_image\": \"{{xmllint_pcmk_rabbitmq_rpc_image.stdout}}\"}}], \"when\": \"(step|int == 0 or step|int == 2)\"}, {\"name\": \"Check for update of rabbitmq container image name\", \"when\": \"step|int == 0\", \"assert\": {\"that\": \"pcmk_rabbitmq_rpc_image == rabbitmq_rpc_image_latest\", \"fail_msg\": \"rabbitmq image change detected, run overcloud external-update --tags ha_image_update first\"}}, {\"name\": \"Tear-down non-HA rabbitmq container\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Remove non-HA rabbitmq container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"rabbitmq\"]}}]}, {\"name\": \"Rabbitmq fetch and retag container image for pacemaker\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Retag pcmklatest to latest rabbitmq image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{rabbitmq_rpc_image}}\", \"container_image_latest\": \"{{rabbitmq_rpc_image_latest}}\"}}]}, {\"name\": \"Check pacemaker cluster running before the minor update\", \"when\": \"step|int == 0\", \"pacemaker_cluster\": \"state=online check_and_fail=true\", \"async\": 30, \"poll\": 4}, {\"name\": \"Acquire the cluster shutdown lock to stop pacemaker cluster\", \"when\": \"step|int == 1\", \"command\": \"systemd-cat -t ha-shutdown /var/lib/container-config-scripts/pacemaker_mutex_shutdown.sh --acquire\"}, {\"name\": \"Stop pacemaker cluster\", \"when\": \"step|int == 1\", \"pacemaker_cluster\": \"state=offline\"}, {\"name\": \"Start pacemaker cluster\", \"when\": \"step|int == 4\", \"pacemaker_cluster\": \"state=online\"}, {\"name\": \"Release the cluster shutdown lock\", \"when\": \"step|int == 4\", \"command\": \"systemd-cat -t ha-shutdown /var/lib/container-config-scripts/pacemaker_mutex_shutdown.sh --release\"}, {\"name\": \"Force pre-fetch of container images\", \"when\": [\"(step|int) == 5\"], \"block\": [{\"name\": \"Pre-fetch all the containers\", \"become\": true, \"containers.podman.podman_image\": {\"name\": \"{{ prefetch_image }}\", \"validate_certs\": false, \"force\": true}, \"register\": \"result\", \"until\": \"result is succeeded\", \"retries\": 5, \"delay\": 5, \"loop_control\": {\"loop_var\": \"prefetch_image\"}, \"loop\": \"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\"}]}, {\"name\": \"Cleanup tripleo-iptables services\", \"when\": [\"(step | int) == 1\"], \"block\": [{\"name\": \"Disable tripleo-iptables.service\", \"systemd\": {\"name\": \"tripleo-iptables.service\", \"state\": \"stopped\", \"enabled\": false}, \"register\": \"systemd_tripleo_iptables\", \"failed_when\": false}, {\"name\": \"Cleanup tripleo-iptables.services\", \"file\": {\"path\": \"/etc/systemd/system/tripleo-iptables.service\", \"state\": \"absent\"}}, {\"name\": \"Disable tripleo-ip6tables.service\", \"systemd\": {\"name\": \"tripleo-ip6tables.service\", \"state\": \"stopped\", \"enabled\": false}, \"register\": \"systemd_tripleo_ip6tables\", \"failed_when\": false}, {\"name\": \"Cleanup tripleo-ip6tables.services\", \"file\": {\"path\": \"/etc/systemd/system/tripleo-ip6tables.service\", \"state\": \"absent\"}}, {\"name\": \"Reload systemd\", \"systemd\": {\"daemon_reload\": true}, \"when\": [\"(systemd_tripleo_iptables is changed or systemd_tripleo_ip6tables is changed)\"]}]}, {\"name\": \"Enforce RHOSP rules regarding subscription.\", \"include_role\": {\"name\": \"tripleo_redhat_enforce\"}, \"vars\": {\"skip_rhel_enforcement\": false}, \"when\": [\"step|int == 0\", \"ansible_facts[\'distribution\'] == \'RedHat\'\", \"not (skip_rhel_enforcement | bool)\"]}, {\"name\": \"Ensure DNF modules have the right stream enabled\", \"vars\": {\"dnf_module_list\": []}, \"tripleo_dnf_stream\": {\"name\": \"{{ item.module }}:{{ item.stream }}\", \"state\": \"enabled\"}, \"loop\": \"{{ dnf_module_list|list }}\", \"when\": [\"step|int == 0\", \"dnf_module_list|length > 0\", \"item.distribution_version is defined\", \"ansible_facts[\'distribution_major_version\'] is version(item.distribution_version, \'==\')\"]}, {\"name\": \"Check for existing yum.pid\", \"stat\": \"path=/run/yum.pid\", \"register\": \"yum_pid_file\", \"when\": \"step|int == 0 or step|int == 3\"}, {\"name\": \"Exit if existing yum process\", \"fail\": \"msg=\\\"ERROR existing yum.pid detected - can\'t continue! Please ensure there is no other package update process for the duration of the minor update worfklow. Exiting.\\\"\", \"when\": \"(step|int == 0 or step|int == 3) and yum_pid_file.stat.exists\"}, {\"name\": \"Special treatment for OpenvSwitch\", \"tripleo_ovs_upgrade\": null, \"when\": [\"step|int == 2\"], \"register\": \"ovs_upgrade\"}, {\"name\": \"Always ensure the openvswitch service is enabled and running after upgrades\", \"service\": {\"name\": \"openvswitch\", \"enabled\": true, \"state\": \"started\"}, \"when\": [\"step|int == 2\", \"ovs_upgrade.changed|bool\"]}, {\"name\": \"Update packages and EFI grub.cfg\", \"when\": [\"step|int == 3\", \"not skip_package_update|bool\"], \"block\": [{\"name\": \"Update all packages\", \"yum\": {\"name\": \"*\", \"state\": \"latest\", \"exclude\": \"ansible-core\"}}, {\"name\": \"Replace EFI grub.cfg with redirect to /boot/grub2/grub.cfg\", \"import_role\": {\"name\": \"tripleo_kernel\", \"tasks_from\": \"efigrub.yml\"}}], \"vars\": {\"skip_package_update\": false}}, {\"name\": \"Ensure openvswitch is running after update\", \"when\": \"step|int == 3\", \"service\": {\"name\": \"openvswitch\", \"enabled\": true, \"state\": \"started\"}, \"ignore_errors\": true}], \"post_update_tasks\": [{\"name\": \"HAProxy bundle post update\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"HAproxy puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"haproxy\", \"tripleo_ha_wrapper_resource_name\": \"haproxy-bundle\", \"tripleo_ha_wrapper_bundle_name\": \"haproxy-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"haproxy\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::haproxy_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": false, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}], \"vars\": {\"tripleo_ha_wrapper_minor_update\": true}}, {\"name\": \"Cleanup local SYN DROP rules\", \"tags\": \"haproxy_syn_block\", \"when\": \"step|int == 1\", \"shell\": \"nft -a list chain filter INPUT | grep {{ ansible_facts[\\\"hostname\\\"]|lower }} | grep haproxy_drop | \\\\\\nawk -F# \'{print \\\"nft delete rule filter INPUT \\\"$2}\' | \\\\\\nwhile read i; do bash -c \\\"$i\\\"; done\\n\"}, {\"name\": \"Cleanup SYN DROP rules from other haproxy nodes\", \"tags\": \"haproxy_syn_block\", \"when\": \"step|int == 1\", \"delegate_to\": \"{{ item }}\", \"loop\": \"{{ groups[\\\"haproxy\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) | difference(ansible_facts[\\\"hostname\\\"]|lower) }}\", \"shell\": \"nft -a list chain raw OUTPUT | grep {{ ansible_facts[\\\"hostname\\\"]|lower }} | grep haproxy_drop | \\\\\\nawk -F# \'{print \\\"nft delete rule raw OUTPUT \\\"$2}\' | \\\\\\nwhile read i; do bash -c \\\"$i\\\"; done\\n\"}, {\"name\": \"Mysql bundle post update\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Mysql puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"mysql\", \"tripleo_ha_wrapper_resource_name\": \"galera\", \"tripleo_ha_wrapper_bundle_name\": \"galera-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Master\", \"tripleo_ha_wrapper_puppet_config_volume\": \"mysql\", \"tripleo_ha_wrapper_puppet_execute\": \"[\\\"Mysql_datadir\\\", \\\"Mysql_user\\\", \\\"Mysql_database\\\", \\\"Mysql_grant\\\", \\\"Mysql_plugin\\\"].each |String $val| { noop_resource($val) }; include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::database::mysql_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": false, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}], \"vars\": {\"tripleo_ha_wrapper_minor_update\": true}}, {\"name\": \"Rabbitmq rpc bundle post update\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Rabbitmq rpc puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"oslo_messaging_rpc\", \"tripleo_ha_wrapper_resource_name\": \"rabbitmq\", \"tripleo_ha_wrapper_bundle_name\": \"rabbitmq-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"rabbitmq\", \"tripleo_ha_wrapper_puppet_execute\": \"[\\\"Rabbitmq_policy\\\", \\\"Rabbitmq_user\\\"].each |String $val| { noop_resource($val) }; include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::rabbitmq_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": false, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}], \"vars\": {\"tripleo_ha_wrapper_minor_update\": true}}, {\"name\": \"Purge Podman\", \"when\": [\"(step | int) == 3\", \"container_cli == \'podman\'\", \"deployment_source_hosts not in group_names\"], \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_purge.yml\"}, \"vars\": {\"deployment_source_hosts\": \"Undercloud\"}}], \"upgrade_batch_tasks\": [], \"service_metadata_settings\": null, \"ansible_group_vars\": {\"ansible_async_dir\": \"/tmp/.ansible_async\", \"tripleo_firewall_frontend_enabled\": true, \"tripleo_tripleo_lvmfilter_enabled\": false, \"tripleo_tripleo_lvmfilter_devices_allowlist\": [], \"tripleo_tripleo_lvmfilter_devices_denylist\": [\".*\"], \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"hieradata_localhost_address\": \"localhost\", \"tripleo_kernel_extra_modules\": {}, \"tripleo_kernel_extra_packages\": {}, \"tripleo_kernel_sysctl_extra_settings\": {\"net.ipv6.conf.default.disable_ipv6\": {\"value\": 0}, \"net.ipv4.ip_local_reserved_ports\": {\"value\": \"35357,49000-49001\"}, \"net.ipv6.conf.all.disable_ipv6\": {\"value\": 0}, \"net.ipv6.conf.lo.disable_ipv6\": {\"value\": 0}, \"net.ipv4.ip_forward\": {\"value\": 1}, \"net.ipv4.conf.all.rp_filter\": {\"value\": 1}, \"net.ipv6.conf.all.forwarding\": {\"value\": 0}, \"net.ipv4.ip_nonlocal_bind\": {\"value\": 1}, \"net.ipv6.ip_nonlocal_bind\": {\"value\": 1}, \"kernel.pid_max\": {\"value\": 1048576}, \"net.ipv4.neigh.default.gc_thresh1\": {\"value\": 1024}, \"net.ipv4.neigh.default.gc_thresh2\": {\"value\": 2048}, \"net.ipv4.neigh.default.gc_thresh3\": {\"value\": 4096}, \"net.bridge.bridge-nf-call-arptables\": {\"value\": 1}, \"net.bridge.bridge-nf-call-iptables\": {\"value\": 1}, \"net.bridge.bridge-nf-call-ip6tables\": {\"value\": 1}, \"fs.inotify.max_user_instances\": {\"value\": 1024}}, \"chrony_role_action\": \"all\", \"chrony_ntp_servers\": [\"pool.ntp.org\"], \"chrony_ntp_pools\": [], \"chrony_global_server_settings\": \"iburst minpoll 6 maxpoll 10\", \"chrony_global_pool_settings\": \"iburst minpoll 6 maxpoll 10\", \"chrony_manage_package\": true, \"chrony_acl_rules\": [\"deny all\"], \"tripleo_nftables_debug\": true, \"tuned_profile\": \"throughput-performance\", \"tuned_custom_profile\": \"\"}, \"keystone_resources\": {}, \"firewall_rules\": {\"107 haproxy stats\": {\"dport\": 1993}, \"109 metrics qdr\": {\"dport\": [5666]}, \"109 accept internal metrics qdr ctlplane subnet 192.168.122.0/24\": {\"dport\": [5667, 5668]}, \"104 mysql galera-bundle\": {\"dport\": [873, 3123, 3306, 4444, 4567, 4568, 9200]}, \"139 nova_metadata\": {\"dport\": [8775]}, \"137 nova_vnc_proxy\": {\"dport\": [6080]}, \"109 rabbitmq-bundle\": {\"dport\": [3122, 4369, 5672, 25672, \"25673-25683\"]}, \"130 pacemaker tcp\": {\"proto\": \"tcp\", \"dport\": [2224, 3121, 21064]}, \"131 pacemaker udp\": {\"proto\": \"udp\", \"dport\": 5405}, \"124 snmp 192.168.122.0/24\": {\"dport\": 161, \"proto\": \"udp\", \"source\": \"192.168.122.0/24\"}, \"003 accept ssh from all\": {\"proto\": \"tcp\", \"dport\": 22, \"extras\": {\"ensure\": \"present\"}}, \"105 ntp\": {\"dport\": 123, \"proto\": \"udp\"}, \"003 accept ssh from ctlplane subnet 192.168.122.0/24\": {\"source\": \"192.168.122.0/24\", \"proto\": \"tcp\", \"dport\": 22}}, \"firewall_frontend_rules\": {\"100 mysql_haproxy\": {\"dport\": [3306]}, \"100 nova_metadatahaproxy_frontend\": {\"dport\": [8775]}, \"100 nova_vncproxy_haproxy_frontend\": {\"dport\": [6080]}}, \"firewall_ssl_frontend_rules\": {\"100 nova_metadatahaproxy_frontend_ssl\": {\"dport\": [13775]}, \"100 nova_vncproxy_haproxy_frontend_ssl\": {\"dport\": [13080]}}, \"firewall_edge_frontend_rules\": {}, \"firewall_edge_ssl_frontend_rules\": null, \"puppet_config\": [{\"config_volume\": \"clustercheck\", \"puppet_tags\": \"file\", \"step_config\": \"include tripleo::profile::pacemaker::clustercheck\", \"config_image\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\"}, {\"config_volume\": \"collectd\", \"puppet_tags\": \"collectd_client_config,exec\", \"step_config\": \"include tripleo::profile::base::metrics::collectd\", \"config_image\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\"}, {\"config_volume\": \"crond\", \"step_config\": \"include tripleo::profile::base::logging::logrotate\", \"config_image\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\"}, {\"config_volume\": \"haproxy\", \"puppet_tags\": \"haproxy_config\", \"step_config\": \"exec {\'wait-for-settle\': command => \'/bin/true\' }\\nclass tripleo::firewall(){}; define tripleo::firewall::rule( $port = undef, $dport = undef, $sport = undef, $proto = undef, $action = undef, $state = undef, $source = undef, $iniface = undef, $chain = undef, $destination = undef, $extras = undef){}\\n[\'pcmk_bundle\', \'pcmk_resource\', \'pcmk_property\', \'pcmk_constraint\', \'pcmk_resource_default\'].each |String $val| { noop_resource($val) }\\ninclude tripleo::profile::pacemaker::haproxy_bundle\", \"config_image\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"volumes\": []}, {\"config_volume\": \"iscsid\", \"puppet_tags\": \"iscsid_config\", \"step_config\": \"include tripleo::profile::base::iscsid\\n\", \"config_image\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"volumes\": [\"/etc/iscsi:/tmp/iscsi.host:z\"]}, {\"config_volume\": \"metrics_qdr\", \"step_config\": \"include tripleo::profile::base::metrics::qdr\\n\", \"config_image\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\"}, {\"config_volume\": \"mysql\", \"puppet_tags\": \"file\", \"step_config\": \"[\'Mysql_datadir\', \'Mysql_user\', \'Mysql_database\', \'Mysql_grant\', \'Mysql_plugin\'].each |String $val| { noop_resource($val) }\\nexec {\'wait-for-settle\': command => \'/bin/true\' }\\ninclude tripleo::profile::pacemaker::database::mysql_bundle\", \"config_image\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\"}, {\"config_volume\": \"nova\", \"puppet_tags\": \"nova_config\", \"step_config\": \"include tripleo::profile::base::nova::conductor\\ninclude tripleo::profile::base::database::mysql::client\", \"config_image\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\"}, {\"config_volume\": \"nova_metadata\", \"puppet_tags\": \"nova_config,nova_api_paste_ini\", \"step_config\": \"include tripleo::profile::base::nova::metadata\\ninclude tripleo::profile::base::database::mysql::client\", \"config_image\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\"}, {\"config_volume\": \"nova\", \"puppet_tags\": \"nova_config\", \"step_config\": \"include tripleo::profile::base::nova::vncproxy\\ninclude tripleo::profile::base::database::mysql::client\", \"config_image\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\"}, {\"config_volume\": \"rabbitmq\", \"puppet_tags\": \"file,file_line\", \"step_config\": \"[\'Rabbitmq_policy\', \'Rabbitmq_user\'].each |String $val| { noop_resource($val) }\\ninclude tripleo::profile::pacemaker::rabbitmq_bundle\", \"config_image\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\"}, {\"config_volume\": \"rsyslog\", \"puppet_tags\": \"rsyslog::generate_concat,concat::fragment\", \"step_config\": \"include tripleo::profile::base::logging::rsyslog\", \"config_image\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\"}], \"kolla_config\": {\"/var/lib/kolla/config_files/clustercheck.json\": {\"command\": \"bash -c $* -- eval source /etc/sysconfig/clustercheck; exec socat -T\\\"${TRIPLEO_HEALTHCHECK_TIMEOUT:-2}\\\" \\\"$TRIPLEO_SOCAT_BIND\\\" system:\\\"grep -qPe \\\\\\\"^\\\\\\\\r\\\\$\\\\\\\" && /usr/bin/clustercheck\\\"\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/collectd.json\": {\"command\": \"/usr/sbin/collectd -f\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/collectd.d\", \"dest\": \"/etc/\", \"merge\": false, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/collectd\", \"owner\": \"collectd:collectd\", \"recurse\": true}, {\"path\": \"/scripts\", \"owner\": \"collectd:collectd\", \"recurse\": true}, {\"path\": \"/config-scripts\", \"owner\": \"collectd:collectd\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/logrotate-crond.json\": {\"command\": \"/usr/sbin/crond -s -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/haproxy.json\": {\"command\": \"bash -c $* -- eval if [ -f /usr/sbin/haproxy-systemd-wrapper ]; then exec /usr/sbin/haproxy-systemd-wrapper -f /etc/haproxy/haproxy.cfg; else exec /usr/sbin/haproxy -f /etc/haproxy/haproxy.cfg -Ws; fi\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"optional\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/lib/haproxy\", \"owner\": \"haproxy:haproxy\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/haproxy/*\", \"owner\": \"haproxy:haproxy\", \"perm\": \"0600\", \"optional\": true}, {\"path\": \"/etc/pki/tls/private/haproxy/*\", \"owner\": \"haproxy:haproxy\", \"perm\": \"0600\", \"optional\": true}]}, \"/var/lib/kolla/config_files/iscsid.json\": {\"command\": \"/usr/sbin/iscsid -f\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src-iscsid/\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/metrics_qdr.json\": {\"command\": \"/usr/sbin/qdrouterd -c /etc/qpid-dispatch/qdrouterd.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/lib/qdrouterd\", \"owner\": \"qdrouterd:qdrouterd\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/metrics_qdr.crt\", \"owner\": \"qdrouterd:qdrouterd\", \"optional\": true}, {\"path\": \"/etc/pki/tls/private/metrics_qdr.key\", \"owner\": \"qdrouterd:qdrouterd\", \"optional\": true}]}, \"/var/lib/kolla/config_files/mysql.json\": {\"command\": \"/usr/sbin/pacemaker_remoted\", \"config_files\": [{\"dest\": \"/etc/libqb/force-filesystem-sockets\", \"source\": \"/dev/null\", \"owner\": \"root\", \"perm\": \"0644\"}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"optional\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/mysql\", \"owner\": \"mysql:mysql\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/mysql.crt\", \"owner\": \"mysql:mysql\", \"perm\": \"0600\", \"optional\": true}, {\"path\": \"/etc/pki/tls/private/mysql.key\", \"owner\": \"mysql:mysql\", \"perm\": \"0600\", \"optional\": true}]}, \"/var/lib/kolla/config_files/nova_conductor.json\": {\"command\": \"/usr/bin/nova-conductor \", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/nova\", \"owner\": \"nova:nova\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/nova_conductor_db_sync.json\": {\"command\": \"/usr/bin/bootstrap_host_exec nova_conductor su nova -s /bin/bash -c \'/usr/bin/nova-manage db sync --local_cell\'\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/nova\", \"owner\": \"nova:nova\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/nova_metadata.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/nova\", \"owner\": \"nova:nova\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/nova_vnc_proxy.json\": {\"command\": \"/usr/bin/nova-novncproxy --web /usr/share/novnc/ \", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/log/nova\", \"owner\": \"nova:nova\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/novnc-proxy.crt\", \"owner\": \"root:root\", \"perm\": \"0644\"}, {\"path\": \"/etc/pki/tls/private/novnc-proxy.key\", \"owner\": \"root:qemu\", \"perm\": \"0640\"}, {\"path\": \"/etc/pki/tls/certs/libvirt-vnc-client-cert.crt\", \"owner\": \"root:root\", \"perm\": \"0644\"}, {\"path\": \"/etc/pki/tls/private/libvirt-vnc-client-cert.key\", \"owner\": \"root:qemu\", \"perm\": \"0640\"}]}, \"/var/lib/kolla/config_files/rabbitmq.json\": {\"command\": \"/usr/sbin/pacemaker_remoted\", \"config_files\": [{\"dest\": \"/etc/libqb/force-filesystem-sockets\", \"source\": \"/dev/null\", \"owner\": \"root\", \"perm\": \"0644\"}, {\"dest\": \"/var/log/btmp\", \"source\": \"/dev/null\", \"owner\": \"root:utmp\", \"perm\": \"0600\"}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"optional\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/lib/rabbitmq\", \"owner\": \"rabbitmq:rabbitmq\", \"recurse\": true}, {\"path\": \"/var/log/rabbitmq\", \"owner\": \"rabbitmq:rabbitmq\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/rabbitmq.crt\", \"owner\": \"rabbitmq:rabbitmq\", \"perm\": \"0600\", \"optional\": true}, {\"path\": \"/etc/pki/tls/private/rabbitmq.key\", \"owner\": \"rabbitmq:rabbitmq\", \"perm\": \"0600\", \"optional\": true}]}, \"/var/lib/kolla/config_files/rsyslog.json\": {\"command\": \"/usr/sbin/rsyslogd -n -iNONE\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/lib/rsyslog\", \"owner\": \"root:root\", \"recurse\": true}, {\"path\": \"/var/log/rsyslog\", \"owner\": \"root:root\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"clustercheck\": {\"start_order\": 1, \"image\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"restart\": \"always\", \"net\": \"host\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": [\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\", \"/etc/puppet:/etc/puppet:ro\", \"/var/lib/kolla/config_files/clustercheck.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/clustercheck:/var/lib/kolla/config_files/src:ro\", \"/var/lib/mysql:/var/lib/mysql\"], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"mysql_wait_bundle\": {\"start_order\": 0, \"detach\": false, \"net\": \"host\", \"ipc\": \"host\", \"user\": \"root\", \"command\": [\"/container_puppet_apply.sh\", \"2\", \"file,file_line,concat,augeas,galera_ready,mysql_database,mysql_grant,mysql_user\", \"include tripleo::profile::pacemaker::database::mysql_bundle\"], \"image\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"volumes\": [\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\", \"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\", \"/var/lib/mysql:/var/lib/mysql:rw,z\", \"/var/lib/config-data/puppet-generated/mysql/root:/root:rw\"], \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": \"1781252715\"}}, \"nova_conductor_init_log\": {\"image\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/nova:/var/log/nova:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R nova:nova /var/log/nova\"], \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": \"1781252715\"}}, \"nova_metadata_init_logs\": {\"image\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/nova:/var/log/nova:z\", \"/var/log/containers/httpd/nova-metadata:/var/log/httpd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R nova:nova /var/log/nova\"]}, \"rabbitmq_wait_bundle\": {\"start_order\": 0, \"detach\": false, \"net\": \"host\", \"ipc\": \"host\", \"user\": \"root\", \"command\": [\"/container_puppet_apply.sh\", \"2\", \"file,file_line,concat,augeas,rabbitmq_policy,rabbitmq_user,rabbitmq_ready\", \"include tripleo::profile::pacemaker::rabbitmq_bundle\", \"\"], \"image\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"volumes\": [\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\", \"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\", \"/bin/true:/bin/epmd\"], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"KOLLA_BOOTSTRAP\": true, \"TRIPLEO_DEPLOY_IDENTIFIER\": \"1781252715\"}}}, \"step_3\": {\"collectd\": {\"image\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"net\": \"host\", \"pid\": \"host\", \"user\": \"root\", \"restart\": \"always\", \"memory\": \"512m\", \"cap_add\": [\"IPC_LOCK\"], \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": [\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\", \"/etc/puppet:/etc/puppet:ro\", \"/var/lib/kolla/config_files/collectd.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/containers/storage/overlay-containers:/var/lib/containers/storage/overlay-containers:ro\", \"/var/lib/config-data/puppet-generated/collectd:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/collectd:/var/log/collectd:rw,z\", \"/var/lib/container-config-scripts:/config-scripts:ro\", \"/var/lib/container-user-scripts:/scripts:z\", \"/run:/run:rw\", \"/sys/fs/cgroup:/sys/fs/cgroup:ro\"], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"iscsid\": {\"start_order\": 2, \"image\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"net\": \"host\", \"privileged\": true, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": [\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\", \"/etc/puppet:/etc/puppet:ro\", \"/var/lib/kolla/config_files/iscsid.json:/var/lib/kolla/config_files/config.json:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", \"/etc/target:/etc/target:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"nova_db_sync\": {\"image\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"cap_add\": [\"AUDIT_WRITE\"], \"start_order\": 3, \"net\": \"host\", \"detach\": false, \"volumes\": [\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\", \"/etc/puppet:/etc/puppet:ro\", \"/var/log/containers/nova:/var/log/nova\", \"/var/lib/kolla/config_files/nova_conductor_db_sync.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/nova:/var/lib/kolla/config_files/src:ro\"], \"user\": \"root\", \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": \"1781252715\"}}, \"rsyslog\": {\"image\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"restart\": \"always\", \"security_opt\": [\"label=disable\"], \"volumes\": [\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\", \"/etc/puppet:/etc/puppet:ro\", \"/var/lib/kolla/config_files/rsyslog.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/rsyslog:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers:/var/log/containers:ro\", \"/var/log/containers/rsyslog:/var/log/rsyslog:rw,z\", \"/var/log:/var/log/host:ro\", \"/var/lib/rsyslog.container:/var/lib/rsyslog:rw,z\"], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}, \"step_4\": {\"logrotate_crond\": {\"image\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"net\": \"none\", \"pid\": \"host\", \"privileged\": true, \"user\": \"root\", \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron\"}, \"volumes\": [\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\", \"/etc/puppet:/etc/puppet:ro\", \"/var/lib/kolla/config_files/logrotate-crond.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/crond:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers:/var/log/containers:z\"], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"nova_conductor\": {\"image\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck 5672\"}, \"volumes\": [\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\", \"/etc/puppet:/etc/puppet:ro\", \"/var/log/containers/nova:/var/log/nova\", \"/var/lib/kolla/config_files/nova_conductor.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/nova:/var/lib/kolla/config_files/src:ro\"], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"nova_metadata\": {\"start_order\": 2, \"image\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"net\": \"host\", \"user\": \"root\", \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": [\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\", \"/etc/puppet:/etc/puppet:ro\", \"/var/log/containers/nova:/var/log/nova:z\", \"/var/log/containers/httpd/nova-metadata:/var/log/httpd:z\", \"/var/lib/kolla/config_files/nova_metadata.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/nova_metadata:/var/lib/kolla/config_files/src:ro\"], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"nova_vnc_proxy\": {\"image\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": [\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\", \"/etc/puppet:/etc/puppet:ro\", \"/var/log/containers/nova:/var/log/nova\", \"/var/lib/kolla/config_files/nova_vnc_proxy.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/nova:/var/lib/kolla/config_files/src:ro\"], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}, \"step_1\": {\"metrics_qdr_init_logs\": {\"start_order\": 0, \"detach\": false, \"image\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/metrics_qdr:/var/log/qdrouterd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R qdrouterd:qdrouterd /var/log/qdrouterd\"]}, \"metrics_qdr\": {\"start_order\": 1, \"image\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"net\": \"host\", \"user\": \"qdrouterd\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": [\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\", \"/etc/puppet:/etc/puppet:ro\", \"/var/lib/kolla/config_files/metrics_qdr.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/metrics_qdr:/var/lib/kolla/config_files/src:ro\", \"/var/lib/metrics_qdr:/var/lib/qdrouterd:z\", \"/var/log/containers/metrics_qdr:/var/log/qdrouterd:z\"], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"mysql_data_ownership\": {\"start_order\": 0, \"detach\": false, \"image\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"net\": \"host\", \"user\": \"root\", \"command\": [\"chown\", \"-R\", \"mysql:\", \"/var/lib/mysql\"], \"volumes\": [\"/var/lib/mysql:/var/lib/mysql:z\"]}, \"mysql_bootstrap\": {\"start_order\": 1, \"detach\": false, \"image\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"net\": \"host\", \"user\": \"root\", \"command\": [\"bash\", \"-ec\", \"if [ -e /var/lib/mysql/mysql ]; then exit 0; fi\\necho -e \\\"\\\\n[mysqld]\\\\nwsrep_provider=none\\\" >> /etc/my.cnf\\nexport DB_ROOT_PASSWORD=$(hiera \'mysql::server::root_password\')\\nkolla_set_configs\\nsudo -u mysql -E kolla_extend_start\\ntimeout ${DB_MAX_TIMEOUT} /bin/bash -c \'while pgrep -af /usr/bin/mysqld_safe | grep -q -v grep; do sleep 1; done\'\\nmysqld_safe --skip-networking --wsrep-on=OFF &\\ntimeout ${DB_MAX_TIMEOUT} /bin/bash -c \'until mysqladmin -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" ping 2>/dev/null; do sleep 1; done\'\\nmysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"CREATE USER \'clustercheck\'@\'localhost\' IDENTIFIED BY \'$(hiera mysql_clustercheck_password)\';\\\"\\nmysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"GRANT PROCESS ON *.* TO \'clustercheck\'@\'localhost\' WITH GRANT OPTION;\\\"\\nmysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"DELETE FROM mysql.user WHERE user = \'root\' AND host NOT IN (\'%\',\'localhost\');\\\"\\ntimeout ${DB_MAX_TIMEOUT} mysqladmin -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" shutdown\"], \"volumes\": [\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\", \"/etc/puppet:/etc/puppet:ro\", \"/var/lib/kolla/config_files/mysql.json:/var/lib/kolla/config_files/config.json:rw,z\", \"/var/lib/config-data/puppet-generated/mysql:/var/lib/kolla/config_files/src:ro,z\", \"/var/lib/mysql:/var/lib/mysql:rw,z\"], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"KOLLA_BOOTSTRAP\": true, \"DB_MAX_TIMEOUT\": 60, \"DB_MARIABACKUP_USER\": \"mariabackup\", \"DB_MARIABACKUP_PASSWORD\": \"zgFej84GkeJYRMxOd5txIKJHX\"}}, \"rabbitmq_bootstrap\": {\"start_order\": 0, \"image\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"net\": \"host\", \"privileged\": false, \"user\": \"root\", \"command\": [\"bash\", \"-ec\", \"kolla_set_configs\\nif [[ -e \\\"/var/lib/rabbitmq/.erlang.cookie\\\" ]]; then rm -f /var/lib/rabbitmq/.erlang.cookie; fi\\nhiera \'rabbitmq::erlang_cookie\' > /var/lib/rabbitmq/.erlang.cookie\\nchown rabbitmq:rabbitmq /var/lib/rabbitmq/.erlang.cookie\\nchmod 400 /var/lib/rabbitmq/.erlang.cookie\"], \"volumes\": [\"/var/lib/kolla/config_files/rabbitmq.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/rabbitmq:/var/lib/kolla/config_files/src:ro\", \"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/var/lib/rabbitmq:/var/lib/rabbitmq:z\", \"/etc/puppet:/etc/puppet:ro,z\"], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": \"1781252715\"}}}}, \"container_config_scripts\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": \"#!/usr/bin/bash\\n# Copyright 2018 Red Hat Inc.\\n#\\n# Licensed under the Apache License, Version 2.0 (the \\\"License\\\"); you may\\n# not use this file except in compliance with the License. You may obtain\\n# a copy of the License at\\n#\\n#      http://www.apache.org/licenses/LICENSE-2.0\\n#\\n# Unless required by applicable law or agreed to in writing, software\\n# distributed under the License is distributed on an \\\"AS IS\\\" BASIS, WITHOUT\\n# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the\\n# License for the specific language governing permissions and limitations\\n# under the License.\\n#\\n# Usage: pyshim.sh <script and/or arguments>\\n#\\n# Unfortunately THT doesn\'t know which version of python might be in a\\n# container so we need this script to be able to try python3 or python2\\n# depending on availability.  Since this is a temporary shim until we\'ve\\n# fully cut over to python3, we check for the existence of python3 first\\n# before falling back to python2. This will help in the transition from\\n# python2 based containers to python3.\\n\\nshow_usage() {\\n    echo \\\"Usage: pyshim.sh <script and/or arguments>\\\"\\n}\\n\\nif [ $# -lt 1 ]\\nthen\\n    show_usage\\n    exit 1\\nfi\\n\\nset -x\\nif command -v python3 >/dev/null; then\\n    python3 \\\"$@\\\"\\nelif command -v python2 >/dev/null; then\\n    python2 \\\"$@\\\"\\nelif command -v python >/dev/null; then\\n    python \\\"$@\\\"\\nelse\\n    echo \\\"ERROR: python is not available!\\\"\\n    exit 1\\nfi\\n\"}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": \"#!/usr/bin/bash\\n\\nset -u\\n\\n# ./pacemaker_restart_bundle.sh mysql galera galera-bundle Master _\\n# ./pacemaker_restart_bundle.sh redis redis redis-bundle Slave Master\\n# ./pacemaker_restart_bundle.sh ovn_dbs ovndb_servers ovn-dbs-bundle Slave Master\\nRESTART_SCRIPTS_DIR=$(dirname $0)\\nTRIPLEO_SERVICE=$1\\nRESOURCE_NAME=$2\\nBUNDLE_NAME=$3\\nWAIT_TARGET_LOCAL=$4\\nWAIT_TARGET_ANYWHERE=${5:-_}\\nTRIPLEO_MINOR_UPDATE=\\\"${TRIPLEO_MINOR_UPDATE:-false}\\\"\\nTRIPLEO_HA_WRAPPER_RESOURCE_EXISTS=\\\"${TRIPLEO_HA_WRAPPER_RESOURCE_EXISTS:-false}\\\"\\n\\nbundle_can_be_restarted() {\\n    local bundle=$1\\n    # As long as the resource bundle is managed by pacemaker and is\\n    # not meant to stay stopped, no matter the state of any inner\\n    # pcmk_remote or ocf resource, we should restart it to give it a\\n    # chance to read the new config.\\n    [ \\\"$(crm_resource --meta -r $1 -g is-managed 2>/dev/null)\\\" != \\\"false\\\" ] && \\\\\\n    [ \\\"$(crm_resource --meta -r $1 -g target-role 2>/dev/null)\\\" != \\\"Stopped\\\" ]\\n}\\n\\nlog() {\\n    local msg=$1\\n    logger -t pcmkrestart \\\"$1\\\"\\n}\\n\\nHOSTNAME=$(/bin/hostname -s)\\nif [ x\\\"${TRIPLEO_MINOR_UPDATE,,}\\\" != x\\\"true\\\" ]; then\\n    if [ x\\\"${TRIPLEO_HA_WRAPPER_RESOURCE_EXISTS,,}\\\" = x\\\"false\\\" ]; then\\n        # Do not restart during initial deployment, as the resource\\n        # has just been created.\\n        SERVICE_NODEID=$(/bin/hiera -c /etc/puppet/hiera.yaml \\\"${TRIPLEO_SERVICE}_short_bootstrap_node_name\\\")\\n        if [[ \\\"${HOSTNAME,,}\\\" == \\\"${SERVICE_NODEID,,}\\\" ]]; then\\n            log \\\"Initial deployment, skipping the restart of ${BUNDLE_NAME}\\\"\\n\\tfi\\n        exit 0\\n    else\\n        # During a stack update, this script is called in parallel on\\n        # every node the resource runs on, after the service\'s configs\\n        # have been updated on all nodes. So we need to run pcs only\\n        # once (e.g. on the service\'s boostrap node).\\n        if bundle_can_be_restarted ${BUNDLE_NAME}; then\\n            SERVICE_NODEID=$(/bin/hiera -c /etc/puppet/hiera.yaml \\\"${TRIPLEO_SERVICE}_short_bootstrap_node_name\\\")\\n            if [[ \\\"${HOSTNAME,,}\\\" == \\\"${SERVICE_NODEID,,}\\\" ]]; then\\n                replicas_running=$(crm_resource -Q -r $BUNDLE_NAME --locate 2>&1 | wc -l)\\n                if [ \\\"$replicas_running\\\" != \\\"0\\\" ]; then\\n                    log \\\"Restarting ${BUNDLE_NAME} globally. Stopping:\\\"\\n                    /sbin/pcs resource disable --wait=600 $BUNDLE_NAME\\n                    log \\\"Restarting ${BUNDLE_NAME} globally. Starting:\\\"\\n                    /sbin/pcs resource enable --wait=600 $BUNDLE_NAME\\n                else\\n                    log \\\"${BUNDLE_NAME} is not running anywhere,\\\" \\\\\\n                         \\\"cleaning up to restart it globally if necessary\\\"\\n                    /sbin/pcs resource cleanup $BUNDLE_NAME\\n                fi\\n            else\\n                log \\\"Skipping global restart of ${BUNDLE_NAME} on ${HOSTNAME} it will be restarted by node ${SERVICE_NODEID}\\\"\\n            fi\\n\\n        else\\n            log \\\"No global restart needed for ${BUNDLE_NAME}.\\\"\\n        fi\\n    fi\\nelse\\n    # During a minor update workflow however, a host gets fully\\n    # updated before updating the next one. So unlike stack\\n    # update, at the time this script is called, the service\'s\\n    # configs aren\'t updated on all nodes yet. So only restart the\\n    # resource locally, where it\'s guaranteed that the config is\\n    # up to date.\\n    HOST=$(facter hostname)\\n\\n    if bundle_can_be_restarted ${BUNDLE_NAME}; then\\n\\t# if the resource is running locally, restart it\\n\\tif crm_resource -r $BUNDLE_NAME --locate 2>&1 | grep -w -q \\\"${HOST}\\\"; then\\n            log \\\"Restarting ${BUNDLE_NAME} locally on \'${HOST}\'\\\"\\n            /sbin/pcs resource restart $BUNDLE_NAME \\\"${HOST}\\\"\\n\\n\\telse\\n\\t    # At this point, if no resource is running locally, it\'s\\n\\t    # either because a) it has failed previously, or b) because\\n\\t    # it\'s an A/P resource running elsewhere.\\n\\t    # By cleaning up resource, we ensure that a) it will try to\\n\\t    # restart, or b) it won\'t do anything if the resource is\\n\\t    # already running elsewhere.\\n            log \\\"${BUNDLE_NAME} is currently not running on \'${HOST}\',\\\" \\\\\\n                 \\\"cleaning up its state to restart it if necessary\\\"\\n            /sbin/pcs resource cleanup $BUNDLE_NAME node=\\\"${HOST}\\\"\\n\\tfi\\n\\n\\t# Wait until the resource is in the expected target state\\n\\t$RESTART_SCRIPTS_DIR/pacemaker_wait_bundle.sh \\\\\\n            $RESOURCE_NAME $BUNDLE_NAME \\\\\\n            \\\"$WAIT_TARGET_LOCAL\\\" \\\"$WAIT_TARGET_ANYWHERE\\\" \\\\\\n\\t    \\\"${HOST}\\\" 600\\n    else\\n        log \\\"No restart needed for ${BUNDLE_NAME}.\\\"\\n    fi\\nfi\\n\"}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": \"#!/usr/bin/bash\\n\\n# ----\\n# Wait for an OCF resource or a bundle to be restarted\\n# ----\\n# e.g.:\\n# M/S OCF:      $0 galera galera-bundle Master\\n# clone OCF:    $0 rabbitmq rabbitmq-bundle Started\\n# A/P M/S OCF:  $0 redis redis-bundle Slave Master\\n# A/P bundle:   $0 openstack-cinder-volume openstack-cinder-volume _ Started\\n# clone bundle: $0 haproxy-bundle haproxy-bundle Started\\n\\n# design note 1:\\n#  - this script is called during a minor update; it is called\\n#    once per node that hosts a service replica.\\n#  - the purpose of this script is to ensure that restarting the\\n#    service replica locally won\'t disrupt the service availability\\n#    for the end user. To reach that goal, the script waits until the\\n#    service is restarted locally or globallu and reaches a given\\n#    target state (i.e. Started, Slave or Master).\\n# design note 2:\\n#   - we don\'t want to track restart error: our only job is to ensure\\n#     service restart synchronization, not service health.\\n#   - In particular, we don\'t want to error out in case the resource\\n#     cannot be restarted locally, because that would make the minor\\n#     update fail, even if potentially other replicas still provide\\n#     the service.\\n# design note 3:\\n#   - we can bail out early if we determine that the resource can\'t\\n#     be restarted automatically by pacemaker (e.g. its \\\"blocked\\\",\\n#     unmanaged or disabled).\\n\\nlog() {\\n    local msg=$1\\n    echo \\\"$(date -u): $1\\\"\\n}\\n\\nusage() {\\n    echo 2>&1 \\\"Usage: $0 NAME BUNDLE_NAME ROLE_LOCAL [ROLE_ANYWHERE] [HOST] [TIMEOUT]\\\"\\n    exit 1\\n}\\n\\npacemaker_supports_promoted() {\\n    # The Promoted token is only matched in recent pacemaker versions\\n    grep -wq \\\"<value>Promoted</value>\\\" /usr/share/pacemaker/resources-*.rng\\n}\\n\\n#\\n# Utility functions to detect stuck resources\\n#\\n\\nbundle_failures_locally() {\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\n    local replicas=$BUNDLE_REPLICAS\\n    local last=$(($replicas - 1))\\n    local replica_name\\n    for i in $(seq 0 $last); do\\n\\treplica_name=${BUNDLE_NAME}-${engine}-${i}\\n\\tcrm_failcount -q -G -r $replica_name -N $HOST\\n    done\\n}\\n\\nbundle_failures_globally() {\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\n    local replicas=$BUNDLE_REPLICAS\\n    local last=$(($replicas - 1))\\n    for i in $(seq 0 $last); do\\n\\tcrm_failcount -q -G -r ${BUNDLE_NAME}-${engine}-${i}\\n    done\\n}\\n\\nbundle_running_globally() {\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\n    # return the number of running bundles replica, i.e. the number of\\n    # docker/podman resource replicas currently running in the cluster\\n    crm_mon --as-xml | xmllint --xpath \\\"count(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource[@resource_agent=\'${OCF}:heartbeat:${engine}\']/node)\\\" -\\n}\\n\\nocf_failures_globally() {\\n    local replicas=$BUNDLE_REPLICAS\\n    local last=$(($replicas - 1))\\n    local bundle_node\\n    for i in $(seq 0 $last); do\\n\\tbundle_node=${BUNDLE_NAME}-${i}\\n\\tcrm_failcount -q -G -r $NAME -N $bundle_node\\n    done\\n}\\n\\ndid_resource_failed_locally() {\\n    local failures\\n    local running\\n    local remotehost\\n    if [ \\\"${NAME}\\\" != \\\"${BUNDLE_NAME}\\\" ]; then\\n\\t# if we\'re dealing with an ocf resource, it is running on a\\n\\t# pacemaker_remote rather that on the real host, and the\\n\\t# failcounts are thus associated to the pcmk remote. Replace\\n\\t# the host\'s name with the pcmk remote\'s name.\\n        remotehost=$(crm_mon --as-xml | xmllint --xpath \\\"string(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource/node[@name=\'${HOST}\']/../../resource[@resource_agent=\'${OCF}:pacemaker:remote\']/@id)\\\" -)\\n\\tif [ -n \\\"${remotehost}\\\" ]; then\\n\\t    crm_failcount -q -G -r $NAME -N $remotehost | grep -q -w INFINITY\\n\\t    return $?\\n\\tfi\\n\\t# If no pcmk remote is currently running, the failcount from\\n\\t# the ocf resource is useless, compute the failcount from the\\n\\t# bundle case instead (computed below).\\n    fi\\n\\n    # for bundles, pacemaker can run any bundle replica locally\\n    # (e.g. galera-bundle-docker-{0,1,2}), and a failure happens when\\n    # there are no more replica to try.\\n    # That is, when _at least_ one replica failed locally, and all the\\n    # others either failed or are currently running elsewhere.\\n    failures=$(bundle_failures_locally $HOST | grep -c -w INFINITY)\\n    running=$(bundle_running_globally)\\n    test $failures -gt 0 && \\\\\\n    test $(( $failures + $running )) -ge $BUNDLE_REPLICAS\\n}\\n\\ndid_resource_failed_globally() {\\n    local remotecount\\n    local failures\\n    if [ \\\"${NAME}\\\" != \\\"${BUNDLE_NAME}\\\" ]; then\\n\\t# we check the state of an ocf resource only if the\\n\\t# pcmkremotes are started\\n        remotecount=$(crm_mon --as-xml | xmllint --xpath \\\"count(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource[@resource_agent=\'${OCF}:pacemaker:remote\']/node)\\\" -)\\n\\tif [ \\\"${remotecount}\\\" = \\\"0\\\" ]; then\\n\\t    # no pcmkremote is running, so check the bundle state\\n\\t    # instead of checking the ocf resource\\n\\t    # bundle failed if all ${BUNDLE_REPLICAS} replicas failed\\n\\t    failures=$(bundle_failures_globally | grep -c -w INFINITY)\\n\\t    test $failures -eq $BUNDLE_REPLICAS\\n\\telse\\n\\t    # ocf resource failed if it failed to start on\\n\\t    # all $BUNDLE_REPLICAS bundle nodes\\n\\t    failures=$(ocf_failures_globally | grep -c -w INFINITY)\\n\\t    test $failures -eq $BUNDLE_REPLICAS\\n\\tfi\\n    else\\n\\t# bundle failed if all ${BUNDLE_REPLICAS} replicas failed\\n\\tfailures=$(bundle_failures_globally | grep -c -w INFINITY)\\n\\ttest $failures -eq $BUNDLE_REPLICAS\\n    fi\\n}\\n\\n\\n# Input validation\\n#\\n\\nNAME=$1\\nif [ -z \\\"${NAME}\\\" ]; then\\n    echo 2>&1 \\\"Error: argument NAME must not be empty\\\"\\n    exit 1\\nfi\\n\\nBUNDLE_NAME=$2\\nif [ -z \\\"${BUNDLE_NAME}\\\" ]; then\\n    echo 2>&1 \\\"Error: argument BUNDLE_NAME must not be empty\\\"\\n    exit 1\\nfi\\n\\nROLE_LOCAL=$3\\nif [ \\\"${ROLE_LOCAL}\\\" = \\\"_\\\" ]; then\\n    ROLE_LOCAL=\\\"\\\"\\nfi\\n\\nROLE_ANYWHERE=$4\\nif [ \\\"${ROLE_ANYWHERE}\\\" = \\\"_\\\" ]; then\\n    ROLE_ANYWHERE=\\\"\\\"\\nfi\\n\\nif [ -z \\\"${ROLE_LOCAL}\\\" ]; then\\n    if [ -z \\\"${ROLE_ANYWHERE}\\\" ]; then\\n        echo 2>&1 \\\"Error: either ROLE_LOCAL or ROLE_ANYWHERE must be non empty\\\"\\n        exit 1\\n    fi\\nelse\\n    if !(echo \\\"${ROLE_LOCAL}\\\" | grep -q -x -E \\\"(Started|Slave|Master|Unpromoted|Promoted)\\\"); then\\n        echo 2>&1 \\\"Error: argument ROLE_LOCAL must be either \'Started\' \'Slave\' \'Master\' \'Unpromoted\' or \'Promoted\'\\\"\\n        exit 1\\n    fi\\nfi\\n\\nif [ -n \\\"${ROLE_ANYWHERE}\\\" ] && !(echo \\\"${ROLE_ANYWHERE}\\\" | grep -q -x -E \\\"(Started|Slave|Master|Unpromoted|Promoted)\\\"); then\\n    echo 2>&1 \\\"Error: argument ROLE_ANYWHERE must be either \'Started\' \'Slave\' \'Master\' \'Unpromoted\' or \'Promoted\'\\\"\\n    exit 1\\nfi\\n\\n# Ensure compatibility with pacemaker 2.1\\nif pacemaker_supports_promoted; then\\n    ROLE_LOCAL=$(echo \\\"$ROLE_LOCAL\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\n    ROLE_ANYWHERE=$(echo \\\"$ROLE_ANYWHERE\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\n    OCF=\\\"ocf\\\"\\nelse\\n    OCF=\\\"ocf:\\\"\\nfi\\n\\nHOST=${5:-$(facter hostname)}\\nTIMEOUT=${6:-600}\\n\\n\\n# Configure the search\\n# ----\\n# Note: we can\'t use crm_resource in all searches because we can\'t\\n# easily extract the host the OCF resources run on (crm_resource\\n# returns the pcmk-remote nodes rather than the hosts)\\n# So instead, we implement various searches with XPath directly.\\n\\nif [ \\\"${BUNDLE_NAME}\\\" != \\\"${NAME}\\\" ]; then\\n# ocf resource\\nlocal_resource_xpath=\\\"//bundle/replica/resource[@resource_agent=\'${OCF}:pacemaker:remote\']/node[@name=\'${HOST}\']/../../resource[@id=\'${NAME}\']\\\"\\nany_resource_xpath=\\\"//bundle//resource[@id=\'${NAME}\']\\\"\\nreplicas_xpath=\\\"//bundle/primitive[@id=\'${BUNDLE_NAME}\']/../*[boolean(@image) and boolean(@replicas)]\\\"\\nelse\\n# bundle resource\\nlocal_resource_xpath=\\\"//bundle[@id=\'${NAME}\']/replica/resource/node[@name=\'${HOST}\']/../../resource\\\"\\nany_resource_xpath=\\\"//bundle[@id=\'${NAME}\']//resource\\\"\\nreplicas_xpath=\\\"//bundle[@id=\'${BUNDLE_NAME}\']/*[boolean(@image) and boolean(@replicas)]\\\"\\nfi\\n\\nbundle_def_xpath=\\\"//bundle[@id=\'${BUNDLE_NAME}\']/*[boolean(@image) and boolean(@replicas)]\\\"\\nBUNDLE_CONTAINER_ENGINE=$(cibadmin -Q | xmllint --xpath \\\"name(${bundle_def_xpath})\\\" -)\\nBUNDLE_REPLICAS=$(cibadmin -Q | xmllint --xpath \\\"string(${bundle_def_xpath}/@replicas)\\\" -)\\n\\n\\n# The wait algorithm follows a two-stage approach\\n#  1. Depending on how the script is called, we first check whether\\n#     the resource is restarted locally. An A/P resource may be\\n#     restarted elsewhere in the cluster.\\n#  2. If needed, check whether the A/P resource has restarted\\n#     elsewhere. For A/P M/S resources, in case the resource is\\n#     restarted as Slave locally, ensure a Master is available.\\n\\nsuccess=1\\nbailout=1\\ntimeout=$TIMEOUT\\nrole=\\\"\\\"\\n\\n# Stage 1: local check\\nif [ -n \\\"$ROLE_LOCAL\\\" ]; then\\n    log \\\"Waiting until ${NAME} has restarted on ${HOST} and is in state ${ROLE_LOCAL}\\\"\\n    log \\\"Will probe resource state with the following XPath pattern: ${local_resource_xpath}\\\"\\n\\n    while [ $timeout -gt 0 ] && [ $bailout -ne 0 ] && [ $success -ne 0 ]; do\\n        resource=$(crm_mon -r --as-xml | xmllint --xpath \\\"${local_resource_xpath}\\\" - 2>/dev/null)\\n        role=$(echo \\\"${resource}\\\" | sed -ne \'s/.*\\\\Wrole=\\\"\\\\([^\\\"]*\\\\)\\\".*/\\\\1/p\')\\n\\n\\tif [ \\\"$(crm_resource --meta -r ${NAME} -g is-managed 2>/dev/null)\\\" = \\\"false\\\" ]; then\\n            log \\\"${NAME} is unmanaged, will never reach target role. Bailing out\\\"\\n            bailout=0\\n            continue\\n\\telif [ \\\"$(crm_resource --meta -r ${NAME} -g target-role 2>/dev/null)\\\" = \\\"Stopped\\\" ]; then\\n            log \\\"${NAME} is disabled, will never reach target role. Bailing out\\\"\\n            bailout=0\\n            continue\\n        elif echo \\\"${resource}\\\" | grep -q -w \\\"\\\\Wblocked=\\\\\\\"true\\\\\\\"\\\"; then\\n            log \\\"${NAME} is blocked, will never reach target role. Bailing out\\\"\\n            bailout=0\\n            continue\\n\\telif did_resource_failed_locally; then\\n            log \\\"${NAME} is in failed state, will never reach target role. Bailing out\\\"\\n            bailout=0\\n            continue\\n        elif [ \\\"$role\\\" = \\\"$ROLE_LOCAL\\\" ]; then\\n            success=0\\n            continue\\n        elif [ -n \\\"$ROLE_ANYWHERE\\\" ] && [ \\\"$role\\\" = \\\"$ROLE_ANYWHERE\\\" ]; then\\n            # A/P: we are restarted in the expected state\\n            success=0\\n            continue\\n        else\\n            log \\\"Waiting for ${NAME} to transition to role ${ROLE_LOCAL} on ${HOST}\\\"\\n        fi\\n\\n        if [ $bailout -ne 0 ] && [ $success -ne 0 ]; then\\n            sleep 4\\n            timeout=$((timeout-4))\\n        fi\\n    done\\nfi\\n\\n# Stage 2: global check\\nif [ $timeout -gt 0 ] && [ -n \\\"$ROLE_ANYWHERE\\\" ] && [ \\\"$role\\\" != \\\"$ROLE_ANYWHERE\\\" ]; then\\n    log \\\"Wait until ${NAME} is restarted anywhere in the cluster in state ${ROLE_ANYWHERE}\\\"\\n    log \\\"Will probe resource state with the following XPath pattern: ${any_resource_xpath}\\\"\\n\\n    success=1\\n    bailout=1\\n    while [ $timeout -gt 0 ] && [ $bailout -ne 0 ] && [ $success -ne 0 ]; do\\n        resources=$(crm_mon -r --as-xml | xmllint --xpath \\\"${any_resource_xpath}\\\" - 2>/dev/null)\\n\\tif [ \\\"$(crm_resource --meta -r ${NAME} -g is-managed 2>/dev/null)\\\" = \\\"false\\\" ]; then\\n            log \\\"${NAME} is unmanaged, will never reach target role. Bailing out\\\"\\n            bailout=0\\n            continue\\n\\telif [ \\\"$(crm_resource --meta -r ${NAME} -g target-role 2>/dev/null)\\\" = \\\"Stopped\\\" ]; then\\n            log \\\"${NAME} is disabled, will never reach target role. Bailing out\\\"\\n            bailout=0\\n            continue\\n        elif ! (echo \\\"${resources}\\\" | grep -q -w \\\"\\\\Wblocked=\\\\\\\"false\\\\\\\"\\\"); then\\n            log \\\"${NAME} blocked, will never reach target role. Bailing out\\\"\\n            bailout=0\\n            continue\\n\\telif did_resource_failed_globally; then\\n            log \\\"${NAME} is in failed state, will never reach target role. Bailing out\\\"\\n            bailout=0\\n            continue\\n        elif echo \\\"${resources}\\\" | grep -q -w \\\"\\\\Wrole=\\\\\\\"${ROLE_ANYWHERE}\\\\\\\"\\\"; then\\n            success=0\\n            continue\\n        else\\n            log \\\"Waiting for ${NAME} to transition to role ${ROLE_ANYWHERE} anywhere in the cluster\\\"\\n        fi\\n\\n        if [ $bailout -ne 0 ] && [ $success -ne 0 ]; then\\n            sleep 4\\n            timeout=$((timeout-4))\\n        fi\\n    done\\nfi\\n\\nif [ $timeout -le 0 ]; then\\n    log \\\"Timeout reached after ${TIMEOUT}s while waiting for ${NAME} to be restarted\\\"\\nelif [ $bailout -le 0 ]; then\\n    log \\\"Restart monitoring for ${NAME} cancelled\\\"\\nfi\\n\\nif [ $success -eq 0 ]; then\\n    log \\\"${NAME} successfully restarted\\\"\\nelse\\n    log \\\"${NAME} was not restarted properly\\\"\\nfi\\n\\n# Don\'t block minor update or stack update if the wait was unsuccessful\\nexit 0\\n\"}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": \"#!/usr/bin/bash\\nset -eu\\n\\nHOST=$1\\nPORT=$2\\n\\necho \\\"$(date -u): Checking whether we can bind to ${HOST}:${PORT}\\\"\\nwhile (ss -Htnl src \\\"${HOST}\\\" \\\"sport = :${PORT}\\\" | grep -wq \\\"${PORT}\\\"); do\\n    echo \\\"$(date -u): ${HOST}:${PORT} still in use, waiting...\\\";\\n    sleep 10;\\ndone\\n\\nshift 2\\nCOMMAND=\\\"$*\\\"\\nif [ -z \\\"${COMMAND}\\\" ]; then\\n    COMMAND=\\\"true\\\"\\nfi\\nexec $COMMAND\\n\"}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": \"#!/usr/bin/bash\\n\\nMAX_RETRIES=10\\nCIB_ENOTFOUND=105\\n\\nusage() {\\n   echo \\\"Set a global property in the cluster with a validity timestamp.\\\"\\n   echo \\\"Usage:\\\"\\n   echo \\\"   $0 --acquire <lock_name> <lock_owner> <lock_ttl_in_seconds>\\\"\\n   echo \\\"   $0 --release <lock_name> <lock_owner>\\\"\\n   echo\\n}\\n\\nlog() {\\n    echo \\\"$(date -u): $1\\\" 1>&2\\n}\\n\\nerror() {\\n    echo \\\"$(date -u): $1\\\" 1>&2\\n    exit 1\\n}\\n\\nlock_create() {\\n    local name=$1\\n    local data=$2\\n    # cibadmin won\'t overwrite a key if someone else succeeded to create it concurrently\\n    cibadmin --sync-call --scope crm_config --create --xml-text \\\"<cluster_property_set id=\'${name}\'><nvpair id=\'${name}-pair\' name=\'${name}\' value=\'${data}\'/></cluster_property_set>\\\" &>/dev/null\\n    return $?\\n}\\n\\nlock_update() {\\n    local name=$1\\n    local expected_data=$2\\n    local new_data=$3\\n    # we only update the lock we expect to see, so we can\'t update someone else\'s lock\\n    cibadmin --sync-call --scope crm_config --modify --xpath \\\"//cluster_property_set/nvpair[@name=\'${name}\' and @value=\'${expected_data}\']/..\\\" --xml-text \\\"<nvpair id=\'${name}-pair\' name=\'${name}\' value=\'${new_data}\'/>\\\" &>/dev/null\\n    return $?\\n}\\n\\nlock_delete() {\\n    local name=$1\\n    local expected_data=$2\\n    # we only delete the lock we expect to see, so we can\'t delete someone else\'s lock\\n    cibadmin --sync-call --scope crm_config --delete --xpath \\\"//cluster_property_set/nvpair[@name=\'${name}\' and @value=\'${expected_data}\']/..\\\" &>/dev/null\\n    return $?\\n}\\n\\nlock_get() {\\n    local lockname=$1\\n    local res\\n    local rc\\n    res=$(cibadmin --query --scope crm_config --xpath \\\"//cluster_property_set/nvpair[@name=\'$lockname\']\\\" 2>/dev/null)\\n    rc=$?\\n    if [ $rc -eq 0 ]; then\\n        echo \\\"$res\\\" | sed -n \'s/.*value=\\\"\\\\([^\\\"]*\\\\)\\\".*/\\\\1/p\'\\n    fi\\n    return $rc\\n}\\n\\nlock_owner() {\\n    local lock=$1\\n    echo \\\"$lock\\\" | cut -d\':\' -f1\\n}\\n\\nlock_has_expired() {\\n    local lock=$1\\n    local expiry=$(echo \\\"$lock\\\" | cut -d\':\' -f2)\\n    local now=$(date +%s)\\n    test $now -ge $expiry\\n}\\n\\n\\n# Perform a lock action and restart if the CIB has been modified before\\n# committing the lock action\\ntry_action() {\\n    local fun=$1\\n    local lock=$2\\n    local requester=$3\\n    local args=${4:-}\\n    local tries=$MAX_RETRIES\\n    local rc=1\\n    if [ \\\"$fun\\\" = \\\"lock_acquire\\\" ] || [ \\\"$fun\\\" = \\\"lock_release\\\" ]; then\\n        log \\\"Try running $fun\\\"\\n    else\\n        return 2\\n    fi\\n    while [ $rc -ne 0 ]; do\\n        $fun $lock $requester $args\\n        rc=$?\\n        if [ $rc -eq 0 ]; then\\n            log \\\"Operation $1 succeeded\\\"\\n            return 0\\n        elif [ $rc -eq 3 ]; then\\n            # rc == 3 -> CIB changed before push\\n            if [ $tries -eq 0 ]; then\\n                log \\\"Failed to commit after $MAX_RETRIES retries. Bailing out.\\\"\\n                return 2\\n            else\\n                log \\\"Failed to commit. Retrying operation.\\\"\\n                tries=$(($tries - 1))\\n            fi\\n        elif [ $rc -eq 2 ]; then\\n            # rc == 2 -> unrecoverable cib error (e.g. pacemaker down)\\n            log \\\"Unexpected failure. Bailing out\\\"\\n            return $rc\\n        else\\n            # rc == 1 -> lock error (not owner, lock doesn\'t exists)\\n            return $rc\\n        fi\\n    done\\n}\\n\\n# The lock mechanism uses cibadmin\'s atomic creation so cluster-wide\\n# state coherency is guaranteed by pacemaker\\nlock_acquire() {\\n    local lockname=$1\\n    local requester=$2\\n    local ttl=$3\\n    local rc\\n    local lock\\n    local expiry\\n    local owner\\n\\n    log \\\"Check whether the lock is already held in the CIB\\\"\\n    lock=$(lock_get $lockname)\\n    rc=$?\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\n        log \\\"Could not retrieve info from the CIB\\\"\\n        return 2\\n    fi\\n\\n    if [ -n \\\"$lock\\\" ]; then\\n        lock_has_expired $lock\\n        rc=$?\\n        if [ $rc -eq 0 ]; then\\n            log \\\"Lock has expired, now available for being held\\\"\\n        else\\n            # lock is still held. check whether we\'re the owner\\n            owner=$(lock_owner $lock)\\n            if [ \\\"$owner\\\" = \\\"$requester\\\" ];then\\n                log \\\"Requester already owns the lock, acquiring attempt will just reconfigure the TTL\\\"\\n            else\\n                log \\\"Lock is held by someone else ($owner)\\\"\\n                return 1\\n            fi\\n        fi\\n    else\\n        log \\\"Lock is not held yet\\\"\\n    fi\\n\\n    # prepare the lock info\\n    expiry=$(($(date +%s) + $ttl))\\n\\n    if [ -n \\\"$lock\\\" ]; then\\n        log \\\"Attempting to update the lock\\\"\\n        lock_update $lockname \\\"$lock\\\" \\\"$requester:$expiry\\\"\\n        rc=$?\\n    else\\n        log \\\"Attempting to acquire the lock\\\"\\n        lock_create $lockname \\\"$requester:$expiry\\\"\\n        rc=$?\\n    fi\\n\\n    if [ $rc -eq 0 ]; then\\n        log \\\"Lock \'$lockname\' acquired by \'$requester\', valid until $(date -d @$expiry)\\\"\\n        return 0\\n    else\\n        log \\\"CIB changed, lock cannot be acquired\\\"\\n        return 3\\n    fi\\n}\\n\\n\\n# The lock mechanism uses the CIB\'s num_updates tag to implement\\n# a conditional store. Cluster-wide locking is guaranteed by pacemaker\\nlock_release() {\\n    local lockname=$1\\n    local requester=$2\\n    local rc\\n    local lock\\n    local owner\\n\\n    log \\\"Check whether the lock is already held in the CIB\\\"\\n    lock=$(lock_get $lockname)\\n    rc=$?\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\n        log \\\"Could not retrieve info from the CIB\\\"\\n        return 2\\n    fi\\n\\n    if [ -z \\\"$lock\\\" ]; then\\n        log \\\"Lock doesn\'t exist. Nothing to release\\\"\\n        return 0\\n    else\\n        log \\\"Lock exists, check whether we\'re the owner\\\"\\n        owner=$(lock_owner $lock)\\n        if [ \\\"$owner\\\" != \\\"$requester\\\" ];then\\n            log \\\"Lock is held by someone else ($owner), will not unlock\\\"\\n            return 1\\n        fi\\n    fi\\n\\n    lock_delete $lockname \\\"$lock\\\"\\n    rc=$?\\n\\n    if [ $rc -eq 0 ]; then\\n        log \\\"Lock \'$lockname\' released by \'$requester\'\\\"\\n        return 0\\n    else\\n        log \\\"CIB deletion error, lock cannot be released\\\"\\n        return 3\\n    fi\\n}\\n\\n\\n# Retrieve the owner of a lock from the CIB\\n# this is a read-only operation, so no need to log debug info\\nlock_get_owner() {\\n    local lockname=$1\\n    local rc\\n    local lock\\n    local owner\\n\\n    lock=$(lock_get $lockname)\\n    rc=$?\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\n        return 2\\n    fi\\n\\n    if [ -z \\\"$lock\\\" ]; then\\n        return 1\\n    else\\n        lock_owner $lock\\n        return 0\\n    fi\\n}\\n\\n\\nACTION=$1\\nLOCKNAME=$2\\nREQUESTER=$3\\nTTL=${4:-60}\\n\\nif [ -z \\\"$ACTION\\\" ]; then\\n    error \\\"Action must be specified\\\"\\nfi\\n\\nif [ $ACTION != \\\"--help\\\" ]; then\\n    if [ -z \\\"$LOCKNAME\\\" ]; then\\n        error \\\"You must specific a lock name\\\"\\n    fi\\n    if [ $ACTION != \\\"--owner\\\" ] && [ $ACTION != \\\"-o\\\" ]; then\\n        if [ -z \\\"$REQUESTER\\\" ]; then\\n            error \\\"You must specific a lock requester\\\"\\n        fi\\n    fi\\nfi\\n\\ncase $ACTION in\\n    --help) usage; exit 0;;\\n    --acquire|-a) try_action lock_acquire $LOCKNAME $REQUESTER $TTL;;\\n    --release|-r) try_action lock_release $LOCKNAME $REQUESTER;;\\n    --acquire-once|-A) lock_acquire $LOCKNAME $REQUESTER $TTL;;\\n    --owner|-o) lock_get_owner $LOCKNAME;;\\n    *) error \\\"Invalid action\\\";;\\nesac\\nexit $?\\n\"}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": \"#!/usr/bin/bash\\n\\n# pacemaker_mutex_restart_bundle.sh --lock mysql galera galera-bundle Master _\\n# pacemaker_mutex_restart_bundle.sh --lock ovn_dbs ovndb_servers ovn-dbs-bundle Slave Master\\n\\nset -u\\n\\nusage() {\\n    echo \\\"Restart a clustered resource in a coordinated way across the cluster\\\"\\n    echo \\\"Usage:\\\"\\n    echo \\\"   $0 --lock <tripleo-service> <pcmk-resource> <pcmk-bundle> <target-state-local> <target-state-cluster>\\\"\\n    echo\\n}\\n\\nlog() {\\n    echo \\\"$(date -u): $1\\\"\\n}\\n\\nerror() {\\n    echo \\\"$(date -u): $1\\\" 1>&2\\n    exit 1\\n}\\n\\npacemaker_supports_promoted() {\\n    # The Promoted token is only matched in recent pacemaker versions\\n    grep -wq \\\"<value>Promoted</value>\\\" /usr/share/pacemaker/resources-*.rng\\n}\\n\\nACTION=$1\\ncase $ACTION in\\n    --help) usage; exit 0;;\\n    --lock) ;;\\n    *) error \\\"Unknown action \'$ACTION\'\\\";;\\nesac\\n\\nTRIPLEO_SERVICE=$2\\nLOCK_NAME=${TRIPLEO_SERVICE}-restart-lock\\nLOCK_OWNER=$(crm_node -n 2>/dev/null)\\nrc=$?\\nif [ $rc -ne 0 ]; then\\n    if [ $rc -eq 102 ]; then\\n        log \\\"Cluster is not running locally, no need to restart resource $TRIPLEO_SERVICE\\\"\\n        exit 0\\n    else\\n        error \\\"Unexpected error while connecting to the cluster (rc: $rc), bailing out\\\"\\n    fi\\nfi\\n\\nRESOURCE_NAME=$3\\nBUNDLE_NAME=$4\\nWAIT_TARGET_LOCAL=$5\\nWAIT_TARGET_ANYWHERE=${6:-_}\\n\\nif pacemaker_supports_promoted; then\\n    WAIT_TARGET_LOCAL=$(echo \\\"$5\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\n    WAIT_TARGET_ANYWHERE=$(echo \\\"${6:-_}\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\n    promoted_role=\\\"Promoted\\\"\\nelse\\n    promoted_role=\\\"Master\\\"\\nfi\\n\\n# The lock TTL should accomodate for the resource start/promote timeout\\nif [ \\\"$RESOURCE_NAME\\\" != \\\"$BUNDLE_NAME\\\" ]; then\\n    if [ \\\"$WAIT_TARGET_LOCAL\\\" = \\\"$promoted_role\\\" ] || [ \\\"$WAIT_TARGET_ANYWHERE\\\" = \\\"$promoted_role\\\" ]; then\\n        rsc_op=\\\"promote\\\"\\n    else\\n        rsc_op=\\\"start\\\"\\n    fi\\n    # <op id=\\\"galera-promote-interval-0s\\\" interval=\\\"0s\\\" name=\\\"promote\\\" on-fail=\\\"block\\\" timeout=\\\"300s\\\"/>\\n    PCMK_TTL=$(cibadmin -Q | xmllint -xpath \\\"string(//primitive[@id=\'${RESOURCE_NAME}\']/operations/op[@name=\'${rsc_op}\']/@timeout)\\\" - | sed \'s/s$//\')\\n    LOCK_TTL=$((PCMK_TTL + 30))\\nelse\\n    # The podman RA\'s default start timeout\\n    LOCK_TTL=90\\nfi\\n\\nlog \\\"Acquire a ${LOCK_TTL}s restart lock for service $TRIPLEO_SERVICE before restarting it\\\"\\n# Loop until we hold the lock. The lock has a TTL, so we\'re guaranteed to get it eventually\\nrc=1\\nwhile [ $rc -ne 0 ]; do\\n    /var/lib/container-config-scripts/pacemaker_resource_lock.sh --acquire $LOCK_NAME $LOCK_OWNER $LOCK_TTL\\n    rc=$?\\n    if [ $rc != 0 ]; then\\n        if [ $rc -gt 1 ]; then\\n            error \\\"Could not acquire lock due to unrecoverable error (rc: $rc), bailing out\\\"\\n        else\\n            log \\\"Could not acquire lock, retrying\\\"\\n            sleep 10\\n        fi\\n    fi\\ndone\\n\\nlog \\\"Restart the service $TRIPLEO_SERVICE locally\\\"\\n# Reuse the local restart script in t-h-t (driven by env var TRIPLEO_MINOR_UPDATE)\\nTRIPLEO_MINOR_UPDATE=true /var/lib/container-config-scripts/pacemaker_restart_bundle.sh $TRIPLEO_SERVICE $RESOURCE_NAME $BUNDLE_NAME $WAIT_TARGET_LOCAL $WAIT_TARGET_ANYWHERE\\n\\n# If we reached this point, always try to release the lock\\nlog \\\"Release the restart lock for service $TRIPLEO_SERVICE\\\"\\n/var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $LOCK_NAME $LOCK_OWNER\\nrc=$?\\nif [ $rc -ne 0 ] && [ $rc -ne 1 ]; then\\n    error \\\"Could not release held lock (rc: $rc)\\\"\\nfi\\n\"}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": \"#!/usr/bin/bash\\n\\n# pacemaker_mutex_shutdown.sh --acquire\\n# pacemaker_mutex_shutdown.sh --release\\n\\nset -u\\n\\nusage() {\\n    echo \\\"Shutdown a cluster node in a coordinated way across the cluster\\\"\\n    echo \\\"Usage:\\\"\\n    echo \\\"   $0 --acquire # prevent other node from shutting down until we hold the lock\\\"\\n    echo \\\"   $0 --release # release the lock, other node can compete for the shutdown lock\\\"\\n    echo\\n}\\n\\nlog() {\\n    echo \\\"$(date -u): $1\\\"\\n}\\n\\nerror() {\\n    echo \\\"$(date -u): $1\\\" 1>&2\\n    exit 1\\n}\\n\\n# Loop until we hold the lock. The lock has a TTL, so we\'re guaranteed to get it eventually\\nshutdown_lock_acquire() {\\n    local lockname=$1\\n    local requester=$2\\n    local ttl=$3\\n    local rc=1\\n    local current_owner\\n    local owner_stopped\\n    local owner_rc\\n\\n    log \\\"Acquiring the shutdown lock\\\"\\n    while [ $rc -ne 0 ]; do\\n        /var/lib/container-config-scripts/pacemaker_resource_lock.sh --acquire-once $lockname $requester $ttl\\n        rc=$?\\n        if [ $rc -ne 0 ]; then\\n            if [ $rc -eq 2 ]; then\\n                error \\\"Could not acquire the shutdown lock due to unrecoverable error (rc: $rc), bailing out\\\"\\n            else\\n                # The lock is held by another node.\\n                current_owner=$(/var/lib/container-config-scripts/pacemaker_resource_lock.sh --owner $lockname)\\n                owner_rc=$?\\n                if [ $owner_rc -eq 2 ]; then\\n                    error \\\"Could not get the shutdown lock owner due to unrecoverable error (rc: $owner_rc), bailing out\\\"\\n                fi\\n                if [ $owner_rc -eq 0 ]; then\\n                    # If the owner is marked as offline, that means it has shutdown and\\n                    # we can clean the lock preemptively and try to acquire it.\\n                    owner_stopped=$(crm_mon -1X | xmllint --xpath \'count(//nodes/node[@name=\\\"\'${current_owner}\'\\\" and @online=\\\"false\\\" and @unclean=\\\"false\\\"])\' -)\\n                    if [ \\\"${owner_stopped}\\\" = \\\"1\\\" ]; then\\n                        log \\\"Shutdown lock held by stopped node \'${current_owner}\', lock can be released\\\"\\n                        /var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $lockname $current_owner\\n                        continue\\n                    fi\\n                fi\\n                log \\\"Shutdown lock held by another node (rc: $rc), retrying\\\"\\n                sleep 10\\n            fi\\n        fi\\n    done\\n    log \\\"Shutdown lock acquired\\\"\\n    return 0\\n}\\n\\n\\n# Release the lock if we still own it. Not owning it anymore is not fatal\\nshutdown_lock_release() {\\n    local lockname=$1\\n    local requester=$2\\n    local rc\\n\\n    log \\\"Releasing the shutdown lock\\\"\\n    /var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $lockname $requester\\n    rc=$?\\n    if [ $rc -ne 0 ]; then\\n        if [ $rc -gt 1 ]; then\\n            error \\\"Could not release the shutdown lock due to unrecoverable error (rc: $rc), bailing out\\\"\\n        else\\n            log \\\"Shutdown lock no longer held, nothing to do\\\"\\n        fi\\n    else\\n        log \\\"Shutdown lock released\\\"\\n    fi\\n    return 0\\n}\\n\\n\\nACTION=$1\\nif [ -z \\\"$ACTION\\\" ]; then\\n    error \\\"Action must be specified\\\"\\nfi\\n\\nLOCK_NAME=tripleo-shutdown-lock\\nLOCK_OWNER=$(crm_node -n 2>/dev/null)\\nrc=$?\\nif [ $rc -ne 0 ]; then\\n    if [ $rc -eq 102 ]; then\\n        log \\\"Cluster is not running locally, no need to aquire the shutdown lock\\\"\\n        exit 0\\n    else\\n        error \\\"Unexpected error while connecting to the cluster (rc: $rc), bailing out\\\"\\n    fi\\nfi\\n\\n# We start with a very high TTL, that long enough to accomodate a cluster stop.\\n# As soon as the node will get offline, the other competing node will be entitled\\n# to steal the lock, so they should never wait that long in practice.\\nLOCK_TTL=600\\n\\n\\ncase $ACTION in\\n    --help) usage; exit 0;;\\n    --acquire|-a) shutdown_lock_acquire ${LOCK_NAME} ${LOCK_OWNER} ${LOCK_TTL};;\\n    --release|-r) shutdown_lock_release ${LOCK_NAME} ${LOCK_OWNER};;\\n    *) error \\\"Invalid action\\\";;\\nesac\\nexit $?\\n\"}, \"collectd_check_health.py\": {\"mode\": \"0755\", \"content\": \"#!/usr/bin/python3\\n#\\n# Copyright 2022 Red Hat Inc.\\n#\\n# Licensed under the Apache License, Version 2.0 (the \\\"License\\\"); you may\\n# not use this file except in compliance with the License. You may obtain\\n# a copy of the License at\\n#\\n#      http://www.apache.org/licenses/LICENSE-2.0\\n#\\n# Unless required by applicable law or agreed to in writing, software\\n# distributed under the License is distributed on an \\\"AS IS\\\" BASIS, WITHOUT\\n# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the\\n# License for the specific language governing permissions and limitations\\n# under the License.\\n\\nimport json\\nimport os\\nimport re\\nimport shutil\\nimport subprocess\\nimport sys\\n\\nfrom pkg_resources import packaging\\n\\n\\nSOCKET = \\\"unix:/run/podman/podman.sock\\\"\\nPS_FORMAT = (\'{\\\"service\\\": \\\"{{.Names}}\\\", \\\"container\\\": \\\"{{.ID}}\\\", \'\\n             \'\\\"status\\\": \\\"{{.State}}\\\", \\\"healthy\\\": \\\"{{.Status}}\\\"},\')\\nBASE_FORMAT = \\\"{service: .Name, container: .Id, status: .State.Running, \\\"\\nRUNNING_REX = re.compile(r\\\"Up .*(?P<health>\\\\(u?n?healthy\\\\))\\\")\\nSKIP_LIST = [\'.*_bootstrap\', \'container-puppet-.*\', \'.*_db_sync\',\\n             \'.*_cron\', \'create_.*_wrapper\', \'.*_wait_bundle\',\\n             \'configure_.*\', \'.*_fix_perms\', \'.*_init_logs?\',\\n             \'.*_init_perm\', \'(nova|placement)_wait_for_.*\', \'nova_.*ensure_\',\\n             \'(swift_)?setup_.*\', \'mysql_data_ownership\', \'swift_copy_rings\',\\n             \'nova_statedir_owner\']\\n\\n\\nclass ExecuteError(Exception):\\n    def __init__(self, rc, msg):\\n        self.rc = rc\\n        self.msg = msg\\n        super().__init__()\\n\\n\\ndef execute(cmd, workdir: str = None,\\n            prev_proc: subprocess.Popen = None) -> subprocess.Popen:\\n    # Note(mmagr): When this script is executed by collectd-sensubility started\\n    #              via collectd the script has non-root permission but inherits\\n    #              environment from collectd with root permission. We need\\n    #              to avoid sensubility access /root when using podman-remote.\\n    #              See https://bugzilla.redhat.com/show_bug.cgi?id=2091076 for\\n    #              more info.\\n    proc_env = os.environ.copy()\\n    proc_env[\\\"HOME\\\"] = \\\"/tmp\\\"\\n    if type(cmd[0]) is list:  # multiple piped commands\\n        last = prev_proc\\n        for c in cmd:\\n            last = execute(c, workdir, last)\\n        return last\\n    else:  # single command\\n        inpipe = prev_proc.stdout if prev_proc is not None else None\\n        proc = subprocess.Popen(cmd, cwd=workdir, env=proc_env, stdin=inpipe,\\n                                stdout=subprocess.PIPE, stderr=subprocess.PIPE)\\n        if prev_proc is not None:\\n            prev_proc.stdout.close()\\n            prev_proc.stderr.close()\\n        return proc\\n\\n\\ndef get_health_from_status(status):\\n    healthy = status in (\'healthy\', \'running\')\\n    return int(healthy)\\n\\n\\ndef fetch_state_from_inspect(cont, fmt):\\n    proc = execute([\\n        [shutil.which(\'podman-remote\'),\\n           \'--url\', SOCKET, \'inspect\', cont[\\\"container\\\"]],\\n        [shutil.which(\'jq\'), \'.[] | %s\' % fmt]\\n    ])\\n    o, e = proc.communicate()\\n    if proc.returncode != 0:\\n        msg = \\\"Failed to fetch status of %s: %s\\\" % (cont, e.decode())\\n        raise ExecuteError(proc.returncode, msg)\\n\\n    item = json.loads(o.decode())\\n    item[\'status\'] = \'running\' if item[\'status\'] else \'stopped\'\\n    if len(item[\'healthy\']) > 0 and item[\'status\'] != \'stopped\':\\n        item[\'status\'] = item[\'healthy\']\\n\\n    item[\'healthy\'] = get_health_from_status(item[\'status\'])\\n    return item\\n\\n\\ndef fetch_state(item):\\n    if \'up \' in item[\'status\'].lower():\\n        item[\'status\'] = \'running\'\\n    if item[\'status\'] != \'running\':\\n        item[\'status\'] = \'stopped\'\\n\\n    match = RUNNING_REX.match(item[\'healthy\'])\\n    if match:\\n        health = match.group(\'health\')\\n    else:\\n        health = \'\'\\n    if health:\\n        item[\'status\'] = health.strip(\\\"()\\\")\\n\\n    item[\'healthy\'] = get_health_from_status(item[\'status\'])\\n    return item\\n\\n\\ndef fetch_container_health(ps_result, inspect_fmt):\\n\\n    def container_filter(item):\\n        for rx in [re.compile(i) for i in SKIP_LIST]:\\n            if rx.match(item[\\\"service\\\"]):\\n                return False\\n        return True\\n    try:\\n        containers = filter(container_filter, json.loads(ps_result))\\n    except json.decoder.JSONDecodeError:\\n        return 1, \\\"%s\\\\nFailed to parse above output.\\\" % ps_result\\n\\n    out = []\\n    for cont in containers:\\n        try:\\n            out.append(fetch_state(cont))\\n        except Exception:\\n            # fallback to slow inspect way in case of any error\\n            try:\\n                out.append(fetch_state_from_inspect(cont, inspect_fmt))\\n            except ExecuteError as ex:\\n                return ex.rc, ex.msg\\n    return 0, out\\n\\n\\nif __name__ == \\\"__main__\\\":\\n    proc = execute([shutil.which(\'podman-remote\'),\\n                    \'--url\', SOCKET, \'version\',\\n                    \'--format\', r\'{{.Server.Version}}\'])\\n    o, e = proc.communicate()\\n    try:\\n        if packaging.version.parse(o.decode().strip()) >= packaging.version.parse(\\\"4.0.0\\\"):\\n            inspect_fmt = BASE_FORMAT + \\\"healthy: .State.Health.Status}\\\"\\n        else:\\n            inspect_fmt = BASE_FORMAT + \\\"healthy: .State.Healthcheck.Status}\\\"\\n    except Exception:\\n        # keep podman-4.0.0+ format in case of version decoding error\\n        inspect_fmt = BASE_FORMAT + \\\"healthy: .State.Health.Status}\\\"\\n\\n    proc = execute([shutil.which(\'podman-remote\'), \'--url\', SOCKET,\\n                    \'ps\', \'--all\', \'--format\', PS_FORMAT])\\n    o, e = proc.communicate()\\n    if proc.returncode != 0:\\n        print(\\\"Failed to list containers:\\\\n%s\\\\n%s\\\" % (o.decode(), e.decode()))\\n        sys.exit(1)\\n\\n    rc, status = fetch_container_health(\\\"[%s]\\\" % o.decode().strip(\\\"\\\\n,\\\"), inspect_fmt)\\n    if rc != 0:\\n        print(\\\"Failed to inspect containers:\\\\n%s\\\" % status)\\n        sys.exit(rc)\\n    print(json.dumps(status))\\n\"}}, \"container_puppet_tasks\": {}, \"host_prep_tasks\": [{\"name\": \"Run firewall role\", \"include_role\": {\"name\": \"tripleo_firewall\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/collectd\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/container-user-scripts/\", \"setype\": \"container_file_t\", \"mode\": \"0755\"}]}, {\"name\": \"import provision_mcelog\", \"include_role\": {\"name\": \"tripleo_provision_mcelog\"}, \"when\": false}, {\"name\": \"allow logrotate to read inside containers\", \"seboolean\": {\"name\": \"logrotate_read_inside_containers\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}, {\"name\": \"get parameters\", \"set_fact\": {\"cert_path\": \"/etc/pki/tls/private/overcloud_endpoint.pem\", \"cert_content\": \"\", \"chain_content\": \"\", \"key_content\": \"\"}, \"no_log\": \"{{ hide_sensitive_logs | bool }}\"}, {\"name\": \"manage certificate\", \"when\": [\"cert_content is defined\", \"cert_content != \'\'\"], \"block\": [{\"name\": \"get DeployedSSLCertificatePath attributes\", \"register\": \"attr_cert_path\", \"stat\": {\"path\": \"{{cert_path}}\"}}, {\"name\": \"set is_haproxy_bootstrap_node fact\", \"set_fact\": \"is_haproxy_bootstrap_node={{haproxy_short_bootstrap_node_name | lower == ansible_facts[\'hostname\'] | lower}}\", \"when\": [\"haproxy_short_bootstrap_node_name|default(false)\"]}, {\"name\": \"get haproxy status\", \"register\": \"haproxy_state\", \"systemd\": {\"name\": \"haproxy\"}}, {\"name\": \"get pacemaker status\", \"register\": \"pacemaker_state\", \"systemd\": {\"name\": \"pacemaker\"}}, {\"name\": \"get docker status\", \"register\": \"docker_state\", \"systemd\": {\"name\": \"docker\"}}, {\"name\": \"get container_id\", \"when\": [\"docker_state.status.ActiveState == \'active\' or container_cli == \'podman\'\", \"attr_cert_path.stat.exists\", \"attr_cert_path.stat.isdir == False\"], \"command\": \"{{ container_cli }} ps -q -f name=\'^haproxy(-bundle)?\'\", \"register\": \"container_id\"}, {\"name\": \"get pcs resource name for haproxy container\", \"when\": [\"bootstrap_node is defined\", \"is_haproxy_bootstrap_node\", \"pacemaker_state.status.ActiveState == \'active\'\", \"attr_cert_path.stat.exists\", \"attr_cert_path.stat.isdir\"], \"shell\": \"pcs status resources | sed -n \'s/^.*container.*: \\\\(haproxy.*\\\\) .*/\\\\1/p\'\\n\", \"register\": \"pacemaker_resource\"}, {\"name\": \"remove DeployedSSLCertificatePath if is dir\", \"when\": \"attr_cert_path.stat.isdir is defined and attr_cert_path.stat.isdir\", \"file\": {\"path\": \"{{cert_path}}\", \"state\": \"absent\"}}, {\"name\": \"push certificate content\", \"no_log\": \"{{ hide_sensitive_logs | bool }}\", \"copy\": {\"dest\": \"{{cert_path}}\", \"mode\": 288, \"owner\": \"root\", \"content\": \"{{cert_content}}\\n{{chain_content}}\\n{{key_content}}\\n\"}}, {\"name\": \"BM haproxy non-pacemaker context\", \"when\": \"haproxy_state.status.ActiveState == \'active\'\", \"block\": [{\"name\": \"set certificate ownership\", \"file\": {\"path\": \"{{cert_path}}\", \"group\": \"haproxy\"}}, {\"name\": \"reload haproxy if enabled\", \"service\": {\"name\": \"haproxy\", \"state\": \"reloaded\"}}]}, {\"name\": \"restart pacemaker resource for haproxy\", \"when\": [\"pacemaker_resource is defined\", \"pacemaker_resource.stdout is defined\", \"pacemaker_resource.stdout != \'\'\"], \"command\": \"pcs resource restart \\\"{{pacemaker_resource.stdout}}\\\"\"}, {\"name\": \"dedicated part for containers\", \"when\": [\"container_id is defined\", \"container_id.stdout is defined\", \"container_id.stdout != \'\'\"], \"block\": [{\"name\": \"copy certificate, chgrp, restart haproxy\", \"shell\": \"set -e\\nif {{ container_cli }} ps -f \\\"id={{ item }}\\\" --format \\\"{{ \'{{\' }}.Names{{ \'}}\' }}\\\" | grep -q \\\"^haproxy-bundle\\\"; then\\n  tar -c {{ cert_path }} | {{container_cli}} exec -i {{ item }} tar -C / -xv\\nelse\\n  {{ container_cli }} cp {{ cert_path }} {{ item }}:{{ cert_path }}\\nfi\\n{{ container_cli }} exec --user root {{ item }} chgrp haproxy {{ cert_path }}\\n{{ container_cli }} kill --signal=HUP {{ item }}\\n\", \"register\": \"container_kill_result\", \"failed_when\": [\"container_kill_result.rc != 0\", \"(\\\"no such container\\\" not in container_kill_result.stderr)\", \"(\\\"container state improper\\\" not in container_kill_result.stderr)\"], \"with_items\": \"{{ container_id.stdout.split(\'\\n\') }}\"}]}]}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/haproxy\", \"setype\": \"var_log_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/haproxy\", \"setype\": \"container_file_t\"}]}, {\"name\": \"Run puppet on the host to apply IPtables rules\", \"no_log\": true, \"shell\": \"puppet apply {{ (puppet_debug|bool) | ternary(\'--debug --verbose\', \'\') }} --detailed-exitcodes --summarize --color=false \\\\\\n    --modulepath \'{{ puppet_modulepath }}\' --tags \'{{ puppet_tags }}\' -e \'{{ puppet_execute }}\'\\n\", \"register\": \"puppet_host_outputs\", \"changed_when\": \"puppet_host_outputs.rc == 2\", \"failed_when\": false, \"vars\": {\"puppet_execute\": \"if hiera(\'enable_load_balancer\', true) { class {\'::tripleo::haproxy\': use_internal_certificates => false, manage_firewall => hiera(\'tripleo::firewall::manage_firewall\', true), }}\", \"puppet_tags\": \"tripleo::firewall::rule\", \"puppet_modulepath\": \"/etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules\", \"puppet_debug\": false}}, {\"name\": \"Debug output for task: Run puppet on the host to apply IPtables rules\", \"debug\": {\"var\": \"puppet_host_outputs.stdout_lines | default([]) | union(puppet_host_outputs.stderr_lines | default([]))\"}, \"when\": [\"not (ansible_check_mode | bool)\", \"puppet_host_outputs.rc is defined\"], \"failed_when\": \"puppet_host_outputs.rc not in [0, 2]\"}, {\"name\": \"create fcontext entry for iscsi\", \"community.general.sefcontext\": {\"target\": \"{{ item.path }}(/.*)?\", \"setype\": \"{{ item.setype }}\", \"state\": \"present\"}, \"with_items\": [{\"path\": \"/etc/iscsi\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/target\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/iscsi\", \"setype\": \"container_file_t\"}]}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\"}, \"with_items\": [{\"path\": \"/etc/iscsi\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/target\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/iscsi\", \"setype\": \"container_file_t\"}]}, {\"name\": \"stat /lib/systemd/system/iscsid.socket\", \"stat\": \"path=/lib/systemd/system/iscsid.socket\", \"register\": \"stat_iscsid_socket\"}, {\"name\": \"Stop and disable iscsid.socket service\", \"service\": \"name=iscsid.socket state=stopped enabled=no\", \"when\": \"stat_iscsid_socket.stat.exists\"}, {\"name\": \"Check if iscsi.service is enabled\", \"command\": \"systemctl is-enabled --quiet iscsi.service\", \"failed_when\": false, \"register\": \"iscsi_service_enabled_result\"}, {\"name\": \"Stop iscsi.service\", \"service\": \"name=iscsi.service state=stopped enabled=no\", \"when\": [\"iscsi_service_enabled_result is changed\", \"iscsi_service_enabled_result.rc == 0\"]}, {\"include_role\": {\"name\": \"tripleo_kernel\"}}, {\"name\": \"create persistent logs directory\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/metrics_qdr\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/metrics_qdr\", \"setype\": \"container_file_t\"}]}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/mysql\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/mysql\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/log/mariadb\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"setype\": \"{{ item.setype }}\", \"state\": \"directory\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/nova\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}, {\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/nova\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/nova-metadata\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}, {\"name\": \"ensure qemu group is present on the host\", \"group\": {\"name\": \"qemu\", \"gid\": 107, \"state\": \"present\"}}, {\"name\": \"ensure qemu user is present on the host\", \"user\": {\"name\": \"qemu\", \"uid\": 107, \"group\": \"qemu\", \"state\": \"present\", \"shell\": \"/sbin/nologin\", \"comment\": \"qemu user\"}}, {\"name\": \"create fcontext for rabbitmq data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/rabbitmq(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/lib/rabbitmq\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/log/containers/rabbitmq\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}, {\"name\": \"stop the Erlang port mapper on the host and make sure it cannot bind to the port used by container\", \"shell\": \"echo \'export ERL_EPMD_ADDRESS=127.0.0.1\' > /etc/rabbitmq/rabbitmq-env.conf\\necho \'export ERL_EPMD_PORT=4370\' >> /etc/rabbitmq/rabbitmq-env.conf\\nfor pid in $(pgrep epmd --ns 1 --nslist pid); do kill $pid; done\\n\"}, {\"name\": \"Make sure python3-novaclient is installed when IHA is enabled\", \"package\": {\"name\": \"python3-novaclient\", \"state\": \"present\"}, \"when\": false}, {\"name\": \"Remove existing entries from logind conf\", \"ansible.builtin.lineinfile\": {\"path\": \"/etc/systemd/logind.conf\", \"regexp\": \"^\\\\s*#?\\\\s*HandlePowerKey\\\\s*=.*\", \"state\": \"absent\"}}, {\"name\": \"Make sure systemd-logind ignores power off\", \"ansible.builtin.lineinfile\": {\"path\": \"/etc/systemd/logind.conf\", \"regexp\": \"^#?HandlePowerKey\", \"line\": \"HandlePowerKey=ignore\"}}, {\"name\": \"Restart systemd-logind\", \"ansible.builtin.service\": {\"name\": \"systemd-logind\", \"state\": \"restarted\"}}, {\"name\": \"Gather service_facts on pacemaker_bootstrap_node\", \"ansible.builtin.service_facts\": null, \"when\": [\"{{(pacemaker_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower)|bool}}\", false]}, {\"name\": \"Check and eventually delete duplicate constraints (bootstrap node)\", \"become\": true, \"shell\": \"COUNT=$(cibadmin --query | xmllint --xpath \'//rsc_location[@rsc=\\\"stonith-fence_compute-fence-nova\\\"]/@id\' - |grep -oP \'(?<=[\\\"])[^\\\"]*\' -c)\\nif [[ $COUNT > 1 ]]; then\\n    echo \\\"Detected $COUNT duplicate constraints, deleting them\\\"\\n    # assemble string with current list of computes\\n    GOOD=$(echo location-stonith-fence_compute-fence-nova-$(hiera pacemaker_remote_short_node_names |grep -oP \'\\\".*?\\\"\' |tr -d \'\\\"\'|tr -d \'\\\\n\' )--10000)\\n    # delete old constraints\\n    for i in $(cibadmin --query | xmllint --xpath \'//rsc_location[@rsc=\\\"stonith-fence_compute-fence-nova\\\"]/@id\' - |grep -oP \'(?<=[\\\"])[^\\\"]*\' |grep -v $GOOD ); do pcs constraint delete $i ; done\\nelse\\n    echo \\\"No duplicate constraint found\\\"\\nfi\\n\", \"when\": [\"{{(pacemaker_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower)|bool}}\", false, \"ansible_facts[\'services\'][\'pacemaker.service\'][\'state\'] == \'running\'\"]}, {\"name\": \"Install and configure Podman\", \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": [], \"container_registry_login\": false, \"container_registry_logins\": {}, \"container_registry_logins_json\": {}, \"container_default_pids_limit\": 4096, \"container_events_logger_mechanism\": \"journald\"}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}, {\"name\": \"Configure tripleo_container_manage to generate systemd drop-in dependencies\", \"copy\": {\"dest\": \"/etc/sysconfig/podman_drop_in\", \"content\": \"This file makes tripleo_container_manage generate additional systemd\\ndependencies for containers that have special\\nstart/stop ordering constraints. It ensures that\\nthose constraints are enforced on reboot/shutdown.\\n\"}}, {\"name\": \"create persistent logs directory for rsyslog\", \"file\": {\"path\": \"/var/log/containers/rsyslog\", \"state\": \"directory\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}}, {\"name\": \"create persistent state directory for rsyslog\", \"file\": {\"path\": \"/var/lib/rsyslog.container\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}, {\"include_role\": {\"name\": \"tripleo_sshd\"}, \"vars\": {\"tripleo_sshd_server_options\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"tripleo_sshd_password_authentication\": \"no\", \"tripleo_sshd_banner_enabled\": false, \"tripleo_sshd_banner_text\": \"\", \"tripleo_sshd_motd_enabled\": false, \"tripleo_sshd_message_of_the_day\": \"\"}}, {\"name\": \"Check for NTP service\", \"shell\": \"systemctl is-active ntpd.service || systemctl is-enabled ntpd.service\", \"failed_when\": false, \"become\": true, \"register\": \"ntp_service_check\"}, {\"name\": \"Disable NTP before configuring Chrony\", \"service\": {\"name\": \"ntpd\", \"state\": \"stopped\", \"enabled\": false}, \"when\": [\"ntp_service_check.rc is defined\", \"ntp_service_check.rc == 0\"]}, {\"name\": \"Install, Configure and Run Chrony\", \"include_role\": {\"name\": \"chrony\"}}, {\"name\": \"Force NTP sync\", \"command\": \"chronyc makestep\"}, {\"name\": \"Ensure system is NTP time synced\", \"command\": \"chronyc waitsync 30\"}, {\"name\": \"Run timezone role\", \"include_role\": {\"name\": \"tripleo_timezone\"}, \"vars\": {\"tripleo_timezone\": \"UTC\"}}, {\"name\": \"Notice - ctlplane subnet is set\", \"debug\": {\"msg\": \"CIDRs found in the ctlplane network tags.\\n\"}}, {\"include_role\": {\"name\": \"tuned\"}}], \"pre_deploy_step_tasks\": []}, \"CellControllerCompute\": {\"service_names\": [], \"monitoring_subscriptions\": [], \"config_settings\": {}, \"global_config_settings\": {}, \"service_config_settings\": {}, \"step_config\": \"\", \"deploy_steps_tasks\": [], \"external_deploy_tasks\": [], \"external_post_deploy_tasks\": [], \"external_update_tasks\": [], \"external_upgrade_tasks\": [], \"scale_tasks\": [], \"pre_upgrade_rolling_tasks\": [], \"upgrade_tasks\": [], \"post_upgrade_tasks\": [], \"update_tasks\": [], \"post_update_tasks\": [], \"upgrade_batch_tasks\": [], \"service_metadata_settings\": null, \"ansible_group_vars\": {\"ansible_async_dir\": \"/tmp/.ansible_async\"}, \"keystone_resources\": {}, \"firewall_rules\": {}, \"firewall_frontend_rules\": {}, \"firewall_ssl_frontend_rules\": {}, \"firewall_edge_frontend_rules\": {}, \"firewall_edge_ssl_frontend_rules\": null, \"puppet_config\": [], \"kolla_config\": {}, \"docker_config\": {}, \"container_config_scripts\": {}, \"container_puppet_tasks\": {}, \"host_prep_tasks\": [], \"pre_deploy_step_tasks\": []}, \"Compute\": {\"service_names\": [\"boot_params_service\", \"ca_certs\", \"collectd\", \"ceilometer_agent_compute\", \"ceilometer_agent_ipmi\", \"iscsid\", \"kernel\", \"metrics_qdr\", \"mysql_client\", \"nova_compute\", \"nova_libvirt\", \"nova_libvirt_guests\", \"nova_migration_target\", \"logrotate_crond\", \"podman\", \"rsyslog\", \"snmp\", \"sshd\", \"chrony\", \"timezone\", \"tripleo_firewall\", \"tripleo_packages\", \"tuned\", \"ovn_controller\", \"ovn_metadata\"], \"monitoring_subscriptions\": [\"overcloud-ceilometer-agent-compute\", \"overcloud-ceilometer-agent-ipmi\", \"overcloud-qdr\", \"overcloud-nova-compute\", \"overcloud-nova-libvirt\", \"overcloud-ovn-metadata\"], \"config_settings\": {\"tripleo::trusted_cas::ca_map\": {}, \"tripleo::profile::base::metrics::collectd::enable_file_logging\": true, \"collectd::plugin::logfile::log_file\": \"/var/log/collectd/collectd.log\", \"collectd::manage_repo\": false, \"collectd::purge\": true, \"collectd::recurse\": true, \"collectd::purge_config\": true, \"collectd::minimum_version\": \"5.7\", \"collectd::interval\": 120, \"collectd::plugin::unixsock::socketgroup\": \"root\", \"collectd::plugin::unixsock::socketfile\": \"/run/collectd-socket\", \"collectd::plugin::unixsock::deletesocket\": true, \"collectd::plugin::cpu::reportbycpu\": true, \"collectd::plugin::cpu::reportbystate\": true, \"collectd::plugin::cpu::reportnumcpu\": false, \"collectd::plugin::cpu::valuespercentage\": true, \"collectd::plugin::df::ignoreselected\": true, \"collectd::plugin::df::reportbydevice\": true, \"collectd::plugin::df::fstypes\": [\"xfs\"], \"collectd::plugin::load::reportrelative\": true, \"collectd::plugin::virt::connection\": \"qemu:///system\", \"collectd::plugin::virt::extra_stats\": \"pcpu cpu_util vcpu memory disk disk_err disk_allocation disk_capacity disk_physical domain_state job_stats_background perf\", \"collectd::plugin::virt::hostname_format\": \"hostname\", \"tripleo.collectd.plugins.collectd\": [\"cpu\", \"df\", \"disk\", \"hugepages\", \"interface\", \"load\", \"memory\", \"unixsock\", \"uptime\"], \"tripleo::profile::base::metrics::collectd::amqp_transport_name\": \"metrics\", \"tripleo::profile::base::metrics::collectd::amqp_address\": \"collectd\", \"tripleo::profile::base::metrics::collectd::amqp_instances\": {}, \"tripleo::profile::base::metrics::collectd::amqp_retry_delay\": 1, \"tripleo::profile::base::metrics::collectd::amqp_host\": \"%{hiera(\'internal_api\')}\", \"tripleo::profile::base::metrics::collectd::amqp_port\": 5666, \"tripleo::profile::base::metrics::collectd::amqp_user\": \"guest\", \"tripleo::profile::base::metrics::collectd::amqp_password\": \"guest\", \"ceilometer::logging::debug\": true, \"ceilometer::agent::polling::manage_polling\": false, \"ceilometer::agent::service_credentials::password\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"ceilometer::agent::service_credentials::auth_url\": \"http://172.17.0.130:5000\", \"ceilometer::agent::service_credentials::region_name\": \"regionOne\", \"ceilometer::agent::service_credentials::project_name\": \"service\", \"ceilometer::agent::service_credentials::user_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::auth_project_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::interface\": \"internalURL\", \"ceilometer::notification_driver\": [\"noop\"], \"ceilometer::amqp_rpc_address_prefix\": \"\", \"ceilometer::amqp_notify_address_prefix\": \"\", \"ceilometer::telemetry_secret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"ceilometer::snmpd_readonly_username\": \"ro_snmp_user\", \"ceilometer::snmpd_readonly_user_password\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"ceilometer::host\": \"%{hiera(\'fqdn_canonical\')}\", \"ceilometer::rabbit_heartbeat_in_pthread\": false, \"ceilometer::cache::enabled\": true, \"ceilometer::cache::tls_enabled\": false, \"ceilometer::cache::backend\": \"dogpile.cache.memcached\", \"ceilometer::agent::polling::instance_discovery_method\": \"libvirt_metadata\", \"ceilometer_redis_password\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"compute_namespace\": true, \"ceilometer::agent::polling::tenant_name_discovery\": false, \"ipmi_namespace\": true, \"tripleo::profile::base::iscsid::chap_algs\": \"SHA3-256,SHA256,SHA1,MD5\", \"tripleo::profile::base::metrics::qdr::listener_addr\": \"%{hiera(\'internal_api\')}\", \"tripleo::haproxy::metrics_qdr\": false, \"tripleo::profile::base::metrics::qdr::listener_port\": 5666, \"tripleo::profile::base::metrics::qdr::username\": \"guest\", \"tripleo::profile::base::metrics::qdr::password\": \"guest\", \"tripleo::profile::base::metrics::qdr::connectors\": [], \"tripleo::profile::base::metrics::qdr::addresses\": [{\"prefix\": \"collectd\", \"distribution\": \"multicast\"}, {\"prefix\": \"ceilometer/metering.sample\", \"distribution\": \"multicast\"}, {\"prefix\": \"ceilometer/event.sample\", \"distribution\": \"multicast\"}], \"tripleo::profile::base::metrics::qdr::autolink_addresses\": [], \"tripleo::profile::base::metrics::qdr::listener_require_ssl\": false, \"tripleo::profile::base::metrics::qdr::listener_require_encrypt\": false, \"tripleo::profile::base::metrics::qdr::listener_sasl_mech\": \"ANONYMOUS\", \"tripleo::profile::base::metrics::qdr::listener_ssl_cert_db\": \"/etc/ipa/ca.crt\", \"tripleo::profile::base::metrics::qdr::listener_ssl_cert_file\": \"/etc/pki/tls/certs/metrics_qdr.crt\", \"tripleo::profile::base::metrics::qdr::listener_ssl_key_file\": \"/etc/pki/tls/private/metrics_qdr.key\", \"tripleo::profile::base::metrics::qdr::listener_ssl_pw_file\": \"\", \"tripleo::profile::base::metrics::qdr::listener_ssl_password\": \"\", \"tripleo::profile::base::metrics::qdr::listener_trusted_certs\": \"\", \"qdr::log_enable\": \"info+\", \"qdr::log_output\": \"/var/log/qdrouterd/metrics_qdr.log\", \"qdr::listener_auth_peer\": false, \"tripleo::profile::base::metrics::qdr::ssl_profiles\": [{\"name\": \"sslProfile\"}], \"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": \"%{hiera(\'internal_api\')}\", \"tripleo::profile::base::database::mysql::client::enable_ssl\": false, \"tripleo::profile::base::database::mysql::client::ssl_ca\": \"/etc/ipa/ca.crt\", \"nova::my_ip\": \"%{hiera(\'internal_api\')}\", \"nova::rabbit_use_ssl\": \"False\", \"nova::keystone::service_user::send_service_user_token\": true, \"nova::keystone::service_user::project_name\": \"service\", \"nova::keystone::service_user::password\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"nova::keystone::service_user::auth_url\": \"http://172.17.0.130:5000\", \"nova::keystone::service_user::region_name\": \"regionOne\", \"nova::placement::project_name\": \"service\", \"nova::placement::password\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"nova::placement::auth_url\": \"http://172.17.0.130:5000\", \"nova::placement::region_name\": \"regionOne\", \"nova::placement::valid_interfaces\": \"internal\", \"nova::os_region_name\": \"regionOne\", \"nova::logging::debug\": true, \"nova::purge_config\": false, \"nova::network::neutron::project_name\": \"service\", \"nova::network::neutron::username\": \"neutron\", \"nova::network::neutron::region_name\": \"regionOne\", \"nova::dhcp_domain\": \"\", \"nova::network::neutron::password\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"nova::network::neutron::auth_url\": \"http://172.17.0.130:5000/v3\", \"nova::network::neutron::valid_interfaces\": \"internal\", \"nova::glance::valid_interfaces\": \"internal\", \"nova::rabbit_heartbeat_timeout_threshold\": 60, \"nova::cinder_catalog_info\": \"volumev3:cinderv3:internalURL\", \"nova::host\": \"%{hiera(\'fqdn_canonical\')}\", \"nova::notify_on_state_change\": \"vm_and_task_state\", \"nova::notification_driver\": [\"noop\"], \"nova::notification_format\": \"unversioned\", \"nova::network::neutron::auth_type\": \"v3password\", \"nova::db::database_db_max_retries\": -1, \"nova::db::database_max_retries\": -1, \"nova::network::neutron::ovs_bridge\": \"br-int\", \"nova::compute::sync_power_state_interval\": 600, \"nova_is_additional_cell\": true, \"nova::cross_az_attach\": true, \"nova::cache::enabled\": true, \"nova::cache::tls_enabled\": false, \"nova::cache::backend\": \"dogpile.cache.memcached\", \"nova::rabbit_heartbeat_in_pthread\": false, \"nova::ovsdb_connection\": \"\", \"nova::compute::vcpu_pin_set\": [], \"nova::compute::cpu_shared_set\": [], \"nova::compute::cpu_dedicated_set\": [], \"nova::compute::reserved_host_memory\": 512, \"nova::compute::reserved_huge_pages\": [], \"nova::compute::neutron_physnets_numa_nodes_mapping\": {}, \"nova::compute::neutron_tunnel_numa_nodes\": [], \"nova::compute::resume_guests_state_on_host_boot\": false, \"nova::compute::libvirt::rx_queue_size\": 512, \"nova::compute::libvirt::tx_queue_size\": 512, \"nova::compute::libvirt::file_backed_memory\": 0, \"nova::compute::libvirt::volume_use_multipath\": false, \"nova::compute::libvirt::hw_machine_type\": \"x86_64=pc-q35-rhel9.0.0\", \"nova::compute::mkisofs_cmd\": \"mkisofs\", \"compute_enable_ksm\": false, \"nova::compute::rbd::libvirt_images_rbd_pool\": \"vms\", \"tripleo::profile::base::nova::compute::nova_nfs_enabled\": false, \"nfs_backend_enable\": false, \"nfs_share\": \"\", \"nfs_options\": \"context=system_u:object_r:nfs_t:s0\", \"nfs_vers\": \"4.2\", \"nova::compute::libvirt::num_pcie_ports\": 16, \"nova::compute::libvirt::mem_stats_period_seconds\": 10, \"nova::compute::rbd::ephemeral_storage\": false, \"resume_guests_state_on_host_boot\": false, \"nova::cpu_allocation_ratio\": 0.0, \"nova::ram_allocation_ratio\": 1.0, \"nova::disk_allocation_ratio\": 0.0, \"nova::compute::max_disk_devices_to_attach\": -1, \"nova::compute::libvirt::pmem_namespaces\": \"\", \"nova_pmem_namespaces\": \"\", \"nova::compute::image_cache::remove_unused_original_minimum_age_seconds\": 86400, \"nova::compute::libvirt::swtpm_enabled\": false, \"nova::compute::vgpu::vgpu_types_device_addresses_mapping\": {}, \"compute_disable_irqbalance\": false, \"nova::compute::libvirt::cpu_mode\": \"host-model\", \"nova::compute::libvirt::cpu_models\": [], \"nova::compute::libvirt::cpu_model_extra_flags\": \"\", \"nova_compute_opt_volumes\": [], \"nova_compute_startup_delay\": 0, \"nova_compute_opt_env_vars\": {}, \"nova::workarounds::never_download_image_if_on_rbd\": false, \"nova::compute::image_type_exclude_list\": [], \"nova_permit_post_copy\": true, \"nova_permit_auto_converge\": true, \"nova_libvirt_max_queues\": 0, \"nova_glance_enable_rbd_download\": false, \"nova_glance_rbd_download_multistore_id\": \"\", \"nova::compute::force_raw_images\": true, \"nova::compute::use_cow_images\": true, \"nova::compute::libvirt::preallocate_images\": \"none\", \"nova::compute::image_cache::manager_interval\": 2400, \"nova::compute::image_cache::remove_unused_base_images\": true, \"nova::compute::image_cache::remove_unused_resized_minimum_age_seconds\": 3600, \"nova::compute::image_cache::precache_concurrency\": 1, \"nova::compute::provider::custom_inventories\": {}, \"nova::compute::rbd::libvirt_images_rbd_glance_copy_poll_interval\": 15, \"nova::compute::rbd::libvirt_images_rbd_glance_copy_timeout\": 600, \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"nova::compute::libvirt::manage_libvirt_services\": false, \"nova::compute::pci::passthrough\": \"\", \"nova::compute::libvirt::migration_support\": false, \"tripleo::profile::base::nova::migration::client::nova_compute_enabled\": true, \"tripleo::profile::base::nova::migration::client::ssh_private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"tripleo::profile::base::nova::migration::client::ssh_port\": 2022, \"nova::compute::rbd::libvirt_images_rbd_glance_store_name\": \"default_backend\", \"nova::compute::rbd::libvirt_images_rbd_ceph_conf\": \"/etc/ceph/ceph.conf\", \"nova::compute::rbd::libvirt_rbd_user\": \"openstack\", \"nova::compute::rbd::rbd_keyring\": \"client.openstack\", \"tripleo::profile::base::nova::compute::cinder_nfs_backend\": false, \"rbd_persistent_storage\": false, \"rbd_disk_cachemodes\": [\"network=writeback\"], \"nova::cinder::username\": \"cinder\", \"nova::cinder::auth_type\": \"v3password\", \"nova::cinder::project_name\": \"service\", \"nova::cinder::password\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"nova::cinder::auth_url\": \"http://172.17.0.130:5000/v3\", \"nova::cinder::region_name\": \"regionOne\", \"nova::compute::rbd::libvirt_rbd_secret_key\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"nova::compute::rbd::libvirt_rbd_secret_uuid\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"nova::compute::instance_usage_audit\": true, \"nova::compute::instance_usage_audit_period\": \"hour\", \"nova::compute::consecutive_build_service_disable_threshold\": \"10\", \"nova::compute::live_migration_wait_for_vif_plug\": true, \"nova::migration::libvirt::live_migration_permit_post_copy\": true, \"nova::migration::libvirt::live_migration_permit_auto_converge\": true, \"nova::migration::libvirt::live_migration_tunnelled\": false, \"nova::compute::vncserver_proxyclient_address\": \"%{hiera(\'internal_api\')}\", \"nova::compute::vncproxy_host\": \"172.21.0.80\", \"nova::vncproxy::common::vncproxy_protocol\": \"http\", \"nova::vncproxy::common::vncproxy_host\": \"172.21.0.83\", \"nova::vncproxy::common::vncproxy_port\": \"6080\", \"nova::compute::verify_glance_signatures\": false, \"nova::workarounds::disable_compute_service_check_for_ffu\": false, \"vhostuser_socket_group\": \"qemu\", \"nova_libvirt_opt_volumes\": [], \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"nova::compute::libvirt::log_outputs\": \"1:file:/var/log/libvirt/libvirtd.log\", \"nova::compute::libvirt::virtlogd::log_outputs\": \"1:file:/var/log/libvirt/virtlogd.log\", \"nova::compute::libvirt::virtsecretd::log_outputs\": \"1:file:/var/log/libvirt/virtsecretd.log\", \"nova::compute::libvirt::virtnodedevd::log_outputs\": \"1:file:/var/log/libvirt/virtnodedevd.log\", \"nova::compute::libvirt::virtqemud::log_outputs\": \"1:file:/var/log/libvirt/virtqemud.log\", \"nova::compute::libvirt::virtproxyd::log_outputs\": \"1:file:/var/log/libvirt/virtproxyd.log\", \"nova::compute::libvirt::virtstoraged::log_outputs\": \"1:file:/var/log/libvirt/virtstoraged.log\", \"nova::compute::libvirt::qemu::memory_backing_dir\": \"\", \"tripleo::profile::base::nova::virtlogd_wrapper::enable_wrapper\": true, \"tripleo::profile::base::nova::virtlogd_wrapper::virtlogd_process_wrapper\": \"/var/lib/container-config-scripts/virtlogd_wrapper\", \"tripleo::profile::base::nova::virtlogd_wrapper::virtlogd_image\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"tripleo::profile::base::nova::virtlogd_wrapper::debug\": true, \"tripleo::profile::base::nova::compute_libvirt_shared::nova_rbd_ceph_conf_path\": \"/var/lib/tripleo-config/ceph\", \"tripleo::profile::base::nova::migration::client::libvirt_enabled\": true, \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\", \"nova::compute::libvirt::enabled_perf_events\": [], \"nova::compute::libvirt::qemu::configure_qemu\": true, \"nova::compute::libvirt::qemu::max_files\": 32768, \"nova::compute::libvirt::qemu::max_processes\": 131072, \"nova::migration::qemu::configure_qemu\": true, \"nova::migration::qemu::migration_port_min\": 61152, \"nova::migration::qemu::migration_port_max\": 61215, \"nova::compute::libvirt::vncserver_listen\": \"%{hiera(\'internal_api\')}\", \"nova::compute::libvirt::log_filters\": \"1:libvirt 1:qemu 1:conf 1:security 3:event 3:json 3:file 3:object 1:util\", \"nova::compute::libvirt::virtlogd::log_filters\": \"1:logging 4:object 4:json 4:event 1:util\", \"nova::compute::libvirt::virtsecretd::log_filters\": \"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\", \"nova::compute::libvirt::virtnodedevd::log_filters\": \"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\", \"nova::compute::libvirt::virtstoraged::log_filters\": \"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\", \"nova::compute::libvirt::virtqemud::log_filters\": \"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\", \"nova::compute::libvirt::virtproxyd::log_filters\": \"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\", \"tripleo::profile::base::nova::libvirt::modular_libvirt\": true, \"nova::compute::libvirt::services::modular_libvirt\": true, \"nova::compute::libvirt::modular_libvirt\": true, \"nova::migration::libvirt::modular_libvirt\": true, \"nova::migration::libvirt::live_migration_inbound_addr\": \"%{hiera(\'fqdn_internal_api\')}\", \"tripleo::profile::base::nova::compute::libvirt_guests::enabled\": false, \"nova::compute::libvirt_guests::shutdown_timeout\": \"300\", \"tripleo::profile::base::sshd::bannertext\": \"\", \"tripleo::profile::base::sshd::motd\": \"\", \"tripleo::profile::base::sshd::options\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"tripleo::profile::base::sshd::password_authentication\": \"no\", \"tripleo::profile::base::nova::migration::target::ssh_authorized_keys\": [\"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"], \"tripleo::profile::base::nova::migration::target::ssh_localaddrs\": [\"%{hiera(\'cold_migration_ssh_inbound_addr\')}\", \"%{hiera(\'live_migration_ssh_inbound_addr\')}\"], \"live_migration_ssh_inbound_addr\": \"%{hiera(\'internal_api\')}\", \"cold_migration_ssh_inbound_addr\": \"%{hiera(\'internal_api\')}\", \"tripleo::profile::base::sshd::port\": [22], \"tripleo::profile::base::logging::logrotate::maxsize\": \"10M\", \"tripleo::profile::base::logging::logrotate::rotation\": \"daily\", \"tripleo::profile::base::logging::logrotate::rotate\": \"14\", \"tripleo::profile::base::logging::logrotate::purge_after_days\": \"14\", \"tripleo::profile::base::logging::logrotate::dateext\": false, \"rsyslog::server::global_config\": {\"WorkDirectory\": {\"type\": \"legacy\", \"target\": \"00_rsyslog.conf\", \"value\": \"/var/lib/rsyslog\"}, \"MaxMessageSize\": {\"type\": \"legacy\", \"target\": \"00_rsyslog.conf\", \"value\": \"32k\"}}, \"rsyslog::confdir\": \"/etc/rsyslog.d\", \"rsyslog::package_name\": \"rsyslog\", \"rsyslog::package_version\": \"installed\", \"rsyslog::manage_package\": true, \"rsyslog::manage_confdir\": true, \"rsyslog::purge_config_files\": true, \"rsyslog::override_default_config\": true, \"rsyslog::config_file\": \"/etc/rsyslog.conf\", \"rsyslog::manage_service\": true, \"rsyslog::service_name\": \"rsyslog\", \"rsyslog::service_status\": \"running\", \"rsyslog::service_enabled\": true, \"rsyslog::external_service\": false, \"rsyslog::use_upstream_repo\": false, \"rsyslog::feature_packages\": [\"rsyslog-elasticsearch\", \"rsyslog-mmnormalize\"], \"rsyslog::global_config_priority\": 10, \"rsyslog::module_load_priority\": 20, \"rsyslog::input_priority\": 30, \"rsyslog::main_queue_priority\": 40, \"rsyslog::parser_priority\": 45, \"rsyslog::template_priority\": 50, \"rsyslog::filter_priority\": 55, \"rsyslog::action_priority\": 60, \"rsyslog::ruleset_priority\": 65, \"rsyslog::lookup_table_priority\": 70, \"rsyslog::legacy_config_priority\": 80, \"rsyslog::custom_priority\": 90, \"rsyslog::target_file\": \"50_openstack_logs.conf\", \"rsyslog::server::modules\": {\"imfile\": {}, \"omelasticsearch\": {}, \"omamqp1\": {}}, \"rsyslog::server::templates\": {\"rsyslog-node-index\": {\"type\": \"list\", \"list_descriptions\": [{\"constant\": {\"value\": \"%{hiera(\'fqdn_canonical\')}-\"}}, {\"property\": {\"name\": \"timereported\", \"dateFormat\": \"year\"}}, {\"constant\": {\"value\": \".\"}}, {\"property\": {\"name\": \"timereported\", \"dateFormat\": \"month\"}}, {\"constant\": {\"value\": \".\"}}, {\"property\": {\"name\": \"timereported\", \"dateFormat\": \"day\"}}]}, \"rsyslog-record\": {\"type\": \"list\", \"options\": {\"jsonf\": \"on\"}, \"list_descriptions\": [{\"property\": {\"outname\": \"@timestamp\", \"name\": \"timereported\", \"dateFormat\": \"rfc3339\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"host\", \"name\": \"hostname\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"severity\", \"name\": \"syslogseverity\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"facility\", \"name\": \"syslogfacility-text\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"tag\", \"name\": \"syslogtag\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"source\", \"name\": \"app-name\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"message\", \"name\": \"msg\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"file\", \"name\": \"$!metadata!filename\", \"format\": \"jsonf\"}}, {\"constant\": {\"outname\": \"cloud\", \"value\": \"multicell.ooo.test\", \"format\": \"jsonf\"}}, {\"constant\": {\"outname\": \"region\", \"value\": \"regionOne\", \"format\": \"jsonf\"}}]}}, \"tripleo::profile::base::logging::rsyslog::reopen_on_truncate\": \"on\", \"tripleo::profile::base::snmp::snmpd_user\": \"ro_snmp_user\", \"tripleo::profile::base::snmp::snmpd_password\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"snmp::agentaddress\": [\"udp:161\", \"udp6:[::1]:161\"], \"snmp::snmpd_options\": \"-LS0-5d\", \"tripleo::firewall::manage_firewall\": false, \"tripleo::firewall::purge_firewall_rules\": false, \"tripleo::packages::enable_install\": true, \"ovn::controller::ovn_bridge_mappings\": [\"datacentre:br-ex\"], \"ovn::controller::ovn_cms_options\": \"enable-chassis-as-gw\", \"ovn::controller::ovn_encap_tos\": \"0\", \"vswitch::ovs::enable_hw_offload\": false, \"container_cpuset_cpus\": \"\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ovn::southbound::port\": 6642, \"ovn::controller::ovn_encap_ip\": \"%{hiera(\'tenant\')}\", \"ovn::controller::ovn_encap_type\": \"geneve\", \"ovn::controller::ovn_bridge\": \"br-int\", \"ovn::controller::hostname\": \"%{hiera(\'fqdn_canonical\')}\", \"ovn::controller::ovn_remote_probe_interval\": 60000, \"ovn::controller::ovn_openflow_probe_interval\": 60, \"ovn::controller::ovn_ofctrl_wait_before_clear\": 8000, \"ovn::controller::garp_max_timeout_sec\": 0, \"ovn::controller::ovn_monitor_all\": true, \"neutron::notification_driver\": [\"noop\"], \"neutron::core_plugin\": \"ml2\", \"neutron::service_plugins\": [\"qos\", \"ovn-router\", \"trunk\", \"segments\", \"port_forwarding\", \"log\"], \"neutron::report_interval\": 300, \"neutron::logging::debug\": true, \"neutron::purge_config\": false, \"neutron::allow_overlapping_ips\": true, \"neutron::dhcp_agent_notification\": false, \"neutron::dns_domain\": \"openstacklocal\", \"neutron::rabbit_heartbeat_timeout_threshold\": 60, \"neutron::host\": \"%{hiera(\'fqdn_canonical\')}\", \"neutron::db::database_db_max_retries\": -1, \"neutron::db::database_max_retries\": -1, \"neutron::db::sync::db_sync_timeout\": 900, \"neutron::global_physnet_mtu\": 1350, \"neutron::db::sync::extra_params\": \"\", \"neutron::vlan_transparent\": false, \"neutron::rabbit_heartbeat_in_pthread\": false, \"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::enable_haproxy_wrapper\": true, \"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::haproxy_process_wrapper\": \"/var/lib/neutron/ovn_metadata_haproxy_wrapper\", \"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::haproxy_image\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::debug\": true, \"tripleo::profile::base::neutron::container_cli\": \"podman\", \"neutron::agents::ovn_metadata::shared_secret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"neutron::agents::ovn_metadata::auth_password\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"neutron::agents::ovn_metadata::auth_url\": \"http://172.17.0.130:5000\", \"neutron::agents::ovn_metadata::auth_tenant\": \"service\", \"neutron::agents::ovn_metadata::metadata_host\": \"172.17.0.133\", \"neutron::agents::ovn_metadata::ovsdb_connection_timeout\": 180, \"neutron::agents::ovn_metadata::ovsdb_probe_interval\": 60000, \"neutron::agents::ovn_metadata::hwol_qos_enabled\": false, \"ovn::northbound::port\": 6641, \"neutron::agents::ovn_metadata::debug\": true, \"neutron::agents::ovn_metadata::metadata_protocol\": \"http\", \"neutron::agents::ovn_metadata::metadata_workers\": \"1\"}, \"global_config_settings\": {}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_collectd\": [{\"tag\": \"collectd\", \"file\": \"/var/log/containers/collectd/collectd.log\"}], \"tripleo_logging_sources_ceilometer_agent_ipmi\": [{\"tag\": \"openstack.ceilometer.agent.ipmi\", \"file\": \"/var/log/containers/ceilometer/ipmi.log\"}], \"tripleo_logging_sources_metrics_qdr\": [{\"tag\": \"openstack.nova.consoleauth\", \"file\": \"/var/log/containers/metrics_qdr/metrics_qdr.log\", \"startmsg.regex\": \"^[0-9]{4}-[0-9]{2}-[0-9]{2} [0-9]{2}:[0-9]{2}:[0-9]{2}(.[0-9]+ \\\\\\\\+[0-9]+)? [A-Z]+ \\\\\\\\([a-z]+\\\\\\\\) \"}], \"tripleo_logging_sources_nova_compute\": [{\"tag\": \"openstack.nova.compute\", \"file\": \"/var/log/containers/nova/nova-compute.log\"}]}, \"keystone\": {\"tripleo::profile::base::keystone::ceilometer_notification_topics\": [\"notifications\"]}, \"collectd\": {\"tripleo.collectd.plugins.nova_compute\": [\"virt\"], \"collectd::plugin::virt::connection\": \"qemu:///system\"}}, \"step_config\": \"include tripleo::trusted_cas\\ninclude tripleo::profile::base::database::mysql::client\\n\\ninclude tripleo::profile::base::snmp\\n\\ninclude ::tripleo::packages\\n\", \"deploy_steps_tasks\": [{\"name\": \"Configure tuned before reboot\", \"when\": \"step|int == 0\", \"include_role\": {\"name\": \"tuned\"}, \"vars\": {\"tuned_profile\": \"throughput-performance\", \"tuned_isolated_cores\": \"\"}}, {\"name\": \"Configure kernel args and reboot\", \"when\": \"step|int == 0\", \"include_role\": {\"name\": \"tripleo_kernel\", \"tasks_from\": \"kernelargs.yml\"}, \"vars\": {\"tripleo_kernel_args\": \"\", \"tripleo_kernel_hugepages\": {}, \"tripleo_kernel_hugepages_remove\": false, \"tripleo_kernel_defer_reboot\": false, \"tripleo_kernel_reboot_timeout\": 900}}, {\"name\": \"set enable_sensubility fact\", \"set_fact\": {\"enable_sensubility\": false}}, {\"name\": \"create podman socket for sensubility purposes\", \"block\": [{\"name\": \"create podman socket and appropriate systemd service\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_service\"}, \"vars\": {\"tripleo_podman_socket_path\": \"/var/lib/tripleo-podman/collectd/podman.sock\"}}, {\"name\": \"create systemd service for ensuring socket file ACL contains collectd\", \"become\": true, \"ansible.builtin.copy\": {\"content\": \"[Unit]\\nDescription=ACL setting for /var/lib/tripleo-podman/collectd/podman.sock\\nRequires=tripleo_collectd.service\\nAfter=tripleo_podman.service\\nAfter=tripleo_collectd.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/usr/bin/podman exec -it collectd setfacl -m m:rwx /run/podman/podman.sock\\nExecStart=/usr/bin/podman exec -it collectd setfacl -R -m u:collectd:rwx /run/podman\\nExecStart=/usr/bin/podman exec -it collectd setfacl -d -m u:collectd:rwx /run/podman\\n\\n[Install]\\nWantedBy=multi-user.target\\n\", \"dest\": \"/etc/systemd/system/tripleo_podman_collectd_acl.service\", \"mode\": 420}}, {\"name\": \"enable podman.sock ACL service\", \"ansible.builtin.service\": {\"name\": \"tripleo_podman_collectd_acl.service\", \"enabled\": true}}, {\"name\": \"create directory for downloads of users\' scripts\", \"file\": {\"path\": \"/var/lib/container-user-scripts\", \"state\": \"directory\", \"setype\": \"container_file_t\", \"mode\": \"0755\"}}, {\"name\": \"download exec scripts\", \"ansible.builtin.get_url\": {\"url\": \"{{ item.source }}\", \"checksum\": \"{{ item.checksum }}\", \"dest\": \"/var/lib/container-user-scripts/{{ item.name }}\", \"mode\": \"0755\"}, \"with_items\": []}], \"when\": [\"enable_sensubility|bool\", \"step|int == 1\"]}, {\"name\": \"Run lvmfilter role\", \"include_role\": {\"name\": \"tripleo_lvmfilter\"}, \"when\": [\"step|int == 1\"]}, {\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"metrics_qdr\", \"dns\": \"{{fqdn_internal_api}}\", \"principal\": \"metrics_qdr/{{fqdn_internal_api}}@{{idm_realm}}\", \"run_after\": \"container_name=$({{container_cli}} ps --format=\\\\{\\\\{.Names\\\\}\\\\} | grep metrics_qdr)\\nservice_crt=\\\"/etc/pki/tls/certs/metrics_qdr.crt\\\"\\nservice_key=\\\"/etc/pki/tls/private/metrics_qdr.key\\n# Copy the new cert from the mount-point to the real path\\n{{container_cli}} exec \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_crt\\\" \\\"$service_crt\\\"\\n# Copy the new key from the mount-point to the real path\\n{{container_cli}} exec \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_key\\\" \\\"$service_key\\\"\\n# Set appropriate permissions\\n{{container_cli}} exec \\\"$container_name\\\" chown qdrouterd:qdrouterd \\\"$service_crt\\\"\\n{{container_cli}} exec \\\"$container_name\\\" chown qdrouterd:qdrouterd \\\"$service_key\\\"\\n# Trigger a container restart to read the new certificate\\n{{container_cli}} restart \\\"$container_name\\\"\\n\", \"key_size\": \"2048\", \"ca\": \"ipa\"}]}}]}, {\"name\": \"install systemd-container for a greenfield\", \"when\": [\"step|int == 1\", \"not check_nova_instances_result.stat.exists\"], \"package\": {\"name\": \"systemd-container\", \"state\": \"present\"}}, {\"name\": \"validate nova-compute container state\", \"containers.podman.podman_container_info\": {\"name\": \"nova_compute\"}, \"register\": \"nova_compute_infos\", \"failed_when\": [\"nova_compute_infos.containers.0.Healthcheck.Status is defined\", \"\'healthy\' not in nova_compute_infos.containers.0.Healthcheck.Status\"], \"retries\": 10, \"delay\": 30, \"tags\": [\"opendev-validation\", \"opendev-validation-nova\"], \"when\": [\"container_cli == \'podman\'\", \"not container_healthcheck_disabled\", \"step|int == 6\"]}, {\"name\": \"manage PMEM namespaces for vPMEM\", \"include_role\": {\"name\": \"tripleo_nvdimm\"}, \"vars\": {\"tripleo_nvdimm_pmem_namespaces\": \"\"}, \"when\": [\"step|int == 1\", \"tripleo_nvdimm_pmem_namespaces != \'\'\"]}, {\"name\": \"manage OS version 9 specific sysctls\", \"when\": [\"step|int == 1\", \"ansible_facts[\'os_family\'] == \'RedHat\'\", \"ansible_facts[\'distribution_major_version\'] is version(\'9\', \'==\')\"], \"block\": [{\"name\": \"Enable post-copy by setting unprivileged_userfaultfd\", \"sysctl\": {\"name\": \"vm.unprivileged_userfaultfd\", \"value\": 1, \"sysctl_set\": true, \"sysctl_file\": \"/etc/sysctl.d/99-tripleo-postcopy.conf\", \"state\": \"present\", \"reload\": true}}]}, {\"name\": \"enable/disable ksm\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"is KSM enabled\", \"set_fact\": {\"compute_ksm_enabled\": false}}, {\"name\": \"disable KSM on compute\", \"when\": \"not compute_ksm_enabled|bool\", \"block\": [{\"name\": \"Check for ksm\", \"shell\": \"systemctl is-active ksm.service || systemctl is-enabled ksm.service\", \"become\": true, \"failed_when\": false, \"register\": \"ksm_service_check\"}, {\"name\": \"disable KSM services\", \"service\": {\"name\": \"{{ item }}\", \"state\": \"stopped\", \"enabled\": false}, \"with_items\": [\"ksm.service\", \"ksmtuned.service\"], \"when\": [\"ksm_service_check.rc is defined\", \"ksm_service_check.rc == 0\"], \"register\": \"ksmdisabled\"}, {\"name\": \"delete PageKSM after disable ksm on compute\", \"command\": \"echo 2 >/sys/kernel/mm/ksm/run\", \"when\": [\"ksm_service_check.rc is defined\", \"ksm_service_check.rc == 0\", \"ksmdisabled is changed\"]}]}, {\"name\": \"enable KSM on compute\", \"when\": \"compute_ksm_enabled|bool\", \"block\": [{\"name\": \"make sure package providing ksmtuned is installed (RHEL8 or CentOS8)\", \"package\": {\"name\": \"qemu-kvm-common\", \"state\": \"present\"}, \"when\": [\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\"]}, {\"name\": \"make sure package providing ksmtuned is installed (RHEL9 or CentOS9)\", \"package\": {\"name\": \"ksmtuned\", \"state\": \"present\"}, \"when\": [\"ansible_facts[\'distribution_major_version\'] is version(\'9\', \'==\')\"]}, {\"name\": \"enable ksmtunded\", \"service\": {\"name\": \"{{ item }}\", \"state\": \"started\", \"enabled\": true}, \"with_items\": [\"ksm.service\", \"ksmtuned.service\"]}]}]}, {\"name\": \"Ensure recovery of containerized virtqemud\", \"when\": \"step|int == 4\", \"become\": true, \"block\": [{\"name\": \"Create virtqemud recovery script\", \"copy\": {\"dest\": \"/usr/libexec/recover_tripleo_nova_virtqemud.sh\", \"mode\": \"0755\", \"content\": \"#!/bin/bash\\npgrep -f /sbin/virtqemud\\n[ $? -eq 0 ] && exit 0\\nkill -9 $(cat /run/nova_virtqemud.pid)\\n\"}}, {\"name\": \"Create virtqemud recovery trigger service\", \"copy\": {\"dest\": \"/etc/systemd/system/tripleo_nova_virtqemud_recover.service\", \"mode\": \"0644\", \"content\": \"[Unit]\\nDescription=Check and recover tripleo_nova_virtqemud\\nAfter=tripleo_nova_virtqemud.service\\nRequisite=tripleo_nova_virtqemud.service\\n[Service]\\nType=oneshot\\nExecStart=bash /usr/libexec/recover_tripleo_nova_virtqemud.sh\\nSyslogIdentifier=recover_tripleo_nova_virtqemud\\n[Install]\\nWantedBy=multi-user.target\\n\"}}, {\"name\": \"Create virtqemud recovery trigger timer\", \"copy\": {\"dest\": \"/etc/systemd/system/tripleo_nova_virtqemud_recover.timer\", \"mode\": \"0644\", \"content\": \"[Unit]\\nDescription=Check and recover tripleo_nova_virtqemud every 10m\\nPartOf=tripleo_nova_virtqemud.service\\n[Timer]\\nOnCalendar=*:5/10\\nOnActiveSec=120\\nOnUnitActiveSec=60\\nRandomizedDelaySec=1m\\n[Install]\\nWantedBy=timers.target\\n\"}}, {\"name\": \"Enable virtqemud recovery trigger service\", \"systemd\": {\"name\": \"tripleo_nova_virtqemud_recover.service\", \"enabled\": true, \"daemon_reload\": true}}, {\"name\": \"Enable virtqemud recovery trigger timer\", \"systemd\": {\"name\": \"tripleo_nova_virtqemud_recover.timer\", \"enabled\": true, \"state\": \"restarted\", \"daemon_reload\": true}, \"register\": \"virtqemud_recover_timer_result\"}, {\"name\": \"Really enable virtqemud recovery trigger timer\", \"shell\": {\"cmd\": \"systemctl enable --now tripleo_nova_virtqemud_recover.timer\"}, \"when\": \"virtqemud_recover_timer_result.status.UnitFileState != \\\"enabled\\\"\"}]}, {\"name\": \"Set up systemd target for libvirt services\", \"when\": \"step|int == 4\", \"block\": [{\"name\": \"Create systemd file\", \"copy\": {\"dest\": \"/etc/systemd/system/tripleo_nova_libvirt.target\", \"mode\": \"0644\", \"owner\": \"root\", \"group\": \"root\", \"content\": \"[Unit]\\nWants=tripleo_nova_virtsecretd.service\\nWants=tripleo_nova_virtnodedevd.service\\nWants=tripleo_nova_virtstoraged.service\\nWants=tripleo_nova_virtproxyd.service\\nWants=tripleo_nova_virtqemud.service\\nAfter=tripleo_nova_virtsecretd.service\\nAfter=tripleo_nova_virtnodedevd.service\\nAfter=tripleo_nova_virtstoraged.service\\nAfter=tripleo_nova_virtproxyd.service\\nAfter=tripleo_nova_virtqemud.service\\n\"}, \"become\": true, \"register\": \"libvirt_target_result\"}, {\"name\": \"Reload systemd\", \"systemd\": {\"name\": \"tripleo_nova_libvirt.target\", \"enabled\": true, \"state\": \"restarted\", \"daemon_reload\": true}, \"become\": true, \"when\": \"libvirt_target_result.changed\"}]}, {\"name\": \"validate nova-migration-target container state\", \"containers.podman.podman_container_info\": {\"name\": \"nova_migration_target\"}, \"register\": \"nova_migration_target_infos\", \"failed_when\": [\"nova_migration_target_infos.containers.0.Healthcheck.Status is defined\", \"\'healthy\' not in nova_migration_target_infos.containers.0.Healthcheck.Status\"], \"retries\": 10, \"delay\": 30, \"tags\": [\"opendev-validation\", \"opendev-validation-nova\"], \"when\": [\"container_cli == \'podman\'\", \"not container_healthcheck_disabled\", \"step|int == 5\"]}, {\"name\": \"configure tmpwatch on the host\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Push script\", \"copy\": {\"dest\": \"/usr/local/sbin/containers-tmpwatch\", \"owner\": \"root\", \"group\": \"root\", \"mode\": 493, \"content\": \"#!/bin/sh\\ntmpwatch --nodirs \\\\\\n  -X \\\"/var/log/containers/*/*log\\\" \\\\\\n  -X \\\"/var/log/containers/*/*/*log\\\" \\\\\\n  -X \\\"/var/log/containers/*/*err\\\" \\\\\\n  {{ LogrotatePurgeAfterDays|int +1 }}d \\\\\\n  /var/log/containers/ 2>&1 | logger -t container-tmpwatch\\n\"}, \"vars\": {\"LogrotatePurgeAfterDays\": \"14\"}}, {\"name\": \"Insert cronjob in root crontab\", \"cron\": {\"name\": \"Remove old logs\", \"special_time\": \"daily\", \"user\": \"root\", \"job\": \"/usr/local/sbin/containers-tmpwatch\"}}]}, {\"when\": [\"(step|int) == 1\"], \"block\": [{\"name\": \"Pre-fetch all the containers\", \"become\": true, \"containers.podman.podman_image\": {\"name\": \"{{ prefetch_image }}\", \"validate_certs\": false, \"force\": true}, \"register\": \"result\", \"until\": \"result is succeeded\", \"retries\": 5, \"delay\": 5, \"loop_control\": {\"loop_var\": \"prefetch_image\"}, \"loop\": \"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\"}]}, {\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"ovn_controller\", \"dns\": \"{{fqdn_internal_api}}\", \"principal\": \"ovn_controller/{{fqdn_internal_api}}@{{idm_realm}}\", \"run_after\": \"systemctl restart tripleo_ovn_controller\\n\", \"key_size\": \"2048\", \"ca\": \"ipa\"}]}}]}, {\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"ovn_metadata\", \"dns\": \"{{fqdn_internal_api}}\", \"principal\": \"ovn_metadata/{{fqdn_internal_api}}@{{idm_realm}}\", \"run_after\": \"systemctl restart tripleo_ovn_metadata_agent\\n\", \"key_size\": \"2048\", \"ca\": \"ipa\"}]}}]}], \"external_deploy_tasks\": [{\"when\": [\"step|int == 0\"], \"name\": \"ovn_controller_external_deploy_init\", \"block\": [{\"name\": \"create ovn mac address for Compute role nodes\", \"tripleo_ovn_mac_addresses\": {\"playbook_dir\": \"{{ playbook_dir }}\", \"stack_name\": \"cell1\", \"role_name\": \"Compute\", \"server_resource_names\": \"{{ groups[\\\"Compute\\\"] }}\", \"ovn_bridge_mappings\": [\"datacentre:br-ex\"], \"ovn_static_bridge_mac_mappings\": {}}}]}], \"external_post_deploy_tasks\": [{\"block\": [{\"name\": \"is additonal Cell?\", \"set_fact\": {\"nova_additional_cell\": true}}, {\"name\": \"check if discover hosts is required\", \"when\": [\"not nova_additional_cell|bool\", \"nova_cellv2_discovery_done is not defined\"], \"block\": [{\"name\": \"discover via nova_manager?\", \"set_fact\": {\"nova_cellv2_discovery_delegate_host\": \"{{ groups[\'nova_manager\'][0] }}\", \"nova_cellv2_discovery_container\": \"nova_manager\"}, \"when\": [\"groups[\'nova_manager\'] is defined and (groups[\'nova_manager\']|length>0)\"]}, {\"name\": \"discover via nova_api?\", \"set_fact\": {\"nova_cellv2_discovery_delegate_host\": \"{{ groups[\'nova_api\'][0] }}\", \"nova_cellv2_discovery_container\": \"nova_api\"}, \"when\": [\"nova_cellv2_discovery_delegate_host is not defined\", \"groups[\'nova_api\'] is defined and (groups[\'nova_api\']|length>0)\"]}, {\"name\": \"Warn if no discovery host available\", \"fail\": {\"msg\": \"No hosts available to run nova cell_v2 host discovery.\"}, \"ignore_errors\": true, \"when\": [\"nova_cellv2_discovery_delegate_host is not defined\"]}, {\"name\": \"Discovering nova hosts\", \"command\": \"{{ container_cli }} exec {{ nova_cellv2_discovery_container }} nova-manage cell_v2 discover_hosts --by-service\", \"become\": true, \"changed_when\": false, \"delegate_to\": \"{{ nova_cellv2_discovery_delegate_host }}\", \"when\": [\"nova_cellv2_discovery_delegate_host is defined\"]}, {\"set_fact\": {\"nova_cellv2_discovery_done\": true}}]}]}], \"external_update_tasks\": [{\"name\": \"Force pull image in case image name doesn\'t change.\", \"when\": \"step|int == 1\", \"tags\": [\"ovn\", \"ovn_image\"], \"become\": true, \"loop\": \"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\", \"delegate_to\": \"{{ item }}\", \"async\": 600, \"poll\": 0, \"register\": \"ovn_controller_image_update\", \"containers.podman.podman_image\": {\"name\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"validate_certs\": false, \"force\": true}}, {\"name\": \"Was the ovn_controller image pull successful.\", \"when\": [\"step|int == 1\", \"\'results\' in ovn_controller_image_update\"], \"tags\": [\"ovn\", \"ovn_image\"], \"become\": true, \"delegate_to\": \"{{ async_result_item.item }}\", \"async_status\": {\"jid\": \"{{ async_result_item.ansible_job_id }}\"}, \"loop\": \"{{ovn_controller_image_update.results }}\", \"loop_control\": {\"loop_var\": \"async_result_item\"}, \"register\": \"async_poll_results\", \"until\": \"async_poll_results.finished\", \"retries\": 600, \"delay\": 1}, {\"name\": \"OVN Container image used\", \"debug\": {\"msg\": \"ovn container will be using {{ image }}\"}, \"vars\": {\"image\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\"}, \"when\": \"step|int == 1\", \"tags\": \"ovn\"}, {\"name\": \"Update OVN OVS related parameters before update.\", \"when\": [\"step|int == 1\"], \"tags\": [\"ovn\"], \"become\": true, \"vars\": {\"timeout\": 8000}, \"shell\": \"set -e\\novs-vsctl set Open_vSwitch . external_ids:ovn-ofctrl-wait-before-clear={{ timeout }}\\novs-vsctl set Open_vSwitch . external_ids:ovn-monitor-all=true\\novs-vsctl set Open_vSwitch . external_ids:ovn-match-northd-version=false\\n\", \"async\": 600, \"poll\": 0, \"register\": \"ovs_vsctl\", \"loop\": \"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\", \"delegate_to\": \"{{ item }}\"}, {\"name\": \"Was the update of OVN OVS related parameter successful.\", \"when\": [\"step|int == 1\", \"\'results\' in ovs_vsctl\"], \"become\": true, \"tags\": [\"ovn\"], \"delegate_to\": \"{{ async_result_item.item }}\", \"async_status\": {\"jid\": \"{{ async_result_item.ansible_job_id }}\"}, \"loop\": \"{{ovs_vsctl.results }}\", \"loop_control\": {\"loop_var\": \"async_result_item\"}, \"register\": \"async_poll_results\", \"until\": \"async_poll_results.finished\", \"retries\": 600, \"delay\": 1}, {\"set_fact\": {\"any_ovn_host\": \"{{groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) | first }}\"}, \"tags\": \"ovn\", \"when\": \"step|int == 1\"}, {\"name\": \"Find ovn_controller configs in container-startup-configs\", \"find\": {\"paths\": \"/var/lib/tripleo-config/container-startup-config/\", \"patterns\": \"*ovn_controller.json\", \"recurse\": true}, \"register\": \"ovn_cont_17_0\", \"delegate_to\": \"{{ any_ovn_host }}\", \"when\": \"(step|int == 1) and (any_ovn_host is defined) and (any_ovn_host|length > 0)\", \"tags\": [\"ovn\"], \"become\": true}, {\"name\": \"get directory path from the ovn_cont_17_0\", \"set_fact\": {\"ovn_config_path\": \"{{ ovn_cont_17_0.files.0.path | dirname }}\"}, \"when\": \"step|int == 1\", \"tags\": \"ovn\"}, {\"name\": \"Get PIDfile used by systemd on each ovn node\", \"when\": [\"step|int == 1\"], \"tags\": [\"ovn\"], \"become\": true, \"shell\": \"set -e\\ngrep PID /etc/systemd/system/tripleo_ovn_controller.service | cut -d= -f2\\n\", \"register\": \"pidfile\", \"loop\": \"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\", \"delegate_to\": \"{{ item }}\"}, {\"name\": \"Update ovn_controller.\", \"vars\": {\"config_step\": \"{{ (\'step_4\' in ovn_config_path) | ternary(\'4\', \'3\')}}\", \"query\": \"results[?item == \'{{item}}\'].stdout\"}, \"when\": \"step|int == 1\", \"tags\": \"ovn\", \"become\": true, \"loop\": \"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\", \"delegate_to\": \"{{ item }}\", \"async\": 600, \"poll\": 0, \"register\": \"ovn_controller_update\", \"tripleo_container_manage\": {\"config_dir\": \"{{ ovn_config_path }}\", \"config_patterns\": \"*ovn_controller.json\", \"config_id\": [\"tripleo_step{{config_step}}\"], \"log_base_path\": \"{{ container_log_stdout_path }}\", \"debug\": \"{{ enable_debug | bool }}\", \"config_overrides\": {\".*ovn_controller\": {\"image\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"conmon_pidfile\": \"{{ pidfile | json_query(query) | first }}\", \"name\": \"ovn_controller\"}}}}, {\"name\": \"Was the ovn_controller successful.\", \"when\": [\"step|int == 1\", \"\'results\' in ovn_controller_update\"], \"tags\": \"ovn\", \"become\": true, \"delegate_to\": \"{{ async_result_item.item }}\", \"async_status\": {\"jid\": \"{{ async_result_item.ansible_job_id }}\"}, \"loop\": \"{{ovn_controller_update.results }}\", \"loop_control\": {\"loop_var\": \"async_result_item\"}, \"register\": \"async_poll_results\", \"until\": \"async_poll_results.finished\", \"retries\": 600, \"delay\": 1}, {\"name\": \"Pause for 30s to give ovn_controllers time to reconnect to dbs\", \"when\": [\"step|int == 1\"], \"tags\": \"ovn\", \"wait_for\": {\"timeout\": 30}}, {\"name\": \"Check if python3-openvswitch3.1 workaround is needed\", \"delegate_to\": \"{{ item }}\", \"become\": true, \"tags\": [\"ovn\", \"ovn_image\"], \"when\": \"step|int == 1\", \"shell\": \"if podman exec ovn_metadata_agent rpm -q python3-openvswitch3.1 > /dev/null ; then echo REQUIRED; else echo OK ; fi\\n\", \"register\": \"metadata_python_ovs_3_1\", \"failed_when\": false, \"loop\": \"{{ groups[\'ovn_metadata\'] | difference(groups[\'excluded_overcloud\']) }}\"}, {\"name\": \"Update ovn_metadata_agents\", \"vars\": {\"hosts_to_update_metadata\": \"{{ metadata_python_ovs_3_1.results | selectattr(\'stdout\', \'eq\', \'REQUIRED\') | map(attribute=\'item\') | list }}\"}, \"tags\": [\"ovn\", \"ovn_image\"], \"when\": [\"step|int == 1\", \"hosts_to_update_metadata | length > 0\"], \"block\": [{\"name\": \"Force pull image in case image name doesn\'t change.\", \"become\": true, \"loop\": \"{{ hosts_to_update_metadata }}\", \"delegate_to\": \"{{ item }}\", \"async\": 600, \"poll\": 0, \"register\": \"ovn_metadata_image_update\", \"containers.podman.podman_image\": {\"name\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"validate_certs\": false, \"force\": true}}, {\"name\": \"Was the ovn_metadata_agent image pull successful.\", \"when\": [\"\'results\' in ovn_metadata_image_update\"], \"become\": true, \"delegate_to\": \"{{ async_result_item.item }}\", \"async_status\": {\"jid\": \"{{ async_result_item.ansible_job_id }}\"}, \"loop\": \"{{ovn_metadata_image_update.results }}\", \"loop_control\": {\"loop_var\": \"async_result_item\"}, \"register\": \"async_poll_results\", \"until\": \"async_poll_results.finished\", \"retries\": 600, \"delay\": 1}, {\"name\": \"Now rotate all ovn_metadata_agents\", \"tags\": [\"ovn_metadata_parallel\"], \"delegate_to\": \"{{ item }}\", \"become\": true, \"tripleo_container_manage\": {\"config_dir\": \"/var/lib/tripleo-config/container-startup-config/step_4\", \"config_id\": [\"ovn_metadata_agent\"], \"config_patterns\": \"*ovn_metadata_agent.json\", \"config_overrides\": {\".*ovn_metadata_agent\": {\"image\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"name\": \"ovn_metadata_agent\"}}}, \"loop\": \"{{ hosts_to_update_metadata }}\", \"async\": 600, \"poll\": 0}]}, {\"name\": \"Now rotate all ovn_metadata_agents\", \"vars\": {\"hosts_to_update_metadata\": \"{{ metadata_python_ovs_3_1.results | selectattr(\'stdout\', \'eq\', \'REQUIRED\') | map(attribute=\'item\') | list }}\"}, \"tags\": [\"never\", \"ovn_metadata_serial\"], \"when\": [\"step|int == 1\", \"hosts_to_update_metadata | length > 0\"], \"delegate_to\": \"{{ item }}\", \"become\": true, \"tripleo_container_manage\": {\"config_dir\": \"/var/lib/tripleo-config/container-startup-config/step_4\", \"config_id\": [\"ovn_metadata_agent\"], \"config_patterns\": \"*ovn_metadata_agent.json\", \"config_overrides\": {\".*ovn_metadata_agent\": {\"image\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"name\": \"ovn_metadata_agent\"}}}, \"loop\": \"{{ hosts_to_update_metadata }}\", \"loop_control\": {\"pause\": 1}}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop logrotate container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"logrotate_crond\"], \"tripleo_delegate_to\": \"{{ groups[\'logrotate_crond\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}, {\"name\": \"Clean up upgrade artifacts\", \"when\": \"step|int == 1\", \"tags\": [\"never\", \"system_upgrade_cleanup\"], \"block\": [{\"name\": \"cleanup tripleo_persist\", \"include_role\": {\"name\": \"tripleo_persist\", \"tasks_from\": \"cleanup.yml\"}}]}], \"scale_tasks\": [{\"when\": [\"step|int == 1\", \"container_cli == \'podman\'\"], \"tags\": \"down\", \"become\": true, \"environment\": {\"OS_CLOUD\": \"overcloud\"}, \"block\": [{\"name\": \"Get nova-compute service ID\", \"command\": \"openstack compute service list --service nova-compute --column ID --column Host --format yaml\", \"register\": \"nova_compute_service_result\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false, \"changed_when\": false}, {\"name\": \"is additional Cell?\", \"set_fact\": {\"is_additional_cell\": true}}, {\"name\": \"Set fact for nova_compute services\", \"set_fact\": {\"nova_compute_service\": \"{{ nova_compute_service_result.stdout | from_yaml | selectattr(\'Host\', \'match\', ansible_facts[\'fqdn\'] ~ \'.*\') | list }}\"}, \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false}, {\"name\": \"Check search output\", \"fail\": {\"msg\": \"Found multiple `{{ ansible_facts[\'fqdn\'] }}`, which is unexpected. This means that the FQDN of the selected device to disable is either wrong or is sharing a name with another host, which is also wrong. Please correct this issue before continuing. Nova service list return data can be found here -> {{ nova_compute_service }}.\"}, \"when\": [\"(nova_compute_service | length) > 1\"]}, {\"name\": \"Disable nova services\", \"when\": [\"(nova_compute_service | length) == 1\"], \"block\": [{\"name\": \"Disable nova-compute service\", \"command\": \"openstack compute service set {{ nova_compute_service[0].Host }} nova-compute --disable\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false, \"when\": [\"not is_additional_cell|bool\"]}, {\"name\": \"Stop nova-compute container\", \"service\": {\"name\": \"tripleo_nova_compute\", \"state\": \"stopped\", \"enabled\": false}, \"become\": true, \"register\": \"stop_nova_compute\", \"failed_when\": \"(\'msg\' in stop_nova_compute and \'Could not find the requested service tripleo_nova_compute\' not in stop_nova_compute.msg) or (\'rc\' in stop_nova_compute and stop_nova_compute.rc != 0)\"}, {\"name\": \"Delete nova-compute service\", \"command\": \"openstack compute service delete {{ nova_compute_service[0].ID }}\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false}]}]}, {\"when\": [\"step|int == 1\", \"container_cli == \'podman\'\"], \"tags\": \"down\", \"become\": true, \"environment\": {\"OS_CLOUD\": \"overcloud\"}, \"block\": [{\"name\": \"Get neutron agents ID\", \"command\": \"openstack network agent list --column ID --column Host --column Binary --format yaml\", \"register\": \"neutron_agents_result\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false, \"changed_when\": false}, {\"name\": \"Filter only current host\", \"set_fact\": {\"neutron_agents\": \"{{ neutron_agents_result.stdout | from_yaml | selectattr(\'Host\', \'match\', ansible_facts[\'fqdn\'] ~ \'.*\') | list }}\"}, \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false}, {\"name\": \"Deleting OVN agents\", \"block\": [{\"name\": \"Stop OVN containers\", \"loop\": [\"tripleo_ovn_controller\", \"tripleo_ovn_metadata_agent\"], \"service\": {\"name\": \"{{ item }}\", \"state\": \"stopped\", \"enabled\": false}, \"become\": true, \"register\": \"stop_containers\", \"failed_when\": \"(\'msg\' in stop_containers and \'Could not find the requested service\' not in stop_containers.msg) or (\'rc\' in stop_containers and stop_containers.rc != 0)\"}, {\"name\": \"Delete neutron agents\", \"loop\": \"{{ neutron_agents }}\", \"loop_control\": {\"loop_var\": \"agent\", \"label\": \"{{ agent.Host }}/{{ agent.Binary }}\"}, \"command\": \"openstack network agent delete {{ agent.ID }}\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false}]}]}], \"pre_upgrade_rolling_tasks\": [], \"upgrade_tasks\": [{\"name\": \"upgrade prepare for leapp to align kernel arg shortcommings in leapp\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"fix grub entries to have name start with GRUB_\", \"replace\": {\"path\": \"/etc/default/grub\", \"regexp\": \"^(TRIPLEO_HEAT_TEMPLATE_KERNEL_ARGS)(.*)\", \"replace\": \"GRUB_\\\\1\\\\2\"}}, {\"name\": \"fix grub entries in append statement\", \"replace\": {\"path\": \"/etc/default/grub\", \"regexp\": \"(.*){(TRIPLEO_HEAT_TEMPLATE_KERNEL_ARGS)}(.*)\", \"replace\": \"\\\\1{GRUB_\\\\2}\\\\3\"}}]}, {\"name\": \"remove rsyslog configuration for podman healthcheck log\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_rsyslog_cleanup\"}}, {\"name\": \"Force pull image collectd\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 3\"], \"containers.podman.podman_image\": {\"name\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"force\": true}}, {\"name\": \"UBI8 to UBI9 switch of collectd\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 5\"], \"block\": [{\"name\": \"Update collectd to UBI9\", \"tripleo_container_manage\": {\"config_dir\": \"/var/lib/tripleo-config/container-startup-config/step_3\", \"config_patterns\": \"collectd.json\", \"config_id\": [\"tripleo_step3\"], \"log_base_path\": \"{{ container_log_stdout_path }}\", \"debug\": \"{{ enable_debug | bool }}\", \"config_overrides\": {\"collectd\": {\"image\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\"}}}}]}, {\"name\": \"Remove openstack-nova-compute and python-nova package during upgrade\", \"package\": {\"name\": [\"openstack-nova-compute\", \"python-nova\"], \"state\": \"removed\"}, \"failed_when\": false, \"when\": \"step|int == 2\"}, {\"name\": \"nova_compute pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount Nova NFS Share\", \"vars\": {\"nfs_backend_enable\": false}, \"mount\": {\"name\": \"/var/lib/nova/instances\", \"state\": \"absent\", \"fstype\": \"nfs4\"}, \"when\": \"nfs_backend_enable|bool\"}]}, {\"name\": \"nova_compute post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Mount Nova NFS Share\", \"vars\": {\"nfs_backend_enable\": false, \"nfs_share\": \"\", \"nfs_options\": \"context=system_u:object_r:nfs_t:s0\", \"nfs_vers\": \"4.2\"}, \"mount\": {\"name\": \"/var/lib/nova/instances\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{nfs_share}}\", \"opts\": \"_netdev,bg,{{nfs_options}},nfsvers={{nfs_vers}}\"}, \"when\": \"nfs_backend_enable|bool\"}]}, {\"name\": \"Fail if we are on RHEL8 as this is monolithic libvirt deployment\", \"when\": [\"step|int == 0\", \"\'system_upgrade\' not in ansible_run_tags\", \"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\"], \"fail\": {\"msg\": \"Use of the Modular Libvirt deployment on RHEL8 results in loss of workloads. Use NovaLibvirtLegacy in roles data.\"}}, {\"name\": \"nova_libvirt_container_tmpfile_cleanup\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Remove old tmpfiles.d config\", \"file\": {\"path\": \"/etc/tmpfiles.d/var-run-libvirt.conf\", \"state\": \"absent\"}}]}, {\"name\": \"Get container virtlogd image\", \"when\": \"step|int == 1\", \"tags\": \"always\", \"set_fact\": {\"virtlogd_image\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\"}}, {\"name\": \"Force pull image novalibvirt\", \"when\": [\"step|int == 1\"], \"containers.podman.podman_image\": {\"name\": \"{{ virtlogd_image }}\", \"force\": true}}, {\"name\": \"Diff OS release in container image and baremetal\", \"when\": \"step|int == 1\", \"shell\": \"diff /etc/redhat-release <(podman run {{ virtlogd_image }} cat /etc/redhat-release)\\n\", \"args\": {\"executable\": \"/bin/bash\"}, \"failed_when\": false, \"register\": \"libvirt_ubi_diff\"}, {\"name\": \"Fail if UBI of the container does not match RHEL of running host\", \"when\": [\"\'system_upgrade\' not in ansible_run_tags\", \"step|int == 1\", \"libvirt_ubi_diff.rc == 1\"], \"fail\": {\"msg\": \"The host operating system versus container UBI does not match.\\n{{ libvirt_ubi_diff.stdout }}\\nMost likely container passed to NovaLibvirt was EL8 one.\\nYou have to pass the correct container for container-image-prepare.\\nIf you would continue all running workloads would get destroyed.\\n\"}}, {\"name\": \"Switch virtlogd image before system upgrade\", \"when\": \"step|int == 1\", \"tags\": [\"never\", \"system_upgrade\"], \"block\": [{\"name\": \"Get running image version\", \"shell\": \"podman ps --filter name=^nova_virtlogd$ --format \\\"{% raw %}{{ .Image }}{% endraw %}\\\"\\n\", \"register\": \"old_virtlogd_image\"}, {\"name\": \"Switch running image to new image in wrapper script\", \"shell\": \"set -o pipefail\\nsed -i -e \'s|{{ old_virtlogd_image.stdout }}|{{ virtlogd_image }}|\' /var/lib/container-config-scripts/virtlogd_wrapper\\n\", \"when\": [\"old_virtlogd_image.stdout != virtlogd_image\", \"old_virtlogd_image.stdout != \'\'\"]}]}, {\"name\": \"nova_migration_target_tmpfile_cleanup\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Remove old tmpfiles.d config\", \"file\": {\"path\": \"/etc/tmpfiles.d/var-run-libvirt.conf\", \"state\": \"absent\"}}]}, {\"name\": \"Ensure old cron.daily is absent\", \"when\": \"step|int == 1\", \"file\": {\"path\": \"/etc/cron.daily/containers-tmpwatch\", \"state\": \"absent\"}}, {\"name\": \"Configure Podman registry\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Make sure the Undercloud hostname is included in /etc/hosts\", \"when\": [\"undercloud_hosts_entries is defined\"], \"lineinfile\": {\"dest\": \"/etc/hosts\", \"line\": \"{{ undercloud_hosts_entries | join(\'\') }}\", \"state\": \"present\"}}]}, {\"name\": \"Run podman install\", \"tags\": [\"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": [], \"container_registry_login\": false, \"container_registry_logins\": {}, \"container_registry_logins_json\": {}, \"container_default_pids_limit\": 4096, \"container_events_logger_mechanism\": \"journald\"}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}, {\"when\": \"step|int == 0\", \"block\": [{\"name\": \"Check if snmpd is enabled\", \"command\": \"systemctl is-enabled --quiet snmpd\", \"failed_when\": false, \"register\": \"snmpd_enabled_result\"}, {\"name\": \"Set fact snmpd_enabled\", \"set_fact\": {\"snmpd_enabled\": \"{{ snmpd_enabled_result.rc == 0 }}\"}}]}, {\"name\": \"Stop snmp service\", \"when\": [\"step|int == 1\", \"snmpd_enabled|bool\"], \"service\": \"name=snmpd state=stopped\"}, {\"name\": \"Cleanup tripleo-iptables services\", \"when\": [\"(step | int) == 1\"], \"block\": [{\"name\": \"Disable tripleo-iptables.service\", \"systemd\": {\"name\": \"tripleo-iptables.service\", \"state\": \"stopped\", \"enabled\": false}, \"register\": \"systemd_tripleo_iptables\", \"failed_when\": false}, {\"name\": \"Cleanup tripleo-iptables.services\", \"file\": {\"path\": \"/etc/systemd/system/tripleo-iptables.service\", \"state\": \"absent\"}}, {\"name\": \"Disable tripleo-ip6tables.service\", \"systemd\": {\"name\": \"tripleo-ip6tables.service\", \"state\": \"stopped\", \"enabled\": false}, \"register\": \"systemd_tripleo_ip6tables\", \"failed_when\": false}, {\"name\": \"Cleanup tripleo-ip6tables.services\", \"file\": {\"path\": \"/etc/systemd/system/tripleo-ip6tables.service\", \"state\": \"absent\"}}, {\"name\": \"Reload systemd\", \"systemd\": {\"daemon_reload\": true}, \"when\": [\"(systemd_tripleo_iptables is changed or systemd_tripleo_ip6tables is changed)\"]}]}, {\"when\": [\"(step | int) == 3\"], \"block\": [{\"name\": \"blank ipv6 rule before activating ipv6 firewall.\", \"shell\": \"cat /etc/sysconfig/ip6tables > /etc/sysconfig/ip6tables.n-o-upgrade; cat</dev/null>/etc/sysconfig/ip6tables\", \"args\": {\"creates\": \"/etc/sysconfig/ip6tables.n-o-upgrade\"}}, {\"name\": \"cleanup unmanaged rules pushed by iptables-services\", \"shell\": \"iptables -C INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT &>/dev/null && \\\\\\n  iptables -D INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT\\niptables -C INPUT -p icmp -j ACCEPT &>/dev/null && \\\\\\n  iptables -D INPUT -p icmp -j ACCEPT\\niptables -C INPUT -i lo -j ACCEPT &>/dev/null && \\\\\\n  iptables -D INPUT -i lo -j ACCEPT\\niptables -C INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT &>/dev/null && \\\\\\n  iptables -D INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT\\niptables -C INPUT -j REJECT --reject-with icmp-host-prohibited &>/dev/null && \\\\\\n  iptables -D INPUT -j REJECT --reject-with icmp-host-prohibited\\niptables -C FORWARD -j REJECT --reject-with icmp-host-prohibited &>/dev/null && \\\\\\n  iptables -D FORWARD -j REJECT --reject-with icmp-host-prohibited\\n\\nsed -i \'/^-A INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A INPUT -p icmp -j ACCEPT$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A INPUT -i lo -j ACCEPT$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A INPUT -j REJECT --reject-with icmp-host-prohibited$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A FORWARD -j REJECT --reject-with icmp-host-prohibited$/d\' /etc/sysconfig/iptables\\n\\nip6tables -C INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT\\nip6tables -C INPUT -p ipv6-icmp -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -p ipv6-icmp -j ACCEPT\\nip6tables -C INPUT -i lo -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -i lo -j ACCEPT\\nip6tables -C INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT\\nip6tables -C INPUT -d fe80::/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -d fe80::/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT\\nip6tables -C INPUT -j REJECT --reject-with icmp6-adm-prohibited &>/dev/null && \\\\\\n  ip6tables -D INPUT -j REJECT --reject-with icmp6-adm-prohibited\\nip6tables -C FORWARD -j REJECT --reject-with icmp6-adm-prohibited &>/dev/null && \\\\\\n  ip6tables -D FORWARD -j REJECT --reject-with icmp6-adm-prohibited\\n\\nsed -i \'/^-A INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -p ipv6-icmp -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -i lo -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -d fe80::\\\\/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -j REJECT --reject-with icmp6-adm-prohibited$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A FORWARD -j REJECT --reject-with icmp6-adm-prohibited$/d\' /etc/sysconfig/ip6tables\"}]}, {\"name\": \"Gather missing facts\", \"setup\": {\"gather_subset\": [\"!all\", \"!min\", \"distribution\"]}, \"tags\": [\"always\"]}, {\"name\": \"Set leapp facts\", \"set_fact\": {\"upgrade_leapp_enabled\": \"{{ _upgradeLeappEnabled | bool and\\n   ansible_facts[\'distribution\'] == \'RedHat\' and\\n   ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\') }}\", \"upgrade_leapp_debug\": false, \"upgrade_leapp_devel_skip\": \"\", \"upgrade_leapp_command_options\": \"\", \"upgrade_leapp_reboot_timeout\": 3600, \"upgrade_leapp_post_reboot_delay\": 120}, \"vars\": {\"_upgradeLeappEnabled\": false}, \"tags\": [\"always\"]}, {\"name\": \"system_upgrade_prepare step 3\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Run LeappRepoInitCommand\", \"shell\": \"#!/bin/bash\\n\\n\"}, {\"name\": \"Remove firewalld bindings\", \"package\": {\"name\": \"python3-firewall\", \"state\": \"absent\"}}, {\"name\": \"install leapp\", \"package\": {\"name\": \"leapp-repository-openstack\", \"state\": \"latest\"}}, {\"name\": \"Run LeappInitCommand\", \"shell\": \"#!/bin/bash\\n\\n\"}, {\"name\": \"Remove vdo\", \"package\": {\"name\": \"vdo\", \"state\": \"absent\"}}, {\"name\": \"add packages into Leapp\'s to_remove file\", \"vars\": {\"pkg_to_remove\": []}, \"lineinfile\": {\"path\": \"/etc/leapp/transaction/to_remove\", \"line\": \"{{ item }}\"}, \"loop\": \"{{ pkg_to_remove }}\"}, {\"name\": \"add packages into Leapp\'s to_install file\", \"vars\": {\"pkg_to_install\": []}, \"lineinfile\": {\"path\": \"/etc/leapp/transaction/to_install\", \"line\": \"{{ item }}\"}, \"loop\": \"{{ pkg_to_install }}\"}, {\"name\": \"check sshd_config file\", \"stat\": {\"path\": \"/etc/ssh/sshd_config\"}, \"register\": \"sshd_config_result\"}, {\"name\": \"add PermitRootLogin option for leapp\", \"lineinfile\": {\"path\": \"/etc/ssh/sshd_config\", \"regexp\": \"^(# *)?PermitRootLogin\", \"line\": \"PermitRootLogin without-password\"}}, {\"name\": \"Remove paunch-services\", \"package\": {\"name\": \"paunch-services\", \"state\": \"absent\"}}, {\"name\": \"tripleo_container_manage reconfiguration\", \"import_role\": {\"name\": \"tripleo_container_manage\", \"tasks_from\": \"shutdown.yml\"}}]}, {\"name\": \"system_upgrade_prepare step 4\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"when\": [\"step|int == 4\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Delete the kernel modules in Leapp database (device_driver_deprecation_data.json)\", \"vars\": {\"modules_to_unload\": []}, \"shell\": \"set -o pipefail && jq \'. | del(.data[] | select(.driver_name == \\\"{{ item }}\\\"))\' /etc/leapp/files/device_driver_deprecation_data.json > /etc/leapp/files/device_driver_deprecation_data.json_modified && mv /etc/leapp/files/device_driver_deprecation_data.json_modified /etc/leapp/files/device_driver_deprecation_data.json\\n\", \"loop\": \"{{ modules_to_unload }}\"}, {\"name\": \"Remove leapp actors to prevent them inhibiting the upgrade\", \"vars\": {\"actors_to_remove\": []}, \"command\": {\"cmd\": \"find /usr/share/leapp-repository/repositories/ -name {{ item }} -type d -print -exec rm -rf \\\"{}\\\" +\"}, \"loop\": \"{{ actors_to_remove }}\"}, {\"name\": \"set leapp required answers\", \"shell\": \"leapp answer --add --section check_vdo.confirm=True\\n\"}, {\"name\": \"Replace EFI grub.cfg with redirect to /boot/grub2/grub.cfg\", \"import_role\": {\"name\": \"tripleo_kernel\", \"tasks_from\": \"efigrub.yml\"}}, {\"name\": \"Keep nics with prefix in NICsPrefixesToUdev from renaming\", \"vars\": {\"nics_prefixes_to_keep\": []}, \"shell\": \"ip -j link show | \\\\ jq -r --arg prefix \\\"{{ item }}\\\" \'.[] |\\n  select((.ifname | startswith($prefix)) and\\n  (.ifname | test(\\\"^.*v[0-9]*$\\\") | not) and\\n  (.ifname | test(\\\"^.*_[0-9]*$\\\") | not) and\\n  (.ifname | test(\\\"^.*\\\\\\\\..*$\\\") | not)) |\\n  if .permaddr? then .address=.permaddr else . end |\\n  \\\"SUBSYSTEM==\\\\\\\"net\\\\\\\",ACTION==\\\\\\\"add\\\\\\\",DRIVERS==\\\\\\\"?*\\\\\\\",\\\" + \\\"NAME=\\\\\\\"\\\" + .ifname +\\\"\\\\\\\" ,ATTR{address}==\\\\\\\"\\\" + .address + \\\"\\\\\\\"\\\"\' >> /etc/udev/rules.d/70-rhosp-persistent-net.rules\\n\", \"loop\": \"{{ nics_prefixes_to_keep|list }}\"}, {\"name\": \"run leapp upgrade (download packages)\", \"shell\": \"{% if upgrade_leapp_devel_skip|default(false) %}{{ upgrade_leapp_devel_skip }}{% endif %} leapp upgrade {% if upgrade_leapp_debug|default(true) %}--debug{% endif %} {% if upgrade_leapp_command_options|default(false) %}{{ upgrade_leapp_command_options }}{% endif %}\\n\", \"when\": \"upgrade_leapp_enabled\"}]}, {\"name\": \"system_upgrade_run step 4\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_reboot\"], \"when\": [\"step|int == 4\", \"upgrade_leapp_enabled\", \"\'Undercloud\' not in group_names\"], \"block\": [{\"name\": \"Run LeappPreRebootCommand\", \"shell\": \"#!/bin/bash\\n\\n\"}, {\"name\": \"Check that nova_libvirt is running\", \"shell\": \"podman ps --filter name=^nova_virtlogd$ --format \\\"{% raw %}{{ .Image }}{% endraw %}\\\"\\n\", \"register\": \"is_virtlogd_image_running\"}, {\"name\": \"Remove systemd files to disable them\", \"file\": {\"path\": \"/etc/systemd/system/{{ item }}\", \"state\": \"absent\"}, \"with_items\": [\"tripleo_nova_libvirt.service\", \"tripleo_nova_virtlogd_wrapper.service\", \"tripleo_nova_libvirt.target\"], \"when\": \"is_virtlogd_image_running.stdout != \'\'\"}, {\"name\": \"reboot to perform the upgrade\", \"reboot\": {\"reboot_timeout\": \"{{upgrade_leapp_reboot_timeout}}\", \"test_command\": \"source /etc/os-release; [ \\\"${VERSION_ID%.*}\\\" -ge \\\"8\\\" ] && systemctl is-system-running | grep -qE \\\"running|degraded\\\" || exit 1\", \"post_reboot_delay\": \"{{ upgrade_leapp_post_reboot_delay }}\"}}, {\"name\": \"Set selinux back to enforcing after leapp reboot\", \"selinux\": {\"policy\": \"targeted\", \"state\": \"enforcing\"}}, {\"name\": \"Run LeappPostRebootCommand\", \"shell\": \"#!/bin/bash\\n\\n\"}]}, {\"name\": \"Host packages setup step0\", \"tags\": \"setup_packages\", \"when\": \"step|int == 0\", \"block\": [{\"name\": \"Package and repo update tasks\", \"block\": [{\"name\": \"Run UpgradeInitCommand\", \"shell\": \"#!/bin/bash\\n\\nif [[ -f /etc/resolv.conf.save ]] ; then rm /etc/resolv.conf.save; fi\\n\\n\"}, {\"name\": \"Run UpgradeInitCommonCommand\", \"shell\": \"#!/bin/bash\\n\\n\"}, {\"name\": \"Ensure DNF modules have the right stream\", \"vars\": {\"dnf_module_list\": []}, \"dnf\": {\"name\": \"@{{ item.module }}:{{ item.stream }}/{{ item.profile|default(\'common\') }}\", \"state\": \"present\"}, \"loop\": \"{{ dnf_module_list|list }}\", \"when\": [\"dnf_module_list|length > 0\", \"item.distribution_version is defined\", \"ansible_facts[\'distribution_major_version\'] is version(item.distribution_version, \'==\')\"]}, {\"name\": \"Ensure TripleO prerequisite packages are installed\", \"package\": {\"name\": [\"jq\", \"lvm2\", \"openstack-selinux\", \"os-net-config\", \"puppet-tripleo\", \"python3-heat-agent*\", \"rsync\"], \"state\": \"present\"}, \"when\": \"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\"}, {\"name\": \"Ensure TripleO prerequisite packages are installed and use role based heat variable to provide specific list of packages\", \"vars\": {\"base_tripleo_packages\": []}, \"package\": {\"name\": \"{{ base_tripleo_packages }}\", \"state\": \"present\"}, \"when\": [\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\", \"base_tripleo_packages|length > 0\"]}, {\"name\": \"WA for 2240185 - If the image is schema 1 and lacks signatures than add empty signatures\", \"shell\": \"for manifest_file in `find /var/lib/containers/storage/overlay-images/ -name \'manifest\'`\\ndo\\n    cat <<< $( jq  \'if .schemaVersion == 1 then if has(\\\"signatures\\\") then . else .signatures=[] end else . end\' $manifest_file ) > $manifest_file\\ndone\\n\", \"when\": \"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\"}]}, {\"name\": \"check if libvirt is installed\", \"command\": \"/usr/bin/rpm -q libvirt-daemon\", \"failed_when\": false, \"register\": \"libvirt_installed\", \"check_mode\": false}, {\"name\": \"make sure libvirt services are disabled and masked\", \"service\": {\"name\": \"{{ item }}\", \"state\": \"stopped\", \"enabled\": false, \"masked\": true, \"daemon_reload\": true}, \"loop\": [\"libvirtd.service\", \"virtlogd.socket\"], \"when\": [\"libvirt_installed.rc == 0\"]}]}, {\"name\": \"Host packages setup step2\", \"tags\": \"setup_packages\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Special treatment for OpenvSwitch\", \"tripleo_ovs_upgrade\": null, \"register\": \"ovs_upgrade\"}, {\"name\": \"Always ensure the openvswitch service is enabled and running after upgrades\", \"service\": {\"name\": \"openvswitch\", \"enabled\": true, \"state\": \"started\"}, \"when\": [\"ovs_upgrade.changed|bool\"]}]}, {\"name\": \"Host packages setup step3\", \"tags\": \"setup_packages\", \"when\": \"step|int == 3\", \"block\": [{\"name\": \"Check for os-net-config upgrade\", \"shell\": \"yum check-upgrade | awk \'/os-net-config/{print}\'\", \"register\": \"os_net_config_need_upgrade\"}, {\"name\": \"Check that os-net-config has legacy configuration\", \"stat\": {\"path\": \"/etc/os-net-config/config.json\", \"get_attributes\": false, \"get_checksum\": false, \"get_mime\": false}, \"register\": \"stat_config_json\"}, {\"name\": \"Check that os-net-config has new configuration\", \"stat\": {\"path\": \"/etc/os-net-config/config.yaml\", \"get_attributes\": false, \"get_checksum\": false, \"get_mime\": false}, \"register\": \"stat_config_yaml\"}, {\"name\": \"Slurp the os-net-config config.json\", \"slurp\": {\"src\": \"/etc/os-net-config/config.json\"}, \"register\": \"os_config_json\", \"when\": [\"stat_config_json.stat.exists\", \"not stat_config_yaml.stat.exists\"]}, {\"name\": \"Write updated /etc/os-net-config/config.yaml\", \"copy\": {\"content\": \"{{ os_config_json.content | b64decode | from_json | to_yaml }}\", \"dest\": \"/etc/os-net-config/config.yaml\"}, \"when\": [\"stat_config_json.stat.exists\", \"not stat_config_yaml.stat.exists\"]}, {\"name\": \"Remove legacy os-net-config configuration\", \"command\": \"mv /etc/os-net-config/config.json /etc/os-net-config/deprecated_config.json\", \"when\": [\"stat_config_json.stat.exists\"]}, {\"block\": [{\"name\": \"Upgrade os-net-config\", \"package\": \"name=os-net-config state=latest\"}, {\"name\": \"take new os-net-config parameters into account now\", \"command\": \"os-net-config --no-activate -c /etc/os-net-config/config.yaml -v --detailed-exit-codes\", \"register\": \"os_net_config_upgrade\", \"failed_when\": \"os_net_config_upgrade.rc not in [0,2]\", \"changed_when\": \"os_net_config_upgrade.rc == 2\"}], \"when\": [\"os_net_config_need_upgrade.stdout\", \"stat_config_yaml.stat.exists or stat_config_json.stat.exists\"]}, {\"name\": \"Update all packages\", \"when\": [\"not skip_package_update|bool\"], \"yum\": {\"name\": \"*\", \"state\": \"latest\", \"exclude\": \"ansible-core\"}, \"vars\": {\"skip_package_update\": false}}, {\"name\": \"Check whether openvswitch exits\", \"command\": \"systemctl status openvswitch.service\", \"register\": \"ovs_service\", \"ignore_errors\": true}, {\"name\": \"Always ensure the openvswitch service is enabled and running after upgrades rhbz#2329821\", \"service\": {\"name\": \"openvswitch\", \"enabled\": true, \"state\": \"started\"}, \"when\": [\"ovs_service.stderr != \\\"Unit openvswitch.service could not be found.\\\"\"]}]}, {\"name\": \"Fetch running ovn_controller image\", \"shell\": \"set -e\\npodman inspect --format \\\"{{\'{{\'}}.ImageName{{\'}}\'}}\\\" ovn_controller\\n\", \"register\": \"running_ovn_image\", \"when\": [\"step|int == 4\"], \"tags\": [\"ovn\", \"ovn_image\"]}, {\"name\": \"Run ovn_controller upgrade\", \"tags\": [\"ovn\", \"ovn_image\"], \"vars\": {\"ovn_controller_image\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\"}, \"when\": [\"step|int == 4\", \"running_ovn_image.stdout != ovn_controller_image\"], \"block\": [{\"name\": \"Force pull image in case image name doesn\'t change.\", \"when\": \"step|int == 4\", \"tags\": [\"ovn\", \"ovn_image\"], \"containers.podman.podman_image\": {\"name\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"validate_certs\": false, \"force\": true}}, {\"name\": \"Update OVN OVS related parameters before update.\", \"when\": [\"step|int == 4\"], \"tags\": [\"ovn\"], \"vars\": {\"timeout\": 8000}, \"shell\": \"set -e\\novs-vsctl set Open_vSwitch . external_ids:ovn-ofctrl-wait-before-clear={{ timeout }}\\novs-vsctl set Open_vSwitch . external_ids:ovn-monitor-all=true\\novs-vsctl set Open_vSwitch . external_ids:ovn-match-northd-version=false\\n\"}, {\"name\": \"Find ovn_controller configs in container-startup-configs\", \"find\": {\"paths\": \"/var/lib/tripleo-config/container-startup-config/\", \"patterns\": \"*ovn_controller.json\", \"recurse\": true}, \"register\": \"ovn_cont_17_0\", \"when\": [\"step|int == 4\"], \"tags\": [\"ovn\"]}, {\"name\": \"get directory path from the ovn_cont_17_0\", \"set_fact\": {\"ovn_config_path\": \"{{ ovn_cont_17_0.files.0.path | dirname }}\"}, \"when\": \"step|int == 4\", \"tags\": \"ovn\"}, {\"name\": \"Get PIDfile used by systemd on each ovn node\", \"when\": [\"step|int == 4\"], \"tags\": [\"ovn\"], \"shell\": \"set -e\\ngrep PID /etc/systemd/system/tripleo_ovn_controller.service | cut -d= -f2\\n\", \"register\": \"pidfile\"}, {\"name\": \"Update ovn_controller.\", \"vars\": {\"config_step\": \"{{ (\'step_4\' in ovn_config_path) | ternary(\'4\', \'3\')}}\"}, \"when\": \"step|int == 4\", \"tags\": \"ovn\", \"tripleo_container_manage\": {\"config_dir\": \"{{ ovn_config_path }}\", \"config_patterns\": \"*ovn_controller.json\", \"config_id\": [\"tripleo_step{{config_step}}\"], \"log_base_path\": \"{{ container_log_stdout_path }}\", \"debug\": \"{{ enable_debug | bool }}\", \"config_overrides\": {\".*ovn_controller\": {\"image\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"conmon_pidfile\": \"{{ pidfile.stdout }}\", \"name\": \"ovn_controller\"}}}}, {\"name\": \"Pause for 30s to give ovn_controllers time to reconnect to dbs\", \"when\": [\"step|int == 4\"], \"tags\": \"ovn\", \"wait_for\": {\"timeout\": 30}}]}], \"post_upgrade_tasks\": [{\"name\": \"Ensure instanceha directory is purged\", \"when\": \"step|int == 1\", \"become\": true, \"file\": {\"path\": \"/var/lib/nova/instanceha\", \"state\": \"absent\"}}, {\"name\": \"Purge Podman\", \"when\": [\"(step | int) == 3\", \"container_cli == \'podman\'\", \"deployment_source_hosts not in group_names\"], \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_purge.yml\"}, \"vars\": {\"deployment_source_hosts\": \"Undercloud\"}}], \"update_tasks\": [{\"name\": \"remove rsyslog configuration for podman healthcheck log\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_rsyslog_cleanup\"}}, {\"name\": \"Remove openstack-nova-compute and python-nova package during upgrade\", \"package\": {\"name\": [\"openstack-nova-compute\", \"python-nova\"], \"state\": \"removed\"}, \"failed_when\": false, \"when\": \"step|int == 2\"}, {\"name\": \"check systemd-container package present or not\", \"package\": {\"name\": \"systemd-container\", \"state\": \"present\"}, \"check_mode\": true, \"register\": \"is_systemd_container_package\"}, {\"name\": \"download systemd-container package if not present\", \"yum\": {\"name\": \"systemd-container\", \"state\": \"present\", \"download_only\": true, \"download_dir\": \"/var/tmp/\"}, \"when\": \"is_systemd_container_package.changed\"}, {\"name\": \"nova_libvirt_container_tmpfile_cleanup\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Remove old tmpfiles.d config\", \"file\": {\"path\": \"/etc/tmpfiles.d/var-run-libvirt.conf\", \"state\": \"absent\"}}]}, {\"name\": \"nova_migration_target_tmpfile_cleanup\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Remove old tmpfiles.d config\", \"file\": {\"path\": \"/etc/tmpfiles.d/var-run-libvirt.conf\", \"state\": \"absent\"}}]}, {\"name\": \"Ensure old cron.daily is absent\", \"when\": \"step|int == 1\", \"file\": {\"path\": \"/etc/cron.daily/containers-tmpwatch\", \"state\": \"absent\"}}, {\"name\": \"Force pre-fetch of container images\", \"when\": [\"(step|int) == 5\"], \"block\": [{\"name\": \"Pre-fetch all the containers\", \"become\": true, \"containers.podman.podman_image\": {\"name\": \"{{ prefetch_image }}\", \"validate_certs\": false, \"force\": true}, \"register\": \"result\", \"until\": \"result is succeeded\", \"retries\": 5, \"delay\": 5, \"loop_control\": {\"loop_var\": \"prefetch_image\"}, \"loop\": \"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\"}]}, {\"name\": \"Cleanup tripleo-iptables services\", \"when\": [\"(step | int) == 1\"], \"block\": [{\"name\": \"Disable tripleo-iptables.service\", \"systemd\": {\"name\": \"tripleo-iptables.service\", \"state\": \"stopped\", \"enabled\": false}, \"register\": \"systemd_tripleo_iptables\", \"failed_when\": false}, {\"name\": \"Cleanup tripleo-iptables.services\", \"file\": {\"path\": \"/etc/systemd/system/tripleo-iptables.service\", \"state\": \"absent\"}}, {\"name\": \"Disable tripleo-ip6tables.service\", \"systemd\": {\"name\": \"tripleo-ip6tables.service\", \"state\": \"stopped\", \"enabled\": false}, \"register\": \"systemd_tripleo_ip6tables\", \"failed_when\": false}, {\"name\": \"Cleanup tripleo-ip6tables.services\", \"file\": {\"path\": \"/etc/systemd/system/tripleo-ip6tables.service\", \"state\": \"absent\"}}, {\"name\": \"Reload systemd\", \"systemd\": {\"daemon_reload\": true}, \"when\": [\"(systemd_tripleo_iptables is changed or systemd_tripleo_ip6tables is changed)\"]}]}, {\"name\": \"Enforce RHOSP rules regarding subscription.\", \"include_role\": {\"name\": \"tripleo_redhat_enforce\"}, \"vars\": {\"skip_rhel_enforcement\": false}, \"when\": [\"step|int == 0\", \"ansible_facts[\'distribution\'] == \'RedHat\'\", \"not (skip_rhel_enforcement | bool)\"]}, {\"name\": \"Ensure DNF modules have the right stream enabled\", \"vars\": {\"dnf_module_list\": []}, \"tripleo_dnf_stream\": {\"name\": \"{{ item.module }}:{{ item.stream }}\", \"state\": \"enabled\"}, \"loop\": \"{{ dnf_module_list|list }}\", \"when\": [\"step|int == 0\", \"dnf_module_list|length > 0\", \"item.distribution_version is defined\", \"ansible_facts[\'distribution_major_version\'] is version(item.distribution_version, \'==\')\"]}, {\"name\": \"Check for existing yum.pid\", \"stat\": \"path=/run/yum.pid\", \"register\": \"yum_pid_file\", \"when\": \"step|int == 0 or step|int == 3\"}, {\"name\": \"Exit if existing yum process\", \"fail\": \"msg=\\\"ERROR existing yum.pid detected - can\'t continue! Please ensure there is no other package update process for the duration of the minor update worfklow. Exiting.\\\"\", \"when\": \"(step|int == 0 or step|int == 3) and yum_pid_file.stat.exists\"}, {\"name\": \"Special treatment for OpenvSwitch\", \"tripleo_ovs_upgrade\": null, \"when\": [\"step|int == 2\"], \"register\": \"ovs_upgrade\"}, {\"name\": \"Always ensure the openvswitch service is enabled and running after upgrades\", \"service\": {\"name\": \"openvswitch\", \"enabled\": true, \"state\": \"started\"}, \"when\": [\"step|int == 2\", \"ovs_upgrade.changed|bool\"]}, {\"name\": \"Update packages and EFI grub.cfg\", \"when\": [\"step|int == 3\", \"not skip_package_update|bool\"], \"block\": [{\"name\": \"Update all packages\", \"yum\": {\"name\": \"*\", \"state\": \"latest\", \"exclude\": \"ansible-core\"}}, {\"name\": \"Replace EFI grub.cfg with redirect to /boot/grub2/grub.cfg\", \"import_role\": {\"name\": \"tripleo_kernel\", \"tasks_from\": \"efigrub.yml\"}}], \"vars\": {\"skip_package_update\": false}}, {\"name\": \"Ensure openvswitch is running after update\", \"when\": \"step|int == 3\", \"service\": {\"name\": \"openvswitch\", \"enabled\": true, \"state\": \"started\"}, \"ignore_errors\": true}], \"post_update_tasks\": [{\"name\": \"Ensure instanceha directory is purged\", \"when\": \"step|int == 1\", \"become\": true, \"file\": {\"path\": \"/var/lib/nova/instanceha\", \"state\": \"absent\"}}, {\"name\": \"Purge Podman\", \"when\": [\"(step | int) == 3\", \"container_cli == \'podman\'\", \"deployment_source_hosts not in group_names\"], \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_purge.yml\"}, \"vars\": {\"deployment_source_hosts\": \"Undercloud\"}}], \"upgrade_batch_tasks\": [], \"service_metadata_settings\": null, \"ansible_group_vars\": {\"ansible_async_dir\": \"/tmp/.ansible_async\", \"tripleo_tripleo_lvmfilter_enabled\": false, \"tripleo_tripleo_lvmfilter_devices_allowlist\": [], \"tripleo_tripleo_lvmfilter_devices_denylist\": [\".*\"], \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"hieradata_localhost_address\": \"localhost\", \"tripleo_kernel_extra_modules\": {}, \"tripleo_kernel_extra_packages\": {}, \"tripleo_kernel_sysctl_extra_settings\": {\"net.ipv6.conf.default.disable_ipv6\": {\"value\": 0}, \"net.ipv4.ip_local_reserved_ports\": {\"value\": \"35357,49000-49001\"}, \"net.ipv6.conf.all.disable_ipv6\": {\"value\": 0}, \"net.ipv6.conf.lo.disable_ipv6\": {\"value\": 0}, \"net.ipv4.ip_forward\": {\"value\": 1}, \"net.ipv4.conf.all.rp_filter\": {\"value\": 1}, \"net.ipv6.conf.all.forwarding\": {\"value\": 0}, \"net.ipv4.ip_nonlocal_bind\": {\"value\": 1}, \"net.ipv6.ip_nonlocal_bind\": {\"value\": 1}, \"kernel.pid_max\": {\"value\": 1048576}, \"net.ipv4.neigh.default.gc_thresh1\": {\"value\": 1024}, \"net.ipv4.neigh.default.gc_thresh2\": {\"value\": 2048}, \"net.ipv4.neigh.default.gc_thresh3\": {\"value\": 4096}, \"net.bridge.bridge-nf-call-arptables\": {\"value\": 1}, \"net.bridge.bridge-nf-call-iptables\": {\"value\": 1}, \"net.bridge.bridge-nf-call-ip6tables\": {\"value\": 1}, \"fs.inotify.max_user_instances\": {\"value\": 1024}, \"fs.aio-max-nr\": {\"value\": 1048576}}, \"tripleo_nova_libvirt_virsh_container\": \"nova_virtproxyd\", \"chrony_role_action\": \"all\", \"chrony_ntp_servers\": [\"pool.ntp.org\"], \"chrony_ntp_pools\": [], \"chrony_global_server_settings\": \"iburst minpoll 6 maxpoll 10\", \"chrony_global_pool_settings\": \"iburst minpoll 6 maxpoll 10\", \"chrony_manage_package\": true, \"chrony_acl_rules\": [\"deny all\"], \"tripleo_nftables_debug\": true, \"tuned_profile\": \"throughput-performance\", \"tuned_custom_profile\": \"\"}, \"keystone_resources\": {}, \"firewall_rules\": {\"109 metrics qdr\": {\"dport\": [5666]}, \"109 accept internal metrics qdr ctlplane subnet 192.168.122.0/24\": {\"dport\": [5667, 5668]}, \"200 nova_libvirt\": {\"dport\": [16514, \"61152-61215\", \"5900-6923\"]}, \"113 nova_migration_target accept libvirt subnet 172.17.0.0/24\": {\"source\": \"172.17.0.0/24\", \"proto\": \"tcp\", \"dport\": 2022}, \"113 nova_migration_target accept api subnet 172.17.0.0/24\": {\"source\": \"172.17.0.0/24\", \"proto\": \"tcp\", \"dport\": 2022}, \"124 snmp 192.168.122.0/24\": {\"dport\": 161, \"proto\": \"udp\", \"source\": \"192.168.122.0/24\"}, \"003 accept ssh from all\": {\"proto\": \"tcp\", \"dport\": 22, \"extras\": {\"ensure\": \"present\"}}, \"105 ntp\": {\"dport\": 123, \"proto\": \"udp\"}, \"003 accept ssh from ctlplane subnet 192.168.122.0/24\": {\"source\": \"192.168.122.0/24\", \"proto\": \"tcp\", \"dport\": 22}, \"118 neutron vxlan networks\": {\"proto\": \"udp\", \"dport\": 4789, \"state\": []}, \"119 neutron geneve networks\": {\"proto\": \"udp\", \"dport\": 6081, \"state\": []}, \"120 neutron geneve networks no conntrack\": {\"proto\": \"udp\", \"dport\": 6081, \"table\": \"raw\", \"chain\": \"OUTPUT\", \"jump\": \"NOTRACK\", \"action\": \"append\", \"state\": [\"INVALID\"]}, \"121 neutron geneve networks no conntrack\": {\"proto\": \"udp\", \"dport\": 6081, \"table\": \"raw\", \"chain\": \"PREROUTING\", \"jump\": \"NOTRACK\", \"action\": \"append\", \"state\": [\"INVALID\"]}}, \"firewall_frontend_rules\": {}, \"firewall_ssl_frontend_rules\": {}, \"firewall_edge_frontend_rules\": {}, \"firewall_edge_ssl_frontend_rules\": null, \"puppet_config\": [{\"config_volume\": \"collectd\", \"puppet_tags\": \"collectd_client_config,exec\", \"step_config\": \"include tripleo::profile::base::metrics::collectd\", \"config_image\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\"}, {\"config_volume\": \"ceilometer\", \"puppet_tags\": \"ceilometer_config\", \"step_config\": \"include tripleo::profile::base::ceilometer::agent::polling\", \"config_image\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, {\"config_volume\": \"ceilometer\", \"puppet_tags\": \"ceilometer_config\", \"step_config\": \"include tripleo::profile::base::ceilometer::agent::polling\\n\", \"config_image\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, {\"config_volume\": \"iscsid\", \"puppet_tags\": \"iscsid_config\", \"step_config\": \"include tripleo::profile::base::iscsid\\n\", \"config_image\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"volumes\": [\"/etc/iscsi:/tmp/iscsi.host:z\"]}, {\"config_volume\": \"metrics_qdr\", \"step_config\": \"include tripleo::profile::base::metrics::qdr\\n\", \"config_image\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\"}, {\"config_volume\": \"nova_libvirt\", \"puppet_tags\": \"nova_config\", \"step_config\": \"# TODO(emilien): figure how to deal with libvirt profile.\\n# We\'ll probably treat it like we do with Neutron plugins.\\n# Until then, just include it in the default nova-compute role.\\ninclude tripleo::profile::base::nova::compute::libvirt\\n\", \"config_image\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\"}, {\"config_volume\": \"nova_libvirt\", \"puppet_tags\": \"libvirtd_config,virtlogd_config,virtproxyd_config,virtqemud_config,virtnodedevd_config,virtsecretd_config,virtstoraged_config,nova_config,file,libvirt_tls_password\", \"step_config\": \"include tripleo::profile::base::nova::libvirt\\n\", \"config_image\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\"}, {\"config_volume\": \"nova_libvirt\", \"puppet_tags\": \"libvirtd_config,nova_config,file,libvirt_tls_password\", \"step_config\": \"include tripleo::profile::base::nova::compute::libvirt_guests\\n\", \"config_image\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\"}, {\"config_volume\": \"nova_libvirt\", \"step_config\": \"include tripleo::profile::base::sshd\\ninclude tripleo::profile::base::nova::migration::target\", \"config_image\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\"}, {\"config_volume\": \"crond\", \"step_config\": \"include tripleo::profile::base::logging::logrotate\", \"config_image\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\"}, {\"config_volume\": \"rsyslog\", \"puppet_tags\": \"rsyslog::generate_concat,concat::fragment\", \"step_config\": \"include tripleo::profile::base::logging::rsyslog\", \"config_image\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\"}, {\"puppet_tags\": \"vs_config,exec\", \"config_volume\": \"ovn_controller\", \"step_config\": \"include tripleo::profile::base::neutron::agents::ovn\\n\", \"config_image\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"volumes\": [\"/lib/modules:/lib/modules:ro\", \"/run/openvswitch:/run/openvswitch:shared,z\", \"/etc/sysconfig/modules:/etc/sysconfig/modules\"]}, {\"puppet_tags\": \"neutron_config,ovn_metadata_agent_config\", \"config_volume\": \"neutron\", \"step_config\": \"include tripleo::profile::base::neutron::ovn_metadata\\n\", \"config_image\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"volumes\": [\"/lib/modules:/lib/modules:ro\", \"/run/openvswitch:/run/openvswitch:shared,z\"]}], \"kolla_config\": {\"/var/lib/kolla/config_files/collectd.json\": {\"command\": \"/usr/sbin/collectd -f\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/collectd.d\", \"dest\": \"/etc/\", \"merge\": false, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/collectd\", \"owner\": \"collectd:collectd\", \"recurse\": true}, {\"path\": \"/scripts\", \"owner\": \"collectd:collectd\", \"recurse\": true}, {\"path\": \"/config-scripts\", \"owner\": \"collectd:collectd\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/ceilometer_agent_compute.json\": {\"command\": \"/usr/bin/ceilometer-polling --polling-namespaces compute --logfile /var/log/ceilometer/compute.log\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/ceilometer-agent-ipmi.json\": {\"command\": \"/usr/bin/ceilometer-polling --polling-namespaces ipmi --logfile /var/log/ceilometer/ipmi.log\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/iscsid.json\": {\"command\": \"/usr/sbin/iscsid -f\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src-iscsid/\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/metrics_qdr.json\": {\"command\": \"/usr/sbin/qdrouterd -c /etc/qpid-dispatch/qdrouterd.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/lib/qdrouterd\", \"owner\": \"qdrouterd:qdrouterd\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/metrics_qdr.crt\", \"owner\": \"qdrouterd:qdrouterd\", \"optional\": true}, {\"path\": \"/etc/pki/tls/private/metrics_qdr.key\", \"owner\": \"qdrouterd:qdrouterd\", \"optional\": true}]}, \"/var/lib/kolla/config_files/nova_compute.json\": {\"command\": \"/usr/bin/nova-compute \", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/nova\", \"owner\": \"nova:nova\", \"recurse\": true}, {\"path\": \"/etc/ceph/ceph.client.openstack.keyring\", \"owner\": \"nova:nova\", \"perm\": \"0600\"}]}, \"/var/lib/kolla/config_files/nova_compute_wait_for_compute_service.json\": {\"command\": \"/container-config-scripts/pyshim.sh /container-config-scripts/nova_wait_for_compute_service.py\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/nova\", \"owner\": \"nova:nova\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/nova_virtlogd.json\": {\"command\": \"/usr/local/bin/virtlogd_wrapper\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/etc/ceph/ceph.client.openstack.keyring\", \"owner\": \"nova:nova\", \"perm\": \"0600\"}]}, \"/var/lib/kolla/config_files/nova_virtsecretd.json\": {\"command\": \"/usr/sbin/virtsecretd --config /etc/libvirt/virtsecretd.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/etc/ceph/ceph.client.openstack.keyring\", \"owner\": \"nova:nova\", \"perm\": \"0600\"}]}, \"/var/lib/kolla/config_files/nova_virtnodedevd.json\": {\"command\": \"/usr/sbin/virtnodedevd --config /etc/libvirt/virtnodedevd.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/etc/ceph/ceph.client.openstack.keyring\", \"owner\": \"nova:nova\", \"perm\": \"0600\"}]}, \"/var/lib/kolla/config_files/nova_virtstoraged.json\": {\"command\": \"/usr/sbin/virtstoraged --config /etc/libvirt/virtstoraged.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/etc/ceph/ceph.client.openstack.keyring\", \"owner\": \"nova:nova\", \"perm\": \"0600\"}]}, \"/var/lib/kolla/config_files/nova_virtqemud.json\": {\"command\": \"/usr/sbin/virtqemud --config /etc/libvirt/virtqemud.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/etc/ceph/ceph.client.openstack.keyring\", \"owner\": \"nova:nova\", \"perm\": \"0600\"}]}, \"/var/lib/kolla/config_files/nova_virtproxyd.json\": {\"command\": \"/usr/sbin/virtproxyd --config /etc/libvirt/virtproxyd.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/etc/ceph/ceph.client.openstack.keyring\", \"owner\": \"nova:nova\", \"perm\": \"0600\"}]}, \"/var/lib/kolla/config_files/nova-migration-target.json\": {\"command\": \"dumb-init --single-child -- /usr/sbin/sshd -D -p 2022\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/host-ssh/ssh_host_*_key\", \"dest\": \"/etc/ssh/\", \"owner\": \"root\", \"perm\": \"0600\"}]}, \"/var/lib/kolla/config_files/logrotate-crond.json\": {\"command\": \"/usr/sbin/crond -s -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/rsyslog.json\": {\"command\": \"/usr/sbin/rsyslogd -n -iNONE\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/lib/rsyslog\", \"owner\": \"root:root\", \"recurse\": true}, {\"path\": \"/var/log/rsyslog\", \"owner\": \"root:root\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/ovn_controller.json\": {\"command\": \"/usr/bin/ovn-controller --pidfile --log-file unix:/run/openvswitch/db.sock \", \"permissions\": [{\"path\": \"/var/log/openvswitch\", \"owner\": \"root:root\", \"recurse\": true}, {\"path\": \"/var/log/ovn\", \"owner\": \"root:root\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/ovn_metadata_agent.json\": {\"command\": \"/usr/bin/networking-ovn-metadata-agent --config-file /etc/neutron/neutron.conf --config-file /etc/neutron/plugins/networking-ovn/networking-ovn-metadata-agent.ini --log-file=/var/log/neutron/ovn-metadata-agent.log\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/neutron\", \"owner\": \"neutron:neutron\", \"recurse\": true}, {\"path\": \"/var/lib/neutron\", \"owner\": \"neutron:neutron\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/ovn_metadata.crt\", \"owner\": \"neutron:neutron\", \"optional\": true, \"perm\": \"0644\"}, {\"path\": \"/etc/pki/tls/private/ovn_metadata.key\", \"owner\": \"neutron:neutron\", \"optional\": true, \"perm\": \"0644\"}]}}, \"docker_config\": {\"step_3\": {\"collectd\": {\"image\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"net\": \"host\", \"pid\": \"host\", \"user\": \"root\", \"restart\": \"always\", \"memory\": \"512m\", \"cap_add\": [\"IPC_LOCK\"], \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": [\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\", \"/etc/puppet:/etc/puppet:ro\", \"/var/lib/kolla/config_files/collectd.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/containers/storage/overlay-containers:/var/lib/containers/storage/overlay-containers:ro\", \"/var/lib/config-data/puppet-generated/collectd:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/collectd:/var/log/collectd:rw,z\", \"/var/lib/container-config-scripts:/config-scripts:ro\", \"/var/lib/container-user-scripts:/scripts:z\", \"/run:/run:rw\", \"/sys/fs/cgroup:/sys/fs/cgroup:ro\"], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"ceilometer_init_log\": {\"start_order\": 0, \"image\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"net\": \"none\", \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"chown -R ceilometer:ceilometer /var/log/ceilometer\"], \"volumes\": [\"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]}, \"iscsid\": {\"start_order\": 2, \"image\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"net\": \"host\", \"privileged\": true, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": [\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\", \"/etc/puppet:/etc/puppet:ro\", \"/var/lib/kolla/config_files/iscsid.json:/var/lib/kolla/config_files/config.json:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", \"/etc/target:/etc/target:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"nova_statedir_owner\": {\"image\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"net\": \"none\", \"user\": \"root\", \"security_opt\": [\"label=disable\"], \"privileged\": false, \"detach\": false, \"volumes\": [\"/var/lib/nova:/var/lib/nova:shared\", \"/var/lib/_nova_secontext:/var/lib/_nova_secontext:shared,z\", \"/var/lib/container-config-scripts:/container-config-scripts:z\"], \"command\": \"/container-config-scripts/pyshim.sh /container-config-scripts/nova_statedir_ownership.py\", \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": \"1781252715\", \"__OS_DEBUG\": \"true\", \"NOVA_STATEDIR_OWNERSHIP_SKIP\": \"triliovault-mounts\"}}, \"nova_virtlogd_wrapper\": {\"start_order\": 0, \"image\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ulimit\": [\"nofile=131072\", \"nproc=126960\"], \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"volumes\": [\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\", \"/etc/puppet:/etc/puppet:ro\", \"/var/log/containers/libvirt:/var/log/libvirt:shared,z\", \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys/fs/cgroup:/sys/fs/cgroup\", \"/sys/fs/selinux:/sys/fs/selinux\", \"/etc/selinux/config:/etc/selinux/config:ro\", \"/etc/libvirt:/etc/libvirt:shared\", \"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\", \"/run/libvirt:/run/libvirt:shared,z\", \"/var/lib/nova:/var/lib/nova:shared\", \"/var/lib/libvirt:/var/lib/libvirt:shared\", \"/var/cache/libvirt:/var/cache/libvirt:shared\", \"/var/lib/vhost_sockets:/var/lib/vhost_sockets\", \"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\", \"/var/lib/tripleo-config/ceph:/var/lib/kolla/config_files/src-ceph:z\", \"/var/lib/kolla/config_files/nova_virtlogd.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/container-config-scripts/virtlogd_wrapper:/usr/local/bin/virtlogd_wrapper:ro\"], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"nova_virtsecretd\": {\"start_order\": 1, \"image\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ulimit\": [\"nofile=131072\", \"nproc=126960\"], \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"pids_limit\": 65536, \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"depends_on\": [\"tripleo_nova_virtlogd_wrapper.service\"], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}, \"volumes\": [\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\", \"/etc/puppet:/etc/puppet:ro\", \"/var/log/containers/libvirt:/var/log/libvirt:shared,z\", \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys/fs/cgroup:/sys/fs/cgroup\", \"/sys/fs/selinux:/sys/fs/selinux\", \"/etc/selinux/config:/etc/selinux/config:ro\", \"/etc/libvirt:/etc/libvirt:shared\", \"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\", \"/run/libvirt:/run/libvirt:shared,z\", \"/var/lib/nova:/var/lib/nova:shared\", \"/var/lib/libvirt:/var/lib/libvirt:shared\", \"/var/cache/libvirt:/var/cache/libvirt:shared\", \"/var/lib/vhost_sockets:/var/lib/vhost_sockets\", \"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\", \"/var/lib/tripleo-config/ceph:/var/lib/kolla/config_files/src-ceph:z\", \"/var/lib/kolla/config_files/nova_virtsecretd.json:/var/lib/kolla/config_files/config.json:ro\"]}, \"nova_virtnodedevd\": {\"start_order\": 2, \"image\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ulimit\": [\"nofile=131072\", \"nproc=126960\"], \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"pids_limit\": 65536, \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"depends_on\": [\"tripleo_nova_virtlogd_wrapper.service\"], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}, \"volumes\": [\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\", \"/etc/puppet:/etc/puppet:ro\", \"/var/log/containers/libvirt:/var/log/libvirt:shared,z\", \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys/fs/cgroup:/sys/fs/cgroup\", \"/sys/fs/selinux:/sys/fs/selinux\", \"/etc/selinux/config:/etc/selinux/config:ro\", \"/etc/libvirt:/etc/libvirt:shared\", \"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\", \"/run/libvirt:/run/libvirt:shared,z\", \"/var/lib/nova:/var/lib/nova:shared\", \"/var/lib/libvirt:/var/lib/libvirt:shared\", \"/var/cache/libvirt:/var/cache/libvirt:shared\", \"/var/lib/vhost_sockets:/var/lib/vhost_sockets\", \"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\", \"/var/lib/tripleo-config/ceph:/var/lib/kolla/config_files/src-ceph:z\", \"/var/lib/kolla/config_files/nova_virtnodedevd.json:/var/lib/kolla/config_files/config.json:ro\"]}, \"nova_virtstoraged\": {\"start_order\": 3, \"image\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ulimit\": [\"nofile=131072\", \"nproc=126960\"], \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"pids_limit\": 65536, \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"depends_on\": [\"tripleo_nova_virtlogd_wrapper.service\"], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}, \"volumes\": [\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\", \"/etc/puppet:/etc/puppet:ro\", \"/var/log/containers/libvirt:/var/log/libvirt:shared,z\", \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys/fs/cgroup:/sys/fs/cgroup\", \"/sys/fs/selinux:/sys/fs/selinux\", \"/etc/selinux/config:/etc/selinux/config:ro\", \"/etc/libvirt:/etc/libvirt:shared\", \"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\", \"/run/libvirt:/run/libvirt:shared,z\", \"/var/lib/nova:/var/lib/nova:shared\", \"/var/lib/libvirt:/var/lib/libvirt:shared\", \"/var/cache/libvirt:/var/cache/libvirt:shared\", \"/var/lib/vhost_sockets:/var/lib/vhost_sockets\", \"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\", \"/var/lib/tripleo-config/ceph:/var/lib/kolla/config_files/src-ceph:z\", \"/var/lib/kolla/config_files/nova_virtstoraged.json:/var/lib/kolla/config_files/config.json:ro\"]}, \"nova_virtqemud\": {\"start_order\": 4, \"image\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ulimit\": [\"nofile=131072\", \"nproc=126960\"], \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"pids_limit\": 65536, \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"depends_on\": [\"tripleo_nova_virtlogd_wrapper.service\"], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}, \"volumes\": [\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\", \"/etc/puppet:/etc/puppet:ro\", \"/var/log/containers/libvirt:/var/log/libvirt:shared,z\", \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys/fs/cgroup:/sys/fs/cgroup\", \"/sys/fs/selinux:/sys/fs/selinux\", \"/etc/selinux/config:/etc/selinux/config:ro\", \"/etc/libvirt:/etc/libvirt:shared\", \"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\", \"/run/libvirt:/run/libvirt:shared,z\", \"/var/lib/nova:/var/lib/nova:shared\", \"/var/lib/libvirt:/var/lib/libvirt:shared\", \"/var/cache/libvirt:/var/cache/libvirt:shared\", \"/var/lib/vhost_sockets:/var/lib/vhost_sockets\", \"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\", \"/var/lib/tripleo-config/ceph:/var/lib/kolla/config_files/src-ceph:z\", \"/var/lib/kolla/config_files/nova_virtqemud.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/log/containers/libvirt/swtpm:/var/log/swtpm:z\"]}, \"nova_virtproxyd\": {\"start_order\": 5, \"image\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ulimit\": [\"nofile=131072\", \"nproc=126960\"], \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"pids_limit\": 65536, \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"depends_on\": [\"tripleo_nova_virtlogd_wrapper.service\"], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}, \"volumes\": [\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\", \"/etc/puppet:/etc/puppet:ro\", \"/var/log/containers/libvirt:/var/log/libvirt:shared,z\", \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys/fs/cgroup:/sys/fs/cgroup\", \"/sys/fs/selinux:/sys/fs/selinux\", \"/etc/selinux/config:/etc/selinux/config:ro\", \"/etc/libvirt:/etc/libvirt:shared\", \"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\", \"/run/libvirt:/run/libvirt:shared,z\", \"/var/lib/nova:/var/lib/nova:shared\", \"/var/lib/libvirt:/var/lib/libvirt:shared\", \"/var/cache/libvirt:/var/cache/libvirt:shared\", \"/var/lib/vhost_sockets:/var/lib/vhost_sockets\", \"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\", \"/var/lib/tripleo-config/ceph:/var/lib/kolla/config_files/src-ceph:z\", \"/var/lib/kolla/config_files/nova_virtproxyd.json:/var/lib/kolla/config_files/config.json:ro\"]}, \"rsyslog\": {\"image\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"restart\": \"always\", \"security_opt\": [\"label=disable\"], \"volumes\": [\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\", \"/etc/puppet:/etc/puppet:ro\", \"/var/lib/kolla/config_files/rsyslog.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/rsyslog:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers:/var/log/containers:ro\", \"/var/log/containers/rsyslog:/var/log/rsyslog:rw,z\", \"/var/log:/var/log/host:ro\", \"/var/lib/rsyslog.container:/var/lib/rsyslog:rw,z\"], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}, \"step_4\": {\"ceilometer_agent_compute\": {\"image\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"depends_on\": [\"tripleo_nova_libvirt.target\"], \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": [\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\", \"/etc/puppet:/etc/puppet:ro\", \"/var/lib/kolla/config_files/ceilometer_agent_compute.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/run/libvirt:/run/libvirt:shared,z\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"ceilometer_agent_ipmi\": {\"image\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"net\": \"host\", \"privileged\": true, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": [\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\", \"/etc/puppet:/etc/puppet:ro\", \"/var/lib/kolla/config_files/ceilometer-agent-ipmi.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"nova_migration_target\": {\"image\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": [\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\", \"/etc/puppet:/etc/puppet:ro\", \"/var/lib/kolla/config_files/nova-migration-target.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\", \"/etc/ssh:/host-ssh:ro\", \"/run/libvirt:/run/libvirt:shared,z\", \"/var/lib/nova:/var/lib/nova:shared\"], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"logrotate_crond\": {\"image\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"net\": \"none\", \"pid\": \"host\", \"privileged\": true, \"user\": \"root\", \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron\"}, \"volumes\": [\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\", \"/etc/puppet:/etc/puppet:ro\", \"/var/lib/kolla/config_files/logrotate-crond.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/crond:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers:/var/log/containers:z\"], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"configure_cms_options\": {\"start_order\": 0, \"detach\": false, \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"CMS_OPTS=$(hiera ovn::controller::ovn_cms_options -c /etc/puppet/hiera.yaml);  if [ X\\\"$CMS_OPTS\\\" !=  X ]; then ovs-vsctl set open . external_ids:ovn-cms-options=$CMS_OPTS;else ovs-vsctl remove open . external_ids ovn-cms-options; fi\"], \"image\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"volumes\": [\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\", \"/etc/puppet:/etc/puppet:ro\", \"/lib/modules:/lib/modules:ro\", \"/run/openvswitch:/run/openvswitch:shared,z\"], \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": \"1781252715\"}}, \"ovn_controller\": {\"start_order\": 1, \"image\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"restart\": \"always\", \"depends_on\": [\"openvswitch.service\"], \"healthcheck\": {\"test\": \"/openstack/healthcheck 6642\"}, \"volumes\": [\"/var/lib/kolla/config_files/ovn_controller.json:/var/lib/kolla/config_files/config.json:ro\", \"/lib/modules:/lib/modules:ro\", \"/run:/run\", \"/var/lib/openvswitch/ovn:/run/ovn:shared,z\", \"/var/log/containers/openvswitch:/var/log/openvswitch:z\", \"/var/log/containers/openvswitch:/var/log/ovn:z\"], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"setup_ovs_manager\": {\"start_order\": 0, \"detach\": false, \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"command\": [\"/container_puppet_apply.sh\", \"4\", \"exec\", \"include tripleo::profile::base::neutron::ovn_metadata\"], \"image\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"volumes\": [\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\", \"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\", \"/lib/modules:/lib/modules:ro\", \"/run/openvswitch:/run/openvswitch:shared,z\"], \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": \"1781252715\"}}, \"ovn_metadata_agent\": {\"start_order\": 1, \"image\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"net\": \"host\", \"pid\": \"host\", \"cgroupns\": \"host\", \"privileged\": true, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": [\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\", \"/etc/puppet:/etc/puppet:ro\", \"/var/log/containers/neutron:/var/log/neutron:z\", \"/var/lib/kolla/config_files/ovn_metadata_agent.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/neutron:/var/lib/kolla/config_files/src:ro\", \"/lib/modules:/lib/modules:ro\", \"/run/openvswitch:/run/openvswitch:shared,z\", \"/var/lib/neutron:/var/lib/neutron:shared,z\", \"/run/netns:/run/netns:shared\", \"/var/lib/neutron/kill_scripts:/etc/neutron/kill_scripts:shared,z\", \"/var/lib/neutron/ovn_metadata_haproxy_wrapper:/usr/local/bin/haproxy:ro\"], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}, \"step_1\": {\"metrics_qdr_init_logs\": {\"start_order\": 0, \"detach\": false, \"image\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/metrics_qdr:/var/log/qdrouterd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R qdrouterd:qdrouterd /var/log/qdrouterd\"]}, \"metrics_qdr\": {\"start_order\": 1, \"image\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"net\": \"host\", \"user\": \"qdrouterd\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": [\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\", \"/etc/puppet:/etc/puppet:ro\", \"/var/lib/kolla/config_files/metrics_qdr.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/metrics_qdr:/var/lib/kolla/config_files/src:ro\", \"/var/lib/metrics_qdr:/var/lib/qdrouterd:z\", \"/var/log/containers/metrics_qdr:/var/log/qdrouterd:z\"], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}, \"step_2\": {\"nova_compute_init_log\": {\"image\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/nova:/var/log/nova:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R nova:nova /var/log/nova\"], \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": \"1781252715\"}}, \"nova_virtqemud_init_logs\": {\"image\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"net\": \"none\", \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"user\": \"root\", \"volumes\": [\"/var/log/containers/libvirt/swtpm:/var/log/swtpm:shared,z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R tss:tss /var/log/swtpm\"], \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": \"1781252715\"}}, \"create_virtlogd_wrapper\": {\"start_order\": 1, \"detach\": false, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"user\": \"root\", \"command\": [\"/container_puppet_apply.sh\", \"4\", \"file\", \"include ::tripleo::profile::base::nova::virtlogd_wrapper\"], \"image\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"volumes\": [\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\", \"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\", \"/var/lib/container-config-scripts:/var/lib/container-config-scripts:shared,z\"], \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": \"1781252715\"}}, \"create_haproxy_wrapper\": {\"start_order\": 1, \"detach\": false, \"net\": \"host\", \"pid\": \"host\", \"user\": \"root\", \"command\": [\"/container_puppet_apply.sh\", \"4\", \"file\", \"include ::tripleo::profile::base::neutron::ovn_metadata_agent_wrappers\"], \"image\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"volumes\": [\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\", \"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\", \"/run/openvswitch:/run/openvswitch:shared,z\", \"/var/lib/neutron:/var/lib/neutron:shared,z\"]}}, \"step_5\": {\"nova_compute\": {\"start_order\": 3, \"image\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ulimit\": [\"nofile=131072\", \"memlock=67108864\"], \"ipc\": \"host\", \"net\": \"host\", \"privileged\": true, \"user\": \"nova\", \"restart\": \"always\", \"depends_on\": [\"tripleo_nova_libvirt.target\"], \"healthcheck\": {\"test\": \"/openstack/healthcheck 5672\"}, \"volumes\": [\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\", \"/etc/puppet:/etc/puppet:ro\", \"/var/log/containers/nova:/var/log/nova\", \"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\", \"/var/lib/kolla/config_files/nova_compute.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", \"/var/lib/tripleo-config/ceph:/var/lib/kolla/config_files/src-ceph:z\", \"/dev:/dev\", \"/lib/modules:/lib/modules:ro\", \"/run:/run\", \"/run/nova:/run/nova:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\", \"/var/lib/libvirt:/var/lib/libvirt:shared\", \"/sys/class/net:/sys/class/net\", \"/sys/bus/pci:/sys/bus/pci\", \"/boot:/boot:ro\", \"/var/lib/nova:/var/lib/nova:shared\"], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"LIBGUESTFS_BACKEND\": \"direct\"}}}}, \"container_config_scripts\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": \"#!/usr/bin/bash\\n# Copyright 2018 Red Hat Inc.\\n#\\n# Licensed under the Apache License, Version 2.0 (the \\\"License\\\"); you may\\n# not use this file except in compliance with the License. You may obtain\\n# a copy of the License at\\n#\\n#      http://www.apache.org/licenses/LICENSE-2.0\\n#\\n# Unless required by applicable law or agreed to in writing, software\\n# distributed under the License is distributed on an \\\"AS IS\\\" BASIS, WITHOUT\\n# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the\\n# License for the specific language governing permissions and limitations\\n# under the License.\\n#\\n# Usage: pyshim.sh <script and/or arguments>\\n#\\n# Unfortunately THT doesn\'t know which version of python might be in a\\n# container so we need this script to be able to try python3 or python2\\n# depending on availability.  Since this is a temporary shim until we\'ve\\n# fully cut over to python3, we check for the existence of python3 first\\n# before falling back to python2. This will help in the transition from\\n# python2 based containers to python3.\\n\\nshow_usage() {\\n    echo \\\"Usage: pyshim.sh <script and/or arguments>\\\"\\n}\\n\\nif [ $# -lt 1 ]\\nthen\\n    show_usage\\n    exit 1\\nfi\\n\\nset -x\\nif command -v python3 >/dev/null; then\\n    python3 \\\"$@\\\"\\nelif command -v python2 >/dev/null; then\\n    python2 \\\"$@\\\"\\nelif command -v python >/dev/null; then\\n    python \\\"$@\\\"\\nelse\\n    echo \\\"ERROR: python is not available!\\\"\\n    exit 1\\nfi\\n\"}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": \"#!/usr/bin/bash\\n\\nset -u\\n\\n# ./pacemaker_restart_bundle.sh mysql galera galera-bundle Master _\\n# ./pacemaker_restart_bundle.sh redis redis redis-bundle Slave Master\\n# ./pacemaker_restart_bundle.sh ovn_dbs ovndb_servers ovn-dbs-bundle Slave Master\\nRESTART_SCRIPTS_DIR=$(dirname $0)\\nTRIPLEO_SERVICE=$1\\nRESOURCE_NAME=$2\\nBUNDLE_NAME=$3\\nWAIT_TARGET_LOCAL=$4\\nWAIT_TARGET_ANYWHERE=${5:-_}\\nTRIPLEO_MINOR_UPDATE=\\\"${TRIPLEO_MINOR_UPDATE:-false}\\\"\\nTRIPLEO_HA_WRAPPER_RESOURCE_EXISTS=\\\"${TRIPLEO_HA_WRAPPER_RESOURCE_EXISTS:-false}\\\"\\n\\nbundle_can_be_restarted() {\\n    local bundle=$1\\n    # As long as the resource bundle is managed by pacemaker and is\\n    # not meant to stay stopped, no matter the state of any inner\\n    # pcmk_remote or ocf resource, we should restart it to give it a\\n    # chance to read the new config.\\n    [ \\\"$(crm_resource --meta -r $1 -g is-managed 2>/dev/null)\\\" != \\\"false\\\" ] && \\\\\\n    [ \\\"$(crm_resource --meta -r $1 -g target-role 2>/dev/null)\\\" != \\\"Stopped\\\" ]\\n}\\n\\nlog() {\\n    local msg=$1\\n    logger -t pcmkrestart \\\"$1\\\"\\n}\\n\\nHOSTNAME=$(/bin/hostname -s)\\nif [ x\\\"${TRIPLEO_MINOR_UPDATE,,}\\\" != x\\\"true\\\" ]; then\\n    if [ x\\\"${TRIPLEO_HA_WRAPPER_RESOURCE_EXISTS,,}\\\" = x\\\"false\\\" ]; then\\n        # Do not restart during initial deployment, as the resource\\n        # has just been created.\\n        SERVICE_NODEID=$(/bin/hiera -c /etc/puppet/hiera.yaml \\\"${TRIPLEO_SERVICE}_short_bootstrap_node_name\\\")\\n        if [[ \\\"${HOSTNAME,,}\\\" == \\\"${SERVICE_NODEID,,}\\\" ]]; then\\n            log \\\"Initial deployment, skipping the restart of ${BUNDLE_NAME}\\\"\\n\\tfi\\n        exit 0\\n    else\\n        # During a stack update, this script is called in parallel on\\n        # every node the resource runs on, after the service\'s configs\\n        # have been updated on all nodes. So we need to run pcs only\\n        # once (e.g. on the service\'s boostrap node).\\n        if bundle_can_be_restarted ${BUNDLE_NAME}; then\\n            SERVICE_NODEID=$(/bin/hiera -c /etc/puppet/hiera.yaml \\\"${TRIPLEO_SERVICE}_short_bootstrap_node_name\\\")\\n            if [[ \\\"${HOSTNAME,,}\\\" == \\\"${SERVICE_NODEID,,}\\\" ]]; then\\n                replicas_running=$(crm_resource -Q -r $BUNDLE_NAME --locate 2>&1 | wc -l)\\n                if [ \\\"$replicas_running\\\" != \\\"0\\\" ]; then\\n                    log \\\"Restarting ${BUNDLE_NAME} globally. Stopping:\\\"\\n                    /sbin/pcs resource disable --wait=600 $BUNDLE_NAME\\n                    log \\\"Restarting ${BUNDLE_NAME} globally. Starting:\\\"\\n                    /sbin/pcs resource enable --wait=600 $BUNDLE_NAME\\n                else\\n                    log \\\"${BUNDLE_NAME} is not running anywhere,\\\" \\\\\\n                         \\\"cleaning up to restart it globally if necessary\\\"\\n                    /sbin/pcs resource cleanup $BUNDLE_NAME\\n                fi\\n            else\\n                log \\\"Skipping global restart of ${BUNDLE_NAME} on ${HOSTNAME} it will be restarted by node ${SERVICE_NODEID}\\\"\\n            fi\\n\\n        else\\n            log \\\"No global restart needed for ${BUNDLE_NAME}.\\\"\\n        fi\\n    fi\\nelse\\n    # During a minor update workflow however, a host gets fully\\n    # updated before updating the next one. So unlike stack\\n    # update, at the time this script is called, the service\'s\\n    # configs aren\'t updated on all nodes yet. So only restart the\\n    # resource locally, where it\'s guaranteed that the config is\\n    # up to date.\\n    HOST=$(facter hostname)\\n\\n    if bundle_can_be_restarted ${BUNDLE_NAME}; then\\n\\t# if the resource is running locally, restart it\\n\\tif crm_resource -r $BUNDLE_NAME --locate 2>&1 | grep -w -q \\\"${HOST}\\\"; then\\n            log \\\"Restarting ${BUNDLE_NAME} locally on \'${HOST}\'\\\"\\n            /sbin/pcs resource restart $BUNDLE_NAME \\\"${HOST}\\\"\\n\\n\\telse\\n\\t    # At this point, if no resource is running locally, it\'s\\n\\t    # either because a) it has failed previously, or b) because\\n\\t    # it\'s an A/P resource running elsewhere.\\n\\t    # By cleaning up resource, we ensure that a) it will try to\\n\\t    # restart, or b) it won\'t do anything if the resource is\\n\\t    # already running elsewhere.\\n            log \\\"${BUNDLE_NAME} is currently not running on \'${HOST}\',\\\" \\\\\\n                 \\\"cleaning up its state to restart it if necessary\\\"\\n            /sbin/pcs resource cleanup $BUNDLE_NAME node=\\\"${HOST}\\\"\\n\\tfi\\n\\n\\t# Wait until the resource is in the expected target state\\n\\t$RESTART_SCRIPTS_DIR/pacemaker_wait_bundle.sh \\\\\\n            $RESOURCE_NAME $BUNDLE_NAME \\\\\\n            \\\"$WAIT_TARGET_LOCAL\\\" \\\"$WAIT_TARGET_ANYWHERE\\\" \\\\\\n\\t    \\\"${HOST}\\\" 600\\n    else\\n        log \\\"No restart needed for ${BUNDLE_NAME}.\\\"\\n    fi\\nfi\\n\"}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": \"#!/usr/bin/bash\\n\\n# ----\\n# Wait for an OCF resource or a bundle to be restarted\\n# ----\\n# e.g.:\\n# M/S OCF:      $0 galera galera-bundle Master\\n# clone OCF:    $0 rabbitmq rabbitmq-bundle Started\\n# A/P M/S OCF:  $0 redis redis-bundle Slave Master\\n# A/P bundle:   $0 openstack-cinder-volume openstack-cinder-volume _ Started\\n# clone bundle: $0 haproxy-bundle haproxy-bundle Started\\n\\n# design note 1:\\n#  - this script is called during a minor update; it is called\\n#    once per node that hosts a service replica.\\n#  - the purpose of this script is to ensure that restarting the\\n#    service replica locally won\'t disrupt the service availability\\n#    for the end user. To reach that goal, the script waits until the\\n#    service is restarted locally or globallu and reaches a given\\n#    target state (i.e. Started, Slave or Master).\\n# design note 2:\\n#   - we don\'t want to track restart error: our only job is to ensure\\n#     service restart synchronization, not service health.\\n#   - In particular, we don\'t want to error out in case the resource\\n#     cannot be restarted locally, because that would make the minor\\n#     update fail, even if potentially other replicas still provide\\n#     the service.\\n# design note 3:\\n#   - we can bail out early if we determine that the resource can\'t\\n#     be restarted automatically by pacemaker (e.g. its \\\"blocked\\\",\\n#     unmanaged or disabled).\\n\\nlog() {\\n    local msg=$1\\n    echo \\\"$(date -u): $1\\\"\\n}\\n\\nusage() {\\n    echo 2>&1 \\\"Usage: $0 NAME BUNDLE_NAME ROLE_LOCAL [ROLE_ANYWHERE] [HOST] [TIMEOUT]\\\"\\n    exit 1\\n}\\n\\npacemaker_supports_promoted() {\\n    # The Promoted token is only matched in recent pacemaker versions\\n    grep -wq \\\"<value>Promoted</value>\\\" /usr/share/pacemaker/resources-*.rng\\n}\\n\\n#\\n# Utility functions to detect stuck resources\\n#\\n\\nbundle_failures_locally() {\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\n    local replicas=$BUNDLE_REPLICAS\\n    local last=$(($replicas - 1))\\n    local replica_name\\n    for i in $(seq 0 $last); do\\n\\treplica_name=${BUNDLE_NAME}-${engine}-${i}\\n\\tcrm_failcount -q -G -r $replica_name -N $HOST\\n    done\\n}\\n\\nbundle_failures_globally() {\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\n    local replicas=$BUNDLE_REPLICAS\\n    local last=$(($replicas - 1))\\n    for i in $(seq 0 $last); do\\n\\tcrm_failcount -q -G -r ${BUNDLE_NAME}-${engine}-${i}\\n    done\\n}\\n\\nbundle_running_globally() {\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\n    # return the number of running bundles replica, i.e. the number of\\n    # docker/podman resource replicas currently running in the cluster\\n    crm_mon --as-xml | xmllint --xpath \\\"count(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource[@resource_agent=\'${OCF}:heartbeat:${engine}\']/node)\\\" -\\n}\\n\\nocf_failures_globally() {\\n    local replicas=$BUNDLE_REPLICAS\\n    local last=$(($replicas - 1))\\n    local bundle_node\\n    for i in $(seq 0 $last); do\\n\\tbundle_node=${BUNDLE_NAME}-${i}\\n\\tcrm_failcount -q -G -r $NAME -N $bundle_node\\n    done\\n}\\n\\ndid_resource_failed_locally() {\\n    local failures\\n    local running\\n    local remotehost\\n    if [ \\\"${NAME}\\\" != \\\"${BUNDLE_NAME}\\\" ]; then\\n\\t# if we\'re dealing with an ocf resource, it is running on a\\n\\t# pacemaker_remote rather that on the real host, and the\\n\\t# failcounts are thus associated to the pcmk remote. Replace\\n\\t# the host\'s name with the pcmk remote\'s name.\\n        remotehost=$(crm_mon --as-xml | xmllint --xpath \\\"string(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource/node[@name=\'${HOST}\']/../../resource[@resource_agent=\'${OCF}:pacemaker:remote\']/@id)\\\" -)\\n\\tif [ -n \\\"${remotehost}\\\" ]; then\\n\\t    crm_failcount -q -G -r $NAME -N $remotehost | grep -q -w INFINITY\\n\\t    return $?\\n\\tfi\\n\\t# If no pcmk remote is currently running, the failcount from\\n\\t# the ocf resource is useless, compute the failcount from the\\n\\t# bundle case instead (computed below).\\n    fi\\n\\n    # for bundles, pacemaker can run any bundle replica locally\\n    # (e.g. galera-bundle-docker-{0,1,2}), and a failure happens when\\n    # there are no more replica to try.\\n    # That is, when _at least_ one replica failed locally, and all the\\n    # others either failed or are currently running elsewhere.\\n    failures=$(bundle_failures_locally $HOST | grep -c -w INFINITY)\\n    running=$(bundle_running_globally)\\n    test $failures -gt 0 && \\\\\\n    test $(( $failures + $running )) -ge $BUNDLE_REPLICAS\\n}\\n\\ndid_resource_failed_globally() {\\n    local remotecount\\n    local failures\\n    if [ \\\"${NAME}\\\" != \\\"${BUNDLE_NAME}\\\" ]; then\\n\\t# we check the state of an ocf resource only if the\\n\\t# pcmkremotes are started\\n        remotecount=$(crm_mon --as-xml | xmllint --xpath \\\"count(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource[@resource_agent=\'${OCF}:pacemaker:remote\']/node)\\\" -)\\n\\tif [ \\\"${remotecount}\\\" = \\\"0\\\" ]; then\\n\\t    # no pcmkremote is running, so check the bundle state\\n\\t    # instead of checking the ocf resource\\n\\t    # bundle failed if all ${BUNDLE_REPLICAS} replicas failed\\n\\t    failures=$(bundle_failures_globally | grep -c -w INFINITY)\\n\\t    test $failures -eq $BUNDLE_REPLICAS\\n\\telse\\n\\t    # ocf resource failed if it failed to start on\\n\\t    # all $BUNDLE_REPLICAS bundle nodes\\n\\t    failures=$(ocf_failures_globally | grep -c -w INFINITY)\\n\\t    test $failures -eq $BUNDLE_REPLICAS\\n\\tfi\\n    else\\n\\t# bundle failed if all ${BUNDLE_REPLICAS} replicas failed\\n\\tfailures=$(bundle_failures_globally | grep -c -w INFINITY)\\n\\ttest $failures -eq $BUNDLE_REPLICAS\\n    fi\\n}\\n\\n\\n# Input validation\\n#\\n\\nNAME=$1\\nif [ -z \\\"${NAME}\\\" ]; then\\n    echo 2>&1 \\\"Error: argument NAME must not be empty\\\"\\n    exit 1\\nfi\\n\\nBUNDLE_NAME=$2\\nif [ -z \\\"${BUNDLE_NAME}\\\" ]; then\\n    echo 2>&1 \\\"Error: argument BUNDLE_NAME must not be empty\\\"\\n    exit 1\\nfi\\n\\nROLE_LOCAL=$3\\nif [ \\\"${ROLE_LOCAL}\\\" = \\\"_\\\" ]; then\\n    ROLE_LOCAL=\\\"\\\"\\nfi\\n\\nROLE_ANYWHERE=$4\\nif [ \\\"${ROLE_ANYWHERE}\\\" = \\\"_\\\" ]; then\\n    ROLE_ANYWHERE=\\\"\\\"\\nfi\\n\\nif [ -z \\\"${ROLE_LOCAL}\\\" ]; then\\n    if [ -z \\\"${ROLE_ANYWHERE}\\\" ]; then\\n        echo 2>&1 \\\"Error: either ROLE_LOCAL or ROLE_ANYWHERE must be non empty\\\"\\n        exit 1\\n    fi\\nelse\\n    if !(echo \\\"${ROLE_LOCAL}\\\" | grep -q -x -E \\\"(Started|Slave|Master|Unpromoted|Promoted)\\\"); then\\n        echo 2>&1 \\\"Error: argument ROLE_LOCAL must be either \'Started\' \'Slave\' \'Master\' \'Unpromoted\' or \'Promoted\'\\\"\\n        exit 1\\n    fi\\nfi\\n\\nif [ -n \\\"${ROLE_ANYWHERE}\\\" ] && !(echo \\\"${ROLE_ANYWHERE}\\\" | grep -q -x -E \\\"(Started|Slave|Master|Unpromoted|Promoted)\\\"); then\\n    echo 2>&1 \\\"Error: argument ROLE_ANYWHERE must be either \'Started\' \'Slave\' \'Master\' \'Unpromoted\' or \'Promoted\'\\\"\\n    exit 1\\nfi\\n\\n# Ensure compatibility with pacemaker 2.1\\nif pacemaker_supports_promoted; then\\n    ROLE_LOCAL=$(echo \\\"$ROLE_LOCAL\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\n    ROLE_ANYWHERE=$(echo \\\"$ROLE_ANYWHERE\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\n    OCF=\\\"ocf\\\"\\nelse\\n    OCF=\\\"ocf:\\\"\\nfi\\n\\nHOST=${5:-$(facter hostname)}\\nTIMEOUT=${6:-600}\\n\\n\\n# Configure the search\\n# ----\\n# Note: we can\'t use crm_resource in all searches because we can\'t\\n# easily extract the host the OCF resources run on (crm_resource\\n# returns the pcmk-remote nodes rather than the hosts)\\n# So instead, we implement various searches with XPath directly.\\n\\nif [ \\\"${BUNDLE_NAME}\\\" != \\\"${NAME}\\\" ]; then\\n# ocf resource\\nlocal_resource_xpath=\\\"//bundle/replica/resource[@resource_agent=\'${OCF}:pacemaker:remote\']/node[@name=\'${HOST}\']/../../resource[@id=\'${NAME}\']\\\"\\nany_resource_xpath=\\\"//bundle//resource[@id=\'${NAME}\']\\\"\\nreplicas_xpath=\\\"//bundle/primitive[@id=\'${BUNDLE_NAME}\']/../*[boolean(@image) and boolean(@replicas)]\\\"\\nelse\\n# bundle resource\\nlocal_resource_xpath=\\\"//bundle[@id=\'${NAME}\']/replica/resource/node[@name=\'${HOST}\']/../../resource\\\"\\nany_resource_xpath=\\\"//bundle[@id=\'${NAME}\']//resource\\\"\\nreplicas_xpath=\\\"//bundle[@id=\'${BUNDLE_NAME}\']/*[boolean(@image) and boolean(@replicas)]\\\"\\nfi\\n\\nbundle_def_xpath=\\\"//bundle[@id=\'${BUNDLE_NAME}\']/*[boolean(@image) and boolean(@replicas)]\\\"\\nBUNDLE_CONTAINER_ENGINE=$(cibadmin -Q | xmllint --xpath \\\"name(${bundle_def_xpath})\\\" -)\\nBUNDLE_REPLICAS=$(cibadmin -Q | xmllint --xpath \\\"string(${bundle_def_xpath}/@replicas)\\\" -)\\n\\n\\n# The wait algorithm follows a two-stage approach\\n#  1. Depending on how the script is called, we first check whether\\n#     the resource is restarted locally. An A/P resource may be\\n#     restarted elsewhere in the cluster.\\n#  2. If needed, check whether the A/P resource has restarted\\n#     elsewhere. For A/P M/S resources, in case the resource is\\n#     restarted as Slave locally, ensure a Master is available.\\n\\nsuccess=1\\nbailout=1\\ntimeout=$TIMEOUT\\nrole=\\\"\\\"\\n\\n# Stage 1: local check\\nif [ -n \\\"$ROLE_LOCAL\\\" ]; then\\n    log \\\"Waiting until ${NAME} has restarted on ${HOST} and is in state ${ROLE_LOCAL}\\\"\\n    log \\\"Will probe resource state with the following XPath pattern: ${local_resource_xpath}\\\"\\n\\n    while [ $timeout -gt 0 ] && [ $bailout -ne 0 ] && [ $success -ne 0 ]; do\\n        resource=$(crm_mon -r --as-xml | xmllint --xpath \\\"${local_resource_xpath}\\\" - 2>/dev/null)\\n        role=$(echo \\\"${resource}\\\" | sed -ne \'s/.*\\\\Wrole=\\\"\\\\([^\\\"]*\\\\)\\\".*/\\\\1/p\')\\n\\n\\tif [ \\\"$(crm_resource --meta -r ${NAME} -g is-managed 2>/dev/null)\\\" = \\\"false\\\" ]; then\\n            log \\\"${NAME} is unmanaged, will never reach target role. Bailing out\\\"\\n            bailout=0\\n            continue\\n\\telif [ \\\"$(crm_resource --meta -r ${NAME} -g target-role 2>/dev/null)\\\" = \\\"Stopped\\\" ]; then\\n            log \\\"${NAME} is disabled, will never reach target role. Bailing out\\\"\\n            bailout=0\\n            continue\\n        elif echo \\\"${resource}\\\" | grep -q -w \\\"\\\\Wblocked=\\\\\\\"true\\\\\\\"\\\"; then\\n            log \\\"${NAME} is blocked, will never reach target role. Bailing out\\\"\\n            bailout=0\\n            continue\\n\\telif did_resource_failed_locally; then\\n            log \\\"${NAME} is in failed state, will never reach target role. Bailing out\\\"\\n            bailout=0\\n            continue\\n        elif [ \\\"$role\\\" = \\\"$ROLE_LOCAL\\\" ]; then\\n            success=0\\n            continue\\n        elif [ -n \\\"$ROLE_ANYWHERE\\\" ] && [ \\\"$role\\\" = \\\"$ROLE_ANYWHERE\\\" ]; then\\n            # A/P: we are restarted in the expected state\\n            success=0\\n            continue\\n        else\\n            log \\\"Waiting for ${NAME} to transition to role ${ROLE_LOCAL} on ${HOST}\\\"\\n        fi\\n\\n        if [ $bailout -ne 0 ] && [ $success -ne 0 ]; then\\n            sleep 4\\n            timeout=$((timeout-4))\\n        fi\\n    done\\nfi\\n\\n# Stage 2: global check\\nif [ $timeout -gt 0 ] && [ -n \\\"$ROLE_ANYWHERE\\\" ] && [ \\\"$role\\\" != \\\"$ROLE_ANYWHERE\\\" ]; then\\n    log \\\"Wait until ${NAME} is restarted anywhere in the cluster in state ${ROLE_ANYWHERE}\\\"\\n    log \\\"Will probe resource state with the following XPath pattern: ${any_resource_xpath}\\\"\\n\\n    success=1\\n    bailout=1\\n    while [ $timeout -gt 0 ] && [ $bailout -ne 0 ] && [ $success -ne 0 ]; do\\n        resources=$(crm_mon -r --as-xml | xmllint --xpath \\\"${any_resource_xpath}\\\" - 2>/dev/null)\\n\\tif [ \\\"$(crm_resource --meta -r ${NAME} -g is-managed 2>/dev/null)\\\" = \\\"false\\\" ]; then\\n            log \\\"${NAME} is unmanaged, will never reach target role. Bailing out\\\"\\n            bailout=0\\n            continue\\n\\telif [ \\\"$(crm_resource --meta -r ${NAME} -g target-role 2>/dev/null)\\\" = \\\"Stopped\\\" ]; then\\n            log \\\"${NAME} is disabled, will never reach target role. Bailing out\\\"\\n            bailout=0\\n            continue\\n        elif ! (echo \\\"${resources}\\\" | grep -q -w \\\"\\\\Wblocked=\\\\\\\"false\\\\\\\"\\\"); then\\n            log \\\"${NAME} blocked, will never reach target role. Bailing out\\\"\\n            bailout=0\\n            continue\\n\\telif did_resource_failed_globally; then\\n            log \\\"${NAME} is in failed state, will never reach target role. Bailing out\\\"\\n            bailout=0\\n            continue\\n        elif echo \\\"${resources}\\\" | grep -q -w \\\"\\\\Wrole=\\\\\\\"${ROLE_ANYWHERE}\\\\\\\"\\\"; then\\n            success=0\\n            continue\\n        else\\n            log \\\"Waiting for ${NAME} to transition to role ${ROLE_ANYWHERE} anywhere in the cluster\\\"\\n        fi\\n\\n        if [ $bailout -ne 0 ] && [ $success -ne 0 ]; then\\n            sleep 4\\n            timeout=$((timeout-4))\\n        fi\\n    done\\nfi\\n\\nif [ $timeout -le 0 ]; then\\n    log \\\"Timeout reached after ${TIMEOUT}s while waiting for ${NAME} to be restarted\\\"\\nelif [ $bailout -le 0 ]; then\\n    log \\\"Restart monitoring for ${NAME} cancelled\\\"\\nfi\\n\\nif [ $success -eq 0 ]; then\\n    log \\\"${NAME} successfully restarted\\\"\\nelse\\n    log \\\"${NAME} was not restarted properly\\\"\\nfi\\n\\n# Don\'t block minor update or stack update if the wait was unsuccessful\\nexit 0\\n\"}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": \"#!/usr/bin/bash\\nset -eu\\n\\nHOST=$1\\nPORT=$2\\n\\necho \\\"$(date -u): Checking whether we can bind to ${HOST}:${PORT}\\\"\\nwhile (ss -Htnl src \\\"${HOST}\\\" \\\"sport = :${PORT}\\\" | grep -wq \\\"${PORT}\\\"); do\\n    echo \\\"$(date -u): ${HOST}:${PORT} still in use, waiting...\\\";\\n    sleep 10;\\ndone\\n\\nshift 2\\nCOMMAND=\\\"$*\\\"\\nif [ -z \\\"${COMMAND}\\\" ]; then\\n    COMMAND=\\\"true\\\"\\nfi\\nexec $COMMAND\\n\"}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": \"#!/usr/bin/bash\\n\\nMAX_RETRIES=10\\nCIB_ENOTFOUND=105\\n\\nusage() {\\n   echo \\\"Set a global property in the cluster with a validity timestamp.\\\"\\n   echo \\\"Usage:\\\"\\n   echo \\\"   $0 --acquire <lock_name> <lock_owner> <lock_ttl_in_seconds>\\\"\\n   echo \\\"   $0 --release <lock_name> <lock_owner>\\\"\\n   echo\\n}\\n\\nlog() {\\n    echo \\\"$(date -u): $1\\\" 1>&2\\n}\\n\\nerror() {\\n    echo \\\"$(date -u): $1\\\" 1>&2\\n    exit 1\\n}\\n\\nlock_create() {\\n    local name=$1\\n    local data=$2\\n    # cibadmin won\'t overwrite a key if someone else succeeded to create it concurrently\\n    cibadmin --sync-call --scope crm_config --create --xml-text \\\"<cluster_property_set id=\'${name}\'><nvpair id=\'${name}-pair\' name=\'${name}\' value=\'${data}\'/></cluster_property_set>\\\" &>/dev/null\\n    return $?\\n}\\n\\nlock_update() {\\n    local name=$1\\n    local expected_data=$2\\n    local new_data=$3\\n    # we only update the lock we expect to see, so we can\'t update someone else\'s lock\\n    cibadmin --sync-call --scope crm_config --modify --xpath \\\"//cluster_property_set/nvpair[@name=\'${name}\' and @value=\'${expected_data}\']/..\\\" --xml-text \\\"<nvpair id=\'${name}-pair\' name=\'${name}\' value=\'${new_data}\'/>\\\" &>/dev/null\\n    return $?\\n}\\n\\nlock_delete() {\\n    local name=$1\\n    local expected_data=$2\\n    # we only delete the lock we expect to see, so we can\'t delete someone else\'s lock\\n    cibadmin --sync-call --scope crm_config --delete --xpath \\\"//cluster_property_set/nvpair[@name=\'${name}\' and @value=\'${expected_data}\']/..\\\" &>/dev/null\\n    return $?\\n}\\n\\nlock_get() {\\n    local lockname=$1\\n    local res\\n    local rc\\n    res=$(cibadmin --query --scope crm_config --xpath \\\"//cluster_property_set/nvpair[@name=\'$lockname\']\\\" 2>/dev/null)\\n    rc=$?\\n    if [ $rc -eq 0 ]; then\\n        echo \\\"$res\\\" | sed -n \'s/.*value=\\\"\\\\([^\\\"]*\\\\)\\\".*/\\\\1/p\'\\n    fi\\n    return $rc\\n}\\n\\nlock_owner() {\\n    local lock=$1\\n    echo \\\"$lock\\\" | cut -d\':\' -f1\\n}\\n\\nlock_has_expired() {\\n    local lock=$1\\n    local expiry=$(echo \\\"$lock\\\" | cut -d\':\' -f2)\\n    local now=$(date +%s)\\n    test $now -ge $expiry\\n}\\n\\n\\n# Perform a lock action and restart if the CIB has been modified before\\n# committing the lock action\\ntry_action() {\\n    local fun=$1\\n    local lock=$2\\n    local requester=$3\\n    local args=${4:-}\\n    local tries=$MAX_RETRIES\\n    local rc=1\\n    if [ \\\"$fun\\\" = \\\"lock_acquire\\\" ] || [ \\\"$fun\\\" = \\\"lock_release\\\" ]; then\\n        log \\\"Try running $fun\\\"\\n    else\\n        return 2\\n    fi\\n    while [ $rc -ne 0 ]; do\\n        $fun $lock $requester $args\\n        rc=$?\\n        if [ $rc -eq 0 ]; then\\n            log \\\"Operation $1 succeeded\\\"\\n            return 0\\n        elif [ $rc -eq 3 ]; then\\n            # rc == 3 -> CIB changed before push\\n            if [ $tries -eq 0 ]; then\\n                log \\\"Failed to commit after $MAX_RETRIES retries. Bailing out.\\\"\\n                return 2\\n            else\\n                log \\\"Failed to commit. Retrying operation.\\\"\\n                tries=$(($tries - 1))\\n            fi\\n        elif [ $rc -eq 2 ]; then\\n            # rc == 2 -> unrecoverable cib error (e.g. pacemaker down)\\n            log \\\"Unexpected failure. Bailing out\\\"\\n            return $rc\\n        else\\n            # rc == 1 -> lock error (not owner, lock doesn\'t exists)\\n            return $rc\\n        fi\\n    done\\n}\\n\\n# The lock mechanism uses cibadmin\'s atomic creation so cluster-wide\\n# state coherency is guaranteed by pacemaker\\nlock_acquire() {\\n    local lockname=$1\\n    local requester=$2\\n    local ttl=$3\\n    local rc\\n    local lock\\n    local expiry\\n    local owner\\n\\n    log \\\"Check whether the lock is already held in the CIB\\\"\\n    lock=$(lock_get $lockname)\\n    rc=$?\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\n        log \\\"Could not retrieve info from the CIB\\\"\\n        return 2\\n    fi\\n\\n    if [ -n \\\"$lock\\\" ]; then\\n        lock_has_expired $lock\\n        rc=$?\\n        if [ $rc -eq 0 ]; then\\n            log \\\"Lock has expired, now available for being held\\\"\\n        else\\n            # lock is still held. check whether we\'re the owner\\n            owner=$(lock_owner $lock)\\n            if [ \\\"$owner\\\" = \\\"$requester\\\" ];then\\n                log \\\"Requester already owns the lock, acquiring attempt will just reconfigure the TTL\\\"\\n            else\\n                log \\\"Lock is held by someone else ($owner)\\\"\\n                return 1\\n            fi\\n        fi\\n    else\\n        log \\\"Lock is not held yet\\\"\\n    fi\\n\\n    # prepare the lock info\\n    expiry=$(($(date +%s) + $ttl))\\n\\n    if [ -n \\\"$lock\\\" ]; then\\n        log \\\"Attempting to update the lock\\\"\\n        lock_update $lockname \\\"$lock\\\" \\\"$requester:$expiry\\\"\\n        rc=$?\\n    else\\n        log \\\"Attempting to acquire the lock\\\"\\n        lock_create $lockname \\\"$requester:$expiry\\\"\\n        rc=$?\\n    fi\\n\\n    if [ $rc -eq 0 ]; then\\n        log \\\"Lock \'$lockname\' acquired by \'$requester\', valid until $(date -d @$expiry)\\\"\\n        return 0\\n    else\\n        log \\\"CIB changed, lock cannot be acquired\\\"\\n        return 3\\n    fi\\n}\\n\\n\\n# The lock mechanism uses the CIB\'s num_updates tag to implement\\n# a conditional store. Cluster-wide locking is guaranteed by pacemaker\\nlock_release() {\\n    local lockname=$1\\n    local requester=$2\\n    local rc\\n    local lock\\n    local owner\\n\\n    log \\\"Check whether the lock is already held in the CIB\\\"\\n    lock=$(lock_get $lockname)\\n    rc=$?\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\n        log \\\"Could not retrieve info from the CIB\\\"\\n        return 2\\n    fi\\n\\n    if [ -z \\\"$lock\\\" ]; then\\n        log \\\"Lock doesn\'t exist. Nothing to release\\\"\\n        return 0\\n    else\\n        log \\\"Lock exists, check whether we\'re the owner\\\"\\n        owner=$(lock_owner $lock)\\n        if [ \\\"$owner\\\" != \\\"$requester\\\" ];then\\n            log \\\"Lock is held by someone else ($owner), will not unlock\\\"\\n            return 1\\n        fi\\n    fi\\n\\n    lock_delete $lockname \\\"$lock\\\"\\n    rc=$?\\n\\n    if [ $rc -eq 0 ]; then\\n        log \\\"Lock \'$lockname\' released by \'$requester\'\\\"\\n        return 0\\n    else\\n        log \\\"CIB deletion error, lock cannot be released\\\"\\n        return 3\\n    fi\\n}\\n\\n\\n# Retrieve the owner of a lock from the CIB\\n# this is a read-only operation, so no need to log debug info\\nlock_get_owner() {\\n    local lockname=$1\\n    local rc\\n    local lock\\n    local owner\\n\\n    lock=$(lock_get $lockname)\\n    rc=$?\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\n        return 2\\n    fi\\n\\n    if [ -z \\\"$lock\\\" ]; then\\n        return 1\\n    else\\n        lock_owner $lock\\n        return 0\\n    fi\\n}\\n\\n\\nACTION=$1\\nLOCKNAME=$2\\nREQUESTER=$3\\nTTL=${4:-60}\\n\\nif [ -z \\\"$ACTION\\\" ]; then\\n    error \\\"Action must be specified\\\"\\nfi\\n\\nif [ $ACTION != \\\"--help\\\" ]; then\\n    if [ -z \\\"$LOCKNAME\\\" ]; then\\n        error \\\"You must specific a lock name\\\"\\n    fi\\n    if [ $ACTION != \\\"--owner\\\" ] && [ $ACTION != \\\"-o\\\" ]; then\\n        if [ -z \\\"$REQUESTER\\\" ]; then\\n            error \\\"You must specific a lock requester\\\"\\n        fi\\n    fi\\nfi\\n\\ncase $ACTION in\\n    --help) usage; exit 0;;\\n    --acquire|-a) try_action lock_acquire $LOCKNAME $REQUESTER $TTL;;\\n    --release|-r) try_action lock_release $LOCKNAME $REQUESTER;;\\n    --acquire-once|-A) lock_acquire $LOCKNAME $REQUESTER $TTL;;\\n    --owner|-o) lock_get_owner $LOCKNAME;;\\n    *) error \\\"Invalid action\\\";;\\nesac\\nexit $?\\n\"}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": \"#!/usr/bin/bash\\n\\n# pacemaker_mutex_restart_bundle.sh --lock mysql galera galera-bundle Master _\\n# pacemaker_mutex_restart_bundle.sh --lock ovn_dbs ovndb_servers ovn-dbs-bundle Slave Master\\n\\nset -u\\n\\nusage() {\\n    echo \\\"Restart a clustered resource in a coordinated way across the cluster\\\"\\n    echo \\\"Usage:\\\"\\n    echo \\\"   $0 --lock <tripleo-service> <pcmk-resource> <pcmk-bundle> <target-state-local> <target-state-cluster>\\\"\\n    echo\\n}\\n\\nlog() {\\n    echo \\\"$(date -u): $1\\\"\\n}\\n\\nerror() {\\n    echo \\\"$(date -u): $1\\\" 1>&2\\n    exit 1\\n}\\n\\npacemaker_supports_promoted() {\\n    # The Promoted token is only matched in recent pacemaker versions\\n    grep -wq \\\"<value>Promoted</value>\\\" /usr/share/pacemaker/resources-*.rng\\n}\\n\\nACTION=$1\\ncase $ACTION in\\n    --help) usage; exit 0;;\\n    --lock) ;;\\n    *) error \\\"Unknown action \'$ACTION\'\\\";;\\nesac\\n\\nTRIPLEO_SERVICE=$2\\nLOCK_NAME=${TRIPLEO_SERVICE}-restart-lock\\nLOCK_OWNER=$(crm_node -n 2>/dev/null)\\nrc=$?\\nif [ $rc -ne 0 ]; then\\n    if [ $rc -eq 102 ]; then\\n        log \\\"Cluster is not running locally, no need to restart resource $TRIPLEO_SERVICE\\\"\\n        exit 0\\n    else\\n        error \\\"Unexpected error while connecting to the cluster (rc: $rc), bailing out\\\"\\n    fi\\nfi\\n\\nRESOURCE_NAME=$3\\nBUNDLE_NAME=$4\\nWAIT_TARGET_LOCAL=$5\\nWAIT_TARGET_ANYWHERE=${6:-_}\\n\\nif pacemaker_supports_promoted; then\\n    WAIT_TARGET_LOCAL=$(echo \\\"$5\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\n    WAIT_TARGET_ANYWHERE=$(echo \\\"${6:-_}\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\n    promoted_role=\\\"Promoted\\\"\\nelse\\n    promoted_role=\\\"Master\\\"\\nfi\\n\\n# The lock TTL should accomodate for the resource start/promote timeout\\nif [ \\\"$RESOURCE_NAME\\\" != \\\"$BUNDLE_NAME\\\" ]; then\\n    if [ \\\"$WAIT_TARGET_LOCAL\\\" = \\\"$promoted_role\\\" ] || [ \\\"$WAIT_TARGET_ANYWHERE\\\" = \\\"$promoted_role\\\" ]; then\\n        rsc_op=\\\"promote\\\"\\n    else\\n        rsc_op=\\\"start\\\"\\n    fi\\n    # <op id=\\\"galera-promote-interval-0s\\\" interval=\\\"0s\\\" name=\\\"promote\\\" on-fail=\\\"block\\\" timeout=\\\"300s\\\"/>\\n    PCMK_TTL=$(cibadmin -Q | xmllint -xpath \\\"string(//primitive[@id=\'${RESOURCE_NAME}\']/operations/op[@name=\'${rsc_op}\']/@timeout)\\\" - | sed \'s/s$//\')\\n    LOCK_TTL=$((PCMK_TTL + 30))\\nelse\\n    # The podman RA\'s default start timeout\\n    LOCK_TTL=90\\nfi\\n\\nlog \\\"Acquire a ${LOCK_TTL}s restart lock for service $TRIPLEO_SERVICE before restarting it\\\"\\n# Loop until we hold the lock. The lock has a TTL, so we\'re guaranteed to get it eventually\\nrc=1\\nwhile [ $rc -ne 0 ]; do\\n    /var/lib/container-config-scripts/pacemaker_resource_lock.sh --acquire $LOCK_NAME $LOCK_OWNER $LOCK_TTL\\n    rc=$?\\n    if [ $rc != 0 ]; then\\n        if [ $rc -gt 1 ]; then\\n            error \\\"Could not acquire lock due to unrecoverable error (rc: $rc), bailing out\\\"\\n        else\\n            log \\\"Could not acquire lock, retrying\\\"\\n            sleep 10\\n        fi\\n    fi\\ndone\\n\\nlog \\\"Restart the service $TRIPLEO_SERVICE locally\\\"\\n# Reuse the local restart script in t-h-t (driven by env var TRIPLEO_MINOR_UPDATE)\\nTRIPLEO_MINOR_UPDATE=true /var/lib/container-config-scripts/pacemaker_restart_bundle.sh $TRIPLEO_SERVICE $RESOURCE_NAME $BUNDLE_NAME $WAIT_TARGET_LOCAL $WAIT_TARGET_ANYWHERE\\n\\n# If we reached this point, always try to release the lock\\nlog \\\"Release the restart lock for service $TRIPLEO_SERVICE\\\"\\n/var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $LOCK_NAME $LOCK_OWNER\\nrc=$?\\nif [ $rc -ne 0 ] && [ $rc -ne 1 ]; then\\n    error \\\"Could not release held lock (rc: $rc)\\\"\\nfi\\n\"}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": \"#!/usr/bin/bash\\n\\n# pacemaker_mutex_shutdown.sh --acquire\\n# pacemaker_mutex_shutdown.sh --release\\n\\nset -u\\n\\nusage() {\\n    echo \\\"Shutdown a cluster node in a coordinated way across the cluster\\\"\\n    echo \\\"Usage:\\\"\\n    echo \\\"   $0 --acquire # prevent other node from shutting down until we hold the lock\\\"\\n    echo \\\"   $0 --release # release the lock, other node can compete for the shutdown lock\\\"\\n    echo\\n}\\n\\nlog() {\\n    echo \\\"$(date -u): $1\\\"\\n}\\n\\nerror() {\\n    echo \\\"$(date -u): $1\\\" 1>&2\\n    exit 1\\n}\\n\\n# Loop until we hold the lock. The lock has a TTL, so we\'re guaranteed to get it eventually\\nshutdown_lock_acquire() {\\n    local lockname=$1\\n    local requester=$2\\n    local ttl=$3\\n    local rc=1\\n    local current_owner\\n    local owner_stopped\\n    local owner_rc\\n\\n    log \\\"Acquiring the shutdown lock\\\"\\n    while [ $rc -ne 0 ]; do\\n        /var/lib/container-config-scripts/pacemaker_resource_lock.sh --acquire-once $lockname $requester $ttl\\n        rc=$?\\n        if [ $rc -ne 0 ]; then\\n            if [ $rc -eq 2 ]; then\\n                error \\\"Could not acquire the shutdown lock due to unrecoverable error (rc: $rc), bailing out\\\"\\n            else\\n                # The lock is held by another node.\\n                current_owner=$(/var/lib/container-config-scripts/pacemaker_resource_lock.sh --owner $lockname)\\n                owner_rc=$?\\n                if [ $owner_rc -eq 2 ]; then\\n                    error \\\"Could not get the shutdown lock owner due to unrecoverable error (rc: $owner_rc), bailing out\\\"\\n                fi\\n                if [ $owner_rc -eq 0 ]; then\\n                    # If the owner is marked as offline, that means it has shutdown and\\n                    # we can clean the lock preemptively and try to acquire it.\\n                    owner_stopped=$(crm_mon -1X | xmllint --xpath \'count(//nodes/node[@name=\\\"\'${current_owner}\'\\\" and @online=\\\"false\\\" and @unclean=\\\"false\\\"])\' -)\\n                    if [ \\\"${owner_stopped}\\\" = \\\"1\\\" ]; then\\n                        log \\\"Shutdown lock held by stopped node \'${current_owner}\', lock can be released\\\"\\n                        /var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $lockname $current_owner\\n                        continue\\n                    fi\\n                fi\\n                log \\\"Shutdown lock held by another node (rc: $rc), retrying\\\"\\n                sleep 10\\n            fi\\n        fi\\n    done\\n    log \\\"Shutdown lock acquired\\\"\\n    return 0\\n}\\n\\n\\n# Release the lock if we still own it. Not owning it anymore is not fatal\\nshutdown_lock_release() {\\n    local lockname=$1\\n    local requester=$2\\n    local rc\\n\\n    log \\\"Releasing the shutdown lock\\\"\\n    /var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $lockname $requester\\n    rc=$?\\n    if [ $rc -ne 0 ]; then\\n        if [ $rc -gt 1 ]; then\\n            error \\\"Could not release the shutdown lock due to unrecoverable error (rc: $rc), bailing out\\\"\\n        else\\n            log \\\"Shutdown lock no longer held, nothing to do\\\"\\n        fi\\n    else\\n        log \\\"Shutdown lock released\\\"\\n    fi\\n    return 0\\n}\\n\\n\\nACTION=$1\\nif [ -z \\\"$ACTION\\\" ]; then\\n    error \\\"Action must be specified\\\"\\nfi\\n\\nLOCK_NAME=tripleo-shutdown-lock\\nLOCK_OWNER=$(crm_node -n 2>/dev/null)\\nrc=$?\\nif [ $rc -ne 0 ]; then\\n    if [ $rc -eq 102 ]; then\\n        log \\\"Cluster is not running locally, no need to aquire the shutdown lock\\\"\\n        exit 0\\n    else\\n        error \\\"Unexpected error while connecting to the cluster (rc: $rc), bailing out\\\"\\n    fi\\nfi\\n\\n# We start with a very high TTL, that long enough to accomodate a cluster stop.\\n# As soon as the node will get offline, the other competing node will be entitled\\n# to steal the lock, so they should never wait that long in practice.\\nLOCK_TTL=600\\n\\n\\ncase $ACTION in\\n    --help) usage; exit 0;;\\n    --acquire|-a) shutdown_lock_acquire ${LOCK_NAME} ${LOCK_OWNER} ${LOCK_TTL};;\\n    --release|-r) shutdown_lock_release ${LOCK_NAME} ${LOCK_OWNER};;\\n    *) error \\\"Invalid action\\\";;\\nesac\\nexit $?\\n\"}, \"collectd_check_health.py\": {\"mode\": \"0755\", \"content\": \"#!/usr/bin/python3\\n#\\n# Copyright 2022 Red Hat Inc.\\n#\\n# Licensed under the Apache License, Version 2.0 (the \\\"License\\\"); you may\\n# not use this file except in compliance with the License. You may obtain\\n# a copy of the License at\\n#\\n#      http://www.apache.org/licenses/LICENSE-2.0\\n#\\n# Unless required by applicable law or agreed to in writing, software\\n# distributed under the License is distributed on an \\\"AS IS\\\" BASIS, WITHOUT\\n# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the\\n# License for the specific language governing permissions and limitations\\n# under the License.\\n\\nimport json\\nimport os\\nimport re\\nimport shutil\\nimport subprocess\\nimport sys\\n\\nfrom pkg_resources import packaging\\n\\n\\nSOCKET = \\\"unix:/run/podman/podman.sock\\\"\\nPS_FORMAT = (\'{\\\"service\\\": \\\"{{.Names}}\\\", \\\"container\\\": \\\"{{.ID}}\\\", \'\\n             \'\\\"status\\\": \\\"{{.State}}\\\", \\\"healthy\\\": \\\"{{.Status}}\\\"},\')\\nBASE_FORMAT = \\\"{service: .Name, container: .Id, status: .State.Running, \\\"\\nRUNNING_REX = re.compile(r\\\"Up .*(?P<health>\\\\(u?n?healthy\\\\))\\\")\\nSKIP_LIST = [\'.*_bootstrap\', \'container-puppet-.*\', \'.*_db_sync\',\\n             \'.*_cron\', \'create_.*_wrapper\', \'.*_wait_bundle\',\\n             \'configure_.*\', \'.*_fix_perms\', \'.*_init_logs?\',\\n             \'.*_init_perm\', \'(nova|placement)_wait_for_.*\', \'nova_.*ensure_\',\\n             \'(swift_)?setup_.*\', \'mysql_data_ownership\', \'swift_copy_rings\',\\n             \'nova_statedir_owner\']\\n\\n\\nclass ExecuteError(Exception):\\n    def __init__(self, rc, msg):\\n        self.rc = rc\\n        self.msg = msg\\n        super().__init__()\\n\\n\\ndef execute(cmd, workdir: str = None,\\n            prev_proc: subprocess.Popen = None) -> subprocess.Popen:\\n    # Note(mmagr): When this script is executed by collectd-sensubility started\\n    #              via collectd the script has non-root permission but inherits\\n    #              environment from collectd with root permission. We need\\n    #              to avoid sensubility access /root when using podman-remote.\\n    #              See https://bugzilla.redhat.com/show_bug.cgi?id=2091076 for\\n    #              more info.\\n    proc_env = os.environ.copy()\\n    proc_env[\\\"HOME\\\"] = \\\"/tmp\\\"\\n    if type(cmd[0]) is list:  # multiple piped commands\\n        last = prev_proc\\n        for c in cmd:\\n            last = execute(c, workdir, last)\\n        return last\\n    else:  # single command\\n        inpipe = prev_proc.stdout if prev_proc is not None else None\\n        proc = subprocess.Popen(cmd, cwd=workdir, env=proc_env, stdin=inpipe,\\n                                stdout=subprocess.PIPE, stderr=subprocess.PIPE)\\n        if prev_proc is not None:\\n            prev_proc.stdout.close()\\n            prev_proc.stderr.close()\\n        return proc\\n\\n\\ndef get_health_from_status(status):\\n    healthy = status in (\'healthy\', \'running\')\\n    return int(healthy)\\n\\n\\ndef fetch_state_from_inspect(cont, fmt):\\n    proc = execute([\\n        [shutil.which(\'podman-remote\'),\\n           \'--url\', SOCKET, \'inspect\', cont[\\\"container\\\"]],\\n        [shutil.which(\'jq\'), \'.[] | %s\' % fmt]\\n    ])\\n    o, e = proc.communicate()\\n    if proc.returncode != 0:\\n        msg = \\\"Failed to fetch status of %s: %s\\\" % (cont, e.decode())\\n        raise ExecuteError(proc.returncode, msg)\\n\\n    item = json.loads(o.decode())\\n    item[\'status\'] = \'running\' if item[\'status\'] else \'stopped\'\\n    if len(item[\'healthy\']) > 0 and item[\'status\'] != \'stopped\':\\n        item[\'status\'] = item[\'healthy\']\\n\\n    item[\'healthy\'] = get_health_from_status(item[\'status\'])\\n    return item\\n\\n\\ndef fetch_state(item):\\n    if \'up \' in item[\'status\'].lower():\\n        item[\'status\'] = \'running\'\\n    if item[\'status\'] != \'running\':\\n        item[\'status\'] = \'stopped\'\\n\\n    match = RUNNING_REX.match(item[\'healthy\'])\\n    if match:\\n        health = match.group(\'health\')\\n    else:\\n        health = \'\'\\n    if health:\\n        item[\'status\'] = health.strip(\\\"()\\\")\\n\\n    item[\'healthy\'] = get_health_from_status(item[\'status\'])\\n    return item\\n\\n\\ndef fetch_container_health(ps_result, inspect_fmt):\\n\\n    def container_filter(item):\\n        for rx in [re.compile(i) for i in SKIP_LIST]:\\n            if rx.match(item[\\\"service\\\"]):\\n                return False\\n        return True\\n    try:\\n        containers = filter(container_filter, json.loads(ps_result))\\n    except json.decoder.JSONDecodeError:\\n        return 1, \\\"%s\\\\nFailed to parse above output.\\\" % ps_result\\n\\n    out = []\\n    for cont in containers:\\n        try:\\n            out.append(fetch_state(cont))\\n        except Exception:\\n            # fallback to slow inspect way in case of any error\\n            try:\\n                out.append(fetch_state_from_inspect(cont, inspect_fmt))\\n            except ExecuteError as ex:\\n                return ex.rc, ex.msg\\n    return 0, out\\n\\n\\nif __name__ == \\\"__main__\\\":\\n    proc = execute([shutil.which(\'podman-remote\'),\\n                    \'--url\', SOCKET, \'version\',\\n                    \'--format\', r\'{{.Server.Version}}\'])\\n    o, e = proc.communicate()\\n    try:\\n        if packaging.version.parse(o.decode().strip()) >= packaging.version.parse(\\\"4.0.0\\\"):\\n            inspect_fmt = BASE_FORMAT + \\\"healthy: .State.Health.Status}\\\"\\n        else:\\n            inspect_fmt = BASE_FORMAT + \\\"healthy: .State.Healthcheck.Status}\\\"\\n    except Exception:\\n        # keep podman-4.0.0+ format in case of version decoding error\\n        inspect_fmt = BASE_FORMAT + \\\"healthy: .State.Health.Status}\\\"\\n\\n    proc = execute([shutil.which(\'podman-remote\'), \'--url\', SOCKET,\\n                    \'ps\', \'--all\', \'--format\', PS_FORMAT])\\n    o, e = proc.communicate()\\n    if proc.returncode != 0:\\n        print(\\\"Failed to list containers:\\\\n%s\\\\n%s\\\" % (o.decode(), e.decode()))\\n        sys.exit(1)\\n\\n    rc, status = fetch_container_health(\\\"[%s]\\\" % o.decode().strip(\\\"\\\\n,\\\"), inspect_fmt)\\n    if rc != 0:\\n        print(\\\"Failed to inspect containers:\\\\n%s\\\" % status)\\n        sys.exit(rc)\\n    print(json.dumps(status))\\n\"}, \"nova_statedir_ownership.py\": {\"mode\": \"0700\", \"content\": \"#!/usr/bin/python3\\n#\\n# Copyright 2018 Red Hat Inc.\\n#\\n# Licensed under the Apache License, Version 2.0 (the \\\"License\\\"); you may\\n# not use this file except in compliance with the License. You may obtain\\n# a copy of the License at\\n#\\n#      http://www.apache.org/licenses/LICENSE-2.0\\n#\\n# Unless required by applicable law or agreed to in writing, software\\n# distributed under the License is distributed on an \\\"AS IS\\\" BASIS, WITHOUT\\n# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the\\n# License for the specific language governing permissions and limitations\\n# under the License.\\nimport logging\\nimport os\\nimport pwd\\nimport selinux\\nimport stat\\nimport sys\\n\\ndebug = os.getenv(\'__OS_DEBUG\', \'false\')\\n\\nif debug.lower() == \'true\':\\n    loglevel = logging.DEBUG\\nelse:\\n    loglevel = logging.INFO\\n\\nlogging.basicConfig(stream=sys.stdout, level=loglevel)\\nLOG = logging.getLogger(\'nova_statedir\')\\n\\n\\nclass PathManager(object):\\n    \\\"\\\"\\\"Helper class to manipulate ownership of a given path\\\"\\\"\\\"\\n    def __init__(self, path):\\n        self.path = path\\n        self.uid = None\\n        self.gid = None\\n        self.is_dir = None\\n        self.secontext = None\\n        self._update()\\n\\n    def _update(self):\\n        try:\\n            statinfo = os.stat(self.path)\\n            self.is_dir = stat.S_ISDIR(statinfo.st_mode)\\n            self.uid = statinfo.st_uid\\n            self.gid = statinfo.st_gid\\n            self.secontext = selinux.lgetfilecon(self.path)[1]\\n        except Exception:\\n            LOG.exception(\'Could not update metadata for %s\', self.path)\\n            raise\\n\\n    def __str__(self):\\n        return \\\"uid: {} gid: {} path: {}{}\\\".format(\\n            self.uid,\\n            self.gid,\\n            self.path,\\n            \'/\' if self.is_dir else \'\'\\n        )\\n\\n    def has_owner(self, uid, gid):\\n        return self.uid == uid and self.gid == gid\\n\\n    def has_either(self, uid, gid):\\n        return self.uid == uid or self.gid == gid\\n\\n    def chown(self, uid, gid):\\n        target_uid = -1\\n        target_gid = -1\\n        if self.uid != uid:\\n            target_uid = uid\\n        if self.gid != gid:\\n            target_gid = gid\\n        if (target_uid, target_gid) != (-1, -1):\\n            LOG.info(\'Changing ownership of %s from %d:%d to %d:%d\',\\n                     self.path,\\n                     self.uid,\\n                     self.gid,\\n                     self.uid if target_uid == -1 else target_uid,\\n                     self.gid if target_gid == -1 else target_gid)\\n            try:\\n                os.chown(self.path, target_uid, target_gid)\\n                self._update()\\n            except Exception:\\n                LOG.exception(\'Could not change ownership of %s: \',\\n                              self.path)\\n                raise\\n        else:\\n            LOG.info(\'Ownership of %s already %d:%d\',\\n                     self.path,\\n                     uid,\\n                     gid)\\n\\n    def chcon(self, context):\\n        # If dir returns whether to recusively set context\\n        try:\\n            try:\\n                selinux.lsetfilecon(self.path, context)\\n                LOG.info(\'Setting selinux context of %s to %s\',\\n                     self.path, context)\\n                return True\\n            except OSError as e:\\n                if self.is_dir and e.errno == 95:\\n                    # Operation not supported, assume NFS mount and skip\\n                    LOG.info(\'Setting selinux context not supported for %s\',\\n                             self.path)\\n                    return False\\n                else:\\n                    raise\\n        except Exception:\\n            LOG.exception(\'Could not set selinux context of %s to %s:\',\\n                          self.path, context)\\n            raise\\n\\n\\nclass NovaStatedirOwnershipManager(object):\\n    \\\"\\\"\\\"Class to manipulate the ownership of the nova statedir (/var/lib/nova).\\n\\n       The nova uid/gid differ on the host and container images. An upgrade\\n       that switches from host systemd services to docker requires a change in\\n       ownership. Previously this was a naive recursive chown, however this\\n       causes issues if nova instance are shared via an NFS mount: any open\\n       filehandles in qemu/libvirt fail with an I/O error (LP1778465).\\n\\n       Instead the upgrade/FFU ansible tasks now lay down a marker file when\\n       stopping and disabling the host systemd services. We use this file to\\n       determine the host nova uid/gid. We then walk the tree and update any\\n       files that have the host uid/gid to the docker nova uid/gid. As files\\n       owned by root/qemu etc... are ignored this avoids the issues with open\\n       filehandles. The marker is removed once the tree has been walked.\\n\\n       For subsequent runs, or for a new deployment, we simply ensure that the\\n       docker nova user/group owns all directories. This is required as the\\n       directories are created with root ownership in host_prep_tasks (the\\n       docker nova uid/gid is not known in this context).\\n    \\\"\\\"\\\"\\n    def __init__(self, statedir, upgrade_marker=\'upgrade_marker\',\\n                 nova_user=\'nova\', secontext_marker=\'../_nova_secontext\',\\n                 exclude_paths=None):\\n        self.statedir = statedir\\n        self.nova_user = nova_user\\n\\n        self.upgrade_marker_path = os.path.join(statedir, upgrade_marker)\\n        self.secontext_marker_path = os.path.normpath(os.path.join(statedir, secontext_marker))\\n        self.upgrade = os.path.exists(self.upgrade_marker_path)\\n\\n        self.exclude_paths = [self.upgrade_marker_path]\\n        if exclude_paths is not None:\\n            for p in exclude_paths:\\n                if not p.startswith(os.path.sep):\\n                    p = os.path.join(self.statedir, p)\\n                self.exclude_paths.append(p)\\n\\n        self.target_uid, self.target_gid = self._get_nova_ids()\\n        self.previous_uid, self.previous_gid = self._get_previous_nova_ids()\\n        self.id_change = (self.target_uid, self.target_gid) != \\\\\\n            (self.previous_uid, self.previous_gid)\\n        self.target_secontext = self._get_secontext()\\n\\n    def _get_nova_ids(self):\\n        nova_uid, nova_gid = pwd.getpwnam(self.nova_user)[2:4]\\n        return nova_uid, nova_gid\\n\\n    def _get_previous_nova_ids(self):\\n        if self.upgrade:\\n            statinfo = os.stat(self.upgrade_marker_path)\\n            return statinfo.st_uid, statinfo.st_gid\\n        else:\\n            return self._get_nova_ids()\\n\\n    def _get_secontext(self):\\n        if os.path.exists(self.secontext_marker_path):\\n            return selinux.lgetfilecon(self.secontext_marker_path)[1]\\n        else:\\n            return None\\n\\n    def _walk(self, top, chcon=True):\\n        for f in os.listdir(top):\\n            pathname = os.path.join(top, f)\\n\\n            if pathname in self.exclude_paths:\\n                continue\\n\\n            try:\\n                pathinfo = PathManager(pathname)\\n                LOG.info(\\\"Checking %s\\\", pathinfo)\\n                if pathinfo.is_dir:\\n                    # Always chown the directories\\n                    pathinfo.chown(self.target_uid, self.target_gid)\\n                    chcon_r = chcon\\n                    if chcon:\\n                        chcon_r = pathinfo.chcon(self.target_secontext)\\n                    self._walk(pathname, chcon_r)\\n                elif self.id_change:\\n                    # Only chown files if it\'s an upgrade and the file is owned by\\n                    # the host nova uid/gid\\n                    pathinfo.chown(\\n                        self.target_uid if pathinfo.uid == self.previous_uid\\n                        else pathinfo.uid,\\n                        self.target_gid if pathinfo.gid == self.previous_gid\\n                        else pathinfo.gid\\n                    )\\n                    if chcon:\\n                        pathinfo.chcon(self.target_secontext)\\n            except Exception:\\n                # Likely to have been caused by external systems\\n                # interacting with this directory tree,\\n                # especially on NFS e.g snapshot dirs.\\n                # Just ignore it and continue on to the next entry\\n                continue\\n\\n    def run(self):\\n        LOG.info(\'Applying nova statedir ownership\')\\n        LOG.info(\'Target ownership for %s: %d:%d\',\\n                 self.statedir,\\n                 self.target_uid,\\n                 self.target_gid)\\n\\n        pathinfo = PathManager(self.statedir)\\n        LOG.info(\\\"Checking %s\\\", pathinfo)\\n        pathinfo.chown(self.target_uid, self.target_gid)\\n        chcon = self.target_secontext is not None\\n\\n        if chcon:\\n            pathinfo.chcon(self.target_secontext)\\n\\n        self._walk(self.statedir, chcon)\\n\\n        if self.upgrade:\\n            LOG.info(\'Removing upgrade_marker %s\',\\n                     self.upgrade_marker_path)\\n            os.unlink(self.upgrade_marker_path)\\n\\n        LOG.info(\'Nova statedir ownership complete\')\\n\\n\\ndef get_exclude_paths():\\n    exclude_paths = os.environ.get(\'NOVA_STATEDIR_OWNERSHIP_SKIP\')\\n    if exclude_paths is not None:\\n        exclude_paths = exclude_paths.split(os.pathsep)\\n    return exclude_paths\\n\\n\\nif __name__ == \'__main__\':\\n    NovaStatedirOwnershipManager(\'/var/lib/nova\', exclude_paths=get_exclude_paths()).run()\\n\"}, \"nova_wait_for_compute_service.py\": {\"mode\": \"0755\", \"content\": \"#!/usr/bin/python3\\n#\\n# Copyright 2018 Red Hat Inc.\\n#\\n# Licensed under the Apache License, Version 2.0 (the \\\"License\\\"); you may\\n# not use this file except in compliance with the License. You may obtain\\n# a copy of the License at\\n#\\n#      http://www.apache.org/licenses/LICENSE-2.0\\n#\\n# Unless required by applicable law or agreed to in writing, software\\n# distributed under the License is distributed on an \\\"AS IS\\\" BASIS, WITHOUT\\n# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the\\n# License for the specific language governing permissions and limitations\\n# under the License.\\nimport argparse\\nimport logging\\nimport os\\nimport six\\nimport socket\\nimport sys\\nimport time\\n\\n\\nfrom keystoneauth1 import loading\\nfrom keystoneauth1 import session\\n\\nfrom novaclient import client\\n\\n# In python3 SafeConfigParser was renamed to ConfigParser and the default\\n# for duplicate options default to true. In case of nova it is valid to\\n# have duplicate option lines, e.g. passthrough_whitelist which leads to\\n# issues reading the nova.conf\\n# https://bugs.launchpad.net/tripleo/+bug/1827775\\nif six.PY3:\\n    from six.moves.configparser import ConfigParser\\n    config = ConfigParser(strict=False)\\nelse:\\n    from six.moves.configparser import SafeConfigParser\\n    config = SafeConfigParser()\\n\\ndebug = os.getenv(\'__OS_DEBUG\', \'false\')\\n\\nif debug.lower() == \'true\':\\n    loglevel = logging.DEBUG\\nelse:\\n    loglevel = logging.INFO\\n\\nlogging.basicConfig(stream=sys.stdout, level=loglevel)\\nLOG = logging.getLogger(\'nova_wait_for_compute_service\')\\n\\niterations = 60\\ntimeout = 10\\nnova_cfg = \'/etc/nova/nova.conf\'\\n\\nif __name__ == \'__main__\':\\n    parser = argparse.ArgumentParser(usage=\'%(prog)s [options]\')\\n    parser.add_argument(\'-k\', \'--insecure\',\\n                        action=\\\"store_false\\\",\\n                        dest=\'insecure\',\\n                        default=True,\\n                        help=\'Allow insecure connection when using SSL\')\\n\\n    args = parser.parse_args()\\n    LOG.debug(\'Running with parameter insecure = %s\',\\n              args.insecure)\\n\\n    if os.path.isfile(nova_cfg):\\n        try:\\n            config.read(nova_cfg)\\n        except Exception:\\n            LOG.exception(\'Error while reading nova.conf:\')\\n    else:\\n        LOG.error(\'Nova configuration file %s does not exist\', nova_cfg)\\n        sys.exit(1)\\n\\n    my_host = config.get(\'DEFAULT\', \'host\')\\n    if not my_host:\\n        # If host isn\'t set nova defaults to this\\n        my_host = socket.gethostname()\\n\\n    loader = loading.get_plugin_loader(\'password\')\\n    auth = loader.load_from_options(\\n        auth_url=config.get(\'neutron\',\\n                            \'auth_url\'),\\n        username=config.get(\'neutron\',\\n                            \'username\'),\\n        password=config.get(\'neutron\',\\n                            \'password\'),\\n        project_name=config.get(\'neutron\',\\n                                \'project_name\'),\\n        project_domain_name=config.get(\'neutron\',\\n                                       \'project_domain_name\'),\\n        user_domain_name=config.get(\'neutron\',\\n                                    \'user_domain_name\'))\\n    sess = session.Session(auth=auth, verify=args.insecure)\\n    nova = client.Client(\'2.11\', session=sess, endpoint_type=\'internal\',\\n                         region_name=config.get(\'neutron\', \'region_name\'))\\n\\n    # Wait until this host is listed in the service list\\n    for i in range(iterations):\\n        try:\\n            service_list = nova.services.list(binary=\'nova-compute\')\\n            for entry in service_list:\\n                host = getattr(entry, \'host\', \'\')\\n                zone = getattr(entry, \'zone\', \'\')\\n                if host == my_host and zone != \'internal\':\\n                    LOG.info(\'Nova-compute service registered\')\\n                    sys.exit(0)\\n            LOG.info(\'Waiting for nova-compute service to register\')\\n        except Exception:\\n            LOG.exception(\\n                \'Error while waiting for nova-compute service to register\')\\n        time.sleep(timeout)\\nsys.exit(1)\\n\\n# vim: set et ts=4 sw=4 :\\n\"}, \"nova_libvirt_init_secret.sh\": {\"mode\": \"0755\", \"content\": \"#!/usr/bin/bash\\n\\nset -e\\n\\nCEPH_INFO=($*)\\n\\nif [ -z \\\"$CEPH_INFO\\\" ]; then\\n    echo \\\"error: At least one CLUSTER:CLIENT tuple must be specified\\\"\\n    exit 1\\nfi\\n\\necho \\\"------------------------------------------------\\\"\\necho \\\"Initializing virsh secrets for: ${CEPH_INFO[@]}\\\"\\n\\nfor INFO in ${CEPH_INFO[@]}; do\\n    IFS=: read CLUSTER CLIENT <<< $INFO\\n    if [ ! -f /etc/ceph/${CLUSTER}.conf ]; then\\n        echo \\\"Error: /etc/ceph/${CLUSTER}.conf was not found\\\"\\n        echo \\\"Path to nova_libvirt_init_secret was ${CEPH_INFO}\\\"\\n        exit 1\\n    fi\\n    FSID=$(awk \'$1 == \\\"fsid\\\" {print $3}\' /etc/ceph/${CLUSTER}.conf)\\n    if [ -z \\\"${FSID}\\\" ]; then\\n        echo \\\"Error: /etc/ceph/${CLUSTER}.conf contained an empty fsid definition\\\"\\n        echo \\\"Check your ceph configuration\\\"\\n        exit 1\\n    fi\\n\\n    echo \\\"--------\\\"\\n    echo \\\"Initializing the virsh secret for \'$CLUSTER\' cluster ($FSID) \'$CLIENT\' client\\\"\\n\\n    # Ensure the secret XML file exists. Puppet should have created a secret.xml\\n    # file for the first cluster\'s secret, so detect when to use that file.\\n    if grep -q $FSID /etc/nova/secret.xml; then\\n        SECRET_FILE=\\\"/etc/nova/secret.xml\\\"\\n        SECRET_NAME=\\\"client.${CLIENT} secret\\\"\\n    else\\n        SECRET_FILE=\\\"/etc/nova/${CLUSTER}-secret.xml\\\"\\n        SECRET_NAME=\\\"${CLUSTER}.client.${CLIENT} secret\\\"\\n    fi\\n\\n    if [ ! -f $SECRET_FILE ]; then\\n        echo \\\"Creating $SECRET_FILE\\\"\\n        cat <<EOF > $SECRET_FILE\\n<secret ephemeral=\'no\' private=\'no\'>\\n  <usage type=\'ceph\'>\\n    <name>${SECRET_NAME}</name>\\n  </usage>\\n  <uuid>${FSID}</uuid>\\n</secret>\\nEOF\\n    else\\n        echo \\\"The $SECRET_FILE file already exists\\\"\\n    fi\\n\\n    # Ensure the libvirt secret is defined\\n    if /usr/bin/virsh secret-list | grep -q $FSID; then\\n        echo \\\"The virsh secret for $FSID has already been defined\\\"\\n    else\\n        /usr/bin/virsh secret-define --file $SECRET_FILE\\n    fi\\n\\n    # Fetch the key from the keyring and ensure the secret is set\\n    KEY=$(awk \'$1 == \\\"key\\\" {print $3}\' /etc/ceph/${CLUSTER}.client.${CLIENT}.keyring)\\n    if /usr/bin/virsh secret-get-value $FSID 2>/dev/null | grep -q $KEY; then\\n        echo \\\"The virsh secret for $FSID has already been set\\\"\\n    else\\n        /usr/bin/virsh secret-set-value --secret $FSID --base64 $KEY\\n    fi\\ndone\\n\"}}, \"container_puppet_tasks\": {}, \"host_prep_tasks\": [{\"name\": \"Run firewall role\", \"include_role\": {\"name\": \"tripleo_firewall\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/collectd\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/container-user-scripts/\", \"setype\": \"container_file_t\", \"mode\": \"0755\"}]}, {\"name\": \"import provision_mcelog\", \"include_role\": {\"name\": \"tripleo_provision_mcelog\"}, \"when\": false}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/ceilometer\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}, {\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}, {\"name\": \"create fcontext entry for iscsi\", \"community.general.sefcontext\": {\"target\": \"{{ item.path }}(/.*)?\", \"setype\": \"{{ item.setype }}\", \"state\": \"present\"}, \"with_items\": [{\"path\": \"/etc/iscsi\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/target\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/iscsi\", \"setype\": \"container_file_t\"}]}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\"}, \"with_items\": [{\"path\": \"/etc/iscsi\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/target\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/iscsi\", \"setype\": \"container_file_t\"}]}, {\"name\": \"stat /lib/systemd/system/iscsid.socket\", \"stat\": \"path=/lib/systemd/system/iscsid.socket\", \"register\": \"stat_iscsid_socket\"}, {\"name\": \"Stop and disable iscsid.socket service\", \"service\": \"name=iscsid.socket state=stopped enabled=no\", \"when\": \"stat_iscsid_socket.stat.exists\"}, {\"name\": \"Check if iscsi.service is enabled\", \"command\": \"systemctl is-enabled --quiet iscsi.service\", \"failed_when\": false, \"register\": \"iscsi_service_enabled_result\"}, {\"name\": \"Stop iscsi.service\", \"service\": \"name=iscsi.service state=stopped enabled=no\", \"when\": [\"iscsi_service_enabled_result is changed\", \"iscsi_service_enabled_result.rc == 0\"]}, {\"include_role\": {\"name\": \"tripleo_kernel\"}}, {\"name\": \"create persistent logs directory\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/metrics_qdr\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/metrics_qdr\", \"setype\": \"container_file_t\"}]}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"setype\": \"{{ item.setype }}\", \"state\": \"directory\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/nova\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}, {\"name\": \"Check for /var/lib/nova/instances directory exitance\", \"stat\": {\"path\": \"/var/lib/nova/instances\"}, \"register\": \"check_nova_instances_result\"}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype | default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/lib/nova\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/_nova_secontext\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/nova/instances\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/libvirt\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/tmpfiles.d\"}]}, {\"name\": \"ensure /run/nova is present upon reboot\", \"copy\": {\"dest\": \"/etc/tmpfiles.d/run-nova.conf\", \"content\": \"d /run/nova 0777 root root - -\\n\"}}, {\"name\": \"create tempfiles\", \"command\": \"systemd-tmpfiles --create\"}, {\"name\": \"Mount Nova NFS Share\", \"vars\": {\"nfs_backend_enable\": false, \"nfs_share\": \"\", \"nfs_options\": \"context=system_u:object_r:nfs_t:s0\", \"nfs_vers\": \"4.2\"}, \"mount\": {\"name\": \"/var/lib/nova/instances\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{nfs_share}}\", \"opts\": \"_netdev,bg,{{nfs_options}},nfsvers={{nfs_vers}}\"}, \"when\": \"nfs_backend_enable|bool\"}, {\"name\": \"delay installation of systemd-container\", \"when\": \"check_nova_instances_result.stat.exists\", \"block\": [{\"name\": \"check systemd-container package installed or not\", \"package\": {\"name\": \"systemd-container\", \"state\": \"present\"}, \"check_mode\": true, \"register\": \"is_systemd_container_package\", \"failed_when\": false}, {\"name\": \"get latest package from downloaded package versions\", \"shell\": \"ls -1t /var/tmp/systemd-container* | head -1\", \"register\": \"latest_systemd_container_package\", \"when\": [\"is_systemd_container_package is defined\", \"(\'changed\' in is_systemd_container_package)\", \"is_systemd_container_package.changed\"], \"failed_when\": false}, {\"name\": \"Install systemd-container package on boot\", \"copy\": {\"dest\": \"/etc/systemd/system/install-systemd-container.service\", \"content\": \"[Unit]\\nDescription=Install systemd container package on system boot\\nBefore=tripleo_nova_virtqemud.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/usr/bin/rpm -ivh {{ latest_systemd_container_package.stdout }}\\nExecStartPost=rm -f /var/tmp/systemd-container*\\n\\n[Install]\\nWantedBy=multi-user.target\\n\"}, \"when\": [\"latest_systemd_container_package is defined\", \"(\'stdout\' in latest_systemd_container_package)\", \"is_systemd_container_package is defined\", \"(\'changed\' in is_systemd_container_package)\", \"is_systemd_container_package.changed\"]}, {\"name\": \"enable install-systemd-container on compute boot\", \"systemd\": {\"name\": \"install-systemd-container\", \"state\": \"stopped\", \"enabled\": true, \"daemon_reload\": true}, \"when\": [\"is_systemd_container_package is defined\", \"(\'changed\' in is_systemd_container_package)\", \"is_systemd_container_package.changed\"]}, {\"name\": \"check if install-systemd-container service exists\", \"stat\": {\"path\": \"/etc/systemd/system/install-systemd-container.service\"}, \"register\": \"install_systemd_container_result\"}, {\"name\": \"disable and mask install-systemd-container on compute boot\", \"systemd\": {\"name\": \"install-systemd-container\", \"enabled\": false, \"masked\": true, \"daemon_reload\": true}, \"when\": [\"is_systemd_container_package is defined\", \"(\'changed\' in is_systemd_container_package)\", \"not is_systemd_container_package.changed\", \"install_systemd_container_result.stat.exists\"]}]}, {\"name\": \"is Nova Resume Guests State On Host Boot enabled\", \"set_fact\": {\"resume_guests_state_on_host_boot_enabled\": false}}, {\"name\": \"install libvirt-guests systemd unit file (docker)\", \"when\": [\"resume_guests_state_on_host_boot_enabled|bool\", \"container_cli == \'docker\'\"], \"block\": [{\"name\": \"libvirt-guests unit to stop nova_compute container before shutdown VMs\", \"copy\": {\"dest\": \"/etc/systemd/system/libvirt-guests.service\", \"content\": \"[Unit]\\nDescription=Suspend/Resume Running libvirt Guests\\nAfter=network.target\\nAfter=time-sync.target\\nAfter=virt-guest-shutdown.target\\nAfter=docker.service\\nAfter=tripleo-container-shutdown.service\\nAfter=rhel-push-plugin.service\\nDocumentation=man:libvirtd(8)\\nDocumentation=https://libvirt.org\\n\\n[Service]\\nEnvironmentFile=-/var/lib/config-data/puppet-generated/nova_libvirt/etc/sysconfig/libvirt-guests\\n# Hack just call traditional service until we factor\\n# out the code\\nExecStart=/bin/{{container_cli}} exec nova_libvirt /bin/sh -x /usr/libexec/libvirt-guests.sh start\\nExecStop=/bin/{{container_cli}} stop nova_compute\\nExecStop=/bin/{{container_cli}}  exec nova_libvirt /bin/sh -x /usr/libexec/libvirt-guests.sh stop\\nType=oneshot\\nRemainAfterExit=yes\\nStandardOutput=journal+console\\nTimeoutStopSec=0\\n\\n[Install]\\nWantedBy=multi-user.target\\n\"}}, {\"name\": \"Making sure virt-guest-shutdown.target is present\", \"copy\": {\"dest\": \"/etc/systemd/system/virt-guest-shutdown.target\", \"content\": \"[Unit]\\nDescription=Libvirt guests shutdown\\nDocumentation=https://libvirt.org\\nAfter=systemd-machined.service\\nAfter=network-online.target\\nAfter=tripleo_nova_libvirt.target\\nBefore=tripleo_nova_compute.service\\n\"}}, {\"name\": \"libvirt-guests enable VM shutdown on compute reboot/shutdown\", \"systemd\": {\"name\": \"libvirt-guests\", \"enabled\": true, \"daemon_reload\": true}}]}, {\"name\": \"install tripleo_nova_libvirt_guests systemd unit file (podman)\", \"when\": [\"resume_guests_state_on_host_boot_enabled|bool\", \"container_cli == \'podman\'\"], \"block\": [{\"name\": \"libvirt-guests unit to stop nova_compute container before shutdown VMs (monolithic libvirt)\", \"copy\": {\"dest\": \"/etc/systemd/system/tripleo_nova_libvirt_guests.service\", \"content\": \"[Unit]\\nDescription=Suspend libvirt Guests in tripleo\\nRequires=virt-guest-shutdown.target\\nAfter=systemd-machined.service\\nAfter=network-online.target\\nAfter=tripleo_nova_libvirt.target\\nBefore=tripleo_nova_compute.service\\nDocumentation=man:libvirtd(8)\\nDocumentation=https://libvirt.org\\n\\n[Service]\\nEnvironmentFile=-/etc/sysconfig/libvirt-guests\\nExecStart=/bin/podman exec nova_libvirt /bin/rm -f /var/lib/libvirt/libvirt-guests\\nExecStop=/bin/podman exec nova_libvirt /bin/sh -x /usr/libexec/libvirt-guests.sh shutdown\\nType=oneshot\\nRemainAfterExit=yes\\nStandardOutput=journal+console\\nTimeoutStopSec=0\\n\\n[Install]\\nWantedBy=multi-user.target\\n\"}, \"when\": \"tripleo_nova_libvirt_virsh_container | default(\'nova_libvirt\') == \'nova_libvirt\'\"}, {\"name\": \"libvirt-guests unit to stop nova_compute container before shutdown VMs (modular libvirt)\", \"copy\": {\"dest\": \"/etc/systemd/system/tripleo_nova_libvirt_guests.service\", \"content\": \"[Unit]\\nDescription=Suspend libvirt Guests in tripleo\\nRequires=virt-guest-shutdown.target\\nAfter=systemd-machined.service\\nAfter=network-online.target\\nAfter=tripleo_nova_libvirt.target\\nBefore=tripleo_nova_compute.service\\nDocumentation=man:libvirtd(8)\\nDocumentation=https://libvirt.org\\n\\n[Service]\\nEnvironmentFile=-/etc/sysconfig/libvirt-guests\\nExecStart=/bin/podman exec nova_virtproxyd /bin/rm -f /var/lib/libvirt/libvirt-guests\\nExecStop=/bin/podman exec nova_virtproxyd /bin/sh -x /usr/libexec/libvirt-guests.sh shutdown\\nType=oneshot\\nRemainAfterExit=yes\\nStandardOutput=journal+console\\nTimeoutStopSec=0\\n\\n[Install]\\nWantedBy=multi-user.target\\n\"}, \"when\": \"tripleo_nova_libvirt_virsh_container | default(\'nova_libvirt\') != \'nova_libvirt\'\"}, {\"name\": \"Making sure virt-guest-shutdown.target is present\", \"copy\": {\"dest\": \"/etc/systemd/system/virt-guest-shutdown.target\", \"content\": \"[Unit]\\nDescription=Libvirt guests shutdown\\nDocumentation=https://libvirt.org\\nAfter=systemd-machined.service\\nAfter=network-online.target\\nAfter=tripleo_nova_libvirt.target\\nBefore=tripleo_nova_compute.service\\n\"}}, {\"name\": \"tripleo_nova_libvirt_guests enable VM shutdown on compute reboot/shutdown\", \"systemd\": {\"name\": \"tripleo_nova_libvirt_guests\", \"enabled\": true, \"daemon_reload\": true}}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": \"/var/lib/tripleo-config/ceph\", \"state\": \"directory\"}}, {\"name\": \"Do we prepend nova startup with a delay\", \"set_fact\": {\"nova_compute_delay\": 0}}, {\"name\": \"install nova-compute delay wrapper script\", \"copy\": {\"content\": \"#!/usr/libexec/platform-python\\n\\\"\\\"\\\"\\nThis wrapper was created to add an optional delay to the startup of nova-compute.\\nWe know that instances will fail to boot, after a compute reboot, if ceph is not\\nhealthy.\\n\\nIdeally, we would poll ceph to get its health, but it\'s not guaranteed that the\\ncompute node will have access to the keys.\\n\\\"\\\"\\\"\\n\\nimport os\\nimport sys\\nimport time\\nimport logging\\nimport argparse\\n\\nparser = argparse.ArgumentParser(description=\'Process some integers.\')\\nparser.add_argument(\'--config-file\', dest=\'nova_config\', action=\'store\',\\n                    default=\\\"/etc/nova/nova.conf\\\",\\n                    help=\'path to nova configuration (default: /etc/nova/nova.conf)\')\\nparser.add_argument(\'--nova-binary\', dest=\'nova_binary\', action=\'store\',\\n                    default=\\\"/usr/bin/nova-compute\\\",\\n                    help=\'path to nova compute binary (default: /usr/bin/nova-compute)\')\\nparser.add_argument(\'--delay\', dest=\'delay\', action=\'store\',\\n                    default=120, type=int,\\n                    help=\'Number of seconds to wait until nova-compute is started\')\\nparser.add_argument(\'--state-dir\', dest=\'state_dir\', action=\'store\',\\n                    default=\\\"/run/nova/startup\\\", help=\'state-file directory\')\\nparser.add_argument(\'--state-file\', dest=\'state_file\', action=\'store\',\\n                    default=\\\"nova-compute-delayed\\\",\\n                    help=\'file exists if we already delayed nova-compute startup\')\\n\\n\\nsections = {}\\n(args, remaining) = parser.parse_known_args(sys.argv)\\n\\nreal_args = [args.nova_binary, \'--config-file\', args.nova_config]\\nreal_args.extend(remaining[1:])\\n\\nif not os.path.isdir(args.state_dir):\\n  os.makedirs(args.state_dir, mode = 0o751)\\n\\nstate_file_name = os.path.join(args.state_dir, args.state_file)\\n\\nif not os.path.isfile(state_file_name):\\n    logging.info(\\\"Delaying nova-compute startup by %s seconds\\\" % args.delay)\\n    time.sleep(args.delay)\\n    open(state_file_name, \'a\').close()\\n\\nlogging.info(\\\"Executing %s\\\" % real_args)\\nos.execv(args.nova_binary, real_args)\\n\", \"dest\": \"/var/lib/nova/delay-nova-compute\", \"mode\": 493}, \"when\": \"nova_compute_delay|int > 0\"}, {\"name\": \"Is irqbalance enabled\", \"set_fact\": {\"compute_irqbalance_disabled\": false}}, {\"name\": \"disable irqbalance service on compute\", \"when\": \"compute_irqbalance_disabled|bool\", \"service\": {\"name\": \"irqbalance.service\", \"state\": \"stopped\", \"enabled\": false}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"setype\": \"{{ item.setype }}\", \"state\": \"directory\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/libvirt\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}, {\"name\": \"create libvirt persistent data directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype | default(omit) }}\", \"mode\": \"{{ item.mode | default(omit) }}\"}, \"with_items\": [{\"path\": \"/etc/libvirt\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/libvirt/secrets\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/libvirt/qemu\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/libvirt\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/cache/libvirt\"}, {\"path\": \"/var/lib/nova\", \"setype\": \"container_file_t\"}, {\"path\": \"/run/libvirt\"}, {\"path\": \"/var/log/containers/libvirt/swtpm\", \"setype\": \"container_file_t\", \"mode\": \"0770\"}]}, {\"name\": \"ensure qemu group is present on the host\", \"group\": {\"name\": \"qemu\", \"gid\": 107, \"state\": \"present\"}}, {\"name\": \"ensure qemu user is present on the host\", \"user\": {\"name\": \"qemu\", \"uid\": 107, \"group\": \"qemu\", \"state\": \"present\", \"shell\": \"/sbin/nologin\", \"comment\": \"qemu user\"}}, {\"name\": \"create directory for vhost-user sockets with qemu ownership\", \"file\": {\"path\": \"/var/lib/vhost_sockets\", \"state\": \"directory\", \"owner\": \"qemu\", \"group\": \"qemu\", \"setype\": \"virt_cache_t\", \"seuser\": \"system_u\"}}, {\"name\": \"check if libvirt is installed\", \"command\": \"/usr/bin/rpm -q libvirt-daemon\", \"failed_when\": false, \"register\": \"libvirt_installed\", \"check_mode\": false}, {\"name\": \"make sure libvirt services are disabled and masked\", \"service\": {\"name\": \"{{ item }}\", \"state\": \"stopped\", \"enabled\": false, \"masked\": true, \"daemon_reload\": true}, \"with_items\": [\"libvirtd.service\", \"virtlogd.socket\"], \"when\": \"libvirt_installed.rc == 0\"}, {\"name\": \"ensure /run/libvirt is present upon reboot\", \"copy\": {\"dest\": \"/etc/tmpfiles.d/run-libvirt.conf\", \"content\": \"d /run/libvirt 0755 root root - -\\n\"}}, {\"name\": \"Enable os_enable_vtpm SELinux boolean for vTPM\", \"seboolean\": {\"name\": \"os_enable_vtpm\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}, {\"name\": \"remove gnutls-qemu.config\", \"file\": {\"path\": \"/etc/crypto-policies/local.d/gnutls-qemu.config\", \"state\": \"absent\"}, \"register\": \"update_gnutls_config\"}, {\"name\": \"update crypto policies\", \"command\": \"update-crypto-policies\", \"when\": \"update_gnutls_config.changed\"}, {\"name\": \"Create libvirt persistent data directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\"}, \"loop\": [{\"path\": \"/run/libvirt\", \"setype\": \"virt_var_run_t\"}]}, {\"name\": \"allow logrotate to read inside containers\", \"seboolean\": {\"name\": \"logrotate_read_inside_containers\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}, {\"name\": \"Install and configure Podman\", \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": [], \"container_registry_login\": false, \"container_registry_logins\": {}, \"container_registry_logins_json\": {}, \"container_default_pids_limit\": 4096, \"container_events_logger_mechanism\": \"journald\"}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}, {\"name\": \"Configure tripleo_container_manage to generate systemd drop-in dependencies\", \"copy\": {\"dest\": \"/etc/sysconfig/podman_drop_in\", \"content\": \"This file makes tripleo_container_manage generate additional systemd\\ndependencies for containers that have special\\nstart/stop ordering constraints. It ensures that\\nthose constraints are enforced on reboot/shutdown.\\n\"}}, {\"name\": \"create persistent logs directory for rsyslog\", \"file\": {\"path\": \"/var/log/containers/rsyslog\", \"state\": \"directory\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}}, {\"name\": \"create persistent state directory for rsyslog\", \"file\": {\"path\": \"/var/lib/rsyslog.container\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}, {\"include_role\": {\"name\": \"tripleo_sshd\"}, \"vars\": {\"tripleo_sshd_server_options\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"tripleo_sshd_password_authentication\": \"no\", \"tripleo_sshd_banner_enabled\": false, \"tripleo_sshd_banner_text\": \"\", \"tripleo_sshd_motd_enabled\": false, \"tripleo_sshd_message_of_the_day\": \"\"}}, {\"name\": \"Check for NTP service\", \"shell\": \"systemctl is-active ntpd.service || systemctl is-enabled ntpd.service\", \"failed_when\": false, \"become\": true, \"register\": \"ntp_service_check\"}, {\"name\": \"Disable NTP before configuring Chrony\", \"service\": {\"name\": \"ntpd\", \"state\": \"stopped\", \"enabled\": false}, \"when\": [\"ntp_service_check.rc is defined\", \"ntp_service_check.rc == 0\"]}, {\"name\": \"Install, Configure and Run Chrony\", \"include_role\": {\"name\": \"chrony\"}}, {\"name\": \"Force NTP sync\", \"command\": \"chronyc makestep\"}, {\"name\": \"Ensure system is NTP time synced\", \"command\": \"chronyc waitsync 30\"}, {\"name\": \"Run timezone role\", \"include_role\": {\"name\": \"tripleo_timezone\"}, \"vars\": {\"tripleo_timezone\": \"UTC\"}}, {\"name\": \"Notice - ctlplane subnet is set\", \"debug\": {\"msg\": \"CIDRs found in the ctlplane network tags.\\n\"}}, {\"include_role\": {\"name\": \"tuned\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/openvswitch\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/openvswitch/ovn\", \"setype\": \"container_file_t\"}]}, {\"name\": \"Copy in cleanup script\", \"copy\": {\"content\": \"#!/usr/bin/bash\\n# Cleanup neutron OVS bridges. To be called on startup to avoid\\n# \\\"difficult-to-debug\\\" issues with partially configured resources.\\n\\nNEUTRON_OVS_CONF=/var/lib/config-data/puppet-generated/neutron/etc/neutron/plugins/ml2/openvswitch_agent.ini\\n\\nif [ -e ${NEUTRON_OVS_CONF} ];\\nthen\\n    INT_BRIDGE=`crudini --get ${NEUTRON_OVS_CONF} ovs integration_bridge`\\n    TUN_BRIDGE=`crudini --get ${NEUTRON_OVS_CONF} ovs tunnel_bridge`\\nfi\\n\\nfor port in `ovs-vsctl list-ports ${INT_BRIDGE:-\\\"br-int\\\"}`;\\ndo\\n    skip_cleanup=`ovs-vsctl --if-exists get Interface $port external_ids:skip_cleanup`\\n    if ! [[ \\\"x$skip_cleanup\\\" == \\\"x\\\\\\\"true\\\\\\\"\\\" ]];\\n    then\\n        ovs-vsctl del-port ${INT_BRIDGE:-\\\"br-int\\\"} $port\\n    fi\\ndone\\n\\novs-vsctl --if-exists del-br ${TUN_BRIDGE:-\\\"br-tun\\\"}\\n\\n# Clean up trunk port bridges\\nfor br in $(ovs-vsctl list-br | egrep \'tbr-[0-9a-f\\\\-]+\'); do\\n    ovs-vsctl --if-exists del-br $br\\ndone\\n\", \"dest\": \"/usr/libexec/neutron-cleanup\", \"force\": true, \"mode\": \"0755\"}}, {\"name\": \"Copy in cleanup service\", \"copy\": {\"content\": \"[Unit]\\nDescription=Neutron cleanup on startup\\nAfter=openvswitch.service network.target\\nBefore=tripleo_neutron_ovs_agent.service tripleo_neutron_dhcp.service tripleo_neutron_l3_agent.service tripleo_nova_compute.service\\nRefuseManualStop=yes\\n\\n[Service]\\nType=oneshot\\nExecStart=/usr/libexec/neutron-cleanup\\n\\n[Install]\\nWantedBy=multi-user.target\\n\", \"dest\": \"/usr/lib/systemd/system/neutron-cleanup.service\", \"force\": true}}, {\"name\": \"Enabling the cleanup service\", \"service\": {\"name\": \"neutron-cleanup\", \"enabled\": true}, \"when\": \"not (ansible_check_mode|bool)\"}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/neutron\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}, {\"name\": \"create /run/netns with temp namespace\", \"command\": \"ip netns add ns_temp\", \"register\": \"ipnetns_add_result\", \"failed_when\": false}, {\"name\": \"remove temp namespace\", \"command\": \"ip netns delete ns_temp\", \"failed_when\": false, \"when\": [\"ipnetns_add_result.rc is defined\", \"ipnetns_add_result.rc == 0\"]}, {\"name\": \"create /var/lib/neutron\", \"file\": {\"path\": \"/var/lib/neutron\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}, {\"name\": \"set conditions\", \"set_fact\": {\"haproxy_wrapper_enabled\": true, \"debug_enabled\": true, \"docker_additional_sockets\": [\"/var/lib/openstack/docker.sock\"]}}, {\"name\": \"create kill_scripts directory within /var/lib/neutron\", \"file\": {\"state\": \"directory\", \"path\": \"/var/lib/neutron/kill_scripts\"}}, {\"name\": \"create haproxy kill script\", \"when\": \"haproxy_wrapper_enabled|bool\", \"copy\": {\"dest\": \"/var/lib/neutron/kill_scripts/haproxy-kill\", \"mode\": 493, \"content\": \"#!/bin/bash\\n{% if debug_enabled|bool -%}\\nset -x\\n{% endif -%}\\nadd_date() {\\n  echo \\\"$(date) $@\\\"\\n}\\n\\n# Set up script logging for debugging purpose.\\n# It will be taken care of by logrotate since there is the .log\\n# suffix.\\nexec 3>&1 4>&2\\ntrap \'exec 2>&4 1>&3\' 0 1 2 3\\nexec 1>>/var/log/neutron/kill-script.log 2>&1\\n\\nSIG=$1\\nPID=$2\\nNETNS=$(ip netns identify ${PID})\\n\\nif [ \\\"x${NETNS}\\\" == \\\"x\\\" ]; then\\n  CLI=\\\"nsenter --all --preserve-credentials -t 1 podman\\\"\\n  SIG=9\\nelse\\n  CLI=\\\"nsenter --net=/run/netns/${NETNS} --preserve-credentials -m -t 1 podman\\\"\\nfi\\n\\nkill_container() {\\n  add_date \\\"Killing container $1 ($2)\\\"\\n  signal_container $1 $2 9\\n}\\n\\nstop_container() {\\n  add_date \\\"Stopping container $1 ($2)\\\"\\n  $CLI stop $2\\n}\\n\\nsignal_container() {\\n  SIGNAL=$3\\n  if [ -z \\\"$SIGNAL\\\" ]; then\\n      SIGNAL=\\\"HUP\\\"\\n  fi\\n  add_date \\\"Sending signal \'$SIGNAL\' to $1 ($2)\\\"\\n  $CLI kill --signal $SIGNAL $2\\n}\\n\\ndelete_container() {\\n  add_date \\\"Deleting container $1 ($2)\\\"\\n  $CLI rm $2 || echo \\\"Deleting container $1 ($2) failed\\\"\\n}\\n\\n\\n{% raw -%}\\nif [ -f /proc/$PID/cgroup ]; then\\n  # Get container ID based on process cgroups\\n  CT_ID=$(awk \'BEGIN {FS=\\\".scope|-\\\"} /\\\\/libpod-/ {if ($(NF-1)) print $(NF-1);exit}\' /proc/$PID/cgroup)\\n  CT_NAME=$($CLI inspect -f \'{{.Name}}\' $CT_ID)\\n\\n  case $SIG in\\n    HUP)\\n      signal_container $CT_NAME $CT_ID\\n      ;;\\n    9)\\n      kill_container $CT_NAME $CT_ID\\n      delete_container $CT_NAME $CT_ID\\n      ;;\\n    15)\\n      stop_container $CT_NAME $CT_ID\\n      delete_container $CT_NAME $CT_ID\\n      ;;\\n    *)\\n      add_date \\\"Unknown action ${SIG} for ${CT_NAME} ${CT_ID}\\\"\\n      exit 1\\n      ;;\\n  esac\\n\\nelse\\n  add_date \\\"No such PID: ${PID}\\\"\\n  exit 1\\nfi\\n{% endraw %}\\n\"}}], \"pre_deploy_step_tasks\": []}, \"BlockStorage\": {\"service_names\": [], \"monitoring_subscriptions\": [], \"config_settings\": {}, \"global_config_settings\": {}, \"service_config_settings\": {}, \"step_config\": \"\", \"deploy_steps_tasks\": [], \"external_deploy_tasks\": [], \"external_post_deploy_tasks\": [], \"external_update_tasks\": [], \"external_upgrade_tasks\": [], \"scale_tasks\": [], \"pre_upgrade_rolling_tasks\": [], \"upgrade_tasks\": [], \"post_upgrade_tasks\": [], \"update_tasks\": [], \"post_update_tasks\": [], \"upgrade_batch_tasks\": [], \"service_metadata_settings\": null, \"ansible_group_vars\": {\"ansible_async_dir\": \"/tmp/.ansible_async\"}, \"keystone_resources\": {}, \"firewall_rules\": {}, \"firewall_frontend_rules\": {}, \"firewall_ssl_frontend_rules\": {}, \"firewall_edge_frontend_rules\": {}, \"firewall_edge_ssl_frontend_rules\": null, \"puppet_config\": [], \"kolla_config\": {}, \"docker_config\": {}, \"container_config_scripts\": {}, \"container_puppet_tasks\": {}, \"host_prep_tasks\": [], \"pre_deploy_step_tasks\": []}, \"ObjectStorage\": {\"service_names\": [], \"monitoring_subscriptions\": [], \"config_settings\": {}, \"global_config_settings\": {}, \"service_config_settings\": {}, \"step_config\": \"\", \"deploy_steps_tasks\": [], \"external_deploy_tasks\": [], \"external_post_deploy_tasks\": [], \"external_update_tasks\": [], \"external_upgrade_tasks\": [], \"scale_tasks\": [], \"pre_upgrade_rolling_tasks\": [], \"upgrade_tasks\": [], \"post_upgrade_tasks\": [], \"update_tasks\": [], \"post_update_tasks\": [], \"upgrade_batch_tasks\": [], \"service_metadata_settings\": null, \"ansible_group_vars\": {\"ansible_async_dir\": \"/tmp/.ansible_async\"}, \"keystone_resources\": {}, \"firewall_rules\": {}, \"firewall_frontend_rules\": {}, \"firewall_ssl_frontend_rules\": {}, \"firewall_edge_frontend_rules\": {}, \"firewall_edge_ssl_frontend_rules\": null, \"puppet_config\": [], \"kolla_config\": {}, \"docker_config\": {}, \"container_config_scripts\": {}, \"container_puppet_tasks\": {}, \"host_prep_tasks\": [], \"pre_deploy_step_tasks\": []}, \"CephStorage\": {\"service_names\": [], \"monitoring_subscriptions\": [], \"config_settings\": {}, \"global_config_settings\": {}, \"service_config_settings\": {}, \"step_config\": \"\", \"deploy_steps_tasks\": [], \"external_deploy_tasks\": [], \"external_post_deploy_tasks\": [], \"external_update_tasks\": [], \"external_upgrade_tasks\": [], \"scale_tasks\": [], \"pre_upgrade_rolling_tasks\": [], \"upgrade_tasks\": [], \"post_upgrade_tasks\": [], \"update_tasks\": [], \"post_update_tasks\": [], \"upgrade_batch_tasks\": [], \"service_metadata_settings\": null, \"ansible_group_vars\": {\"ansible_async_dir\": \"/tmp/.ansible_async\"}, \"keystone_resources\": {}, \"firewall_rules\": {}, \"firewall_frontend_rules\": {}, \"firewall_ssl_frontend_rules\": {}, \"firewall_edge_frontend_rules\": {}, \"firewall_edge_ssl_frontend_rules\": null, \"puppet_config\": [], \"kolla_config\": {}, \"docker_config\": {}, \"container_config_scripts\": {}, \"container_puppet_tasks\": {}, \"host_prep_tasks\": [], \"pre_deploy_step_tasks\": []}, \"Networker\": {\"service_names\": [], \"monitoring_subscriptions\": [], \"config_settings\": {}, \"global_config_settings\": {}, \"service_config_settings\": {}, \"step_config\": \"\", \"deploy_steps_tasks\": [], \"external_deploy_tasks\": [], \"external_post_deploy_tasks\": [], \"external_update_tasks\": [], \"external_upgrade_tasks\": [], \"scale_tasks\": [], \"pre_upgrade_rolling_tasks\": [], \"upgrade_tasks\": [], \"post_upgrade_tasks\": [], \"update_tasks\": [], \"post_update_tasks\": [], \"upgrade_batch_tasks\": [], \"service_metadata_settings\": null, \"ansible_group_vars\": {\"ansible_async_dir\": \"/tmp/.ansible_async\"}, \"keystone_resources\": {}, \"firewall_rules\": {}, \"firewall_frontend_rules\": {}, \"firewall_ssl_frontend_rules\": {}, \"firewall_edge_frontend_rules\": {}, \"firewall_edge_ssl_frontend_rules\": null, \"puppet_config\": [], \"kolla_config\": {}, \"docker_config\": {}, \"container_config_scripts\": {}, \"container_puppet_tasks\": {}, \"host_prep_tasks\": [], \"pre_deploy_step_tasks\": []}}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"BlockStorageCount\": 0, \"ObjectStorageCount\": 0, \"CephStorageCount\": 0, \"NetworkerCount\": 0, \"ServiceNetMapLower\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"PingTestGatewayIPsMap\": {\"Controller\": [\"192.168.122.10\"], \"CellController\": [\"192.168.122.10\"], \"CellControllerCompute\": [\"192.168.122.10\"], \"Compute\": [\"192.168.122.10\"], \"BlockStorage\": [\"192.168.122.10\"], \"ObjectStorage\": [\"192.168.122.10\"], \"CephStorage\": [\"192.168.122.10\"], \"Networker\": [\"192.168.122.10\"]}, \"PingTestIpsMap\": {\"Controller\": \"    \", \"CellController\": \"192.168.122.106 172.18.0.106 172.20.0.106 172.17.0.106 172.19.0.106\", \"CellControllerCompute\": \"    \", \"Compute\": \"192.168.122.107 172.18.0.107 172.17.0.107 172.19.0.107\", \"BlockStorage\": \"   \", \"ObjectStorage\": \"   \", \"CephStorage\": \"  \", \"Networker\": \"  \"}, \"HostsEntry\": \"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane,192.168.122.93  multicell.ctlplane.localdomain,172.18.0.143  multicell.storage.localdomain,172.20.0.153  multicell.storagemgmt.localdomain,172.17.0.133  multicell.internalapi.localdomain,172.21.0.83  multicell.ooo.test,172.17.0.106 np0000071538.ooo.test np0000071538,172.18.0.106 np0000071538.storage.ooo.test np0000071538.storage,172.20.0.106 np0000071538.storagemgmt.ooo.test np0000071538.storagemgmt,172.17.0.106 np0000071538.internalapi.ooo.test np0000071538.internalapi,172.19.0.106 np0000071538.tenant.ooo.test np0000071538.tenant,192.168.122.106 np0000071538.ctlplane.ooo.test np0000071538.ctlplane,172.17.0.107 np0000071539.ooo.test np0000071539,172.18.0.107 np0000071539.storage.ooo.test np0000071539.storage,172.17.0.107 np0000071539.internalapi.ooo.test np0000071539.internalapi,172.19.0.107 np0000071539.tenant.ooo.test np0000071539.tenant,192.168.122.107 np0000071539.ctlplane.ooo.test np0000071539.ctlplane,192.168.122.90  multicell.ctlplane.localdomain,172.18.0.140  multicell.storage.localdomain,172.20.0.150  multicell.storagemgmt.localdomain,172.17.0.130  multicell.internalapi.localdomain,172.21.0.80  multicell.ooo.test,172.17.0.103 np0000071537.ooo.test np0000071537,172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage,172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt,172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi,172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant,192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\", \"EnabledServices\": \"boot_params_service,ca_certs,clustercheck,collectd,container_image_prepare,logrotate_crond,haproxy,iscsid,kernel,metrics_qdr,mysql,mysql_client,nova_conductor,nova_metadata,nova_vnc_proxy,oslo_messaging_rpc,pacemaker,podman,rsyslog,snmp,sshd,chrony,timezone,tripleo_firewall,tripleo_packages,tuned,boot_params_service,ca_certs,collectd,ceilometer_agent_compute,ceilometer_agent_ipmi,iscsid,kernel,metrics_qdr,mysql_client,nova_compute,nova_libvirt,nova_libvirt_guests,nova_migration_target,logrotate_crond,podman,rsyslog,snmp,sshd,chrony,timezone,tripleo_firewall,tripleo_packages,tuned,ovn_controller,ovn_metadata\", \"ControlVirtualIP\": \"192.168.122.93\", \"EnabledNetworks\": \"Storage,StorageMgmt,InternalApi,Tenant,External\", \"NetVipMap\": {\"ctlplane\": \"192.168.122.93\", \"ctlplane_subnet\": \"192.168.122.93/24\", \"ctlplane_uri\": \"192.168.122.93\", \"storage\": \"172.18.0.143\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.143\", \"storage_mgmt\": \"172.20.0.153\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.153\", \"internal_api\": \"172.17.0.133\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.133\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.83\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.83\"}, \"CloudNames\": {\"cloud_name_storage\": \"multicell.storage.localdomain\", \"cloud_name_storage_mgmt\": \"multicell.storagemgmt.localdomain\", \"cloud_name_internal_api\": \"multicell.internalapi.localdomain\", \"cloud_name_external\": \"multicell.ooo.test\", \"cloud_name_ctlplane\": \"multicell.ctlplane.localdomain\"}, \"UndercloudHostsEntries\": \"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"ExtraHostsEntries\": \"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane,192.168.122.90  multicell.ctlplane.localdomain,172.18.0.140  multicell.storage.localdomain,172.20.0.150  multicell.storagemgmt.localdomain,172.17.0.130  multicell.internalapi.localdomain,172.21.0.80  multicell.ooo.test,172.17.0.103 np0000071537.ooo.test np0000071537,172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage,172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt,172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi,172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant,192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\", \"VipHostsEntries\": \"192.168.122.93  multicell.ctlplane.localdomain,172.18.0.143  multicell.storage.localdomain,172.20.0.153  multicell.storagemgmt.localdomain,172.17.0.133  multicell.internalapi.localdomain,172.21.0.83  multicell.ooo.test\", \"KeystoneResourcesConfigs\": {}, \"NetCidrMap\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(196,'2026-06-12 08:26:49',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Extra Post Deployment Config\", \"parameters\": {\"servers\": {\"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"servers\": {\"0\": \"fdfd9831-4e7f-49b0-88e6-ee2bc9bc0add\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(197,'2026-06-12 08:26:51',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Extra Post Deployment Config\", \"parameters\": {\"servers\": {\"type\": \"json\"}, \"EndpointMap\": {\"default\": {}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"OS::Heat::None\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"OS::Heat::None\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaScheduler\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaShare\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Network::Management\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"servers\": {\"0\": \"9c74e5b3-24cc-4b92-a048-87963237f199\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.133:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.133:3306\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.133\", \"host_nobrackets\": \"172.17.0.133\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.133:8775\", \"uri_no_suffix\": \"http://172.17.0.133:8775\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.83\", \"host_nobrackets\": \"172.21.0.83\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.83:6080\", \"uri_no_suffix\": \"http://172.21.0.83:6080\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000071537\", \"cell1-controller-0\": \"np0000071538\", \"cell1-compute-0\": \"np0000071539\", \"cell2-controller-compute-0\": \"np0000071540\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"SshFirewallAllowAll\": true, \"NovaAdditionalCell\": true, \"NovaLocalMetadataPerCell\": true, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.113\", \"use_neutron\": false}], \"DockerPuppetDebug\": true, \"ControllerCount\": 0, \"CellControllerCount\": 1, \"CellControllerComputeCount\": 0, \"ComputeCount\": 1, \"NeutronGlobalPhysnetMtu\": 1350, \"CinderLVMLoopDeviceSize\": 20480, \"CloudName\": \"multicell.ooo.test\", \"CloudNameInternal\": \"multicell.internalapi.localdomain\", \"CloudNameStorage\": \"multicell.storage.localdomain\", \"CloudNameStorageManagement\": \"multicell.storagemgmt.localdomain\", \"CloudNameCtlplane\": \"multicell.ctlplane.localdomain\", \"CloudDomain\": \"ooo.test\", \"OVNCMSOptions\": \"enable-chassis-as-gw\", \"NeutronPhysicalBridge\": \"br-ex\", \"NeutronNetworkType\": \"geneve\", \"NeutronBridgeMappings\": \"datacentre:br-ex\", \"CellControllerComputeHostnameFormat\": \"%stackname%-controller-compute-%index%\", \"CellControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"ComputeHostnameFormat\": \"%stackname%-compute-%index%\", \"ControllerHostnameFormat\": \"%stackname%-controller-%index%\", \"NetworkConfigWithAnsible\": false, \"ControllerNetworkConfigUpdate\": false, \"ComputeNetworkConfigUpdate\": false, \"BlockStorageNetworkConfigUpdate\": false, \"ObjectStorageNetworkConfigUpdate\": false, \"CephStorageNetworkConfigUpdate\": false, \"NetworkerNetworkConfigUpdate\": false, \"CellControllerNetworkConfigUpdate\": false, \"CellControllerComputeNetworkConfigUpdate\": false, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"localdomain\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"compute-2-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.109\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"controller-0-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071538-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000071539-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"compute-2\": {\"ctlplane\": {\"ip_address\": \"192.168.122.109\", \"ip_address_uri\": \"192.168.122.109\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.109\", \"ip_address_uri\": \"172.21.0.109\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.109\", \"ip_address_uri\": \"172.17.0.109\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.109\", \"ip_address_uri\": \"172.18.0.109\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.109\", \"ip_address_uri\": \"172.20.0.109\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.109\", \"ip_address_uri\": \"172.19.0.109\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"controller-0\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071538\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000071539\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"AdminPassword\": \"bUe66HleZhJpBVjnSHAhIOXaa\", \"AdminToken\": \"BiQBw7GX7DmVOFbZmHwIY6J8Y\", \"AllNodesExtraMapData\": {\"memcached_node_ips\": [\"172.17.0.103\"], \"oslo_messaging_notify_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"oslo_messaging_notify_short_bootstrap_node_name\": \"np0000071537\", \"oslo_messaging_rpc_node_names\": [\"np0000071537.internalapi.ooo.test\"], \"ovn_dbs_node_ips\": [\"172.17.0.103\"], \"redis_vip\": \"192.168.122.110\"}, \"AuthCloudName\": \"overcloud\", \"CeilometerMeteringSecret\": \"EPgaQlmbDVmqQsiNdVrRly1ai\", \"CeilometerPassword\": \"LcRR8yGk8HFbgdc1qmDrKhpIE\", \"CinderPassword\": \"GD6nH1mrNie1qXOxmU8IDr1Aa\", \"EndpointMapOverride\": {\"AodhAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8042\", \"uri_no_suffix\": \"http://172.17.0.130:8042\"}, \"AodhPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8042\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8042\", \"uri_no_suffix\": \"http://172.21.0.80:8042\"}, \"BarbicanAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9311\", \"uri_no_suffix\": \"http://172.17.0.130:9311\"}, \"BarbicanPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9311\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9311\", \"uri_no_suffix\": \"http://172.21.0.80:9311\"}, \"CephDashboardInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8444\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8444\", \"uri_no_suffix\": \"http://192.168.122.90:8444\"}, \"CephGrafanaInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"3100\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:3100\", \"uri_no_suffix\": \"http://172.18.0.140:3100\"}, \"CephRgwAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"CephRgwPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"CinderAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV2Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV2Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"CinderV3Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8776\"}, \"CinderV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8776\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8776\"}, \"DesignateAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignateInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9001/v2\", \"uri_no_suffix\": \"http://172.17.0.130:9001\"}, \"DesignatePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9001\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9001/v2\", \"uri_no_suffix\": \"http://172.21.0.80:9001\"}, \"DockerRegistryInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"8787\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:8787\", \"uri_no_suffix\": \"http://192.168.122.90:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.80:2049\", \"uri_no_suffix\": \"nfs://172.21.0.80:2049\"}, \"GlanceAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlanceInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9293\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9293\", \"uri_no_suffix\": \"http://172.17.0.130:9293\"}, \"GlancePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9292\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9292\", \"uri_no_suffix\": \"http://172.21.0.80:9292\"}, \"GnocchiAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8041\", \"uri_no_suffix\": \"http://172.17.0.130:8041\"}, \"GnocchiPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8041\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8041\", \"uri_no_suffix\": \"http://172.21.0.80:8041\"}, \"HeatAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatCfnAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8000/v1\", \"uri_no_suffix\": \"http://172.17.0.130:8000\"}, \"HeatCfnPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8000/v1\", \"uri_no_suffix\": \"http://172.21.0.80:8000\"}, \"HeatInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8004\"}, \"HeatPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8004\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8004\"}, \"HorizonPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"80\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:80/dashboard\", \"uri_no_suffix\": \"http://172.21.0.80:80\"}, \"IronicAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicInspectorAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:5050\", \"uri_no_suffix\": \"http://192.168.122.90:5050\"}, \"IronicInspectorPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5050\", \"uri_no_suffix\": \"http://172.21.0.80:5050\"}, \"IronicInternal\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:6385/v1\", \"uri_no_suffix\": \"http://192.168.122.90:6385\"}, \"IronicPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6385\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6385/v1\", \"uri_no_suffix\": \"http://172.21.0.80:6385\"}, \"KeystoneAdmin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystonePublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"KeystoneV3Admin\": {\"host\": \"192.168.122.90\", \"host_nobrackets\": \"192.168.122.90\", \"port\": \"35357\", \"protocol\": \"http\", \"uri\": \"http://192.168.122.90:35357/v3\", \"uri_no_suffix\": \"http://192.168.122.90:35357\"}, \"KeystoneV3Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:5000/v3\", \"uri_no_suffix\": \"http://172.17.0.130:5000\"}, \"KeystoneV3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5000\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:5000/v3\", \"uri_no_suffix\": \"http://172.21.0.80:5000\"}, \"ManilaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v2\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v2\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"ManilaV1Admin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Internal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.17.0.130:8786\"}, \"ManilaV1Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8786\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8786\"}, \"MetricsQdrPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://172.21.0.80:5666\", \"uri_no_suffix\": \"amqp://172.21.0.80:5666\"}, \"MysqlCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"MysqlInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://172.17.0.130:3306\", \"uri_no_suffix\": \"mysql+pymysql://172.17.0.130:3306\"}, \"NeutronAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9696\", \"uri_no_suffix\": \"http://172.17.0.130:9696\"}, \"NeutronPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9696\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9696\", \"uri_no_suffix\": \"http://172.21.0.80:9696\"}, \"NovaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8774/v2.1\", \"uri_no_suffix\": \"http://172.17.0.130:8774\"}, \"NovaMetadataCellInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaMetadataInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8775\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8775\", \"uri_no_suffix\": \"http://172.17.0.130:8775\"}, \"NovaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8774\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8774/v2.1\", \"uri_no_suffix\": \"http://172.21.0.80:8774\"}, \"NovaVNCProxyAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:6080\", \"uri_no_suffix\": \"http://172.17.0.130:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"6080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:6080\", \"uri_no_suffix\": \"http://172.21.0.80:6080\"}, \"NovajoinAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9090/v1\", \"uri_no_suffix\": \"http://172.17.0.130:9090\"}, \"NovajoinPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9090\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9090/v1\", \"uri_no_suffix\": \"http://172.21.0.80:9090\"}, \"OctaviaAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:9876\", \"uri_no_suffix\": \"http://172.17.0.130:9876\"}, \"OctaviaPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"9876\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:9876\", \"uri_no_suffix\": \"http://172.21.0.80:9876\"}, \"PlacementAdmin\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementInternal\": {\"host\": \"172.17.0.130\", \"host_nobrackets\": \"172.17.0.130\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.17.0.130:8778/placement\", \"uri_no_suffix\": \"http://172.17.0.130:8778\"}, \"PlacementPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8778\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8778/placement\", \"uri_no_suffix\": \"http://172.21.0.80:8778\"}, \"SwiftAdmin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftInternal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftPublic\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}, \"SwiftS3Admin\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Internal\": {\"host\": \"172.18.0.140\", \"host_nobrackets\": \"172.18.0.140\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.18.0.140:8080\", \"uri_no_suffix\": \"http://172.18.0.140:8080\"}, \"SwiftS3Public\": {\"host\": \"172.21.0.80\", \"host_nobrackets\": \"172.21.0.80\", \"port\": \"8080\", \"protocol\": \"http\", \"uri\": \"http://172.21.0.80:8080\", \"uri_no_suffix\": \"http://172.21.0.80:8080\"}}, \"ExtraHostFileEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\", \"192.168.122.90  multicell.ctlplane.localdomain\", \"172.18.0.140  multicell.storage.localdomain\", \"172.20.0.150  multicell.storagemgmt.localdomain\", \"172.17.0.130  multicell.internalapi.localdomain\", \"172.21.0.80  multicell.ooo.test\", \"172.17.0.103 np0000071537.ooo.test np0000071537\", \"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\", \"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\", \"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\", \"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\", \"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\"], \"GlancePassword\": \"J200o48UisGSxwI0LqyJ9SKOW\", \"GlobalConfigExtraMapData\": {\"memcached_authtoken_port\": 11211, \"memcached_port\": 11211, \"oslo_messaging_notify_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_notify_port\": 5672, \"oslo_messaging_notify_scheme\": \"rabbit\", \"oslo_messaging_notify_use_ssl\": \"False\", \"oslo_messaging_notify_user_name\": \"guest\", \"oslo_messaging_rpc_password\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"oslo_messaging_rpc_port\": 5672, \"oslo_messaging_rpc_scheme\": \"rabbit\", \"oslo_messaging_rpc_use_ssl\": \"False\", \"oslo_messaging_rpc_user_name\": \"guest\", \"ovn_db_clustered\": true}, \"HAProxyStatsPassword\": \"MUfjd43QRvJhihQtc3FyU3ZcN\", \"HeatAuthEncryptionKey\": \"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\", \"HeatPassword\": \"WU8n16xtnWLSyaokXBXP0O3v3\", \"HeatStackDomainAdminPassword\": \"YvwP7a3Kpz2xnnoxHiPGU2HfW\", \"HorizonSecret\": \"qjsk85XMGV\", \"KeystoneCredential0\": \"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\", \"KeystoneCredential1\": \"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\"}}, \"LibvirtTLSPassword\": \"2CigqEmSelPTodxLFsXPpqGIh\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"qVfKhK3S4eoAhDlTRZhbii2Z9\", \"MysqlMariabackupPassword\": \"zgFej84GkeJYRMxOd5txIKJHX\", \"MysqlRootPassword\": \"lewodgEGks\", \"NeutronMetadataProxySharedSecret\": \"8w93bMk7ykp2VXaxsdJErpmNY\", \"NeutronPassword\": \"qnvMdngIoyiS9ntQpzmg868ob\", \"NovaPassword\": \"1Ii49H1EfmLUfEWsgfy9vla3q\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"NvleZPciNHzWAChh\", \"PlacementPassword\": \"f10sfIlDF9m1IGLZ9AeeMIXIv\", \"RabbitCookie\": \"2ljqdppvti5CXNoMTl6c\", \"RabbitPassword\": \"IBD6qNR8tM6oqdPBU1tpCvaKF\", \"RedisPassword\": \"zTfbzAZoNB6iKueE7EslkZpK7\", \"RpcPassword\": \"ezCMjhKa1U6SzsSlqK3G7UGxC\", \"SnmpdReadonlyUserPassword\": \"KjPkLxPsqu3qjdbO0SJ0shPX\", \"SwiftHashSuffix\": \"dF7eJe9aaQv02P7wDZQuDq78C\", \"SwiftPassword\": \"QN915NTjnlQknPxmrojB6rIqt\", \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.93\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.83\", \"ip_address_uri\": \"172.21.0.83\", \"ip_subnet\": \"172.21.0.83/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.133\", \"ip_address_uri\": \"172.17.0.133\", \"ip_subnet\": \"172.17.0.133/24\"}, \"storage\": {\"ip_address\": \"172.18.0.143\", \"ip_address_uri\": \"172.18.0.143\", \"ip_subnet\": \"172.18.0.143/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.153\", \"ip_address_uri\": \"172.20.0.153\", \"ip_subnet\": \"172.20.0.153/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": \"172.21.0.1\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"CephClientKey\": \"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\", \"CephClusterFSID\": \"b845fa31-b08e-44fd-ab60-5226bad3e713\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781252715, \"NovaComputeLibvirtType\": \"qemu\", \"NtpServer\": \"pool.ntp.org\", \"RootStackName\": \"cell1\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
/*!40000 ALTER TABLE `raw_template` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `raw_template_files`
--

DROP TABLE IF EXISTS `raw_template_files`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `raw_template_files` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `files` longtext DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `raw_template_files`
--

LOCK TABLES `raw_template_files` WRITE;
/*!40000 ALTER TABLE `raw_template_files` DISABLE KEYS */;
INSERT INTO `raw_template_files` VALUES (1,'{\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"parameters\\\": {\\\"name\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\"}, \\\"actions\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": [\\\"CREATE\\\", \\\"UPDATE\\\"]}, \\\"server\\\": {\\\"type\\\": \\\"string\\\"}, \\\"config\\\": {\\\"type\\\": \\\"string\\\"}, \\\"input_values\\\": {\\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"input values for the software deployments\\\", \\\"default\\\": {}}, \\\"input_key\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"get_input\\\"}, \\\"signal_transport\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"CFN_SIGNAL\\\"}, \\\"input_values_validate\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"LAX\\\"}}, \\\"resources\\\": {\\\"TripleODeployment\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"value\\\": {\\\"name\\\": {\\\"get_param\\\": \\\"name\\\"}, \\\"server\\\": {\\\"get_param\\\": \\\"server\\\"}, \\\"config\\\": {\\\"get_param\\\": \\\"config\\\"}, \\\"input_values\\\": {\\\"get_param\\\": \\\"input_values\\\"}, \\\"deployment\\\": {\\\"get_resource\\\": \\\"TripleOSoftwareDeployment\\\"}}}}, \\\"TripleOSoftwareDeployment\\\": {\\\"type\\\": \\\"OS::Heat::StructuredDeployment\\\", \\\"properties\\\": {\\\"name\\\": \\\"deployment_resource\\\", \\\"config\\\": {\\\"get_param\\\": \\\"config\\\"}, \\\"server\\\": \\\"fake_server_id\\\", \\\"input_values\\\": {\\\"get_param\\\": \\\"input_values\\\"}, \\\"signal_transport\\\": \\\"NO_SIGNAL\\\", \\\"actions\\\": {\\\"get_param\\\": \\\"actions\\\"}}}}, \\\"outputs\\\": {\\\"deploy_status_code\\\": {\\\"value\\\": 0}, \\\"deploy_stderr\\\": {\\\"value\\\": \\\"\\\"}, \\\"deploy_stdout\\\": {\\\"value\\\": \\\"\\\"}, \\\"show\\\": {\\\"value\\\": \\\"\\\"}, \\\"update_managed_packages\\\": {\\\"description\\\": \\\"boolean value indicating whether to upgrade managed packages\\\", \\\"value\\\": false}, \\\"hostname\\\": {\\\"description\\\": \\\"hostname\\\", \\\"value\\\": \\\"\\\"}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"parameters\\\": {\\\"name\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\"}, \\\"actions\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": [\\\"CREATE\\\", \\\"UPDATE\\\"]}, \\\"server\\\": {\\\"type\\\": \\\"string\\\"}, \\\"config\\\": {\\\"type\\\": \\\"string\\\"}, \\\"input_values\\\": {\\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"input values for the software deployments\\\", \\\"default\\\": {}}, \\\"input_key\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"get_input\\\"}, \\\"signal_transport\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"CFN_SIGNAL\\\"}, \\\"input_values_validate\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"LAX\\\"}}, \\\"resources\\\": {\\\"TripleODeployment\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"value\\\": {\\\"name\\\": {\\\"get_param\\\": \\\"name\\\"}, \\\"server\\\": {\\\"get_param\\\": \\\"server\\\"}, \\\"config\\\": {\\\"get_param\\\": \\\"config\\\"}, \\\"input_values\\\": {\\\"get_param\\\": \\\"input_values\\\"}, \\\"deployment\\\": {\\\"get_resource\\\": \\\"TripleOSoftwareDeployment\\\"}}}}, \\\"TripleOSoftwareDeployment\\\": {\\\"type\\\": \\\"OS::Heat::SoftwareDeployment\\\", \\\"properties\\\": {\\\"name\\\": \\\"deployment_resource\\\", \\\"config\\\": {\\\"get_param\\\": \\\"config\\\"}, \\\"server\\\": \\\"fake_server_id\\\", \\\"input_values\\\": {\\\"get_param\\\": \\\"input_values\\\"}, \\\"signal_transport\\\": \\\"NO_SIGNAL\\\", \\\"actions\\\": {\\\"get_param\\\": \\\"actions\\\"}}}}, \\\"outputs\\\": {\\\"deploy_status_code\\\": {\\\"value\\\": 0}, \\\"deploy_stderr\\\": {\\\"value\\\": \\\"\\\"}, \\\"deploy_stdout\\\": {\\\"value\\\": \\\"\\\"}, \\\"show\\\": {\\\"value\\\": \\\"\\\"}, \\\"update_managed_packages\\\": {\\\"description\\\": \\\"boolean value indicating whether to upgrade managed packages\\\", \\\"value\\\": false}, \\\"hostname\\\": {\\\"description\\\": \\\"hostname\\\", \\\"value\\\": \\\"\\\"}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/deploy-steps-playbooks-common.yaml\": \"---\\n# If a new play with potential facts gathering is added, make sure we set:\\n# any_errors_fatal: false\\n# ignore_unreachable: true\\n# So we don\'t break the MaxFailPercentage feature since these plays can\'t use\\n# Ansible strategies.\\n\\n- hosts: localhost\\n  name: Check if required variables are defined\\n  tasks:\\n    - ansible.builtin.fail:\\n        msg: deploy_source_host variable is not defined\\n      when: deploy_source_host is not defined\\n    - ansible.builtin.fail:\\n        msg: deploy_target_host variable is not defined\\n      when: deploy_target_host is not defined\\n    # Keep in mind that you will still need to use defaults in order to be\\n    # able to pass Ansible own syntax check for blocks like \'hosts\'.\\n\\n- hosts: all\\n  name: Clear cached facts\\n  # We don\'t want to gather facts, just clear them\\n  gather_facts: false\\n  tasks:\\n    - ansible.builtin.meta: clear_facts\\n  tags:\\n    - facts\\n\\n- hosts: \\\"{{ deploy_source_host | default([]) }}:{{ deploy_target_host | default([]) }}\\\"\\n  name: Gather facts\\n  strategy: tripleo_free\\n  gather_facts: true\\n  tasks:\\n    - name: Set legacy facts\\n      ansible.builtin.set_fact:\\n        ansible_distribution: \\\"{{ ansible_facts[\'distribution\'] }}\\\"\\n        ansible_distribution_major_version: \\\"{{ ansible_facts[\'distribution_major_version\'] }}\\\"\\n        ansible_distribution_release: \\\"{{ ansible_facts[\'distribution_release\'] }}\\\"\\n        ansible_distribution_version: \\\"{{ ansible_facts[\'distribution_version\'] }}\\\"\\n        ansible_os_family: \\\"{{ ansible_facts[\'os_family\'] }}\\\"\\n  tags:\\n    - facts\\n\\n- hosts: all\\n  name: Load global variables\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: false\\n  ignore_unreachable: true\\n  tasks:\\n    - ansible.builtin.include_vars: global_vars.yaml  # noqa: missing-import\\n      no_log: true\\n  tags:\\n    - always\\n\\n- hosts: all\\n  name: Include extra variables from files\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: false\\n  ignore_unreachable: true\\n  tasks:\\n    - name: Include Service VIP vars\\n      ansible.builtin.include_vars:\\n        file: \\\"{{ playbook_dir }}/service_vip_vars.yaml\\\"\\n        name: service_vip_vars\\n      ignore_errors: yes\\n    - name: Include OVN bridge MAC address variables\\n      ansible.builtin.include_vars:\\n        file: \\\"{{ playbook_dir }}/ovn_bridge_mac_address_vars.yaml\\\"\\n        name: ovn_bridge_mac_address_vars\\n      ignore_errors: yes\\n  tags:\\n    - always\\n\\n- hosts: \\\"{{ deploy_target_host | default([]) }}\\\"\\n  name: Render all_nodes data as group_vars for overcloud\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  # we don\'t skip errors or ignore unreachable on this one because it\'s\\n  # delegated to localhost. localhost should never be unreachable (tm)\\n  any_errors_fatal: True\\n  tasks:\\n    - name: Render all_nodes data as group_vars for overcloud\\n      delegate_to: localhost\\n      become: false\\n      run_once: true\\n      tripleo_all_nodes_data:\\n  tags:\\n    - facts\\n    - always\\n\\n- hosts: \\\"{{ deploy_target_host | default([]) }}\\\"\\n  name: Set all_nodes data as group_vars for overcloud\\n  gather_facts: \\\"{{ gather_facts | default(false) }}\\\"\\n  any_errors_fatal: false\\n  ignore_unreachable: true\\n  tasks:\\n    - name: Set all_nodes data as group_vars for overcloud\\n      ansible.builtin.include_vars: \\\"{{ playbook_dir }}/group_vars/overcloud.json\\\"\\n      no_log: true\\n  tags:\\n    - facts\\n    - always\\n\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/deploy-steps-tasks.yaml\": \"#####################################################\\n# Per step puppet configuration of the baremetal host\\n#####################################################\\n\\n- name: Write the config_step hieradata\\n  become: true\\n  no_log: True\\n  copy:\\n    content: \\\"{{ dict(step=step|int) | to_json }}\\\"\\n    dest: /etc/puppet/{{ ansible_check_mode | bool | ternary(\'check-mode/\', \'\') }}hieradata/config_step.json\\n    force: true\\n    mode: \'0600\'\\n  check_mode: no\\n  tags:\\n    - host_config\\n\\n- name: Run puppet host configuration for step {{ step }}\\n  become: true\\n  async: 3600\\n  poll: 0\\n  when: enable_puppet|bool\\n  shell: >-\\n    set -o pipefail;\\n    puppet apply {{ host_puppet_config_debug | default(\'\') }}\\n    --modulepath=/etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules\\n    --detailed-exitcodes\\n    --summarize\\n    --color=false\\n    {{ ansible_check_mode | bool | ternary(\'--noop\', \'\') }}\\n    {{ ansible_check_mode | bool | ternary(\'--hiera_config /etc/puppet/check-mode/hiera.yaml\', \'\') }}\\n    /var/lib/tripleo-config/{{ ansible_check_mode | bool | ternary(\'check-mode/\', \'\') }}puppet_step_config.pp\\n    2>&1 | logger -s -t puppet-user\\n  register: puppet_host_async_result\\n  no_log: true\\n  tags:\\n    - host_config\\n  check_mode: no\\n\\n- name: Wait for puppet host configuration to finish\\n  async_status:\\n    jid: \\\"{{ puppet_host_async_result.ansible_job_id }}\\\"\\n  register: puppet_host_outputs\\n  until: puppet_host_outputs.finished\\n  retries: 360\\n  delay: 10\\n  failed_when:\\n    - (not puppet_host_outputs.finished) or (puppet_host_outputs.rc is defined and puppet_host_outputs.rc not in [0, 2])\\n  when:\\n    - not (ansible_check_mode | bool)\\n    - enable_puppet|bool\\n  tags:\\n    - host_config\\n\\n- name: \\\"Debug output for task: Run puppet host configuration for step {{ step }}\\\"\\n  debug:\\n    var: puppet_host_outputs.stdout_lines | default([]) | union(puppet_host_outputs.stderr_lines | default([]))\\n  when:\\n    - not ansible_check_mode|bool\\n    - enable_puppet | bool\\n    - puppet_host_outputs.rc is defined\\n  changed_when: puppet_host_outputs.rc == 2\\n  failed_when: puppet_host_outputs.rc not in [0, 2]\\n  tags:\\n    - host_config\\n\\n#######################################\\n# Pre-cache facts for puppet containers\\n#######################################\\n# We don\'t want the pre-cache tasks to be skipped in dry-run so we force\\n# check_mode to \\\"no\\\".\\n# https://bugzilla.redhat.com/show_bug.cgi?id=1738529\\n- name: Pre-cache facts for puppet containers\\n  include_role:\\n    name: tripleo_puppet_cache\\n  tags:\\n    - container_config\\n    - container_config_tasks\\n\\n#######################################\\n# Generate config via puppet containers\\n#######################################\\n\\n- name: Include container-puppet tasks (generate config) during step 1\\n  include_tasks: generate-config-tasks.yaml\\n  when: step|int == 1\\n  tags:\\n    - container_config\\n\\n#####################################\\n# Per step starting of the containers\\n#####################################\\n\\n- name: Per step starting of the containers using tripleo-ansible\\n  become: true\\n  environment:\\n    TRIPLEO_MINOR_UPDATE: \'{{ tripleo_minor_update | default(false) }}\'\\n  block:\\n    - name: \\\"Manage containers for step {{ step }} with tripleo-ansible\\\"\\n      include_role:\\n        name: tripleo_container_manage\\n      vars:\\n        tripleo_container_manage_concurrency: 5\\n        tripleo_container_manage_systemd_order: true\\n        tripleo_container_manage_cli: \\\"{{ container_cli }}\\\"\\n        tripleo_container_manage_config: \\\"/var/lib/tripleo-config/container-startup-config/step_{{ step }}\\\"\\n        tripleo_container_manage_config_id: \\\"tripleo_step{{ step }}\\\"\\n        tripleo_container_manage_debug: \\\"{{ enable_debug | bool }}\\\"\\n        tripleo_container_manage_healthcheck_disabled: \\\"{{ container_healthcheck_disabled | bool }}\\\"\\n        tripleo_container_manage_log_path: \\\"{{ container_log_stdout_path }}\\\"\\n        tripleo_container_manage_config_patterns: \'*.json\'\\n        tripleo_container_manage_check_puppet_config: true\\n        tripleo_container_manage_valid_exit_code: [0]\\n      tags:\\n        - container_startup_configs\\n\\n########################################################\\n# Bootstrap tasks - run any tasks that have been defined\\n########################################################\\n\\n- name: \\\"Clean container_puppet_tasks for {{ansible_facts[\'hostname\'] | lower}} step {{step}}\\\"\\n  become: true\\n  file:\\n    path: /var/lib/container-puppet/container-puppet-tasks{{step}}.json\\n    state: absent\\n  tags:\\n    - container_config_tasks\\n\\n- name: Calculate container_puppet_tasks for {{ansible_facts[\'hostname\'] | lower}} step {{step}}\\n  set_fact:\\n    \\\"{{\'host_container_puppet_tasks_\' ~ step}}\\\": \\\"{{lookup(\'vars\', \'host_container_puppet_tasks_\' ~ step, default=[]) | union([item])}}\\\"\\n  loop: \\\"{{container_puppet_tasks.get(\'step_\' ~ step, [])}}\\\"\\n  when: (groups[item.service_name] | default ([]) | map(\'extract\', hostvars, \'inventory_hostname\') | sort | first | lower) == ansible_facts[\'hostname\'] | lower\\n  vars:\\n    container_puppet_tasks: \\\"{{ lookup(\'file\', tripleo_role_name + \'/container_puppet_tasks.yaml\', errors=\'ignore\') | default({}, True) | from_yaml }}\\\"\\n  tags:\\n    - container_config_tasks\\n\\n- name: Include container-puppet tasks for step {{step}}\\n  include_tasks: host-container-puppet-tasks.yaml\\n  when: (\'host_container_puppet_tasks_\' ~ step)  is defined\\n  tags:\\n    - container_config_tasks\\n\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/common-container-config-scripts.yaml\": \"- name: Create fcontext entry for container-config-scripts\\n  community.general.sefcontext:\\n    target: \\\"/var/lib/container-config-scripts(/.*)?\\\"\\n    setype: container_file_t\\n    state: present\\n  tags:\\n    - container_config_scripts\\n\\n- name: Create /var/lib/container-config-scripts\\n  become: true\\n  file:\\n    path: /var/lib/container-config-scripts\\n    state: directory\\n    setype: container_file_t\\n  tags:\\n    - container_config_scripts\\n\\n- name: Write container config scripts\\n  become: true\\n  no_log: True\\n  tripleo_container_config_scripts:\\n    config_data: \\\"{{ lookup(\'file\', tripleo_role_name + \'/container_config_scripts.yaml\', errors=\'ignore\') | default({}, True) | from_yaml }}\\\"\\n    config_dir: /var/lib/container-config-scripts\\n  tags:\\n    - container_config_scripts\\n\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/hiera-steps-tasks.yaml\": \"- name: Hiera config\\n  include_role:\\n    name: tripleo_hieradata\\n- name: Hiera symlink\\n  become: true\\n  file:\\n    src: /etc/puppet/hiera.yaml\\n    dest: /etc/hiera.yaml\\n    state: link\\n    force: true\\n- name: Hieradata from vars\\n  include_role:\\n    name: tripleo_hieradata\\n    tasks_from: hieradata_vars.yaml\\n  vars:\\n    hieradata_templates_list:\\n      - bootstrap_node\\n      - all_nodes\\n      - vip_data\\n      - net_ip_map\\n      - cloud_domain\\n      - fqdn\\n      - service_names\\n      - service_configs\\n      - extraconfig\\n      - role_extraconfig\\n      - ovn_chassis_mac_map\\n- name: Ensure ansible_managed hieradata file exists\\n  include_role:\\n    name: tripleo_hieradata\\n    tasks_from: ansible_hieradata.yml\\n\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/deploy-steps-tasks-step-0.yaml\": \"- name: Deploy step tasks for step 0\\n  delegate_to: localhost\\n  run_once: true\\n  debug:\\n    msg: Use --start-at-task \'Deploy step tasks for step 0\' to resume from this task\\n  when: \\\"tripleo_minor_update is not defined or tripleo_minor_update != \'true\'\\\"\\n- name: Ensure /var/log/journal exists\\n  become: true\\n  file: path=/var/log/journal state=directory mode=0750 owner=root group=root setype=var_log_t\\n- name: Check cloud-init status\\n  shell: systemctl is-active cloud-init.service || systemctl is-enabled cloud-init.service\\n  failed_when: false\\n  become: true\\n  register: cloud_init_enabled\\n- name: Check if cloud-init is disabled via kernel args\\n  shell: cat /proc/cmdline | grep -q cloud-init=disabled\\n  failed_when: false\\n  check_mode: false\\n  register: cloud_init_vendor_disabled\\n- name: Wait for cloud-init to finish, if enabled\\n  community.general.cloud_init_data_facts:\\n    filter: status\\n  register: res\\n  until: >\\n    res.cloud_init_data_facts.status.v1.stage is defined and\\n    not res.cloud_init_data_facts.status.v1.stage\\n  retries: 50\\n  delay: 5\\n  when:\\n    - cloud_init_enabled.rc is defined\\n    - cloud_init_enabled.rc == 0\\n    - cloud_init_vendor_disabled.rc is not defined or cloud_init_vendor_disabled.rc != 0\\n- name: Create /var/lib/container-puppet\\n  become: true\\n  no_log: True\\n  file: path=/var/lib/container-puppet state=directory setype=container_file_t selevel=s0 recurse=true\\n- name: Write container-puppet.sh\\n  become: true\\n  no_log: True\\n  copy: src=container_puppet_script.yaml dest=/var/lib/container-puppet/container-puppet.sh force=yes mode=0755 setype=container_file_t\\n- include_tasks: \\\"{{ _task_file_path }}\\\"\\n  vars:\\n    _task_file_path: \\\"{{ tripleo_role_name }}/deploy_steps_tasks_step0.yaml\\\"\\n  when: \\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\"\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/common-container-setup-tasks.yaml\": \"- name: Create and ensure setype for /var/log/containers directory\\n  become: true\\n  file:\\n    path: /var/log/containers\\n    state: directory\\n    setype: container_file_t\\n    selevel: s0\\n    mode: 0750\\n  tags:\\n    - host_config\\n\\n- name: Create ContainerLogStdoutPath directory\\n  become: true\\n  file:\\n    path: \\\"{{ container_log_stdout_path }}\\\"\\n    state: directory\\n    selevel: s0\\n  tags:\\n    - host_config\\n\\n- name: Create /var/lib/tripleo-config directory\\n  become: true\\n  file:\\n    path: /var/lib/tripleo-config\\n    state: directory\\n    setype: container_file_t\\n    selevel: s0\\n    recurse: true\\n  tags:\\n    - host_config\\n    - container_config\\n    - container_config_tasks\\n    - container_config_scripts\\n    - container_startup_configs\\n\\n# The container config files\\n# /var/lib/container-startup-configs.json is removed as we now write\\n# per-step files instead\\n- name: Clean old /var/lib/container-startup-configs.json file\\n  become: true\\n  file:\\n    path: /var/lib/container-startup-configs.json\\n    state: absent\\n  tags:\\n    - container_startup_configs\\n\\n# For legacy, can be removed in Train cycle\\n- name: Clean old /var/lib/docker-container-startup-configs.json file\\n  become: true\\n  file:\\n    path: /var/lib/docker-container-startup-configs.json\\n    state: absent\\n  tags:\\n    - container_startup_configs\\n\\n- import_tasks: common_container_config_scripts.yaml\\n\\n# This file location is deprecated and the new location is now:\\n# /var/lib/tripleo-config/container-startup-config/step_X/<container_name>.json\\n# Can be removed in V cycle\\n- name: Write /var/lib/tripleo-config/container-startup-config-readme.txt\\n  become: true\\n  no_log: True\\n  copy:\\n    content: \\\"Container startup configs moved to /var/lib/tripleo-config/container-startup-config\\\"\\n    dest: /var/lib/tripleo-config/container-startup-config-readme.txt\\n    force: yes\\n    mode: \'0600\'\\n  tags:\\n    - container_startup_configs\\n\\n- name: Generate startup configs files per step and per container\\n  become: true\\n  container_startup_config:\\n    config_base_dir: /var/lib/tripleo-config/container-startup-config\\n    config_data: \\\"{{ lookup(\'template\', (tripleo_role_name + \'/docker_config.yaml\'), errors=\'ignore\') | default({}, True) | from_yaml }}\\\"\\n  tags:\\n    - container_startup_configs\\n\\n- name: Create /var/lib/kolla/config_files directory\\n  become: true\\n  file:\\n    path: /var/lib/kolla/config_files\\n    state: directory\\n    setype: container_file_t\\n    selevel: s0\\n    recurse: true\\n  tags:\\n    - container_startup_configs\\n\\n- name: Create /var/lib/config-data directory\\n  become: true\\n  file:\\n    path: /var/lib/config-data\\n    mode: 0755\\n    state: directory\\n    setype: container_file_t\\n    selevel: s0\\n\\n- name: Write container config json files\\n  become: true\\n  tripleo_container_configs:\\n    config_data: \\\"{{ lookup(\'file\', tripleo_role_name + \'/kolla_config.yaml\', errors=\'ignore\') | default({}, True) | from_yaml }}\\\"\\n  tags:\\n    - container_startup_configs\\n\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/deploy-steps-tasks-step-1.yaml\": \"- name: Delete existing /var/lib/tripleo-config/check-mode directory for check mode\\n  become: true\\n  file:\\n    path: /var/lib/tripleo-config/check-mode\\n    state: absent\\n  tags:\\n    - host_config\\n    - container_config\\n    - container_config_tasks\\n    - container_config_scripts\\n    - container_startup_configs\\n  when:\\n    - ansible_check_mode|bool\\n  check_mode: no\\n\\n- name: Create /var/lib/tripleo-config/check-mode directory for check mode\\n  become: true\\n  file:\\n    path: /var/lib/tripleo-config/check-mode\\n    state: directory\\n    setype: container_file_t\\n    selevel: s0\\n    recurse: true\\n  tags:\\n    - host_config\\n    - container_config\\n    - container_config_tasks\\n    - container_config_scripts\\n    - container_startup_configs\\n  when:\\n    - ansible_check_mode|bool\\n  check_mode: no\\n\\n# Puppet manifest for baremetal host configuration\\n- name: Write the puppet step_config manifest\\n  become: true\\n  no_log: True\\n  copy:\\n    content: \\\"{{ lookup(\'file\', tripleo_role_name + \'/step_config.pp\', errors=\'ignore\') | default(\'\', True) }}\\\"\\n    dest: /var/lib/tripleo-config/{{ ansible_check_mode | bool | ternary(\'check-mode/\', \'\') }}puppet_step_config.pp\\n    force: yes\\n    mode: \'0600\'\\n  tags:\\n    - host_config\\n  check_mode: no\\n  diff: no\\n\\n- name: Diff puppet step_config manifest changes for check mode\\n  command:\\n    diff -uN /var/lib/tripleo-config/puppet_step_config.pp /var/lib/tripleo-config/check-mode/puppet_step_config.pp\\n  register: diff_results\\n  tags:\\n    - host_config\\n  check_mode: no\\n  when:\\n    - ansible_check_mode|bool\\n    - ansible_diff_mode\\n  failed_when: false\\n  changed_when: diff_results.rc == 1\\n\\n- name: Diff puppet step_config manifest changes for check mode\\n  debug:\\n    var: diff_results.stdout_lines\\n  changed_when: diff_results.rc == 1\\n  when:\\n    - ansible_check_mode|bool\\n    - ansible_diff_mode\\n  tags:\\n    - host_config\\n\\n# Puppet Containers Config directory used to generate container configs\\n- name: Create /var/lib/container-puppet\\n  become: true\\n  file:\\n    path: /var/lib/container-puppet\\n    state: directory\\n    setype: container_file_t\\n    selevel: s0\\n  tags:\\n    - container_config\\n    - container_config_tasks\\n\\n- name: Delete existing /var/lib/container-puppet/check-mode for check mode\\n  become: true\\n  file:\\n    path: /var/lib/container-puppet/check-mode\\n    state: absent\\n  tags:\\n    - container_config\\n  check_mode: no\\n  when:\\n    - ansible_check_mode|bool\\n\\n- name: Create /var/lib/container-puppet/check-mode for check mode\\n  become: true\\n  file:\\n    path: /var/lib/container-puppet/check-mode\\n    state: directory\\n    setype: container_file_t\\n    selevel: s0\\n  tags:\\n    - container_config\\n  check_mode: no\\n  when:\\n    - ansible_check_mode|bool\\n\\n- name: Write container-puppet.json file\\n  become: true\\n  no_log: True\\n  copy:\\n    content: \\\"{{ lookup(\'template\', tripleo_role_name + \'/puppet_config.yaml\', errors=\'ignore\') | default([], True) | from_yaml | to_nice_json }}\\\"\\n    dest: /var/lib/container-puppet/{{ ansible_check_mode | bool | ternary(\'check-mode/\', \'\') }}container-puppet.json\\n    force: yes\\n    mode: \'0600\'\\n  tags:\\n    - container_config\\n  check_mode: no\\n  diff: no\\n\\n- name: Diff container-puppet.json changes for check mode\\n  command:\\n    diff -uN /var/lib/container-puppet/container-puppet.json /var/lib/container-puppet/check-mode/container-puppet.json\\n  register: diff_results\\n  tags:\\n    - container_config\\n  check_mode: no\\n  when:\\n    - ansible_check_mode|bool\\n    - ansible_diff_mode\\n  failed_when: false\\n  changed_when: diff_results.rc == 1\\n\\n- name: Diff container-puppet.json changes for check mode\\n  debug:\\n    var: diff_results.stdout_lines\\n  changed_when: diff_results.rc == 1\\n  when:\\n    - ansible_check_mode|bool\\n    - ansible_diff_mode\\n  tags:\\n    - container_config\\n\\n- name: Ensure config hashes are up-to-date for container startup configs\\n  become: true\\n  container_puppet_config:\\n    update_config_hash_only: true\\n  tags:\\n    - container_startup_configs\\n\\n- name: Set host puppet debugging fact string\\n  set_fact:\\n    host_puppet_config_debug: \\\"--debug --verbose\\\"\\n  when:\\n    - enable_puppet | bool\\n    - enable_debug | bool\\n  tags:\\n    - host_config\\n\\n- name: Check for /etc/puppet/check-mode directory for check mode\\n  stat:\\n    path: /etc/puppet/check-mode\\n  register: check_mode_dir\\n  when: ansible_check_mode|bool\\n  tags:\\n    - host_config\\n    - container_config\\n\\n- name: Create /etc/puppet/check-mode/hieradata directory for check mode\\n  become: true\\n  file:\\n    path: /etc/puppet/check-mode/hieradata\\n    state: directory\\n    setype: container_file_t\\n    selevel: s0\\n    recurse: true\\n  check_mode: no\\n  when:\\n    - ansible_check_mode|bool\\n    - not check_mode_dir.stat.exists\\n  tags:\\n    - host_config\\n    - container_config\\n\\n- name: Create puppet check-mode files if they don\'t exist for check mode\\n  become: true\\n  shell: |\\n    cp -a /etc/puppet/hiera.yaml /etc/puppet/check-mode/hiera.yaml\\n    cp -a /etc/puppet/hieradata/* /etc/puppet/check-mode/hieradata/\\n    sed -i \'s/\\\\/etc\\\\/puppet\\\\/hieradata/\\\\/etc\\\\/puppet\\\\/check-mode\\\\/hieradata/\' /etc/puppet/check-mode/hiera.yaml\\n  when:\\n    - ansible_check_mode|bool\\n    - not check_mode_dir.stat.exists\\n  check_mode: no\\n  tags:\\n    - host_config\\n    - container_config\\n\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/container-puppet.sh\": \"#!/bin/bash\\n# Licensed under the Apache License, Version 2.0 (the \\\"License\\\"); you may\\n# not use this file except in compliance with the License. You may obtain\\n# a copy of the License at\\n#\\n#      http://www.apache.org/licenses/LICENSE-2.0\\n#\\n# Unless required by applicable law or agreed to in writing, software\\n# distributed under the License is distributed on an \\\"AS IS\\\" BASIS, WITHOUT\\n# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the\\n# License for the specific language governing permissions and limitations\\n# under the License.\\n\\nset -e\\n[ \\\"$DEBUG\\\" = \\\"false\\\" ] || set -x\\nrm -rf /etc/puppet\\nmkdir -p /etc/puppet\\ncp -dR /tmp/puppet-etc/* /etc/puppet\\nrm -Rf /etc/puppet/ssl # not in use and causes permission errors\\necho \\\"{\\\\\\\"step\\\\\\\": $STEP}\\\" > /etc/puppet/hieradata/docker_puppet.json\\nTAGS=\\\"\\\"\\nif [ -n \\\"$PUPPET_TAGS\\\" ]; then\\n    TAGS=\\\"--tags \\\\\\\"$PUPPET_TAGS\\\\\\\"\\\"\\nfi\\n\\nif [ ! -z ${STEP_CONFIG+x} ]; then\\n    echo -e \\\"${STEP_CONFIG}\\\" | tee /etc/config.pp\\nfi\\n\\nCHECK_MODE=\\\"\\\"\\nif [ -d \\\"/tmp/puppet-check-mode\\\" ]; then\\n    mkdir -p /etc/puppet/check-mode\\n    cp -a /tmp/puppet-check-mode/* /etc/puppet/check-mode\\n    CHECK_MODE=\\\"--hiera_config /etc/puppet/check-mode/hiera.yaml\\\"\\nfi\\n\\n# Create a reference timestamp to easily find all files touched by\\n# puppet. The sync ensures we get all the files we want due to\\n# different timestamp.\\nconf_data_path=\\\"/var/lib/config-data/${NAME}\\\"\\norigin_of_time=\\\"${conf_data_path}.origin_of_time\\\"\\ntouch $origin_of_time\\nsync\\n\\nexport NET_HOST=\\\"${NET_HOST:-false}\\\"\\nset +e\\nif [ \\\"$NET_HOST\\\" == \\\"false\\\" ]; then\\n    export FACTER_hostname=$HOSTNAME\\nfi\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nexport FACTER_uuid=$(cat /sys/class/dmi/id/product_uuid | tr \'[:upper:]\' \'[:lower:]\')\\necho \'Running puppet\'\\n# FIXME(bogdando): stdout may be falling behind of the logged syslog messages\\nset -x\\n/usr/bin/puppet apply --summarize \\\\\\n                      --detailed-exitcodes \\\\\\n                      --color=false \\\\\\n                      --modulepath=/etc/puppet/modules:/usr/share/openstack-puppet/modules \\\\\\n                      $TAGS \\\\\\n                      $CHECK_MODE \\\\\\n                      /etc/config.pp \\\\\\n                      2>&1 | logger -s -t puppet-user\\nrc=${PIPESTATUS[0]}\\n[ \\\"$DEBUG\\\" = \\\"false\\\" ] && set +x\\nset -e\\nif [ $rc -ne 2 -a $rc -ne 0 ]; then\\n    exit $rc\\nfi\\n\\nverbosity=\\\"\\\"\\n[ \\\"$DEBUG\\\" = \\\"false\\\" ] || verbosity=\\\"-v\\\"\\n\\n# Disables archiving\\nif [ -z \\\"$NO_ARCHIVE\\\" ]; then\\n    archivedirs=(\\\"/etc\\\" \\\"/root\\\" \\\"/opt\\\" \\\"/var/www\\\" \\\"/var/spool/cron\\\" \\\"/var/lib/nova/.ssh\\\")\\n    rsync_srcs=\\\"\\\"\\n    for d in \\\"${archivedirs[@]}\\\"; do\\n        if [ -d \\\"$d\\\" ]; then\\n            rsync_srcs+=\\\" $d\\\"\\n        fi\\n    done\\n    # On stack update, if a password was changed in a config file,\\n    # some services (e.g. mysql) must change their internal state\\n    # (e.g. password in mysql DB) when tripleo_container_manage restarts them;\\n    # and they need the old password to achieve that.\\n    # For those services, we update the config hash to notify\\n    # tripleo_container_manage that a restart is needed, but we do not update\\n    # the password file in container-puppet if the file already existed\\n    # before and let the service regenerate it instead.\\n    password_files=\\\"/root/.my.cnf\\\"\\n\\n    exclude_files=\\\"\\\"\\n    for p in $password_files; do\\n        if [ -f \\\"$p\\\" -a -f \\\"${conf_data_path}$p\\\" ]; then\\n            exclude_files+=\\\" --exclude=$p\\\"\\n        fi\\n    done\\n\\n    # Exclude read-only mounted directories/files which we do not want\\n    # to copy or delete.\\n    ro_files=\\\"/etc/puppet/ /etc/puppetlabs/ /opt/puppetlabs/ /etc/pki/ca-trust/extracted \\\"\\n    ro_files+=\\\"/etc/pki/ca-trust/source/anchors /etc/pki/tls/certs/ca-bundle.crt \\\"\\n    ro_files+=\\\"/etc/pki/tls/certs/ca-bundle.trust.crt /etc/pki/tls/cert.pem \\\"\\n    ro_files+=\\\"/etc/hosts /etc/localtime /etc/hostname \\\"\\n    # /etc/openldap is bind mounted with \\\"ro\\\" option in keystone containers.\\n    ro_files+=\\\"/etc/openldap\\\"\\n    for ro in $ro_files; do\\n        if [ -e \\\"$ro\\\" ]; then\\n            exclude_files+=\\\" --exclude=$ro\\\"\\n        fi\\n    done\\n\\n    echo \\\"Evaluating config files to be removed for the $NAME configuration\\\"\\n    TMPFILE=$(mktemp /tmp/tmp.XXXXXXXXXX)\\n    TMPFILE2=$(mktemp /tmp/tmp.XXXXXXXXXX)\\n    trap \'rm -rf $TMPFILE $TMPFILE2\' EXIT INT HUP\\n    rsync -av -R --dry-run --delete-after $exclude_files $rsync_srcs ${conf_data_path} |\\\\\\n        awk \'/^deleting/ {print $2}\' > $TMPFILE\\n\\n    echo \\\"Rsyncing config files from ${rsync_srcs} into ${conf_data_path}\\\"\\n    rsync -a $verbosity -R --delay-updates --delete-after $exclude_files $rsync_srcs ${conf_data_path}\\n\\n    # Also make a copy of files modified during puppet run\\n    echo \\\"Gathering files modified after $(stat -c \'%y\' $origin_of_time)\\\"\\n\\n    # Purge obsoleted contents to maintain a fresh and filtered mirror\\n    puppet_generated_path=/var/lib/config-data/puppet-generated/${NAME}\\n    mkdir -p ${puppet_generated_path}\\n    echo \\\"Ensuring the removed config files are also purged in ${puppet_generated_path}:\\\"\\n    cat $TMPFILE | sort\\n    cat $TMPFILE | xargs -n1 -r -I{} \\\\\\n        bash -c \\\"rm -rf ${puppet_generated_path}/{}\\\"\\n    exec 5>&1\\n    exec 1>$TMPFILE2\\n    find $rsync_srcs -newer $origin_of_time -not -path \'/etc/puppet*\' -print0\\n    exec 1>&5\\n    echo \\\"Files modified during puppet run:\\\"\\n    cat $TMPFILE2 | xargs -0 printf \\\"%s\\\\n\\\" | sort -h\\n    echo \\\"Rsyncing the modified files into ${puppet_generated_path}\\\"\\n    rsync -a $verbosity -R -0 --delay-updates --delete-after $exclude_files \\\\\\n        --files-from=$TMPFILE2 / ${puppet_generated_path}\\n\\n    # Cleanup any special files that might have been copied into place\\n    # previously because fixes for LP#1860607 did not cleanup and required\\n    # manual intervention if a container hit this. We can safely remove these\\n    # files because they should be bind mounted into containers\\n    for ro in $ro_files; do\\n        if [ -e \\\"${puppet_generated_path}/${ro}\\\" ]; then\\n            rm -rf \\\"${puppet_generated_path}/${ro}\\\"\\n        fi\\n    done\\n\\n    # Write a checksum of the config-data dir, this is used as a\\n    # salt to trigger container restart when the config changes\\n    # note: while being excluded from the output, password files\\n    # are still included in checksum computation\\n    additional_checksum_files=\\\"\\\"\\n    excluded_original_passwords=\\\"\\\"\\n    for p in $password_files; do\\n        if [ -f \\\"$p\\\" ]; then\\n            additional_checksum_files+=\\\" $p\\\"\\n            excluded_original_passwords+=\\\" --exclude=/var/lib/config-data/*${p}\\\"\\n        fi\\n    done\\n    # We need to exclude the swift rings and backups as those change over time\\n    # and containers do not need to restart if they change\\n    EXCLUDE=--exclude=\'*/etc/swift/backups/*\'\\\\ --exclude=\'*/etc/swift/*.ring.gz\'\\\\ --exclude=\'*/etc/swift/*.builder\'\\\\ --exclude=\'*/etc/libvirt/passwd.db\'\\\\ ${excluded_original_passwords}\\n\\n    # We need to repipe the tar command through \'tar xO\' to force text\\n    # output because otherwise the sed command cannot work. The sed is\\n    # needed because puppet puts timestamps as comments in cron and\\n    # parsedfile resources, hence triggering a change at every redeploy\\n    tar -c --mtime=\'1970-01-01\' $EXCLUDE -f - ${conf_data_path} $additional_checksum_files | tar xO | \\\\\\n            sed \'/^#.*HEADER.*/d; s/\\\\#.HEADER.*//g\' | md5sum | awk \'{print $1}\' > ${conf_data_path}.md5sum\\n    tar -c --mtime=\'1970-01-01\' $EXCLUDE -f - ${puppet_generated_path} $additional_checksum_files --mtime=\'1970-01-01\' | tar xO \\\\\\n            | sed \'/^#.*HEADER.*/d; s/\\\\#.HEADER.*//g\' | md5sum | awk \'{print $1}\' > ${puppet_generated_path}.md5sum\\nfi\\n\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/generate-config-tasks.yaml\": \"- name: Block for container-puppet tasks (generate config) during step {{ step }} with tripleo-ansible\\n  become: true\\n  tags:\\n    - container_config\\n  block:\\n    - name: Create base directory puppet configs\\n      file:\\n        path: \\\"/var/lib/tripleo-config/container-puppet-config\\\"\\n        mode: 0700\\n        recurse: true\\n        setype: container_file_t\\n\\n    - name: \\\"Generate container puppet configs for step {{ step }}\\\"\\n      container_puppet_config:\\n        check_mode: \'{{ ansible_check_mode | bool | ternary(1, 0) }}\'\\n        config_vol_prefix: \\\"/var/lib/config-data{{ ansible_check_mode | bool | ternary(\'/check-mode\', \'\') }}\\\"\\n        debug: \\\"{{ docker_puppet_debug | bool }}\\\"\\n        net_host: true\\n        no_archive: false\\n        puppet_config: \\\"/var/lib/container-puppet/{{ ansible_check_mode | bool | ternary(\'check-mode/\', \'\') }}container-puppet.json\\\"\\n        short_hostname: \\\"{{ ansible_facts[\'hostname\'] | lower }}\\\"\\n        step: \\\"{{ step }}\\\"\\n\\n    - name: \\\"Manage Puppet containers (generate config) for step {{ step }} with tripleo-ansible\\\"\\n      include_role:\\n        name: tripleo_container_manage\\n      vars:\\n        tripleo_container_manage_concurrency: \\\"{{ docker_puppet_process_count }}\\\"\\n        tripleo_container_manage_systemd_order: false\\n        tripleo_container_manage_systemd_teardown: false\\n        tripleo_container_manage_config: \\\"/var/lib/tripleo-config/container-puppet-config/step_{{ step }}\\\"\\n        tripleo_container_manage_config_patterns: \'container-puppet-*.json\'\\n        tripleo_container_manage_config_id: \\\"tripleo_puppet_step{{ step }}\\\"\\n        tripleo_container_manage_debug: \\\"{{ docker_puppet_debug | bool }}\\\"\\n        # puppet with --detailed-exitcodes will return 0 for success and\\n        # no changes and 2 for success and resource changes. Other\\n        # numbers are failures\\n        tripleo_container_manage_valid_exit_code: [0, 2]\\n\\n- name: Diff puppet-generated changes for check mode\\n  become: true\\n  shell: |\\n    diff -ruN --no-dereference -q /var/lib/config-data/puppet-generated /var/lib/config-data/check-mode/puppet-generated\\n    diff -ruN --no-dereference /var/lib/config-data/puppet-generated /var/lib/config-data/check-mode/puppet-generated\\n  register: diff_results\\n  tags:\\n    - container_config\\n  check_mode: no\\n  when:\\n    - ansible_check_mode|bool\\n    - ansible_diff_mode\\n  failed_when: false\\n  changed_when: diff_results.rc == 1\\n\\n- name: Diff puppet-generated changes for check mode\\n  debug:\\n    var: diff_results.stdout_lines\\n  changed_when: diff_results.rc == 1\\n  when:\\n    - ansible_check_mode|bool\\n    - ansible_diff_mode\\n  tags:\\n    - container_config\\n\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/host-container-puppet-tasks.yaml\": \"- name: Write container-puppet-tasks json file for {{ansible_facts[\'hostname\'] | lower}} step {{step}}\\n  no_log: True\\n  copy:\\n    content: \\\"{{lookup (\'vars\', \'host_container_puppet_tasks_\' ~ step, default=[]) | to_nice_json}}\\\"\\n    dest: \\\"/var/lib/container-puppet/{{ ansible_check_mode | bool | ternary(\'check-mode/\', \'\') }}container-puppet-tasks{{step}}.json\\\"\\n    force: yes\\n    mode: \'0600\'\\n  check_mode: no\\n  tags:\\n    - container_config_tasks\\n\\n- name: Block for container-puppet tasks (bootstrap tasks) for step {{ step }} with tripleo-ansible\\n  tags:\\n    - container_config_tasks\\n  block:\\n    - name: \\\"Generate container puppet configs for step {{ step }}\\\"\\n      container_puppet_config:\\n        check_mode: \'{{ ansible_check_mode | bool | ternary(1, 0) }}\'\\n        config_vol_prefix: \\\"/var/lib/config-data{{ ansible_check_mode | bool | ternary(\'/check-mode\', \'\') }}\\\"\\n        debug: \\\"{{ docker_puppet_debug | bool }}\\\"\\n        net_host: true\\n        no_archive: true\\n        puppet_config: \\\"/var/lib/container-puppet/{{ ansible_check_mode | bool | ternary(\'check-mode/\', \'\') }}container-puppet-tasks{{ step }}.json\\\"\\n        short_hostname: \\\"{{ ansible_facts[\'hostname\'] | lower }}\\\"\\n        step: \\\"{{ step }}\\\"\\n\\n    - name: \\\"Manage Puppet containers (bootstrap tasks) for step {{ step }} with tripleo-ansible\\\"\\n      include_role:\\n        name: tripleo_container_manage\\n      vars:\\n        tripleo_container_manage_concurrency: \\\"{{ docker_puppet_process_count }}\\\"\\n        tripleo_container_manage_systemd_order: false\\n        tripleo_container_manage_systemd_teardown: false\\n        tripleo_container_manage_config: \\\"/var/lib/tripleo-config/container-puppet-config/step_{{ step }}\\\"\\n        tripleo_container_manage_config_patterns: \'container-puppet-*.json\'\\n        tripleo_container_manage_config_id: \\\"tripleo_puppet_step{{ step }}\\\"\\n        tripleo_container_manage_debug: \\\"{{ docker_puppet_debug | bool }}\\\"\\n        # puppet with --detailed-exitcodes will return 0 for success and\\n        # no changes and 2 for success and resource changes. Other\\n        # numbers are failures\\n        tripleo_container_manage_valid_exit_code: [0, 2]\\n\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Post-deploy configuration steps via puppet for all roles, as defined in ../roles_data.yaml\\\\n\\\", \\\"parameters\\\": {\\\"servers\\\": {\\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"Mapping of Role name e.g Controller to a list of servers\\\"}, \\\"role_data\\\": {\\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"Mapping of Role name e.g Controller to the per-role data\\\"}, \\\"DeployIdentifier\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\\\n\\\"}, \\\"deployment_source_hosts\\\": {\\\"default\\\": \\\"Undercloud\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Host or hostgroup that runs the deployment\\\"}, \\\"deployment_target_hosts\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Host or hostgroup that consists of the target systems for the deployment. Defaults to all hosts in the current Heat stack if not set.\\\\n\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ConfigDebug\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to run config management (e.g. Puppet) in debug mode.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"HideSensitiveLogs\\\": {\\\"default\\\": true, \\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"Set it to false if you don\'t want to activate the no_log feature within ansible modules.\\\\n\\\"}, \\\"EnablePuppet\\\": {\\\"default\\\": true, \\\"description\\\": \\\"Whether to run the puppet (baremetal) deployment tasks.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"EnablePaunch\\\": {\\\"default\\\": false, \\\"description\\\": \\\"(DEPRECATED) Whether to run paunch during container deployment tasks.\\\\n\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"DockerPuppetDebug\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false, \\\"description\\\": \\\"Set to True to enable debug logging with Puppet Containers\\\"}, \\\"DockerPuppetProcessCount\\\": {\\\"type\\\": \\\"number\\\", \\\"default\\\": 6, \\\"description\\\": \\\"Number of concurrent processes to use when running container-puppet to generate config files.\\\"}, \\\"ContainerCli\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"podman\\\", \\\"description\\\": \\\"CLI tool used to manage containers.\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"docker\\\", \\\"podman\\\"]}]}, \\\"DockerPuppetMountHostPuppet\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": true, \\\"description\\\": \\\"Whether containerized puppet executions use modules from the baremetal host. Defaults to true. Can be set to false to consume puppet modules from containers directly.\\\"}, \\\"ContainerLogStdoutPath\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Absolute path for container stdout output (Podman only)\\\", \\\"default\\\": \\\"/var/log/containers/stdouts\\\"}, \\\"ContainerHealthcheckDisabled\\\": {\\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"Whether or not we disable the container healthcheck.\\\", \\\"default\\\": false}, \\\"SELinuxMode\\\": {\\\"default\\\": \\\"enforcing\\\", \\\"description\\\": \\\"Configures SELinux mode\\\", \\\"type\\\": \\\"string\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"enforcing\\\", \\\"permissive\\\", \\\"disabled\\\"]}]}, \\\"ControllerCount\\\": {\\\"description\\\": \\\"Number of Controller nodes to deploy\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 1}, \\\"CellControllerCount\\\": {\\\"description\\\": \\\"Number of CellController nodes to deploy\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 1}, \\\"CellControllerComputeCount\\\": {\\\"description\\\": \\\"Number of CellControllerCompute nodes to deploy\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 1}, \\\"ComputeCount\\\": {\\\"description\\\": \\\"Number of Compute nodes to deploy\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 1}, \\\"BlockStorageCount\\\": {\\\"description\\\": \\\"Number of BlockStorage nodes to deploy\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 0}, \\\"ObjectStorageCount\\\": {\\\"description\\\": \\\"Number of ObjectStorage nodes to deploy\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 0}, \\\"CephStorageCount\\\": {\\\"description\\\": \\\"Number of CephStorage nodes to deploy\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 0}, \\\"NetworkerCount\\\": {\\\"description\\\": \\\"Number of Networker nodes to deploy\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 0}, \\\"ServiceNetMapLower\\\": {\\\"description\\\": \\\"Mapping of service name to network name\\\", \\\"type\\\": \\\"json\\\", \\\"default\\\": {}}, \\\"ValidateControllersIcmp\\\": {\\\"default\\\": true, \\\"description\\\": \\\"Validation to ensure that all controllers can be reached with ICMP\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"ValidateGatewaysIcmp\\\": {\\\"default\\\": true, \\\"description\\\": \\\"Validation to ensure that all gateways can be reached with ICMP\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"ValidateFqdn\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Optional validation to ensure FQDN as set by Nova matches the name set in /etc/hosts.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"PingTestGatewayIPsMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"A map of role name to list of gateway IP addresses for each network, used to ping test each gateway.\\\", \\\"type\\\": \\\"json\\\"}, \\\"PingTestIpsMap\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"A map of role name to a space separated list of IP addresses used to ping test each available network interface.\\\", \\\"type\\\": \\\"json\\\"}, \\\"NetworkSafeDefaults\\\": {\\\"default\\\": true, \\\"description\\\": \\\"Allow to enable/disable safe networking defaults if os-net-config would fail to run with the provided config.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"DeployArtifactURLs\\\": {\\\"default\\\": [], \\\"description\\\": \\\"A list of HTTP URLs containing deployment artifacts to be pulled. Currently supports tarballs and RPM packages.\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"DeployArtifactFILEs\\\": {\\\"default\\\": [], \\\"description\\\": \\\"A list of files containing deployment artifacts to be pushed. Currently supports tarballs and RPM packages.\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"HostsEntry\\\": {\\\"default\\\": [], \\\"type\\\": \\\"comma_delimited_list\\\", \\\"description\\\": \\\"A list of entries to be added to /etc/hosts on each node.\\\"}, \\\"AnsibleHostVarsMap\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {}}, \\\"EnabledServices\\\": {\\\"default\\\": [], \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"ControlVirtualIP\\\": {\\\"type\\\": \\\"string\\\"}, \\\"EnabledNetworks\\\": {\\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"NetVipMap\\\": {\\\"type\\\": \\\"json\\\"}, \\\"StorageNetName\\\": {\\\"default\\\": \\\"storage\\\", \\\"description\\\": \\\"The name of the storage network.\\\", \\\"type\\\": \\\"string\\\"}, \\\"StorageMgmtNetName\\\": {\\\"default\\\": \\\"storage_mgmt\\\", \\\"description\\\": \\\"The name of the storage_mgmt network.\\\", \\\"type\\\": \\\"string\\\"}, \\\"InternalApiNetName\\\": {\\\"default\\\": \\\"internal_api\\\", \\\"description\\\": \\\"The name of the internal_api network.\\\", \\\"type\\\": \\\"string\\\"}, \\\"TenantNetName\\\": {\\\"default\\\": \\\"tenant\\\", \\\"description\\\": \\\"The name of the tenant network.\\\", \\\"type\\\": \\\"string\\\"}, \\\"ExternalNetName\\\": {\\\"default\\\": \\\"external\\\", \\\"description\\\": \\\"The name of the external network.\\\", \\\"type\\\": \\\"string\\\"}, \\\"CloudNames\\\": {\\\"type\\\": \\\"json\\\"}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"CloudDomain\\\": {\\\"default\\\": \\\"localdomain\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"The DNS domain used for the hosts. This must match the overcloud_domain_name configured on the undercloud.\\\\n\\\"}, \\\"NovaAdditionalCell\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether this is an cell additional to the default cell.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"AllNodesExtraMapData\\\": {\\\"default\\\": {}, \\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"Map of extra data (hieradata) to set on each node.\\\"}, \\\"UndercloudHostsEntries\\\": {\\\"default\\\": [], \\\"description\\\": \\\"List of undercloud hosts entries to be appended to /etc/hosts. The value is populated with the HEAT_HOSTS entries on the undercloud by tripleoclient when running deploy.\\\\n\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"ExtraHostsEntries\\\": {\\\"default\\\": [], \\\"description\\\": \\\"List of extra hosts entries to be appended to /etc/hosts\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"VipHostsEntries\\\": {\\\"default\\\": [], \\\"description\\\": \\\"List of VIP (virtual IP) hosts entries to be appended to /etc/hosts\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"KeystoneResourcesConfigs\\\": {\\\"description\\\": \\\"The keystone resources config.\\\", \\\"type\\\": \\\"json\\\", \\\"default\\\": {}}, \\\"RootStackName\\\": {\\\"description\\\": \\\"The name of the stack/plan.\\\", \\\"type\\\": \\\"string\\\"}, \\\"NetCidrMap\\\": {\\\"description\\\": \\\"Mapping of CIDRs to network name\\\", \\\"type\\\": \\\"json\\\", \\\"default\\\": {}}}, \\\"parameter_groups\\\": [{\\\"label\\\": \\\"deprecated\\\", \\\"description\\\": \\\"The following parameters are deprecated and will be removed. They should not\\\\nbe relied on for new deployments. If you have concerns regarding deprecated\\\\nparameters, please contact the TripleO development team on IRC or the\\\\nOpenStack mailing list.\\\\n\\\", \\\"parameters\\\": [\\\"EnablePaunch\\\", \\\"ServiceNetMapLower\\\"]}], \\\"conditions\\\": {\\\"ControllerNonZero\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"ControllerCount\\\"}, 0]}}, \\\"CellControllerNonZero\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"CellControllerCount\\\"}, 0]}}, \\\"CellControllerComputeNonZero\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"CellControllerComputeCount\\\"}, 0]}}, \\\"ComputeNonZero\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"ComputeCount\\\"}, 0]}}, \\\"BlockStorageNonZero\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"BlockStorageCount\\\"}, 0]}}, \\\"ObjectStorageNonZero\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"ObjectStorageCount\\\"}, 0]}}, \\\"CephStorageNonZero\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"CephStorageCount\\\"}, 0]}}, \\\"NetworkerNonZero\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"NetworkerCount\\\"}, 0]}}}, \\\"resources\\\": {\\\"PreDeployStepTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"list_concat_unique\\\": [{\\\"if\\\": [\\\"ControllerNonZero\\\", {\\\"get_param\\\": [\\\"role_data\\\", \\\"Controller\\\", \\\"pre_deploy_step_tasks\\\"]}, []]}, {\\\"if\\\": [\\\"CellControllerNonZero\\\", {\\\"get_param\\\": [\\\"role_data\\\", \\\"CellController\\\", \\\"pre_deploy_step_tasks\\\"]}, []]}, {\\\"if\\\": [\\\"CellControllerComputeNonZero\\\", {\\\"get_param\\\": [\\\"role_data\\\", \\\"CellControllerCompute\\\", \\\"pre_deploy_step_tasks\\\"]}, []]}, {\\\"if\\\": [\\\"ComputeNonZero\\\", {\\\"get_param\\\": [\\\"role_data\\\", \\\"Compute\\\", \\\"pre_deploy_step_tasks\\\"]}, []]}, {\\\"if\\\": [\\\"BlockStorageNonZero\\\", {\\\"get_param\\\": [\\\"role_data\\\", \\\"BlockStorage\\\", \\\"pre_deploy_step_tasks\\\"]}, []]}, {\\\"if\\\": [\\\"ObjectStorageNonZero\\\", {\\\"get_param\\\": [\\\"role_data\\\", \\\"ObjectStorage\\\", \\\"pre_deploy_step_tasks\\\"]}, []]}, {\\\"if\\\": [\\\"CephStorageNonZero\\\", {\\\"get_param\\\": [\\\"role_data\\\", \\\"CephStorage\\\", \\\"pre_deploy_step_tasks\\\"]}, []]}, {\\\"if\\\": [\\\"NetworkerNonZero\\\", {\\\"get_param\\\": [\\\"role_data\\\", \\\"Networker\\\", \\\"pre_deploy_step_tasks\\\"]}, []]}]}}}, \\\"ExternalDeployTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"list_concat_unique\\\": [{\\\"if\\\": [\\\"ControllerNonZero\\\", {\\\"get_param\\\": [\\\"role_data\\\", \\\"Controller\\\", \\\"external_deploy_tasks\\\"]}, []]}, {\\\"if\\\": [\\\"CellControllerNonZero\\\", {\\\"get_param\\\": [\\\"role_data\\\", \\\"CellController\\\", \\\"external_deploy_tasks\\\"]}, []]}, {\\\"if\\\": [\\\"CellControllerComputeNonZero\\\", {\\\"get_param\\\": [\\\"role_data\\\", \\\"CellControllerCompute\\\", \\\"external_deploy_tasks\\\"]}, []]}, {\\\"if\\\": [\\\"ComputeNonZero\\\", {\\\"get_param\\\": [\\\"role_data\\\", \\\"Compute\\\", \\\"external_deploy_tasks\\\"]}, []]}, {\\\"if\\\": [\\\"BlockStorageNonZero\\\", {\\\"get_param\\\": [\\\"role_data\\\", \\\"BlockStorage\\\", \\\"external_deploy_tasks\\\"]}, []]}, {\\\"if\\\": [\\\"ObjectStorageNonZero\\\", {\\\"get_param\\\": [\\\"role_data\\\", \\\"ObjectStorage\\\", \\\"external_deploy_tasks\\\"]}, []]}, {\\\"if\\\": [\\\"CephStorageNonZero\\\", {\\\"get_param\\\": [\\\"role_data\\\", \\\"CephStorage\\\", \\\"external_deploy_tasks\\\"]}, []]}, {\\\"if\\\": [\\\"NetworkerNonZero\\\", {\\\"get_param\\\": [\\\"role_data\\\", \\\"Networker\\\", \\\"external_deploy_tasks\\\"]}, []]}]}}}, \\\"ExternalPostDeployTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"list_concat_unique\\\": [{\\\"if\\\": [\\\"ControllerNonZero\\\", {\\\"get_param\\\": [\\\"role_data\\\", \\\"Controller\\\", \\\"external_post_deploy_tasks\\\"]}, []]}, {\\\"if\\\": [\\\"CellControllerNonZero\\\", {\\\"get_param\\\": [\\\"role_data\\\", \\\"CellController\\\", \\\"external_post_deploy_tasks\\\"]}, []]}, {\\\"if\\\": [\\\"CellControllerComputeNonZero\\\", {\\\"get_param\\\": [\\\"role_data\\\", \\\"CellControllerCompute\\\", \\\"external_post_deploy_tasks\\\"]}, []]}, {\\\"if\\\": [\\\"ComputeNonZero\\\", {\\\"get_param\\\": [\\\"role_data\\\", \\\"Compute\\\", \\\"external_post_deploy_tasks\\\"]}, []]}, {\\\"if\\\": [\\\"BlockStorageNonZero\\\", {\\\"get_param\\\": [\\\"role_data\\\", \\\"BlockStorage\\\", \\\"external_post_deploy_tasks\\\"]}, []]}, {\\\"if\\\": [\\\"ObjectStorageNonZero\\\", {\\\"get_param\\\": [\\\"role_data\\\", \\\"ObjectStorage\\\", \\\"external_post_deploy_tasks\\\"]}, []]}, {\\\"if\\\": [\\\"CephStorageNonZero\\\", {\\\"get_param\\\": [\\\"role_data\\\", \\\"CephStorage\\\", \\\"external_post_deploy_tasks\\\"]}, []]}, {\\\"if\\\": [\\\"NetworkerNonZero\\\", {\\\"get_param\\\": [\\\"role_data\\\", \\\"Networker\\\", \\\"external_post_deploy_tasks\\\"]}, []]}]}}}, \\\"ScaleTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"list_concat_unique\\\": [{\\\"get_param\\\": [\\\"role_data\\\", \\\"Controller\\\", \\\"scale_tasks\\\"]}, {\\\"get_param\\\": [\\\"role_data\\\", \\\"CellController\\\", \\\"scale_tasks\\\"]}, {\\\"get_param\\\": [\\\"role_data\\\", \\\"CellControllerCompute\\\", \\\"scale_tasks\\\"]}, {\\\"get_param\\\": [\\\"role_data\\\", \\\"Compute\\\", \\\"scale_tasks\\\"]}, {\\\"get_param\\\": [\\\"role_data\\\", \\\"BlockStorage\\\", \\\"scale_tasks\\\"]}, {\\\"get_param\\\": [\\\"role_data\\\", \\\"ObjectStorage\\\", \\\"scale_tasks\\\"]}, {\\\"get_param\\\": [\\\"role_data\\\", \\\"CephStorage\\\", \\\"scale_tasks\\\"]}, {\\\"get_param\\\": [\\\"role_data\\\", \\\"Networker\\\", \\\"scale_tasks\\\"]}]}}}, \\\"ExternalUpdateTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"list_concat_unique\\\": [{\\\"if\\\": [\\\"ControllerNonZero\\\", {\\\"get_param\\\": [\\\"role_data\\\", \\\"Controller\\\", \\\"external_update_tasks\\\"]}, []]}, {\\\"if\\\": [\\\"CellControllerNonZero\\\", {\\\"get_param\\\": [\\\"role_data\\\", \\\"CellController\\\", \\\"external_update_tasks\\\"]}, []]}, {\\\"if\\\": [\\\"CellControllerComputeNonZero\\\", {\\\"get_param\\\": [\\\"role_data\\\", \\\"CellControllerCompute\\\", \\\"external_update_tasks\\\"]}, []]}, {\\\"if\\\": [\\\"ComputeNonZero\\\", {\\\"get_param\\\": [\\\"role_data\\\", \\\"Compute\\\", \\\"external_update_tasks\\\"]}, []]}, {\\\"if\\\": [\\\"BlockStorageNonZero\\\", {\\\"get_param\\\": [\\\"role_data\\\", \\\"BlockStorage\\\", \\\"external_update_tasks\\\"]}, []]}, {\\\"if\\\": [\\\"ObjectStorageNonZero\\\", {\\\"get_param\\\": [\\\"role_data\\\", \\\"ObjectStorage\\\", \\\"external_update_tasks\\\"]}, []]}, {\\\"if\\\": [\\\"CephStorageNonZero\\\", {\\\"get_param\\\": [\\\"role_data\\\", \\\"CephStorage\\\", \\\"external_update_tasks\\\"]}, []]}, {\\\"if\\\": [\\\"NetworkerNonZero\\\", {\\\"get_param\\\": [\\\"role_data\\\", \\\"Networker\\\", \\\"external_update_tasks\\\"]}, []]}]}}}, \\\"ExternalUpgradeTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"list_concat_unique\\\": [{\\\"if\\\": [\\\"ControllerNonZero\\\", {\\\"get_param\\\": [\\\"role_data\\\", \\\"Controller\\\", \\\"external_upgrade_tasks\\\"]}, []]}, {\\\"if\\\": [\\\"CellControllerNonZero\\\", {\\\"get_param\\\": [\\\"role_data\\\", \\\"CellController\\\", \\\"external_upgrade_tasks\\\"]}, []]}, {\\\"if\\\": [\\\"CellControllerComputeNonZero\\\", {\\\"get_param\\\": [\\\"role_data\\\", \\\"CellControllerCompute\\\", \\\"external_upgrade_tasks\\\"]}, []]}, {\\\"if\\\": [\\\"ComputeNonZero\\\", {\\\"get_param\\\": [\\\"role_data\\\", \\\"Compute\\\", \\\"external_upgrade_tasks\\\"]}, []]}, {\\\"if\\\": [\\\"BlockStorageNonZero\\\", {\\\"get_param\\\": [\\\"role_data\\\", \\\"BlockStorage\\\", \\\"external_upgrade_tasks\\\"]}, []]}, {\\\"if\\\": [\\\"ObjectStorageNonZero\\\", {\\\"get_param\\\": [\\\"role_data\\\", \\\"ObjectStorage\\\", \\\"external_upgrade_tasks\\\"]}, []]}, {\\\"if\\\": [\\\"CephStorageNonZero\\\", {\\\"get_param\\\": [\\\"role_data\\\", \\\"CephStorage\\\", \\\"external_upgrade_tasks\\\"]}, []]}, {\\\"if\\\": [\\\"NetworkerNonZero\\\", {\\\"get_param\\\": [\\\"role_data\\\", \\\"Networker\\\", \\\"external_upgrade_tasks\\\"]}, []]}]}}}, \\\"BootstrapServerId\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"switch($.data = {} => \\\\\\\"no_bootstrap_server\\\\\\\", $.data != {} => $.data.items().orderBy($[0]).first()[1])\\\", \\\"data\\\": {\\\"get_param\\\": [\\\"servers\\\", \\\"CellControllerCompute\\\"]}}}}}, \\\"ControllerExtraConfigPost\\\": {\\\"condition\\\": \\\"ControllerNonZero\\\", \\\"type\\\": \\\"OS::TripleO::NodeExtraConfigPost\\\", \\\"properties\\\": {\\\"servers\\\": {\\\"get_param\\\": [\\\"servers\\\", \\\"Controller\\\"]}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}}}, \\\"ControllerPostConfig\\\": {\\\"condition\\\": \\\"ControllerNonZero\\\", \\\"type\\\": \\\"OS::TripleO::Tasks::ControllerPostConfig\\\", \\\"depends_on\\\": [\\\"ControllerExtraConfigPost\\\", \\\"CellControllerExtraConfigPost\\\", \\\"CellControllerComputeExtraConfigPost\\\", \\\"ComputeExtraConfigPost\\\", \\\"BlockStorageExtraConfigPost\\\", \\\"ObjectStorageExtraConfigPost\\\", \\\"CephStorageExtraConfigPost\\\", \\\"NetworkerExtraConfigPost\\\"], \\\"properties\\\": {\\\"servers\\\": {\\\"get_param\\\": \\\"servers\\\"}, \\\"input_values\\\": {\\\"deploy_identifier\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}}}}, \\\"CellControllerExtraConfigPost\\\": {\\\"condition\\\": \\\"CellControllerNonZero\\\", \\\"type\\\": \\\"OS::TripleO::NodeExtraConfigPost\\\", \\\"properties\\\": {\\\"servers\\\": {\\\"get_param\\\": [\\\"servers\\\", \\\"CellController\\\"]}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}}}, \\\"CellControllerPostConfig\\\": {\\\"condition\\\": \\\"CellControllerNonZero\\\", \\\"type\\\": \\\"OS::TripleO::Tasks::CellControllerPostConfig\\\", \\\"depends_on\\\": [\\\"ControllerExtraConfigPost\\\", \\\"CellControllerExtraConfigPost\\\", \\\"CellControllerComputeExtraConfigPost\\\", \\\"ComputeExtraConfigPost\\\", \\\"BlockStorageExtraConfigPost\\\", \\\"ObjectStorageExtraConfigPost\\\", \\\"CephStorageExtraConfigPost\\\", \\\"NetworkerExtraConfigPost\\\"], \\\"properties\\\": {\\\"servers\\\": {\\\"get_param\\\": \\\"servers\\\"}, \\\"input_values\\\": {\\\"deploy_identifier\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}}}}, \\\"CellControllerComputeExtraConfigPost\\\": {\\\"condition\\\": \\\"CellControllerComputeNonZero\\\", \\\"type\\\": \\\"OS::TripleO::NodeExtraConfigPost\\\", \\\"properties\\\": {\\\"servers\\\": {\\\"get_param\\\": [\\\"servers\\\", \\\"CellControllerCompute\\\"]}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}}}, \\\"CellControllerComputePostConfig\\\": {\\\"condition\\\": \\\"CellControllerComputeNonZero\\\", \\\"type\\\": \\\"OS::TripleO::Tasks::CellControllerComputePostConfig\\\", \\\"depends_on\\\": [\\\"ControllerExtraConfigPost\\\", \\\"CellControllerExtraConfigPost\\\", \\\"CellControllerComputeExtraConfigPost\\\", \\\"ComputeExtraConfigPost\\\", \\\"BlockStorageExtraConfigPost\\\", \\\"ObjectStorageExtraConfigPost\\\", \\\"CephStorageExtraConfigPost\\\", \\\"NetworkerExtraConfigPost\\\"], \\\"properties\\\": {\\\"servers\\\": {\\\"get_param\\\": \\\"servers\\\"}, \\\"input_values\\\": {\\\"deploy_identifier\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}}}}, \\\"ComputeExtraConfigPost\\\": {\\\"condition\\\": \\\"ComputeNonZero\\\", \\\"type\\\": \\\"OS::TripleO::NodeExtraConfigPost\\\", \\\"properties\\\": {\\\"servers\\\": {\\\"get_param\\\": [\\\"servers\\\", \\\"Compute\\\"]}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}}}, \\\"ComputePostConfig\\\": {\\\"condition\\\": \\\"ComputeNonZero\\\", \\\"type\\\": \\\"OS::TripleO::Tasks::ComputePostConfig\\\", \\\"depends_on\\\": [\\\"ControllerExtraConfigPost\\\", \\\"CellControllerExtraConfigPost\\\", \\\"CellControllerComputeExtraConfigPost\\\", \\\"ComputeExtraConfigPost\\\", \\\"BlockStorageExtraConfigPost\\\", \\\"ObjectStorageExtraConfigPost\\\", \\\"CephStorageExtraConfigPost\\\", \\\"NetworkerExtraConfigPost\\\"], \\\"properties\\\": {\\\"servers\\\": {\\\"get_param\\\": \\\"servers\\\"}, \\\"input_values\\\": {\\\"deploy_identifier\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}}}}, \\\"BlockStorageExtraConfigPost\\\": {\\\"condition\\\": \\\"BlockStorageNonZero\\\", \\\"type\\\": \\\"OS::TripleO::NodeExtraConfigPost\\\", \\\"properties\\\": {\\\"servers\\\": {\\\"get_param\\\": [\\\"servers\\\", \\\"BlockStorage\\\"]}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}}}, \\\"BlockStoragePostConfig\\\": {\\\"condition\\\": \\\"BlockStorageNonZero\\\", \\\"type\\\": \\\"OS::TripleO::Tasks::BlockStoragePostConfig\\\", \\\"depends_on\\\": [\\\"ControllerExtraConfigPost\\\", \\\"CellControllerExtraConfigPost\\\", \\\"CellControllerComputeExtraConfigPost\\\", \\\"ComputeExtraConfigPost\\\", \\\"BlockStorageExtraConfigPost\\\", \\\"ObjectStorageExtraConfigPost\\\", \\\"CephStorageExtraConfigPost\\\", \\\"NetworkerExtraConfigPost\\\"], \\\"properties\\\": {\\\"servers\\\": {\\\"get_param\\\": \\\"servers\\\"}, \\\"input_values\\\": {\\\"deploy_identifier\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}}}}, \\\"ObjectStorageExtraConfigPost\\\": {\\\"condition\\\": \\\"ObjectStorageNonZero\\\", \\\"type\\\": \\\"OS::TripleO::NodeExtraConfigPost\\\", \\\"properties\\\": {\\\"servers\\\": {\\\"get_param\\\": [\\\"servers\\\", \\\"ObjectStorage\\\"]}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}}}, \\\"ObjectStoragePostConfig\\\": {\\\"condition\\\": \\\"ObjectStorageNonZero\\\", \\\"type\\\": \\\"OS::TripleO::Tasks::ObjectStoragePostConfig\\\", \\\"depends_on\\\": [\\\"ControllerExtraConfigPost\\\", \\\"CellControllerExtraConfigPost\\\", \\\"CellControllerComputeExtraConfigPost\\\", \\\"ComputeExtraConfigPost\\\", \\\"BlockStorageExtraConfigPost\\\", \\\"ObjectStorageExtraConfigPost\\\", \\\"CephStorageExtraConfigPost\\\", \\\"NetworkerExtraConfigPost\\\"], \\\"properties\\\": {\\\"servers\\\": {\\\"get_param\\\": \\\"servers\\\"}, \\\"input_values\\\": {\\\"deploy_identifier\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}}}}, \\\"CephStorageExtraConfigPost\\\": {\\\"condition\\\": \\\"CephStorageNonZero\\\", \\\"type\\\": \\\"OS::TripleO::NodeExtraConfigPost\\\", \\\"properties\\\": {\\\"servers\\\": {\\\"get_param\\\": [\\\"servers\\\", \\\"CephStorage\\\"]}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}}}, \\\"CephStoragePostConfig\\\": {\\\"condition\\\": \\\"CephStorageNonZero\\\", \\\"type\\\": \\\"OS::TripleO::Tasks::CephStoragePostConfig\\\", \\\"depends_on\\\": [\\\"ControllerExtraConfigPost\\\", \\\"CellControllerExtraConfigPost\\\", \\\"CellControllerComputeExtraConfigPost\\\", \\\"ComputeExtraConfigPost\\\", \\\"BlockStorageExtraConfigPost\\\", \\\"ObjectStorageExtraConfigPost\\\", \\\"CephStorageExtraConfigPost\\\", \\\"NetworkerExtraConfigPost\\\"], \\\"properties\\\": {\\\"servers\\\": {\\\"get_param\\\": \\\"servers\\\"}, \\\"input_values\\\": {\\\"deploy_identifier\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}}}}, \\\"NetworkerExtraConfigPost\\\": {\\\"condition\\\": \\\"NetworkerNonZero\\\", \\\"type\\\": \\\"OS::TripleO::NodeExtraConfigPost\\\", \\\"properties\\\": {\\\"servers\\\": {\\\"get_param\\\": [\\\"servers\\\", \\\"Networker\\\"]}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}}}, \\\"NetworkerPostConfig\\\": {\\\"condition\\\": \\\"NetworkerNonZero\\\", \\\"type\\\": \\\"OS::TripleO::Tasks::NetworkerPostConfig\\\", \\\"depends_on\\\": [\\\"ControllerExtraConfigPost\\\", \\\"CellControllerExtraConfigPost\\\", \\\"CellControllerComputeExtraConfigPost\\\", \\\"ComputeExtraConfigPost\\\", \\\"BlockStorageExtraConfigPost\\\", \\\"ObjectStorageExtraConfigPost\\\", \\\"CephStorageExtraConfigPost\\\", \\\"NetworkerExtraConfigPost\\\"], \\\"properties\\\": {\\\"servers\\\": {\\\"get_param\\\": \\\"servers\\\"}, \\\"input_values\\\": {\\\"deploy_identifier\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}}}}}, \\\"outputs\\\": {\\\"RoleConfig\\\": {\\\"description\\\": \\\"Mapping of config data for all roles\\\", \\\"value\\\": {\\\"global_vars\\\": {\\\"deploy_steps_max\\\": 6, \\\"service_net_map\\\": {\\\"get_param\\\": \\\"ServiceNetMapLower\\\"}, \\\"validate_controllers_icmp\\\": {\\\"get_param\\\": \\\"ValidateControllersIcmp\\\"}, \\\"validate_gateways_icmp\\\": {\\\"get_param\\\": \\\"ValidateGatewaysIcmp\\\"}, \\\"validate_fqdn\\\": {\\\"get_param\\\": \\\"ValidateFqdn\\\"}, \\\"ping_test_gateway_ips\\\": {\\\"get_param\\\": \\\"PingTestGatewayIPsMap\\\"}, \\\"ping_test_ips\\\": {\\\"get_param\\\": \\\"PingTestIpsMap\\\"}, \\\"network_safe_defaults\\\": {\\\"get_param\\\": \\\"NetworkSafeDefaults\\\"}, \\\"deploy_artifact_urls\\\": {\\\"get_param\\\": \\\"DeployArtifactURLs\\\"}, \\\"deploy_artifact_files\\\": {\\\"get_param\\\": \\\"DeployArtifactFILEs\\\"}, \\\"hosts_entry\\\": {\\\"get_param\\\": \\\"HostsEntry\\\"}, \\\"primary_role_name\\\": \\\"CellControllerCompute\\\", \\\"deploy_identifier\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}, \\\"container_cli\\\": {\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"enabled_services\\\": {\\\"get_param\\\": \\\"EnabledServices\\\"}, \\\"control_virtual_ip\\\": {\\\"get_param\\\": \\\"ControlVirtualIP\\\"}, \\\"enabled_networks\\\": {\\\"get_param\\\": \\\"EnabledNetworks\\\"}, \\\"net_vip_map\\\": {\\\"get_param\\\": \\\"NetVipMap\\\"}, \\\"nova_additional_cell\\\": {\\\"get_param\\\": \\\"NovaAdditionalCell\\\"}, \\\"hide_sensitive_logs\\\": {\\\"get_param\\\": \\\"HideSensitiveLogs\\\"}, \\\"storage_net_name\\\": {\\\"get_param\\\": \\\"StorageNetName\\\"}, \\\"storage_mgmt_net_name\\\": {\\\"get_param\\\": \\\"StorageMgmtNetName\\\"}, \\\"internal_api_net_name\\\": {\\\"get_param\\\": \\\"InternalApiNetName\\\"}, \\\"tenant_net_name\\\": {\\\"get_param\\\": \\\"TenantNetName\\\"}, \\\"external_net_name\\\": {\\\"get_param\\\": \\\"ExternalNetName\\\"}, \\\"networks\\\": {\\\"Storage\\\": {\\\"name\\\": {\\\"get_param\\\": \\\"StorageNetName\\\"}, \\\"name_lower\\\": \\\"storage\\\"}, \\\"StorageMgmt\\\": {\\\"name\\\": {\\\"get_param\\\": \\\"StorageMgmtNetName\\\"}, \\\"name_lower\\\": \\\"storage_mgmt\\\"}, \\\"InternalApi\\\": {\\\"name\\\": {\\\"get_param\\\": \\\"InternalApiNetName\\\"}, \\\"name_lower\\\": \\\"internal_api\\\"}, \\\"Tenant\\\": {\\\"name\\\": {\\\"get_param\\\": \\\"TenantNetName\\\"}, \\\"name_lower\\\": \\\"tenant\\\"}, \\\"External\\\": {\\\"name\\\": {\\\"get_param\\\": \\\"ExternalNetName\\\"}, \\\"name_lower\\\": \\\"external\\\"}}, \\\"network_virtual_ips\\\": {\\\"ctlplane\\\": {\\\"ip_address\\\": {\\\"get_param\\\": [\\\"NetVipMap\\\", \\\"ctlplane\\\"]}, \\\"index\\\": 1}, \\\"storage\\\": {\\\"ip_address\\\": {\\\"get_param\\\": [\\\"NetVipMap\\\", {\\\"get_param\\\": \\\"StorageNetName\\\"}]}, \\\"index\\\": 2}, \\\"storage_mgmt\\\": {\\\"ip_address\\\": {\\\"get_param\\\": [\\\"NetVipMap\\\", {\\\"get_param\\\": \\\"StorageMgmtNetName\\\"}]}, \\\"index\\\": 3}, \\\"internal_api\\\": {\\\"ip_address\\\": {\\\"get_param\\\": [\\\"NetVipMap\\\", {\\\"get_param\\\": \\\"InternalApiNetName\\\"}]}, \\\"index\\\": 4}, \\\"external\\\": {\\\"ip_address\\\": {\\\"get_param\\\": [\\\"NetVipMap\\\", {\\\"get_param\\\": \\\"ExternalNetName\\\"}]}, \\\"index\\\": 5}}, \\\"cloud_names\\\": {\\\"get_param\\\": \\\"CloudNames\\\"}, \\\"enable_internal_tls\\\": {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, \\\"cloud_domain\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"all_nodes_extra_map_data\\\": {\\\"get_param\\\": \\\"AllNodesExtraMapData\\\"}, \\\"undercloud_hosts_entries\\\": {\\\"get_param\\\": \\\"UndercloudHostsEntries\\\"}, \\\"extra_hosts_entries\\\": {\\\"get_param\\\": \\\"ExtraHostsEntries\\\"}, \\\"vip_hosts_entries\\\": {\\\"get_param\\\": \\\"VipHostsEntries\\\"}, \\\"keystone_resources\\\": {\\\"get_param\\\": \\\"KeystoneResourcesConfigs\\\"}, \\\"net_cidr_map\\\": {\\\"get_param\\\": \\\"NetCidrMap\\\"}}, \\\"common_deploy_steps_playbooks\\\": {\\\"get_file\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/deploy-steps-playbooks-common.yaml\\\"}, \\\"common_deploy_steps_tasks\\\": {\\\"get_file\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/deploy-steps-tasks.yaml\\\"}, \\\"common_container_config_scripts\\\": {\\\"get_file\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/common-container-config-scripts.yaml\\\"}, \\\"hiera_steps_tasks\\\": {\\\"get_file\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/hiera-steps-tasks.yaml\\\"}, \\\"deploy_steps_tasks_step_0\\\": {\\\"get_file\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/deploy-steps-tasks-step-0.yaml\\\"}, \\\"common_container_setup_tasks\\\": {\\\"get_file\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/common-container-setup-tasks.yaml\\\"}, \\\"common_deploy_steps_tasks_step_1\\\": {\\\"get_file\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/deploy-steps-tasks-step-1.yaml\\\"}, \\\"container_puppet_script\\\": {\\\"get_file\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/container-puppet.sh\\\"}, \\\"generate-config-tasks\\\": {\\\"get_file\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/generate-config-tasks.yaml\\\"}, \\\"host-container-puppet-tasks\\\": {\\\"get_file\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/host-container-puppet-tasks.yaml\\\"}, \\\"deploy_steps_0_playbook\\\": {\\\"str_replace\\\": {\\\"params\\\": {\\\"BOOTSTRAP_SERVER_ID\\\": {\\\"get_attr\\\": [\\\"BootstrapServerId\\\", \\\"value\\\"]}, \\\"DEPLOY_SOURCE_HOST\\\": {\\\"get_param\\\": \\\"deployment_source_hosts\\\"}, \\\"DEPLOY_TARGET_HOST\\\": {\\\"if\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"deployment_target_hosts\\\"}, \\\"\\\"]}, {\\\"get_param\\\": \\\"RootStackName\\\"}, {\\\"get_param\\\": \\\"deployment_target_hosts\\\"}]}, \\\"DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}, \\\"ENABLE_DEBUG\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"ENABLE_PUPPET\\\": {\\\"get_param\\\": \\\"EnablePuppet\\\"}, \\\"CONTAINER_CLI\\\": {\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"CONTAINER_LOG_STDOUT_PATH\\\": {\\\"get_param\\\": \\\"ContainerLogStdoutPath\\\"}, \\\"CONTAINER_HEALTHCHECK_DISABLED\\\": {\\\"get_param\\\": \\\"ContainerHealthcheckDisabled\\\"}, \\\"DOCKER_PUPPET_DEBUG\\\": {\\\"get_param\\\": \\\"DockerPuppetDebug\\\"}, \\\"DOCKER_PUPPET_PROCESS_COUNT\\\": {\\\"get_param\\\": \\\"DockerPuppetProcessCount\\\"}, \\\"DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\": {\\\"get_param\\\": \\\"DockerPuppetMountHostPuppet\\\"}, \\\"SELINUX_MODE\\\": {\\\"get_param\\\": \\\"SELinuxMode\\\"}}, \\\"template\\\": \\\"- hosts: DEPLOY_SOURCE_HOST\\\\n  strategy: tripleo_free\\\\n  name: External deployment step 0\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  become: false\\\\n  vars:\\\\n    step: 0\\\\n    enable_debug: ENABLE_DEBUG\\\\n  tasks:\\\\n    - name: External deployment step 0\\\\n      delegate_to: localhost\\\\n      run_once: true\\\\n      debug:\\\\n        msg: Use --start-at-task \'External deployment step 0\' to resume from this task\\\\n    - include_tasks: \\\\\\\"external_deploy_steps_tasks_step0.yaml\\\\\\\"\\\\n      when:\\\\n        - playbook_dir ~ \'/external_deploy_steps_tasks_step0.yaml\' is exists\\\\n  tags:\\\\n    - external\\\\n    - external_deploy_steps\\\\n    - step0\\\\n\\\\n- import_playbook: common_deploy_steps_playbooks.yaml\\\\n  vars:\\\\n    deploy_source_host: \\\\\\\"DEPLOY_SOURCE_HOST\\\\\\\"\\\\n    deploy_target_host: \\\\\\\"DEPLOY_TARGET_HOST\\\\\\\"\\\\n\\\"}}, \\\"deploy_steps_selinux_playbook\\\": {\\\"str_replace\\\": {\\\"params\\\": {\\\"BOOTSTRAP_SERVER_ID\\\": {\\\"get_attr\\\": [\\\"BootstrapServerId\\\", \\\"value\\\"]}, \\\"DEPLOY_SOURCE_HOST\\\": {\\\"get_param\\\": \\\"deployment_source_hosts\\\"}, \\\"DEPLOY_TARGET_HOST\\\": {\\\"if\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"deployment_target_hosts\\\"}, \\\"\\\"]}, {\\\"get_param\\\": \\\"RootStackName\\\"}, {\\\"get_param\\\": \\\"deployment_target_hosts\\\"}]}, \\\"DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}, \\\"ENABLE_DEBUG\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"ENABLE_PUPPET\\\": {\\\"get_param\\\": \\\"EnablePuppet\\\"}, \\\"CONTAINER_CLI\\\": {\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"CONTAINER_LOG_STDOUT_PATH\\\": {\\\"get_param\\\": \\\"ContainerLogStdoutPath\\\"}, \\\"CONTAINER_HEALTHCHECK_DISABLED\\\": {\\\"get_param\\\": \\\"ContainerHealthcheckDisabled\\\"}, \\\"DOCKER_PUPPET_DEBUG\\\": {\\\"get_param\\\": \\\"DockerPuppetDebug\\\"}, \\\"DOCKER_PUPPET_PROCESS_COUNT\\\": {\\\"get_param\\\": \\\"DockerPuppetProcessCount\\\"}, \\\"DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\": {\\\"get_param\\\": \\\"DockerPuppetMountHostPuppet\\\"}, \\\"SELINUX_MODE\\\": {\\\"get_param\\\": \\\"SELinuxMode\\\"}}, \\\"template\\\": \\\"- hosts: DEPLOY_TARGET_HOST\\\\n  strategy: tripleo_linear\\\\n  name: Manage SELinux\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  tasks:\\\\n    - name: Set selinux state\\\\n      become: true\\\\n      selinux:\\\\n        policy: targeted\\\\n        state: SELINUX_MODE\\\\n\\\\n- hosts: all\\\\n  strategy: tripleo_linear\\\\n  name: Generate /etc/hosts\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  tasks:\\\\n\\\\n    - name: Configure Hosts Entries\\\\n      include_role:\\\\n        name: tripleo_hosts_entries\\\\n      vars:\\\\n        tripleo_hosts_entries_undercloud_hosts_entries: \\\\\\\"{{ undercloud_hosts_entries }}\\\\\\\"\\\\n        tripleo_hosts_entries_extra_hosts_entries: \\\\\\\"{{ extra_hosts_entries }}\\\\\\\"\\\\n        tripleo_hosts_entries_vip_hosts_entries: \\\\\\\"{{ vip_hosts_entries }}\\\\\\\"\\\\n\\\"}}, \\\"deploy_steps_common_roles_playbook\\\": {\\\"str_replace\\\": {\\\"params\\\": {\\\"BOOTSTRAP_SERVER_ID\\\": {\\\"get_attr\\\": [\\\"BootstrapServerId\\\", \\\"value\\\"]}, \\\"DEPLOY_SOURCE_HOST\\\": {\\\"get_param\\\": \\\"deployment_source_hosts\\\"}, \\\"DEPLOY_TARGET_HOST\\\": {\\\"if\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"deployment_target_hosts\\\"}, \\\"\\\"]}, {\\\"get_param\\\": \\\"RootStackName\\\"}, {\\\"get_param\\\": \\\"deployment_target_hosts\\\"}]}, \\\"DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}, \\\"ENABLE_DEBUG\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"ENABLE_PUPPET\\\": {\\\"get_param\\\": \\\"EnablePuppet\\\"}, \\\"CONTAINER_CLI\\\": {\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"CONTAINER_LOG_STDOUT_PATH\\\": {\\\"get_param\\\": \\\"ContainerLogStdoutPath\\\"}, \\\"CONTAINER_HEALTHCHECK_DISABLED\\\": {\\\"get_param\\\": \\\"ContainerHealthcheckDisabled\\\"}, \\\"DOCKER_PUPPET_DEBUG\\\": {\\\"get_param\\\": \\\"DockerPuppetDebug\\\"}, \\\"DOCKER_PUPPET_PROCESS_COUNT\\\": {\\\"get_param\\\": \\\"DockerPuppetProcessCount\\\"}, \\\"DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\": {\\\"get_param\\\": \\\"DockerPuppetMountHostPuppet\\\"}, \\\"SELINUX_MODE\\\": {\\\"get_param\\\": \\\"SELinuxMode\\\"}}, \\\"template\\\": \\\"- hosts: DEPLOY_TARGET_HOST\\\\n  strategy: tripleo_linear\\\\n  name: Common roles for TripleO servers\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  # pre_tasks run before any roles in a play, so we use it for the\\\\n  # named debug task for --start-at-task.\\\\n  pre_tasks:\\\\n    - name: Common roles for TripleO servers\\\\n      delegate_to: localhost\\\\n      run_once: true\\\\n      debug:\\\\n        msg: Use --start-at-task \'Common roles for TripleO servers\' to resume from this task\\\\n  tasks:\\\\n    - include_role:\\\\n        name: tripleo_bootstrap\\\\n    - include_role:\\\\n        name: tripleo_ssh_known_hosts\\\\n  tags:\\\\n    - common_roles\\\\n\\\"}}, \\\"deploy_steps_0_tasks_playbook\\\": {\\\"str_replace\\\": {\\\"params\\\": {\\\"BOOTSTRAP_SERVER_ID\\\": {\\\"get_attr\\\": [\\\"BootstrapServerId\\\", \\\"value\\\"]}, \\\"DEPLOY_SOURCE_HOST\\\": {\\\"get_param\\\": \\\"deployment_source_hosts\\\"}, \\\"DEPLOY_TARGET_HOST\\\": {\\\"if\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"deployment_target_hosts\\\"}, \\\"\\\"]}, {\\\"get_param\\\": \\\"RootStackName\\\"}, {\\\"get_param\\\": \\\"deployment_target_hosts\\\"}]}, \\\"DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}, \\\"ENABLE_DEBUG\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"ENABLE_PUPPET\\\": {\\\"get_param\\\": \\\"EnablePuppet\\\"}, \\\"CONTAINER_CLI\\\": {\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"CONTAINER_LOG_STDOUT_PATH\\\": {\\\"get_param\\\": \\\"ContainerLogStdoutPath\\\"}, \\\"CONTAINER_HEALTHCHECK_DISABLED\\\": {\\\"get_param\\\": \\\"ContainerHealthcheckDisabled\\\"}, \\\"DOCKER_PUPPET_DEBUG\\\": {\\\"get_param\\\": \\\"DockerPuppetDebug\\\"}, \\\"DOCKER_PUPPET_PROCESS_COUNT\\\": {\\\"get_param\\\": \\\"DockerPuppetProcessCount\\\"}, \\\"DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\": {\\\"get_param\\\": \\\"DockerPuppetMountHostPuppet\\\"}, \\\"SELINUX_MODE\\\": {\\\"get_param\\\": \\\"SELinuxMode\\\"}}, \\\"template\\\": \\\"- hosts: CellControllerCompute:DEPLOY_TARGET_HOST\\\\n  strategy: tripleo_free\\\\n  name: Deploy step tasks for step 0\\\\n  become: true\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  vars:\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    step: 0\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    enable_puppet: ENABLE_PUPPET\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n  tasks:\\\\n    - import_tasks: deploy_steps_tasks_step_0.yaml\\\\n  tags:\\\\n    - overcloud\\\\n    - deploy_steps\\\\n    - step0\\\\n\\\"}}, \\\"deploy_steps_pre_network_playbook\\\": {\\\"str_replace\\\": {\\\"params\\\": {\\\"BOOTSTRAP_SERVER_ID\\\": {\\\"get_attr\\\": [\\\"BootstrapServerId\\\", \\\"value\\\"]}, \\\"DEPLOY_SOURCE_HOST\\\": {\\\"get_param\\\": \\\"deployment_source_hosts\\\"}, \\\"DEPLOY_TARGET_HOST\\\": {\\\"if\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"deployment_target_hosts\\\"}, \\\"\\\"]}, {\\\"get_param\\\": \\\"RootStackName\\\"}, {\\\"get_param\\\": \\\"deployment_target_hosts\\\"}]}, \\\"DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}, \\\"ENABLE_DEBUG\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"ENABLE_PUPPET\\\": {\\\"get_param\\\": \\\"EnablePuppet\\\"}, \\\"CONTAINER_CLI\\\": {\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"CONTAINER_LOG_STDOUT_PATH\\\": {\\\"get_param\\\": \\\"ContainerLogStdoutPath\\\"}, \\\"CONTAINER_HEALTHCHECK_DISABLED\\\": {\\\"get_param\\\": \\\"ContainerHealthcheckDisabled\\\"}, \\\"DOCKER_PUPPET_DEBUG\\\": {\\\"get_param\\\": \\\"DockerPuppetDebug\\\"}, \\\"DOCKER_PUPPET_PROCESS_COUNT\\\": {\\\"get_param\\\": \\\"DockerPuppetProcessCount\\\"}, \\\"DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\": {\\\"get_param\\\": \\\"DockerPuppetMountHostPuppet\\\"}, \\\"SELINUX_MODE\\\": {\\\"get_param\\\": \\\"SELinuxMode\\\"}}, \\\"template\\\": \\\"- hosts: CellControllerCompute:DEPLOY_TARGET_HOST\\\\n  strategy: tripleo_free\\\\n  name: Server pre network steps\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  vars:\\\\n    deploy_source_host: \\\\\\\"DEPLOY_SOURCE_HOST\\\\\\\"\\\\n  tasks:\\\\n\\\\n    - name: Server pre-network deployments\\\\n      delegate_to: localhost\\\\n      run_once: true\\\\n      debug:\\\\n        msg: Use --start-at-task \'Server pre-network deployments\' to resume from this task\\\\n    - import_tasks: hiera_steps_tasks.yaml\\\\n    - include_tasks: deployments.yaml\\\\n      vars:\\\\n        force: false\\\\n      with_items: \\\\\\\"{{ hostvars[inventory_hostname][\'pre_network_\' ~ tripleo_role_name]|default([]) }}\\\\\\\"\\\\n\\\\n  tags:\\\\n    - overcloud\\\\n    - pre_deploy_steps\\\\n\\\"}}, \\\"deploy_steps_network_deployments_playbook\\\": {\\\"str_replace\\\": {\\\"params\\\": {\\\"BOOTSTRAP_SERVER_ID\\\": {\\\"get_attr\\\": [\\\"BootstrapServerId\\\", \\\"value\\\"]}, \\\"DEPLOY_SOURCE_HOST\\\": {\\\"get_param\\\": \\\"deployment_source_hosts\\\"}, \\\"DEPLOY_TARGET_HOST\\\": {\\\"if\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"deployment_target_hosts\\\"}, \\\"\\\"]}, {\\\"get_param\\\": \\\"RootStackName\\\"}, {\\\"get_param\\\": \\\"deployment_target_hosts\\\"}]}, \\\"DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}, \\\"ENABLE_DEBUG\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"ENABLE_PUPPET\\\": {\\\"get_param\\\": \\\"EnablePuppet\\\"}, \\\"CONTAINER_CLI\\\": {\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"CONTAINER_LOG_STDOUT_PATH\\\": {\\\"get_param\\\": \\\"ContainerLogStdoutPath\\\"}, \\\"CONTAINER_HEALTHCHECK_DISABLED\\\": {\\\"get_param\\\": \\\"ContainerHealthcheckDisabled\\\"}, \\\"DOCKER_PUPPET_DEBUG\\\": {\\\"get_param\\\": \\\"DockerPuppetDebug\\\"}, \\\"DOCKER_PUPPET_PROCESS_COUNT\\\": {\\\"get_param\\\": \\\"DockerPuppetProcessCount\\\"}, \\\"DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\": {\\\"get_param\\\": \\\"DockerPuppetMountHostPuppet\\\"}, \\\"SELINUX_MODE\\\": {\\\"get_param\\\": \\\"SELinuxMode\\\"}}, \\\"template\\\": \\\"- hosts: CellControllerCompute:DEPLOY_TARGET_HOST\\\\n  strategy: tripleo_free\\\\n  name: Server network deployments\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  tasks:\\\\n\\\\n    - name: Network Configuration\\\\n      delegate_to: localhost\\\\n      run_once: true\\\\n      debug:\\\\n        msg: Use --start-at-task \'Network Configuration\' to resume from this task\\\\n    - name: Check NetworkConfig script existence\\\\n      delegate_to: localhost\\\\n      stat:\\\\n        path: \\\\\\\"{{ tripleo_role_name ~ \'/NetworkConfig\' }}\\\\\\\"\\\\n      register: NetworkConfig_stat\\\\n      when: not tripleo_network_config_with_ansible\\\\n    - name: Run Network Config\\\\n      import_role:\\\\n        name: tripleo_network_config\\\\n      vars:\\\\n        tripleo_network_config_script_path: \\\\\\\"{{ NetworkConfig_stat.stat.path }}\\\\\\\"\\\\n        tripleo_network_config_update: \\\\\\\"{{ network_config_update }}\\\\\\\"\\\\n        tripleo_network_config_nmstate: \\\\\\\"{{ use_nmstate }}\\\\\\\"\\\\n        tripleo_network_config_purge: \\\\\\\"{{ ifcfg_purge }}\\\\\\\"\\\\n        tripleo_network_config_async_timeout: \\\\\\\"{{ async_timeout | default(300) }}\\\\\\\"\\\\n        tripleo_network_config_async_poll: \\\\\\\"{{ async_poll | default(3) }}\\\\\\\"\\\\n        tripleo_network_config_hide_sensitive_logs: false\\\\n        tripleo_network_config_legacy_script: false\\\\n        tripleo_network_config_safe_defaults: \\\\\\\"{{ network_safe_defaults }}|bool\\\\\\\"\\\\n      when:\\\\n        - tripleo_network_config_with_ansible or NetworkConfig_stat.stat.exists\\\\n  tags:\\\\n    - overcloud\\\\n    - pre_deploy_steps\\\\n    - network_deploy_steps\\\\n\\\"}}, \\\"deploy_steps_network_validation_playbook\\\": {\\\"str_replace\\\": {\\\"params\\\": {\\\"BOOTSTRAP_SERVER_ID\\\": {\\\"get_attr\\\": [\\\"BootstrapServerId\\\", \\\"value\\\"]}, \\\"DEPLOY_SOURCE_HOST\\\": {\\\"get_param\\\": \\\"deployment_source_hosts\\\"}, \\\"DEPLOY_TARGET_HOST\\\": {\\\"if\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"deployment_target_hosts\\\"}, \\\"\\\"]}, {\\\"get_param\\\": \\\"RootStackName\\\"}, {\\\"get_param\\\": \\\"deployment_target_hosts\\\"}]}, \\\"DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}, \\\"ENABLE_DEBUG\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"ENABLE_PUPPET\\\": {\\\"get_param\\\": \\\"EnablePuppet\\\"}, \\\"CONTAINER_CLI\\\": {\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"CONTAINER_LOG_STDOUT_PATH\\\": {\\\"get_param\\\": \\\"ContainerLogStdoutPath\\\"}, \\\"CONTAINER_HEALTHCHECK_DISABLED\\\": {\\\"get_param\\\": \\\"ContainerHealthcheckDisabled\\\"}, \\\"DOCKER_PUPPET_DEBUG\\\": {\\\"get_param\\\": \\\"DockerPuppetDebug\\\"}, \\\"DOCKER_PUPPET_PROCESS_COUNT\\\": {\\\"get_param\\\": \\\"DockerPuppetProcessCount\\\"}, \\\"DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\": {\\\"get_param\\\": \\\"DockerPuppetMountHostPuppet\\\"}, \\\"SELINUX_MODE\\\": {\\\"get_param\\\": \\\"SELinuxMode\\\"}}, \\\"template\\\": \\\"- hosts: CellControllerCompute:DEPLOY_TARGET_HOST\\\\n  strategy: tripleo_free\\\\n  name: Server network validation\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  tasks:\\\\n\\\\n    - name: Basic Network Validation\\\\n      include_role:\\\\n        name: tripleo_nodes_validation\\\\n      vars:\\\\n        tripleo_nodes_validation_validate_controllers_icmp: \\\\\\\"{{ validate_controllers_icmp }}\\\\\\\"\\\\n        tripleo_nodes_validation_validate_gateway_icmp: \\\\\\\"{{ validate_gateways_icmp }}\\\\\\\"\\\\n        tripleo_nodes_validation_validate_fqdn: \\\\\\\"{{ validate_fqdn }}\\\\\\\"\\\\n        tripleo_nodes_validation_ping_test_ips: \\\\\\\"{{ ping_test_ips.get(tripleo_role_name, \'\').split() | list | unique }}\\\\\\\"\\\\n        tripleo_nodes_validation_ping_test_gateway_ips: \\\\\\\"{{ ping_test_gateway_ips.get(tripleo_role_name, []) }}\\\\\\\"\\\\n  tags:\\\\n    - overcloud\\\\n    - pre_deploy_steps\\\\n    - network_deploy_steps\\\\n\\\"}}, \\\"deploy_steps_pre_deployment_playbook\\\": {\\\"str_replace\\\": {\\\"params\\\": {\\\"BOOTSTRAP_SERVER_ID\\\": {\\\"get_attr\\\": [\\\"BootstrapServerId\\\", \\\"value\\\"]}, \\\"DEPLOY_SOURCE_HOST\\\": {\\\"get_param\\\": \\\"deployment_source_hosts\\\"}, \\\"DEPLOY_TARGET_HOST\\\": {\\\"if\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"deployment_target_hosts\\\"}, \\\"\\\"]}, {\\\"get_param\\\": \\\"RootStackName\\\"}, {\\\"get_param\\\": \\\"deployment_target_hosts\\\"}]}, \\\"DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}, \\\"ENABLE_DEBUG\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"ENABLE_PUPPET\\\": {\\\"get_param\\\": \\\"EnablePuppet\\\"}, \\\"CONTAINER_CLI\\\": {\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"CONTAINER_LOG_STDOUT_PATH\\\": {\\\"get_param\\\": \\\"ContainerLogStdoutPath\\\"}, \\\"CONTAINER_HEALTHCHECK_DISABLED\\\": {\\\"get_param\\\": \\\"ContainerHealthcheckDisabled\\\"}, \\\"DOCKER_PUPPET_DEBUG\\\": {\\\"get_param\\\": \\\"DockerPuppetDebug\\\"}, \\\"DOCKER_PUPPET_PROCESS_COUNT\\\": {\\\"get_param\\\": \\\"DockerPuppetProcessCount\\\"}, \\\"DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\": {\\\"get_param\\\": \\\"DockerPuppetMountHostPuppet\\\"}, \\\"SELINUX_MODE\\\": {\\\"get_param\\\": \\\"SELinuxMode\\\"}}, \\\"template\\\": \\\"- hosts: CellControllerCompute:DEPLOY_TARGET_HOST\\\\n  strategy: tripleo_free\\\\n  name: Server pre deployment steps\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  tasks:\\\\n    - name: Server pre deployments\\\\n      delegate_to: localhost\\\\n      run_once: true\\\\n      debug:\\\\n        msg: Use --start-at-task \'Server pre deployments\' to resume from this task\\\\n\\\\n    - import_tasks: hiera_steps_tasks.yaml\\\\n    - include_tasks: deployments.yaml\\\\n      vars:\\\\n        force: false\\\\n      with_items: \\\\\\\"{{ hostvars[inventory_hostname][\'pre_deployments_\' ~ tripleo_role_name]|default([]) }}\\\\\\\"\\\\n\\\\n  tags:\\\\n    - overcloud\\\\n    - pre_deploy_steps\\\\n\\\"}}, \\\"deploy_steps_host_prep_playbook\\\": {\\\"str_replace\\\": {\\\"params\\\": {\\\"BOOTSTRAP_SERVER_ID\\\": {\\\"get_attr\\\": [\\\"BootstrapServerId\\\", \\\"value\\\"]}, \\\"DEPLOY_SOURCE_HOST\\\": {\\\"get_param\\\": \\\"deployment_source_hosts\\\"}, \\\"DEPLOY_TARGET_HOST\\\": {\\\"if\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"deployment_target_hosts\\\"}, \\\"\\\"]}, {\\\"get_param\\\": \\\"RootStackName\\\"}, {\\\"get_param\\\": \\\"deployment_target_hosts\\\"}]}, \\\"DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}, \\\"ENABLE_DEBUG\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"ENABLE_PUPPET\\\": {\\\"get_param\\\": \\\"EnablePuppet\\\"}, \\\"CONTAINER_CLI\\\": {\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"CONTAINER_LOG_STDOUT_PATH\\\": {\\\"get_param\\\": \\\"ContainerLogStdoutPath\\\"}, \\\"CONTAINER_HEALTHCHECK_DISABLED\\\": {\\\"get_param\\\": \\\"ContainerHealthcheckDisabled\\\"}, \\\"DOCKER_PUPPET_DEBUG\\\": {\\\"get_param\\\": \\\"DockerPuppetDebug\\\"}, \\\"DOCKER_PUPPET_PROCESS_COUNT\\\": {\\\"get_param\\\": \\\"DockerPuppetProcessCount\\\"}, \\\"DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\": {\\\"get_param\\\": \\\"DockerPuppetMountHostPuppet\\\"}, \\\"SELINUX_MODE\\\": {\\\"get_param\\\": \\\"SELinuxMode\\\"}}, \\\"template\\\": \\\"- hosts: CellControllerCompute:DEPLOY_TARGET_HOST\\\\n  strategy: tripleo_free\\\\n  name: Host prep steps\\\\n  become: true\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  vars:\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    enable_puppet: ENABLE_PUPPET\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n  tasks:\\\\n\\\\n    - name: Host prep steps\\\\n      delegate_to: localhost\\\\n      run_once: true\\\\n      debug:\\\\n        msg: Use --start-at-task \'Host prep steps\' to resume from this task\\\\n    - name: Deploy Artifacts\\\\n      tripleo_push_artifacts:\\\\n        artifact_urls: \\\\\\\"{{ deploy_artifact_urls | default([]) }}\\\\\\\"\\\\n        artifact_paths: \\\\\\\"{{ deploy_artifact_files | default([]) }}\\\\\\\"\\\\n      when:\\\\n        - ((deploy_artifact_urls | default([]) | length) > 0) or\\\\n          ((deploy_artifact_files | default([]) | length) > 0)\\\\n    - include_tasks: \\\\\\\"{{ _task_file_path }}\\\\\\\"\\\\n      vars:\\\\n        _task_file_path: \\\\\\\"{{ tripleo_role_name }}/host_prep_tasks.yaml\\\\\\\"\\\\n      when: \\\\\\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\\\\\"\\\\n  tags:\\\\n    - overcloud\\\\n    - host_prep_steps\\\\n\\\"}}, \\\"deploy_steps_container_setup_tasks_playbook\\\": {\\\"str_replace\\\": {\\\"params\\\": {\\\"BOOTSTRAP_SERVER_ID\\\": {\\\"get_attr\\\": [\\\"BootstrapServerId\\\", \\\"value\\\"]}, \\\"DEPLOY_SOURCE_HOST\\\": {\\\"get_param\\\": \\\"deployment_source_hosts\\\"}, \\\"DEPLOY_TARGET_HOST\\\": {\\\"if\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"deployment_target_hosts\\\"}, \\\"\\\"]}, {\\\"get_param\\\": \\\"RootStackName\\\"}, {\\\"get_param\\\": \\\"deployment_target_hosts\\\"}]}, \\\"DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}, \\\"ENABLE_DEBUG\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"ENABLE_PUPPET\\\": {\\\"get_param\\\": \\\"EnablePuppet\\\"}, \\\"CONTAINER_CLI\\\": {\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"CONTAINER_LOG_STDOUT_PATH\\\": {\\\"get_param\\\": \\\"ContainerLogStdoutPath\\\"}, \\\"CONTAINER_HEALTHCHECK_DISABLED\\\": {\\\"get_param\\\": \\\"ContainerHealthcheckDisabled\\\"}, \\\"DOCKER_PUPPET_DEBUG\\\": {\\\"get_param\\\": \\\"DockerPuppetDebug\\\"}, \\\"DOCKER_PUPPET_PROCESS_COUNT\\\": {\\\"get_param\\\": \\\"DockerPuppetProcessCount\\\"}, \\\"DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\": {\\\"get_param\\\": \\\"DockerPuppetMountHostPuppet\\\"}, \\\"SELINUX_MODE\\\": {\\\"get_param\\\": \\\"SELinuxMode\\\"}}, \\\"template\\\": \\\"- hosts: CellControllerCompute:DEPLOY_TARGET_HOST\\\\n  strategy: tripleo_free\\\\n  name: Overcloud container setup tasks\\\\n  become: true\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  vars:\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    enable_puppet: ENABLE_PUPPET\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n  tasks:\\\\n    - name: Overcloud container setup tasks\\\\n      block:\\\\n        - name: Overcloud container setup tasks\\\\n          delegate_to: localhost\\\\n          run_once: true\\\\n          debug:\\\\n            msg: Use --start-at-task \'Overcloud container setup tasks\' to resume from this task\\\\n        - name: Write config data\\\\n          include_tasks: common_container_setup_tasks.yaml\\\\n          when:\\\\n            - (deploy_identifier is defined and deploy_identifier != \\\\\\\"\\\\\\\" and deploy_identifier is not none)\\\\n  tags:\\\\n    - overcloud\\\\n    - container_setup_tasks\\\\n\\\"}}, \\\"deploy_steps_pre_deployment_tasks_playbook\\\": {\\\"str_replace\\\": {\\\"params\\\": {\\\"BOOTSTRAP_SERVER_ID\\\": {\\\"get_attr\\\": [\\\"BootstrapServerId\\\", \\\"value\\\"]}, \\\"DEPLOY_SOURCE_HOST\\\": {\\\"get_param\\\": \\\"deployment_source_hosts\\\"}, \\\"DEPLOY_TARGET_HOST\\\": {\\\"if\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"deployment_target_hosts\\\"}, \\\"\\\"]}, {\\\"get_param\\\": \\\"RootStackName\\\"}, {\\\"get_param\\\": \\\"deployment_target_hosts\\\"}]}, \\\"DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}, \\\"ENABLE_DEBUG\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"ENABLE_PUPPET\\\": {\\\"get_param\\\": \\\"EnablePuppet\\\"}, \\\"CONTAINER_CLI\\\": {\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"CONTAINER_LOG_STDOUT_PATH\\\": {\\\"get_param\\\": \\\"ContainerLogStdoutPath\\\"}, \\\"CONTAINER_HEALTHCHECK_DISABLED\\\": {\\\"get_param\\\": \\\"ContainerHealthcheckDisabled\\\"}, \\\"DOCKER_PUPPET_DEBUG\\\": {\\\"get_param\\\": \\\"DockerPuppetDebug\\\"}, \\\"DOCKER_PUPPET_PROCESS_COUNT\\\": {\\\"get_param\\\": \\\"DockerPuppetProcessCount\\\"}, \\\"DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\": {\\\"get_param\\\": \\\"DockerPuppetMountHostPuppet\\\"}, \\\"SELINUX_MODE\\\": {\\\"get_param\\\": \\\"SELinuxMode\\\"}}, \\\"template\\\": \\\"- hosts: CellControllerCompute:DEPLOY_TARGET_HOST\\\\n  strategy: tripleo_free\\\\n  name: Pre Deployment Step Tasks\\\\n  become: true\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  vars:\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    enable_puppet: ENABLE_PUPPET\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n  tasks:\\\\n\\\\n    - name: Pre Deployment Step Tasks\\\\n      delegate_to: localhost\\\\n      run_once: true\\\\n      debug:\\\\n        msg: Use --start-at-task \'Pre Deployment Step Tasks\' to resume from this task\\\\n    - include_tasks: \\\\\\\"{{ _task_file_path }}\\\\\\\"\\\\n      vars:\\\\n        _task_file_path: \\\\\\\"{{ tripleo_role_name }}/pre_deploy_step_tasks.yaml\\\\\\\"\\\\n      when: \\\\\\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\\\\\"\\\\n  tags:\\\\n    - overcloud\\\\n    - pre_deploy_steps_tasks\\\\n\\\"}}, \\\"deploy_steps_external_deployment_playbook\\\": {\\\"str_replace\\\": {\\\"params\\\": {\\\"BOOTSTRAP_SERVER_ID\\\": {\\\"get_attr\\\": [\\\"BootstrapServerId\\\", \\\"value\\\"]}, \\\"DEPLOY_SOURCE_HOST\\\": {\\\"get_param\\\": \\\"deployment_source_hosts\\\"}, \\\"DEPLOY_TARGET_HOST\\\": {\\\"if\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"deployment_target_hosts\\\"}, \\\"\\\"]}, {\\\"get_param\\\": \\\"RootStackName\\\"}, {\\\"get_param\\\": \\\"deployment_target_hosts\\\"}]}, \\\"DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}, \\\"ENABLE_DEBUG\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"ENABLE_PUPPET\\\": {\\\"get_param\\\": \\\"EnablePuppet\\\"}, \\\"CONTAINER_CLI\\\": {\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"CONTAINER_LOG_STDOUT_PATH\\\": {\\\"get_param\\\": \\\"ContainerLogStdoutPath\\\"}, \\\"CONTAINER_HEALTHCHECK_DISABLED\\\": {\\\"get_param\\\": \\\"ContainerHealthcheckDisabled\\\"}, \\\"DOCKER_PUPPET_DEBUG\\\": {\\\"get_param\\\": \\\"DockerPuppetDebug\\\"}, \\\"DOCKER_PUPPET_PROCESS_COUNT\\\": {\\\"get_param\\\": \\\"DockerPuppetProcessCount\\\"}, \\\"DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\": {\\\"get_param\\\": \\\"DockerPuppetMountHostPuppet\\\"}, \\\"SELINUX_MODE\\\": {\\\"get_param\\\": \\\"SELinuxMode\\\"}}, \\\"template\\\": \\\"- hosts: DEPLOY_SOURCE_HOST\\\\n  strategy: tripleo_free\\\\n  name: External deployment step 1\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  become: false\\\\n  vars:\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    step: \'1\'\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    enable_puppet: ENABLE_PUPPET\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n  tasks:\\\\n    - name: External deployment step 1\\\\n      delegate_to: localhost\\\\n      run_once: true\\\\n      debug:\\\\n        msg: Use --start-at-task \'External deployment step 1\' to resume from this task\\\\n    - include_tasks: \\\\\\\"external_deploy_steps_tasks_step1.yaml\\\\\\\"\\\\n      when:\\\\n        - playbook_dir ~ \'/external_deploy_steps_tasks_step1.yaml\' is exists\\\\n  tags:\\\\n    - external\\\\n    - external_deploy_steps\\\\n    - step1\\\\n\\\\n- hosts: CellControllerCompute:DEPLOY_TARGET_HOST\\\\n  strategy: tripleo_free\\\\n  name: Deploy step tasks for 1\\\\n  become: true\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  vars:\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    step: \'1\'\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    enable_puppet: ENABLE_PUPPET\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n  tasks:\\\\n    - name: Deploy step tasks for 1\\\\n      delegate_to: localhost\\\\n      run_once: true\\\\n      debug:\\\\n        msg: Use --start-at-task \'Deploy step tasks for 1\' to resume from this task\\\\n    - name: Write the config_step hieradata for the deploy step 1 tasks\\\\n\\\\n      copy:\\\\n        content: \\\\\\\"{{ dict(step=step | int) | to_json }}\\\\\\\"\\\\n        dest: /etc/puppet/hieradata/config_step.json\\\\n        force: true\\\\n        mode: \'0600\'\\\\n\\\\n\\\\n    - name: Overcloud common bootstrap tasks for step 1\\\\n      block:\\\\n        - name: \\\\\\\"Check if /var/lib/tripleo-config/container-startup-config/step_1 already exists\\\\\\\"\\\\n          stat:\\\\n            path: \\\\\\\"/var/lib/tripleo-config/container-startup-config/step_1\\\\\\\"\\\\n          register: container_startup_configs_json_stat\\\\n        - name: Write config data at the start of step 1\\\\n          include_tasks: common_deploy_steps_tasks_step_1.yaml\\\\n          when:\\\\n            - ((deploy_identifier is defined and deploy_identifier != \\\\\\\"\\\\\\\" and deploy_identifier is not none) or\\\\n              not container_startup_configs_json_stat.stat.exists)\\\\n\\\\n\\\\n    - include_tasks: \\\\\\\"{{ _task_file_path }}\\\\\\\"\\\\n      vars:\\\\n        _task_file_path: \\\\\\\"{{ tripleo_role_name }}/deploy_steps_tasks_step{{ step }}.yaml\\\\\\\"\\\\n      when: \\\\\\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\\\\\"\\\\n\\\\n    - name: Overcloud common deploy step tasks 1\\\\n      block:\\\\n        - name: \\\\\\\"Check if /var/lib/tripleo-config/container-startup-config/step_1 already exists\\\\\\\"\\\\n          stat:\\\\n            path: \\\\\\\"/var/lib/tripleo-config/container-startup-config/step_1\\\\\\\"\\\\n          register: container_startup_configs_json_stat\\\\n        - include_tasks: common_deploy_steps_tasks.yaml\\\\n          when: (deploy_identifier is defined and deploy_identifier != \\\\\\\"\\\\\\\" and deploy_identifier is not none) or\\\\n                (container_startup_configs_json_stat is defined and not container_startup_configs_json_stat.stat.exists)\\\\n  tags:\\\\n    - overcloud\\\\n    - deploy_steps\\\\n    - step1\\\\n- hosts: DEPLOY_SOURCE_HOST\\\\n  strategy: tripleo_free\\\\n  name: External deployment step 2\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  become: false\\\\n  vars:\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    step: \'2\'\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    enable_puppet: ENABLE_PUPPET\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n  tasks:\\\\n    - name: External deployment step 2\\\\n      delegate_to: localhost\\\\n      run_once: true\\\\n      debug:\\\\n        msg: Use --start-at-task \'External deployment step 2\' to resume from this task\\\\n    - include_tasks: \\\\\\\"external_deploy_steps_tasks_step2.yaml\\\\\\\"\\\\n      when:\\\\n        - playbook_dir ~ \'/external_deploy_steps_tasks_step2.yaml\' is exists\\\\n  tags:\\\\n    - external\\\\n    - external_deploy_steps\\\\n    - step2\\\\n\\\\n- hosts: CellControllerCompute:DEPLOY_TARGET_HOST\\\\n  strategy: tripleo_free\\\\n  name: Deploy step tasks for 2\\\\n  become: true\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  vars:\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    step: \'2\'\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    enable_puppet: ENABLE_PUPPET\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n  tasks:\\\\n    - name: Deploy step tasks for 2\\\\n      delegate_to: localhost\\\\n      run_once: true\\\\n      debug:\\\\n        msg: Use --start-at-task \'Deploy step tasks for 2\' to resume from this task\\\\n    - name: Write the config_step hieradata for the deploy step 2 tasks\\\\n\\\\n      copy:\\\\n        content: \\\\\\\"{{ dict(step=step | int) | to_json }}\\\\\\\"\\\\n        dest: /etc/puppet/hieradata/config_step.json\\\\n        force: true\\\\n        mode: \'0600\'\\\\n\\\\n\\\\n\\\\n    - include_tasks: \\\\\\\"{{ _task_file_path }}\\\\\\\"\\\\n      vars:\\\\n        _task_file_path: \\\\\\\"{{ tripleo_role_name }}/deploy_steps_tasks_step{{ step }}.yaml\\\\\\\"\\\\n      when: \\\\\\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\\\\\"\\\\n\\\\n    - name: Overcloud common deploy step tasks 2\\\\n      block:\\\\n        - name: \\\\\\\"Check if /var/lib/tripleo-config/container-startup-config/step_2 already exists\\\\\\\"\\\\n          stat:\\\\n            path: \\\\\\\"/var/lib/tripleo-config/container-startup-config/step_2\\\\\\\"\\\\n          register: container_startup_configs_json_stat\\\\n        - include_tasks: common_deploy_steps_tasks.yaml\\\\n          when: (deploy_identifier is defined and deploy_identifier != \\\\\\\"\\\\\\\" and deploy_identifier is not none) or\\\\n                (container_startup_configs_json_stat is defined and not container_startup_configs_json_stat.stat.exists)\\\\n  tags:\\\\n    - overcloud\\\\n    - deploy_steps\\\\n    - step2\\\\n- hosts: DEPLOY_SOURCE_HOST\\\\n  strategy: tripleo_free\\\\n  name: External deployment step 3\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  become: false\\\\n  vars:\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    step: \'3\'\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    enable_puppet: ENABLE_PUPPET\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n  tasks:\\\\n    - name: External deployment step 3\\\\n      delegate_to: localhost\\\\n      run_once: true\\\\n      debug:\\\\n        msg: Use --start-at-task \'External deployment step 3\' to resume from this task\\\\n    - include_tasks: \\\\\\\"external_deploy_steps_tasks_step3.yaml\\\\\\\"\\\\n      when:\\\\n        - playbook_dir ~ \'/external_deploy_steps_tasks_step3.yaml\' is exists\\\\n  tags:\\\\n    - external\\\\n    - external_deploy_steps\\\\n    - step3\\\\n\\\\n- hosts: CellControllerCompute:DEPLOY_TARGET_HOST\\\\n  strategy: tripleo_free\\\\n  name: Deploy step tasks for 3\\\\n  become: true\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  vars:\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    step: \'3\'\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    enable_puppet: ENABLE_PUPPET\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n  tasks:\\\\n    - name: Deploy step tasks for 3\\\\n      delegate_to: localhost\\\\n      run_once: true\\\\n      debug:\\\\n        msg: Use --start-at-task \'Deploy step tasks for 3\' to resume from this task\\\\n    - name: Write the config_step hieradata for the deploy step 3 tasks\\\\n\\\\n      copy:\\\\n        content: \\\\\\\"{{ dict(step=step | int) | to_json }}\\\\\\\"\\\\n        dest: /etc/puppet/hieradata/config_step.json\\\\n        force: true\\\\n        mode: \'0600\'\\\\n\\\\n\\\\n\\\\n    - include_tasks: \\\\\\\"{{ _task_file_path }}\\\\\\\"\\\\n      vars:\\\\n        _task_file_path: \\\\\\\"{{ tripleo_role_name }}/deploy_steps_tasks_step{{ step }}.yaml\\\\\\\"\\\\n      when: \\\\\\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\\\\\"\\\\n\\\\n    - name: Overcloud common deploy step tasks 3\\\\n      block:\\\\n        - name: \\\\\\\"Check if /var/lib/tripleo-config/container-startup-config/step_3 already exists\\\\\\\"\\\\n          stat:\\\\n            path: \\\\\\\"/var/lib/tripleo-config/container-startup-config/step_3\\\\\\\"\\\\n          register: container_startup_configs_json_stat\\\\n        - include_tasks: common_deploy_steps_tasks.yaml\\\\n          when: (deploy_identifier is defined and deploy_identifier != \\\\\\\"\\\\\\\" and deploy_identifier is not none) or\\\\n                (container_startup_configs_json_stat is defined and not container_startup_configs_json_stat.stat.exists)\\\\n  tags:\\\\n    - overcloud\\\\n    - deploy_steps\\\\n    - step3\\\\n- hosts: DEPLOY_SOURCE_HOST\\\\n  strategy: tripleo_free\\\\n  name: External deployment step 4\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  become: false\\\\n  vars:\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    step: \'4\'\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    enable_puppet: ENABLE_PUPPET\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n  tasks:\\\\n    - name: External deployment step 4\\\\n      delegate_to: localhost\\\\n      run_once: true\\\\n      debug:\\\\n        msg: Use --start-at-task \'External deployment step 4\' to resume from this task\\\\n    - include_tasks: \\\\\\\"external_deploy_steps_tasks_step4.yaml\\\\\\\"\\\\n      when:\\\\n        - playbook_dir ~ \'/external_deploy_steps_tasks_step4.yaml\' is exists\\\\n  tags:\\\\n    - external\\\\n    - external_deploy_steps\\\\n    - step4\\\\n\\\\n- hosts: CellControllerCompute:DEPLOY_TARGET_HOST\\\\n  strategy: tripleo_free\\\\n  name: Deploy step tasks for 4\\\\n  become: true\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  vars:\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    step: \'4\'\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    enable_puppet: ENABLE_PUPPET\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n  tasks:\\\\n    - name: Deploy step tasks for 4\\\\n      delegate_to: localhost\\\\n      run_once: true\\\\n      debug:\\\\n        msg: Use --start-at-task \'Deploy step tasks for 4\' to resume from this task\\\\n    - name: Write the config_step hieradata for the deploy step 4 tasks\\\\n\\\\n      copy:\\\\n        content: \\\\\\\"{{ dict(step=step | int) | to_json }}\\\\\\\"\\\\n        dest: /etc/puppet/hieradata/config_step.json\\\\n        force: true\\\\n        mode: \'0600\'\\\\n\\\\n\\\\n\\\\n    - include_tasks: \\\\\\\"{{ _task_file_path }}\\\\\\\"\\\\n      vars:\\\\n        _task_file_path: \\\\\\\"{{ tripleo_role_name }}/deploy_steps_tasks_step{{ step }}.yaml\\\\\\\"\\\\n      when: \\\\\\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\\\\\"\\\\n\\\\n    - name: Overcloud common deploy step tasks 4\\\\n      block:\\\\n        - name: \\\\\\\"Check if /var/lib/tripleo-config/container-startup-config/step_4 already exists\\\\\\\"\\\\n          stat:\\\\n            path: \\\\\\\"/var/lib/tripleo-config/container-startup-config/step_4\\\\\\\"\\\\n          register: container_startup_configs_json_stat\\\\n        - include_tasks: common_deploy_steps_tasks.yaml\\\\n          when: (deploy_identifier is defined and deploy_identifier != \\\\\\\"\\\\\\\" and deploy_identifier is not none) or\\\\n                (container_startup_configs_json_stat is defined and not container_startup_configs_json_stat.stat.exists)\\\\n  tags:\\\\n    - overcloud\\\\n    - deploy_steps\\\\n    - step4\\\\n- hosts: DEPLOY_SOURCE_HOST\\\\n  strategy: tripleo_free\\\\n  name: External deployment step 5\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  become: false\\\\n  vars:\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    step: \'5\'\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    enable_puppet: ENABLE_PUPPET\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n  tasks:\\\\n    - name: External deployment step 5\\\\n      delegate_to: localhost\\\\n      run_once: true\\\\n      debug:\\\\n        msg: Use --start-at-task \'External deployment step 5\' to resume from this task\\\\n    - include_tasks: \\\\\\\"external_deploy_steps_tasks_step5.yaml\\\\\\\"\\\\n      when:\\\\n        - playbook_dir ~ \'/external_deploy_steps_tasks_step5.yaml\' is exists\\\\n  tags:\\\\n    - external\\\\n    - external_deploy_steps\\\\n    - step5\\\\n\\\\n- hosts: CellControllerCompute:DEPLOY_TARGET_HOST\\\\n  strategy: tripleo_free\\\\n  name: Deploy step tasks for 5\\\\n  become: true\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  vars:\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    step: \'5\'\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    enable_puppet: ENABLE_PUPPET\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n  tasks:\\\\n    - name: Deploy step tasks for 5\\\\n      delegate_to: localhost\\\\n      run_once: true\\\\n      debug:\\\\n        msg: Use --start-at-task \'Deploy step tasks for 5\' to resume from this task\\\\n    - name: Write the config_step hieradata for the deploy step 5 tasks\\\\n\\\\n      copy:\\\\n        content: \\\\\\\"{{ dict(step=step | int) | to_json }}\\\\\\\"\\\\n        dest: /etc/puppet/hieradata/config_step.json\\\\n        force: true\\\\n        mode: \'0600\'\\\\n\\\\n\\\\n\\\\n    - include_tasks: \\\\\\\"{{ _task_file_path }}\\\\\\\"\\\\n      vars:\\\\n        _task_file_path: \\\\\\\"{{ tripleo_role_name }}/deploy_steps_tasks_step{{ step }}.yaml\\\\\\\"\\\\n      when: \\\\\\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\\\\\"\\\\n\\\\n    - name: Overcloud common deploy step tasks 5\\\\n      block:\\\\n        - name: \\\\\\\"Check if /var/lib/tripleo-config/container-startup-config/step_5 already exists\\\\\\\"\\\\n          stat:\\\\n            path: \\\\\\\"/var/lib/tripleo-config/container-startup-config/step_5\\\\\\\"\\\\n          register: container_startup_configs_json_stat\\\\n        - include_tasks: common_deploy_steps_tasks.yaml\\\\n          when: (deploy_identifier is defined and deploy_identifier != \\\\\\\"\\\\\\\" and deploy_identifier is not none) or\\\\n                (container_startup_configs_json_stat is defined and not container_startup_configs_json_stat.stat.exists)\\\\n  tags:\\\\n    - overcloud\\\\n    - deploy_steps\\\\n    - step5\\\\n\\\"}}, \\\"deploy_steps_post_deployment_playbook\\\": {\\\"str_replace\\\": {\\\"params\\\": {\\\"BOOTSTRAP_SERVER_ID\\\": {\\\"get_attr\\\": [\\\"BootstrapServerId\\\", \\\"value\\\"]}, \\\"DEPLOY_SOURCE_HOST\\\": {\\\"get_param\\\": \\\"deployment_source_hosts\\\"}, \\\"DEPLOY_TARGET_HOST\\\": {\\\"if\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"deployment_target_hosts\\\"}, \\\"\\\"]}, {\\\"get_param\\\": \\\"RootStackName\\\"}, {\\\"get_param\\\": \\\"deployment_target_hosts\\\"}]}, \\\"DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}, \\\"ENABLE_DEBUG\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"ENABLE_PUPPET\\\": {\\\"get_param\\\": \\\"EnablePuppet\\\"}, \\\"CONTAINER_CLI\\\": {\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"CONTAINER_LOG_STDOUT_PATH\\\": {\\\"get_param\\\": \\\"ContainerLogStdoutPath\\\"}, \\\"CONTAINER_HEALTHCHECK_DISABLED\\\": {\\\"get_param\\\": \\\"ContainerHealthcheckDisabled\\\"}, \\\"DOCKER_PUPPET_DEBUG\\\": {\\\"get_param\\\": \\\"DockerPuppetDebug\\\"}, \\\"DOCKER_PUPPET_PROCESS_COUNT\\\": {\\\"get_param\\\": \\\"DockerPuppetProcessCount\\\"}, \\\"DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\": {\\\"get_param\\\": \\\"DockerPuppetMountHostPuppet\\\"}, \\\"SELINUX_MODE\\\": {\\\"get_param\\\": \\\"SELinuxMode\\\"}}, \\\"template\\\": \\\"\\\\n- hosts: CellControllerCompute:DEPLOY_TARGET_HOST\\\\n  strategy: tripleo_free\\\\n  name: Server Post Deployments\\\\n  become: true\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  tasks:\\\\n    - name: Server Post Deployments\\\\n      delegate_to: localhost\\\\n      run_once: true\\\\n      debug:\\\\n        msg: Use --start-at-task \'Server Post Deployments\' to resume from this task\\\\n\\\\n    - include_tasks: deployments.yaml\\\\n      vars:\\\\n        force: false\\\\n      with_items: \\\\\\\"{{ hostvars[inventory_hostname][\'post_deployments_\' ~ tripleo_role_name]|default([]) }}\\\\\\\"\\\\n  tags:\\\\n    - overcloud\\\\n    - post_deploy_steps\\\\n\\\"}}, \\\"deploy_steps_post_deploy_tasks_playbook\\\": {\\\"str_replace\\\": {\\\"params\\\": {\\\"BOOTSTRAP_SERVER_ID\\\": {\\\"get_attr\\\": [\\\"BootstrapServerId\\\", \\\"value\\\"]}, \\\"DEPLOY_SOURCE_HOST\\\": {\\\"get_param\\\": \\\"deployment_source_hosts\\\"}, \\\"DEPLOY_TARGET_HOST\\\": {\\\"if\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"deployment_target_hosts\\\"}, \\\"\\\"]}, {\\\"get_param\\\": \\\"RootStackName\\\"}, {\\\"get_param\\\": \\\"deployment_target_hosts\\\"}]}, \\\"DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}, \\\"ENABLE_DEBUG\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"ENABLE_PUPPET\\\": {\\\"get_param\\\": \\\"EnablePuppet\\\"}, \\\"CONTAINER_CLI\\\": {\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"CONTAINER_LOG_STDOUT_PATH\\\": {\\\"get_param\\\": \\\"ContainerLogStdoutPath\\\"}, \\\"CONTAINER_HEALTHCHECK_DISABLED\\\": {\\\"get_param\\\": \\\"ContainerHealthcheckDisabled\\\"}, \\\"DOCKER_PUPPET_DEBUG\\\": {\\\"get_param\\\": \\\"DockerPuppetDebug\\\"}, \\\"DOCKER_PUPPET_PROCESS_COUNT\\\": {\\\"get_param\\\": \\\"DockerPuppetProcessCount\\\"}, \\\"DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\": {\\\"get_param\\\": \\\"DockerPuppetMountHostPuppet\\\"}, \\\"SELINUX_MODE\\\": {\\\"get_param\\\": \\\"SELinuxMode\\\"}}, \\\"template\\\": \\\"- hosts: DEPLOY_SOURCE_HOST\\\\n  strategy: tripleo_linear\\\\n  name: External deployment Post Deploy tasks\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  become: false\\\\n  vars:\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    enable_puppet: ENABLE_PUPPET\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n  tasks:\\\\n    - name: External deployment Post Deploy tasks\\\\n      delegate_to: localhost\\\\n      run_once: true\\\\n      debug:\\\\n        msg: Use --start-at-task \'External deployment Post Deploy tasks\' to resume from this task\\\\n    - import_tasks: external_post_deploy_steps_tasks.yaml\\\\n  tags:\\\\n    - external\\\\n    - external_deploy_steps\\\\n    - external_post_deploy_steps\\\\n\\\"}}, \\\"deploy_steps_playbook\\\": {\\\"str_replace\\\": {\\\"params\\\": {\\\"BOOTSTRAP_SERVER_ID\\\": {\\\"get_attr\\\": [\\\"BootstrapServerId\\\", \\\"value\\\"]}, \\\"DEPLOY_SOURCE_HOST\\\": {\\\"get_param\\\": \\\"deployment_source_hosts\\\"}, \\\"DEPLOY_TARGET_HOST\\\": {\\\"if\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"deployment_target_hosts\\\"}, \\\"\\\"]}, {\\\"get_param\\\": \\\"RootStackName\\\"}, {\\\"get_param\\\": \\\"deployment_target_hosts\\\"}]}, \\\"DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}, \\\"ENABLE_DEBUG\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"ENABLE_PUPPET\\\": {\\\"get_param\\\": \\\"EnablePuppet\\\"}, \\\"CONTAINER_CLI\\\": {\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"CONTAINER_LOG_STDOUT_PATH\\\": {\\\"get_param\\\": \\\"ContainerLogStdoutPath\\\"}, \\\"CONTAINER_HEALTHCHECK_DISABLED\\\": {\\\"get_param\\\": \\\"ContainerHealthcheckDisabled\\\"}, \\\"DOCKER_PUPPET_DEBUG\\\": {\\\"get_param\\\": \\\"DockerPuppetDebug\\\"}, \\\"DOCKER_PUPPET_PROCESS_COUNT\\\": {\\\"get_param\\\": \\\"DockerPuppetProcessCount\\\"}, \\\"DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\": {\\\"get_param\\\": \\\"DockerPuppetMountHostPuppet\\\"}, \\\"SELINUX_MODE\\\": {\\\"get_param\\\": \\\"SELinuxMode\\\"}}, \\\"template\\\": \\\"- import_playbook: deploy_steps_0_playbook.yaml\\\\n- import_playbook: deploy_steps_selinux_playbook.yaml\\\\n- import_playbook: deploy_steps_common_roles_playbook.yaml\\\\n- import_playbook: deploy_steps_0_tasks_playbook.yaml\\\\n- import_playbook: deploy_steps_pre_network_playbook.yaml\\\\n- import_playbook: deploy_steps_network_deployments_playbook.yaml\\\\n- import_playbook: deploy_steps_network_validation_playbook.yaml\\\\n- import_playbook: deploy_steps_pre_deployment_playbook.yaml\\\\n- import_playbook: deploy_steps_host_prep_playbook.yaml\\\\n- import_playbook: deploy_steps_container_setup_tasks_playbook.yaml\\\\n- import_playbook: deploy_steps_pre_deployment_tasks_playbook.yaml\\\\n- import_playbook: deploy_steps_external_deployment_playbook.yaml\\\\n- import_playbook: deploy_steps_post_deployment_playbook.yaml\\\\n- import_playbook: deploy_steps_post_deploy_tasks_playbook.yaml\\\\n\\\"}}, \\\"external_deploy_steps_tasks\\\": {\\\"get_attr\\\": [\\\"ExternalDeployTasks\\\", \\\"value\\\"]}, \\\"external_post_deploy_steps_tasks\\\": {\\\"get_attr\\\": [\\\"ExternalPostDeployTasks\\\", \\\"value\\\"]}, \\\"pre_deploy_step_tasks\\\": {\\\"get_attr\\\": [\\\"PreDeployStepTasks\\\", \\\"value\\\"]}, \\\"update_steps_playbook\\\": {\\\"str_replace\\\": {\\\"params\\\": {\\\"BOOTSTRAP_SERVER_ID\\\": {\\\"get_attr\\\": [\\\"BootstrapServerId\\\", \\\"value\\\"]}, \\\"DEPLOY_SOURCE_HOST\\\": {\\\"get_param\\\": \\\"deployment_source_hosts\\\"}, \\\"DEPLOY_TARGET_HOST\\\": {\\\"if\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"deployment_target_hosts\\\"}, \\\"\\\"]}, {\\\"get_param\\\": \\\"RootStackName\\\"}, {\\\"get_param\\\": \\\"deployment_target_hosts\\\"}]}, \\\"DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}, \\\"ENABLE_DEBUG\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"ENABLE_PUPPET\\\": {\\\"get_param\\\": \\\"EnablePuppet\\\"}, \\\"CONTAINER_CLI\\\": {\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"CONTAINER_LOG_STDOUT_PATH\\\": {\\\"get_param\\\": \\\"ContainerLogStdoutPath\\\"}, \\\"CONTAINER_HEALTHCHECK_DISABLED\\\": {\\\"get_param\\\": \\\"ContainerHealthcheckDisabled\\\"}, \\\"DOCKER_PUPPET_DEBUG\\\": {\\\"get_param\\\": \\\"DockerPuppetDebug\\\"}, \\\"DOCKER_PUPPET_PROCESS_COUNT\\\": {\\\"get_param\\\": \\\"DockerPuppetProcessCount\\\"}, \\\"DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\": {\\\"get_param\\\": \\\"DockerPuppetMountHostPuppet\\\"}, \\\"SELINUX_MODE\\\": {\\\"get_param\\\": \\\"SELinuxMode\\\"}}, \\\"template\\\": \\\"- hosts: DEPLOY_TARGET_HOST\\\\n  strategy: tripleo_linear\\\\n  name: External update step 0\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  become: false\\\\n  vars:\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    step: 0\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    enable_puppet: ENABLE_PUPPET\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n  tasks:\\\\n    - import_tasks:\\\\n        file: external_update_steps_tasks.yaml\\\\n      delegate_to: localhost\\\\n      run_once: true\\\\n  tags:\\\\n    - step0\\\\n    - external\\\\n    - external_update_steps\\\\n- import_playbook: common_deploy_steps_playbooks.yaml\\\\n  vars:\\\\n    deploy_source_host: \\\\\\\"DEPLOY_SOURCE_HOST\\\\\\\"\\\\n    deploy_target_host: \\\\\\\"DEPLOY_TARGET_HOST\\\\\\\"\\\\n- hosts: Controller\\\\n  name: Run update\\\\n  become: true\\\\n  serial: \\\\\\\"{{ update_serial | default(1)}}\\\\\\\"\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  vars:\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    enable_puppet: ENABLE_PUPPET\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n    tripleo_minor_update: true\\\\n    tripleo_redhat_enforce: true\\\\n    \\\\n  tasks:\\\\n    - import_tasks: hiera_steps_tasks.yaml\\\\n    - import_tasks: common_container_config_scripts.yaml\\\\n    - name: Make sure container configuration is refreshed\\\\n      import_tasks: common_container_setup_tasks.yaml\\\\n    - import_tasks: \\\\\\\"Controller/update_tasks_step0.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"0\\\\\\\"\\\\n    - import_tasks: \\\\\\\"Controller/update_tasks_step1.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"1\\\\\\\"\\\\n    - import_tasks: \\\\\\\"Controller/update_tasks_step2.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"2\\\\\\\"\\\\n    - import_tasks: \\\\\\\"Controller/update_tasks_step3.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"3\\\\\\\"\\\\n    - import_tasks: \\\\\\\"Controller/update_tasks_step4.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"4\\\\\\\"\\\\n    - import_tasks: \\\\\\\"Controller/update_tasks_step5.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"5\\\\\\\"\\\\n\\\\n    - include_tasks: \\\\\\\"{{ _task_file_path }}\\\\\\\"\\\\n      vars:\\\\n        _task_file_path: \\\\\\\"{{ tripleo_role_name }}/host_prep_tasks.yaml\\\\\\\"\\\\n      when: \\\\\\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\\\\\"\\\\n\\\\n    - import_tasks: deploy_steps_tasks_step_0.yaml\\\\n      vars:\\\\n        step: 0\\\\n    - name: Write config data at the start of step 1\\\\n      import_tasks: common_deploy_steps_tasks_step_1.yaml\\\\n    - import_tasks: common_deploy_steps_tasks.yaml\\\\n      vars:\\\\n        step: \\\\\\\"1\\\\\\\"\\\\n    - import_tasks: common_deploy_steps_tasks.yaml\\\\n      vars:\\\\n        step: \\\\\\\"2\\\\\\\"\\\\n    - import_tasks: common_deploy_steps_tasks.yaml\\\\n      vars:\\\\n        step: \\\\\\\"3\\\\\\\"\\\\n    - import_tasks: common_deploy_steps_tasks.yaml\\\\n      vars:\\\\n        step: \\\\\\\"4\\\\\\\"\\\\n    - import_tasks: common_deploy_steps_tasks.yaml\\\\n      vars:\\\\n        step: \\\\\\\"5\\\\\\\"\\\\n    - import_tasks: \\\\\\\"Controller/post_update_tasks_step0.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"0\\\\\\\"\\\\n    - import_tasks: \\\\\\\"Controller/post_update_tasks_step1.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"1\\\\\\\"\\\\n    - import_tasks: \\\\\\\"Controller/post_update_tasks_step2.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"2\\\\\\\"\\\\n    - import_tasks: \\\\\\\"Controller/post_update_tasks_step3.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"3\\\\\\\"\\\\n- hosts: CellController\\\\n  name: Run update\\\\n  become: true\\\\n  serial: \\\\\\\"{{ update_serial | default(1)}}\\\\\\\"\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  vars:\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    enable_puppet: ENABLE_PUPPET\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n    tripleo_minor_update: true\\\\n    tripleo_redhat_enforce: true\\\\n    \\\\n  tasks:\\\\n    - import_tasks: hiera_steps_tasks.yaml\\\\n    - import_tasks: common_container_config_scripts.yaml\\\\n    - name: Make sure container configuration is refreshed\\\\n      import_tasks: common_container_setup_tasks.yaml\\\\n    - import_tasks: \\\\\\\"CellController/update_tasks_step0.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"0\\\\\\\"\\\\n    - import_tasks: \\\\\\\"CellController/update_tasks_step1.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"1\\\\\\\"\\\\n    - import_tasks: \\\\\\\"CellController/update_tasks_step2.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"2\\\\\\\"\\\\n    - import_tasks: \\\\\\\"CellController/update_tasks_step3.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"3\\\\\\\"\\\\n    - import_tasks: \\\\\\\"CellController/update_tasks_step4.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"4\\\\\\\"\\\\n    - import_tasks: \\\\\\\"CellController/update_tasks_step5.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"5\\\\\\\"\\\\n\\\\n    - include_tasks: \\\\\\\"{{ _task_file_path }}\\\\\\\"\\\\n      vars:\\\\n        _task_file_path: \\\\\\\"{{ tripleo_role_name }}/host_prep_tasks.yaml\\\\\\\"\\\\n      when: \\\\\\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\\\\\"\\\\n\\\\n    - import_tasks: deploy_steps_tasks_step_0.yaml\\\\n      vars:\\\\n        step: 0\\\\n    - name: Write config data at the start of step 1\\\\n      import_tasks: common_deploy_steps_tasks_step_1.yaml\\\\n    - import_tasks: common_deploy_steps_tasks.yaml\\\\n      vars:\\\\n        step: \\\\\\\"1\\\\\\\"\\\\n    - import_tasks: common_deploy_steps_tasks.yaml\\\\n      vars:\\\\n        step: \\\\\\\"2\\\\\\\"\\\\n    - import_tasks: common_deploy_steps_tasks.yaml\\\\n      vars:\\\\n        step: \\\\\\\"3\\\\\\\"\\\\n    - import_tasks: common_deploy_steps_tasks.yaml\\\\n      vars:\\\\n        step: \\\\\\\"4\\\\\\\"\\\\n    - import_tasks: common_deploy_steps_tasks.yaml\\\\n      vars:\\\\n        step: \\\\\\\"5\\\\\\\"\\\\n    - import_tasks: \\\\\\\"CellController/post_update_tasks_step0.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"0\\\\\\\"\\\\n    - import_tasks: \\\\\\\"CellController/post_update_tasks_step1.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"1\\\\\\\"\\\\n    - import_tasks: \\\\\\\"CellController/post_update_tasks_step2.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"2\\\\\\\"\\\\n    - import_tasks: \\\\\\\"CellController/post_update_tasks_step3.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"3\\\\\\\"\\\\n- hosts: CellControllerCompute\\\\n  name: Run update\\\\n  become: true\\\\n  serial: \\\\\\\"{{ update_serial | default(1)}}\\\\\\\"\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  vars:\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    enable_puppet: ENABLE_PUPPET\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n    tripleo_minor_update: true\\\\n    tripleo_redhat_enforce: true\\\\n    \\\\n  tasks:\\\\n    - import_tasks: hiera_steps_tasks.yaml\\\\n    - import_tasks: common_container_config_scripts.yaml\\\\n    - name: Make sure container configuration is refreshed\\\\n      import_tasks: common_container_setup_tasks.yaml\\\\n    - import_tasks: \\\\\\\"CellControllerCompute/update_tasks_step0.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"0\\\\\\\"\\\\n    - import_tasks: \\\\\\\"CellControllerCompute/update_tasks_step1.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"1\\\\\\\"\\\\n    - import_tasks: \\\\\\\"CellControllerCompute/update_tasks_step2.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"2\\\\\\\"\\\\n    - import_tasks: \\\\\\\"CellControllerCompute/update_tasks_step3.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"3\\\\\\\"\\\\n    - import_tasks: \\\\\\\"CellControllerCompute/update_tasks_step4.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"4\\\\\\\"\\\\n    - import_tasks: \\\\\\\"CellControllerCompute/update_tasks_step5.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"5\\\\\\\"\\\\n\\\\n    - include_tasks: \\\\\\\"{{ _task_file_path }}\\\\\\\"\\\\n      vars:\\\\n        _task_file_path: \\\\\\\"{{ tripleo_role_name }}/host_prep_tasks.yaml\\\\\\\"\\\\n      when: \\\\\\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\\\\\"\\\\n\\\\n    - import_tasks: deploy_steps_tasks_step_0.yaml\\\\n      vars:\\\\n        step: 0\\\\n    - name: Write config data at the start of step 1\\\\n      import_tasks: common_deploy_steps_tasks_step_1.yaml\\\\n    - import_tasks: common_deploy_steps_tasks.yaml\\\\n      vars:\\\\n        step: \\\\\\\"1\\\\\\\"\\\\n    - import_tasks: common_deploy_steps_tasks.yaml\\\\n      vars:\\\\n        step: \\\\\\\"2\\\\\\\"\\\\n    - import_tasks: common_deploy_steps_tasks.yaml\\\\n      vars:\\\\n        step: \\\\\\\"3\\\\\\\"\\\\n    - import_tasks: common_deploy_steps_tasks.yaml\\\\n      vars:\\\\n        step: \\\\\\\"4\\\\\\\"\\\\n    - import_tasks: common_deploy_steps_tasks.yaml\\\\n      vars:\\\\n        step: \\\\\\\"5\\\\\\\"\\\\n    - import_tasks: \\\\\\\"CellControllerCompute/post_update_tasks_step0.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"0\\\\\\\"\\\\n    - import_tasks: \\\\\\\"CellControllerCompute/post_update_tasks_step1.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"1\\\\\\\"\\\\n    - import_tasks: \\\\\\\"CellControllerCompute/post_update_tasks_step2.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"2\\\\\\\"\\\\n    - import_tasks: \\\\\\\"CellControllerCompute/post_update_tasks_step3.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"3\\\\\\\"\\\\n- hosts: Compute\\\\n  name: Run update\\\\n  become: true\\\\n  serial: \\\\\\\"{{ update_serial | default(25)}}\\\\\\\"\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  vars:\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    enable_puppet: ENABLE_PUPPET\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n    tripleo_minor_update: true\\\\n    tripleo_redhat_enforce: true\\\\n    \\\\n  tasks:\\\\n    - import_tasks: hiera_steps_tasks.yaml\\\\n    - import_tasks: common_container_config_scripts.yaml\\\\n    - name: Make sure container configuration is refreshed\\\\n      import_tasks: common_container_setup_tasks.yaml\\\\n    - import_tasks: \\\\\\\"Compute/update_tasks_step0.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"0\\\\\\\"\\\\n    - import_tasks: \\\\\\\"Compute/update_tasks_step1.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"1\\\\\\\"\\\\n    - import_tasks: \\\\\\\"Compute/update_tasks_step2.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"2\\\\\\\"\\\\n    - import_tasks: \\\\\\\"Compute/update_tasks_step3.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"3\\\\\\\"\\\\n    - import_tasks: \\\\\\\"Compute/update_tasks_step4.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"4\\\\\\\"\\\\n    - import_tasks: \\\\\\\"Compute/update_tasks_step5.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"5\\\\\\\"\\\\n\\\\n    - include_tasks: \\\\\\\"{{ _task_file_path }}\\\\\\\"\\\\n      vars:\\\\n        _task_file_path: \\\\\\\"{{ tripleo_role_name }}/host_prep_tasks.yaml\\\\\\\"\\\\n      when: \\\\\\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\\\\\"\\\\n\\\\n    - import_tasks: deploy_steps_tasks_step_0.yaml\\\\n      vars:\\\\n        step: 0\\\\n    - name: Write config data at the start of step 1\\\\n      import_tasks: common_deploy_steps_tasks_step_1.yaml\\\\n    - import_tasks: common_deploy_steps_tasks.yaml\\\\n      vars:\\\\n        step: \\\\\\\"1\\\\\\\"\\\\n    - import_tasks: common_deploy_steps_tasks.yaml\\\\n      vars:\\\\n        step: \\\\\\\"2\\\\\\\"\\\\n    - import_tasks: common_deploy_steps_tasks.yaml\\\\n      vars:\\\\n        step: \\\\\\\"3\\\\\\\"\\\\n    - import_tasks: common_deploy_steps_tasks.yaml\\\\n      vars:\\\\n        step: \\\\\\\"4\\\\\\\"\\\\n    - import_tasks: common_deploy_steps_tasks.yaml\\\\n      vars:\\\\n        step: \\\\\\\"5\\\\\\\"\\\\n    - import_tasks: \\\\\\\"Compute/post_update_tasks_step0.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"0\\\\\\\"\\\\n    - import_tasks: \\\\\\\"Compute/post_update_tasks_step1.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"1\\\\\\\"\\\\n    - import_tasks: \\\\\\\"Compute/post_update_tasks_step2.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"2\\\\\\\"\\\\n    - import_tasks: \\\\\\\"Compute/post_update_tasks_step3.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"3\\\\\\\"\\\\n- hosts: BlockStorage\\\\n  name: Run update\\\\n  become: true\\\\n  serial: \\\\\\\"{{ update_serial | default(25)}}\\\\\\\"\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  vars:\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    enable_puppet: ENABLE_PUPPET\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n    tripleo_minor_update: true\\\\n    tripleo_redhat_enforce: true\\\\n    \\\\n  tasks:\\\\n    - import_tasks: hiera_steps_tasks.yaml\\\\n    - import_tasks: common_container_config_scripts.yaml\\\\n    - name: Make sure container configuration is refreshed\\\\n      import_tasks: common_container_setup_tasks.yaml\\\\n    - import_tasks: \\\\\\\"BlockStorage/update_tasks_step0.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"0\\\\\\\"\\\\n    - import_tasks: \\\\\\\"BlockStorage/update_tasks_step1.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"1\\\\\\\"\\\\n    - import_tasks: \\\\\\\"BlockStorage/update_tasks_step2.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"2\\\\\\\"\\\\n    - import_tasks: \\\\\\\"BlockStorage/update_tasks_step3.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"3\\\\\\\"\\\\n    - import_tasks: \\\\\\\"BlockStorage/update_tasks_step4.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"4\\\\\\\"\\\\n    - import_tasks: \\\\\\\"BlockStorage/update_tasks_step5.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"5\\\\\\\"\\\\n\\\\n    - include_tasks: \\\\\\\"{{ _task_file_path }}\\\\\\\"\\\\n      vars:\\\\n        _task_file_path: \\\\\\\"{{ tripleo_role_name }}/host_prep_tasks.yaml\\\\\\\"\\\\n      when: \\\\\\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\\\\\"\\\\n\\\\n    - import_tasks: deploy_steps_tasks_step_0.yaml\\\\n      vars:\\\\n        step: 0\\\\n    - name: Write config data at the start of step 1\\\\n      import_tasks: common_deploy_steps_tasks_step_1.yaml\\\\n    - import_tasks: common_deploy_steps_tasks.yaml\\\\n      vars:\\\\n        step: \\\\\\\"1\\\\\\\"\\\\n    - import_tasks: common_deploy_steps_tasks.yaml\\\\n      vars:\\\\n        step: \\\\\\\"2\\\\\\\"\\\\n    - import_tasks: common_deploy_steps_tasks.yaml\\\\n      vars:\\\\n        step: \\\\\\\"3\\\\\\\"\\\\n    - import_tasks: common_deploy_steps_tasks.yaml\\\\n      vars:\\\\n        step: \\\\\\\"4\\\\\\\"\\\\n    - import_tasks: common_deploy_steps_tasks.yaml\\\\n      vars:\\\\n        step: \\\\\\\"5\\\\\\\"\\\\n    - import_tasks: \\\\\\\"BlockStorage/post_update_tasks_step0.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"0\\\\\\\"\\\\n    - import_tasks: \\\\\\\"BlockStorage/post_update_tasks_step1.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"1\\\\\\\"\\\\n    - import_tasks: \\\\\\\"BlockStorage/post_update_tasks_step2.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"2\\\\\\\"\\\\n    - import_tasks: \\\\\\\"BlockStorage/post_update_tasks_step3.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"3\\\\\\\"\\\\n- hosts: ObjectStorage\\\\n  name: Run update\\\\n  become: true\\\\n  serial: \\\\\\\"{{ update_serial | default(1)}}\\\\\\\"\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  vars:\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    enable_puppet: ENABLE_PUPPET\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n    tripleo_minor_update: true\\\\n    tripleo_redhat_enforce: true\\\\n    \\\\n  tasks:\\\\n    - import_tasks: hiera_steps_tasks.yaml\\\\n    - import_tasks: common_container_config_scripts.yaml\\\\n    - name: Make sure container configuration is refreshed\\\\n      import_tasks: common_container_setup_tasks.yaml\\\\n    - import_tasks: \\\\\\\"ObjectStorage/update_tasks_step0.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"0\\\\\\\"\\\\n    - import_tasks: \\\\\\\"ObjectStorage/update_tasks_step1.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"1\\\\\\\"\\\\n    - import_tasks: \\\\\\\"ObjectStorage/update_tasks_step2.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"2\\\\\\\"\\\\n    - import_tasks: \\\\\\\"ObjectStorage/update_tasks_step3.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"3\\\\\\\"\\\\n    - import_tasks: \\\\\\\"ObjectStorage/update_tasks_step4.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"4\\\\\\\"\\\\n    - import_tasks: \\\\\\\"ObjectStorage/update_tasks_step5.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"5\\\\\\\"\\\\n\\\\n    - include_tasks: \\\\\\\"{{ _task_file_path }}\\\\\\\"\\\\n      vars:\\\\n        _task_file_path: \\\\\\\"{{ tripleo_role_name }}/host_prep_tasks.yaml\\\\\\\"\\\\n      when: \\\\\\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\\\\\"\\\\n\\\\n    - import_tasks: deploy_steps_tasks_step_0.yaml\\\\n      vars:\\\\n        step: 0\\\\n    - name: Write config data at the start of step 1\\\\n      import_tasks: common_deploy_steps_tasks_step_1.yaml\\\\n    - import_tasks: common_deploy_steps_tasks.yaml\\\\n      vars:\\\\n        step: \\\\\\\"1\\\\\\\"\\\\n    - import_tasks: common_deploy_steps_tasks.yaml\\\\n      vars:\\\\n        step: \\\\\\\"2\\\\\\\"\\\\n    - import_tasks: common_deploy_steps_tasks.yaml\\\\n      vars:\\\\n        step: \\\\\\\"3\\\\\\\"\\\\n    - import_tasks: common_deploy_steps_tasks.yaml\\\\n      vars:\\\\n        step: \\\\\\\"4\\\\\\\"\\\\n    - import_tasks: common_deploy_steps_tasks.yaml\\\\n      vars:\\\\n        step: \\\\\\\"5\\\\\\\"\\\\n    - import_tasks: \\\\\\\"ObjectStorage/post_update_tasks_step0.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"0\\\\\\\"\\\\n    - import_tasks: \\\\\\\"ObjectStorage/post_update_tasks_step1.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"1\\\\\\\"\\\\n    - import_tasks: \\\\\\\"ObjectStorage/post_update_tasks_step2.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"2\\\\\\\"\\\\n    - import_tasks: \\\\\\\"ObjectStorage/post_update_tasks_step3.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"3\\\\\\\"\\\\n- hosts: CephStorage\\\\n  name: Run update\\\\n  become: true\\\\n  serial: \\\\\\\"{{ update_serial | default(1)}}\\\\\\\"\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  vars:\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    enable_puppet: ENABLE_PUPPET\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n    tripleo_minor_update: true\\\\n    tripleo_redhat_enforce: False\\\\n    \\\\n  tasks:\\\\n    - import_tasks: hiera_steps_tasks.yaml\\\\n    - import_tasks: common_container_config_scripts.yaml\\\\n    - name: Make sure container configuration is refreshed\\\\n      import_tasks: common_container_setup_tasks.yaml\\\\n    - import_tasks: \\\\\\\"CephStorage/update_tasks_step0.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"0\\\\\\\"\\\\n    - import_tasks: \\\\\\\"CephStorage/update_tasks_step1.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"1\\\\\\\"\\\\n    - import_tasks: \\\\\\\"CephStorage/update_tasks_step2.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"2\\\\\\\"\\\\n    - import_tasks: \\\\\\\"CephStorage/update_tasks_step3.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"3\\\\\\\"\\\\n    - import_tasks: \\\\\\\"CephStorage/update_tasks_step4.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"4\\\\\\\"\\\\n    - import_tasks: \\\\\\\"CephStorage/update_tasks_step5.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"5\\\\\\\"\\\\n\\\\n    - include_tasks: \\\\\\\"{{ _task_file_path }}\\\\\\\"\\\\n      vars:\\\\n        _task_file_path: \\\\\\\"{{ tripleo_role_name }}/host_prep_tasks.yaml\\\\\\\"\\\\n      when: \\\\\\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\\\\\"\\\\n\\\\n    - import_tasks: deploy_steps_tasks_step_0.yaml\\\\n      vars:\\\\n        step: 0\\\\n    - name: Write config data at the start of step 1\\\\n      import_tasks: common_deploy_steps_tasks_step_1.yaml\\\\n    - import_tasks: common_deploy_steps_tasks.yaml\\\\n      vars:\\\\n        step: \\\\\\\"1\\\\\\\"\\\\n    - import_tasks: common_deploy_steps_tasks.yaml\\\\n      vars:\\\\n        step: \\\\\\\"2\\\\\\\"\\\\n    - import_tasks: common_deploy_steps_tasks.yaml\\\\n      vars:\\\\n        step: \\\\\\\"3\\\\\\\"\\\\n    - import_tasks: common_deploy_steps_tasks.yaml\\\\n      vars:\\\\n        step: \\\\\\\"4\\\\\\\"\\\\n    - import_tasks: common_deploy_steps_tasks.yaml\\\\n      vars:\\\\n        step: \\\\\\\"5\\\\\\\"\\\\n    - import_tasks: \\\\\\\"CephStorage/post_update_tasks_step0.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"0\\\\\\\"\\\\n    - import_tasks: \\\\\\\"CephStorage/post_update_tasks_step1.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"1\\\\\\\"\\\\n    - import_tasks: \\\\\\\"CephStorage/post_update_tasks_step2.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"2\\\\\\\"\\\\n    - import_tasks: \\\\\\\"CephStorage/post_update_tasks_step3.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"3\\\\\\\"\\\\n- hosts: Networker\\\\n  name: Run update\\\\n  become: true\\\\n  serial: \\\\\\\"{{ update_serial | default(1)}}\\\\\\\"\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  vars:\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    enable_puppet: ENABLE_PUPPET\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n    tripleo_minor_update: true\\\\n    tripleo_redhat_enforce: true\\\\n    \\\\n  tasks:\\\\n    - import_tasks: hiera_steps_tasks.yaml\\\\n    - import_tasks: common_container_config_scripts.yaml\\\\n    - name: Make sure container configuration is refreshed\\\\n      import_tasks: common_container_setup_tasks.yaml\\\\n    - import_tasks: \\\\\\\"Networker/update_tasks_step0.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"0\\\\\\\"\\\\n    - import_tasks: \\\\\\\"Networker/update_tasks_step1.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"1\\\\\\\"\\\\n    - import_tasks: \\\\\\\"Networker/update_tasks_step2.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"2\\\\\\\"\\\\n    - import_tasks: \\\\\\\"Networker/update_tasks_step3.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"3\\\\\\\"\\\\n    - import_tasks: \\\\\\\"Networker/update_tasks_step4.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"4\\\\\\\"\\\\n    - import_tasks: \\\\\\\"Networker/update_tasks_step5.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"5\\\\\\\"\\\\n\\\\n    - include_tasks: \\\\\\\"{{ _task_file_path }}\\\\\\\"\\\\n      vars:\\\\n        _task_file_path: \\\\\\\"{{ tripleo_role_name }}/host_prep_tasks.yaml\\\\\\\"\\\\n      when: \\\\\\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\\\\\"\\\\n\\\\n    - import_tasks: deploy_steps_tasks_step_0.yaml\\\\n      vars:\\\\n        step: 0\\\\n    - name: Write config data at the start of step 1\\\\n      import_tasks: common_deploy_steps_tasks_step_1.yaml\\\\n    - import_tasks: common_deploy_steps_tasks.yaml\\\\n      vars:\\\\n        step: \\\\\\\"1\\\\\\\"\\\\n    - import_tasks: common_deploy_steps_tasks.yaml\\\\n      vars:\\\\n        step: \\\\\\\"2\\\\\\\"\\\\n    - import_tasks: common_deploy_steps_tasks.yaml\\\\n      vars:\\\\n        step: \\\\\\\"3\\\\\\\"\\\\n    - import_tasks: common_deploy_steps_tasks.yaml\\\\n      vars:\\\\n        step: \\\\\\\"4\\\\\\\"\\\\n    - import_tasks: common_deploy_steps_tasks.yaml\\\\n      vars:\\\\n        step: \\\\\\\"5\\\\\\\"\\\\n    - import_tasks: \\\\\\\"Networker/post_update_tasks_step0.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"0\\\\\\\"\\\\n    - import_tasks: \\\\\\\"Networker/post_update_tasks_step1.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"1\\\\\\\"\\\\n    - import_tasks: \\\\\\\"Networker/post_update_tasks_step2.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"2\\\\\\\"\\\\n    - import_tasks: \\\\\\\"Networker/post_update_tasks_step3.yaml\\\\\\\"\\\\n      vars:\\\\n        step: \\\\\\\"3\\\\\\\"\\\\n\\\"}}, \\\"external_update_steps_tasks\\\": {\\\"get_attr\\\": [\\\"ExternalUpdateTasks\\\", \\\"value\\\"]}, \\\"external_update_steps_playbook\\\": {\\\"str_replace\\\": {\\\"params\\\": {\\\"BOOTSTRAP_SERVER_ID\\\": {\\\"get_attr\\\": [\\\"BootstrapServerId\\\", \\\"value\\\"]}, \\\"DEPLOY_SOURCE_HOST\\\": {\\\"get_param\\\": \\\"deployment_source_hosts\\\"}, \\\"DEPLOY_TARGET_HOST\\\": {\\\"if\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"deployment_target_hosts\\\"}, \\\"\\\"]}, {\\\"get_param\\\": \\\"RootStackName\\\"}, {\\\"get_param\\\": \\\"deployment_target_hosts\\\"}]}, \\\"DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}, \\\"ENABLE_DEBUG\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"ENABLE_PUPPET\\\": {\\\"get_param\\\": \\\"EnablePuppet\\\"}, \\\"CONTAINER_CLI\\\": {\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"CONTAINER_LOG_STDOUT_PATH\\\": {\\\"get_param\\\": \\\"ContainerLogStdoutPath\\\"}, \\\"CONTAINER_HEALTHCHECK_DISABLED\\\": {\\\"get_param\\\": \\\"ContainerHealthcheckDisabled\\\"}, \\\"DOCKER_PUPPET_DEBUG\\\": {\\\"get_param\\\": \\\"DockerPuppetDebug\\\"}, \\\"DOCKER_PUPPET_PROCESS_COUNT\\\": {\\\"get_param\\\": \\\"DockerPuppetProcessCount\\\"}, \\\"DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\": {\\\"get_param\\\": \\\"DockerPuppetMountHostPuppet\\\"}, \\\"SELINUX_MODE\\\": {\\\"get_param\\\": \\\"SELinuxMode\\\"}}, \\\"template\\\": \\\"- hosts: DEPLOY_SOURCE_HOST\\\\n  name: External update step 0\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  become: false\\\\n  vars:\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    step: 0\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    enable_puppet: ENABLE_PUPPET\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n  tasks:\\\\n    - import_tasks: external_update_steps_tasks.yaml\\\\n  tags:\\\\n    - step0\\\\n    - external\\\\n    - external_update_steps\\\\n- import_playbook: common_deploy_steps_playbooks.yaml\\\\n  vars:\\\\n    deploy_source_host: \\\\\\\"DEPLOY_SOURCE_HOST\\\\\\\"\\\\n    deploy_target_host: \\\\\\\"DEPLOY_TARGET_HOST\\\\\\\"\\\\n- hosts: DEPLOY_SOURCE_HOST\\\\n  name: External update step 1\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  become: false\\\\n  vars:\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    step: \'1\'\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    enable_puppet: ENABLE_PUPPET\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n  tasks:\\\\n    - import_tasks: external_update_steps_tasks.yaml\\\\n  tags:\\\\n    - step1\\\\n    - external\\\\n    - external_update_steps\\\\n- hosts: DEPLOY_SOURCE_HOST\\\\n  name: External update step 2\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  become: false\\\\n  vars:\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    step: \'2\'\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    enable_puppet: ENABLE_PUPPET\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n  tasks:\\\\n    - import_tasks: external_update_steps_tasks.yaml\\\\n  tags:\\\\n    - step2\\\\n    - external\\\\n    - external_update_steps\\\\n# putting both update and deploy tasks in the same\\\\n# playbook allows influencing the deploy tasks by\\\\n# variables \\\\\\\"exported\\\\\\\" from update tasks\\\\n- hosts: DEPLOY_SOURCE_HOST\\\\n  name: External deploy step 1\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  become: false\\\\n  vars:\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    step: \'1\'\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    enable_puppet: ENABLE_PUPPET\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n  tasks:\\\\n    - import_tasks: external_deploy_steps_tasks.yaml\\\\n  tags:\\\\n    - external\\\\n    - external_deploy_steps\\\\n    - step1\\\\n# putting both update and deploy tasks in the same\\\\n# playbook allows influencing the deploy tasks by\\\\n# variables \\\\\\\"exported\\\\\\\" from update tasks\\\\n- hosts: DEPLOY_SOURCE_HOST\\\\n  name: External deploy step 2\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  become: false\\\\n  vars:\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    step: \'2\'\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    enable_puppet: ENABLE_PUPPET\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n  tasks:\\\\n    - import_tasks: external_deploy_steps_tasks.yaml\\\\n  tags:\\\\n    - external\\\\n    - external_deploy_steps\\\\n    - step2\\\\n# putting both update and deploy tasks in the same\\\\n# playbook allows influencing the deploy tasks by\\\\n# variables \\\\\\\"exported\\\\\\\" from update tasks\\\\n- hosts: DEPLOY_SOURCE_HOST\\\\n  name: External deploy step 3\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  become: false\\\\n  vars:\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    step: \'3\'\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    enable_puppet: ENABLE_PUPPET\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n  tasks:\\\\n    - import_tasks: external_deploy_steps_tasks.yaml\\\\n  tags:\\\\n    - external\\\\n    - external_deploy_steps\\\\n    - step3\\\\n# putting both update and deploy tasks in the same\\\\n# playbook allows influencing the deploy tasks by\\\\n# variables \\\\\\\"exported\\\\\\\" from update tasks\\\\n- hosts: DEPLOY_SOURCE_HOST\\\\n  name: External deploy step 4\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  become: false\\\\n  vars:\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    step: \'4\'\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    enable_puppet: ENABLE_PUPPET\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n  tasks:\\\\n    - import_tasks: external_deploy_steps_tasks.yaml\\\\n  tags:\\\\n    - external\\\\n    - external_deploy_steps\\\\n    - step4\\\\n# putting both update and deploy tasks in the same\\\\n# playbook allows influencing the deploy tasks by\\\\n# variables \\\\\\\"exported\\\\\\\" from update tasks\\\\n- hosts: DEPLOY_SOURCE_HOST\\\\n  name: External deploy step 5\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  become: false\\\\n  vars:\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    step: \'5\'\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    enable_puppet: ENABLE_PUPPET\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n  tasks:\\\\n    - import_tasks: external_deploy_steps_tasks.yaml\\\\n  tags:\\\\n    - external\\\\n    - external_deploy_steps\\\\n    - step5\\\\n\\\"}}, \\\"pre_upgrade_rolling_steps_tasks\\\": \\\"\\\\n- include_tasks: \\\\\\\"{{ _task_file_path }}\\\\\\\"\\\\n  vars:\\\\n    _task_file_path: \\\\\\\"{{ tripleo_role_name }}/pre_upgrade_rolling_tasks.yaml\\\\\\\"\\\\n  when: \\\\\\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\\\\\"\\\\n  tags:\\\\n    - always\\\\n\\\", \\\"pre_upgrade_rolling_steps_playbook\\\": {\\\"str_replace\\\": {\\\"params\\\": {\\\"BOOTSTRAP_SERVER_ID\\\": {\\\"get_attr\\\": [\\\"BootstrapServerId\\\", \\\"value\\\"]}, \\\"DEPLOY_SOURCE_HOST\\\": {\\\"get_param\\\": \\\"deployment_source_hosts\\\"}, \\\"DEPLOY_TARGET_HOST\\\": {\\\"if\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"deployment_target_hosts\\\"}, \\\"\\\"]}, {\\\"get_param\\\": \\\"RootStackName\\\"}, {\\\"get_param\\\": \\\"deployment_target_hosts\\\"}]}, \\\"DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}, \\\"ENABLE_DEBUG\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"ENABLE_PUPPET\\\": {\\\"get_param\\\": \\\"EnablePuppet\\\"}, \\\"CONTAINER_CLI\\\": {\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"CONTAINER_LOG_STDOUT_PATH\\\": {\\\"get_param\\\": \\\"ContainerLogStdoutPath\\\"}, \\\"CONTAINER_HEALTHCHECK_DISABLED\\\": {\\\"get_param\\\": \\\"ContainerHealthcheckDisabled\\\"}, \\\"DOCKER_PUPPET_DEBUG\\\": {\\\"get_param\\\": \\\"DockerPuppetDebug\\\"}, \\\"DOCKER_PUPPET_PROCESS_COUNT\\\": {\\\"get_param\\\": \\\"DockerPuppetProcessCount\\\"}, \\\"DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\": {\\\"get_param\\\": \\\"DockerPuppetMountHostPuppet\\\"}, \\\"SELINUX_MODE\\\": {\\\"get_param\\\": \\\"SELinuxMode\\\"}}, \\\"template\\\": \\\"- import_playbook: common_deploy_steps_playbooks.yaml\\\\n  vars:\\\\n    deploy_source_host: \\\\\\\"DEPLOY_SOURCE_HOST:Controller\\\\\\\"\\\\n    deploy_target_host: \\\\\\\"DEPLOY_TARGET_HOST\\\\\\\"\\\\n- hosts: Controller\\\\n  name: Run pre-upgrade rolling tasks\\\\n  serial:  1\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  tasks:\\\\n    - include_tasks: pre_upgrade_rolling_steps_tasks.yaml\\\\n      with_sequence: start=0 end=0\\\\n      loop_control:\\\\n        loop_var: step\\\\n- import_playbook: common_deploy_steps_playbooks.yaml\\\\n  vars:\\\\n    deploy_source_host: \\\\\\\"DEPLOY_SOURCE_HOST:CellController\\\\\\\"\\\\n    deploy_target_host: \\\\\\\"DEPLOY_TARGET_HOST\\\\\\\"\\\\n- hosts: CellController\\\\n  name: Run pre-upgrade rolling tasks\\\\n  serial:  1\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  tasks:\\\\n    - include_tasks: pre_upgrade_rolling_steps_tasks.yaml\\\\n      with_sequence: start=0 end=0\\\\n      loop_control:\\\\n        loop_var: step\\\\n- import_playbook: common_deploy_steps_playbooks.yaml\\\\n  vars:\\\\n    deploy_source_host: \\\\\\\"DEPLOY_SOURCE_HOST:CellControllerCompute\\\\\\\"\\\\n    deploy_target_host: \\\\\\\"DEPLOY_TARGET_HOST\\\\\\\"\\\\n- hosts: CellControllerCompute\\\\n  name: Run pre-upgrade rolling tasks\\\\n  serial:  1\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  tasks:\\\\n    - include_tasks: pre_upgrade_rolling_steps_tasks.yaml\\\\n      with_sequence: start=0 end=0\\\\n      loop_control:\\\\n        loop_var: step\\\\n- import_playbook: common_deploy_steps_playbooks.yaml\\\\n  vars:\\\\n    deploy_source_host: \\\\\\\"DEPLOY_SOURCE_HOST:Compute\\\\\\\"\\\\n    deploy_target_host: \\\\\\\"DEPLOY_TARGET_HOST\\\\\\\"\\\\n- hosts: Compute\\\\n  name: Run pre-upgrade rolling tasks\\\\n  serial:  1\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  tasks:\\\\n    - include_tasks: pre_upgrade_rolling_steps_tasks.yaml\\\\n      with_sequence: start=0 end=0\\\\n      loop_control:\\\\n        loop_var: step\\\\n- import_playbook: common_deploy_steps_playbooks.yaml\\\\n  vars:\\\\n    deploy_source_host: \\\\\\\"DEPLOY_SOURCE_HOST:BlockStorage\\\\\\\"\\\\n    deploy_target_host: \\\\\\\"DEPLOY_TARGET_HOST\\\\\\\"\\\\n- hosts: BlockStorage\\\\n  name: Run pre-upgrade rolling tasks\\\\n  serial:  1\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  tasks:\\\\n    - include_tasks: pre_upgrade_rolling_steps_tasks.yaml\\\\n      with_sequence: start=0 end=0\\\\n      loop_control:\\\\n        loop_var: step\\\\n- import_playbook: common_deploy_steps_playbooks.yaml\\\\n  vars:\\\\n    deploy_source_host: \\\\\\\"DEPLOY_SOURCE_HOST:ObjectStorage\\\\\\\"\\\\n    deploy_target_host: \\\\\\\"DEPLOY_TARGET_HOST\\\\\\\"\\\\n- hosts: ObjectStorage\\\\n  name: Run pre-upgrade rolling tasks\\\\n  serial:  1\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  tasks:\\\\n    - include_tasks: pre_upgrade_rolling_steps_tasks.yaml\\\\n      with_sequence: start=0 end=0\\\\n      loop_control:\\\\n        loop_var: step\\\\n- import_playbook: common_deploy_steps_playbooks.yaml\\\\n  vars:\\\\n    deploy_source_host: \\\\\\\"DEPLOY_SOURCE_HOST:CephStorage\\\\\\\"\\\\n    deploy_target_host: \\\\\\\"DEPLOY_TARGET_HOST\\\\\\\"\\\\n- hosts: CephStorage\\\\n  name: Run pre-upgrade rolling tasks\\\\n  serial:  1\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  tasks:\\\\n    - include_tasks: pre_upgrade_rolling_steps_tasks.yaml\\\\n      with_sequence: start=0 end=0\\\\n      loop_control:\\\\n        loop_var: step\\\\n- import_playbook: common_deploy_steps_playbooks.yaml\\\\n  vars:\\\\n    deploy_source_host: \\\\\\\"DEPLOY_SOURCE_HOST:Networker\\\\\\\"\\\\n    deploy_target_host: \\\\\\\"DEPLOY_TARGET_HOST\\\\\\\"\\\\n- hosts: Networker\\\\n  name: Run pre-upgrade rolling tasks\\\\n  serial:  1\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  tasks:\\\\n    - include_tasks: pre_upgrade_rolling_steps_tasks.yaml\\\\n      with_sequence: start=0 end=0\\\\n      loop_control:\\\\n        loop_var: step\\\\n\\\"}}, \\\"upgrade_steps_playbook\\\": {\\\"str_replace\\\": {\\\"params\\\": {\\\"BOOTSTRAP_SERVER_ID\\\": {\\\"get_attr\\\": [\\\"BootstrapServerId\\\", \\\"value\\\"]}, \\\"DEPLOY_SOURCE_HOST\\\": {\\\"get_param\\\": \\\"deployment_source_hosts\\\"}, \\\"DEPLOY_TARGET_HOST\\\": {\\\"if\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"deployment_target_hosts\\\"}, \\\"\\\"]}, {\\\"get_param\\\": \\\"RootStackName\\\"}, {\\\"get_param\\\": \\\"deployment_target_hosts\\\"}]}, \\\"DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}, \\\"ENABLE_DEBUG\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"ENABLE_PUPPET\\\": {\\\"get_param\\\": \\\"EnablePuppet\\\"}, \\\"CONTAINER_CLI\\\": {\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"CONTAINER_LOG_STDOUT_PATH\\\": {\\\"get_param\\\": \\\"ContainerLogStdoutPath\\\"}, \\\"CONTAINER_HEALTHCHECK_DISABLED\\\": {\\\"get_param\\\": \\\"ContainerHealthcheckDisabled\\\"}, \\\"DOCKER_PUPPET_DEBUG\\\": {\\\"get_param\\\": \\\"DockerPuppetDebug\\\"}, \\\"DOCKER_PUPPET_PROCESS_COUNT\\\": {\\\"get_param\\\": \\\"DockerPuppetProcessCount\\\"}, \\\"DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\": {\\\"get_param\\\": \\\"DockerPuppetMountHostPuppet\\\"}, \\\"SELINUX_MODE\\\": {\\\"get_param\\\": \\\"SELinuxMode\\\"}}, \\\"template\\\": \\\"- import_playbook: common_deploy_steps_playbooks.yaml\\\\n  vars:\\\\n    deploy_source_host: \\\\\\\"DEPLOY_SOURCE_HOST\\\\\\\"\\\\n    deploy_target_host: \\\\\\\"DEPLOY_TARGET_HOST\\\\\\\"\\\\n- hosts: DEPLOY_TARGET_HOST\\\\n  strategy: tripleo_free\\\\n  name: Upgrade tasks for step 0\\\\n  become: true\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  vars:\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    step: \'0\'\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n  tasks:\\\\n\\\\n    - include_tasks: \\\\\\\"{{ _task_file_path }}\\\\\\\"\\\\n      vars:\\\\n        _task_file_path: \\\\\\\"{{ tripleo_role_name }}/upgrade_tasks_step{{ step }}.yaml\\\\\\\"\\\\n      when: \\\\\\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\\\\\"\\\\n      tags:\\\\n        - always\\\\n\\\\n  tags:\\\\n    - upgrade_steps\\\\n    - upgrade_step0\\\\n- hosts: DEPLOY_TARGET_HOST\\\\n  strategy: tripleo_free\\\\n  name: Upgrade tasks for step 1\\\\n  become: true\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  vars:\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    step: \'1\'\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n  tasks:\\\\n\\\\n    - include_tasks: \\\\\\\"{{ _task_file_path }}\\\\\\\"\\\\n      vars:\\\\n        _task_file_path: \\\\\\\"{{ tripleo_role_name }}/upgrade_tasks_step{{ step }}.yaml\\\\\\\"\\\\n      when: \\\\\\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\\\\\"\\\\n      tags:\\\\n        - always\\\\n\\\\n  tags:\\\\n    - upgrade_steps\\\\n    - upgrade_step1\\\\n- hosts: DEPLOY_TARGET_HOST\\\\n  strategy: tripleo_free\\\\n  name: Upgrade tasks for step 2\\\\n  become: true\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  vars:\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    step: \'2\'\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n  tasks:\\\\n\\\\n    - include_tasks: \\\\\\\"{{ _task_file_path }}\\\\\\\"\\\\n      vars:\\\\n        _task_file_path: \\\\\\\"{{ tripleo_role_name }}/upgrade_tasks_step{{ step }}.yaml\\\\\\\"\\\\n      when: \\\\\\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\\\\\"\\\\n      tags:\\\\n        - always\\\\n\\\\n  tags:\\\\n    - upgrade_steps\\\\n    - upgrade_step2\\\\n- hosts: DEPLOY_TARGET_HOST\\\\n  strategy: tripleo_free\\\\n  name: Upgrade tasks for step 3\\\\n  become: true\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  vars:\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    step: \'3\'\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n  tasks:\\\\n\\\\n    - include_tasks: \\\\\\\"{{ _task_file_path }}\\\\\\\"\\\\n      vars:\\\\n        _task_file_path: \\\\\\\"{{ tripleo_role_name }}/upgrade_tasks_step{{ step }}.yaml\\\\\\\"\\\\n      when: \\\\\\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\\\\\"\\\\n      tags:\\\\n        - always\\\\n\\\\n  tags:\\\\n    - upgrade_steps\\\\n    - upgrade_step3\\\\n- hosts: DEPLOY_TARGET_HOST\\\\n  strategy: tripleo_free\\\\n  name: Upgrade tasks for step 4\\\\n  become: true\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  vars:\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    step: \'4\'\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n  tasks:\\\\n\\\\n    - include_tasks: \\\\\\\"{{ _task_file_path }}\\\\\\\"\\\\n      vars:\\\\n        _task_file_path: \\\\\\\"{{ tripleo_role_name }}/upgrade_tasks_step{{ step }}.yaml\\\\\\\"\\\\n      when: \\\\\\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\\\\\"\\\\n      tags:\\\\n        - always\\\\n\\\\n  tags:\\\\n    - upgrade_steps\\\\n    - upgrade_step4\\\\n- hosts: DEPLOY_TARGET_HOST\\\\n  strategy: tripleo_free\\\\n  name: Upgrade tasks for step 5\\\\n  become: true\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  vars:\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    step: \'5\'\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n  tasks:\\\\n\\\\n    - include_tasks: \\\\\\\"{{ _task_file_path }}\\\\\\\"\\\\n      vars:\\\\n        _task_file_path: \\\\\\\"{{ tripleo_role_name }}/upgrade_tasks_step{{ step }}.yaml\\\\\\\"\\\\n      when: \\\\\\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\\\\\"\\\\n      tags:\\\\n        - always\\\\n\\\\n  tags:\\\\n    - upgrade_steps\\\\n    - upgrade_step5\\\\n\\\"}}, \\\"post_upgrade_steps_tasks\\\": \\\"\\\\n- include_tasks: \\\\\\\"{{ _task_file_path }}\\\\\\\"\\\\n  vars:\\\\n    _task_file_path: \\\\\\\"{{ tripleo_role_name }}/post_upgrade_tasks.yaml\\\\\\\"\\\\n  when: \\\\\\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\\\\\"\\\\n  tags:\\\\n    - always\\\\n\\\", \\\"post_upgrade_steps_playbook\\\": {\\\"str_replace\\\": {\\\"params\\\": {\\\"BOOTSTRAP_SERVER_ID\\\": {\\\"get_attr\\\": [\\\"BootstrapServerId\\\", \\\"value\\\"]}, \\\"DEPLOY_SOURCE_HOST\\\": {\\\"get_param\\\": \\\"deployment_source_hosts\\\"}, \\\"DEPLOY_TARGET_HOST\\\": {\\\"if\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"deployment_target_hosts\\\"}, \\\"\\\"]}, {\\\"get_param\\\": \\\"RootStackName\\\"}, {\\\"get_param\\\": \\\"deployment_target_hosts\\\"}]}, \\\"DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}, \\\"ENABLE_DEBUG\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"ENABLE_PUPPET\\\": {\\\"get_param\\\": \\\"EnablePuppet\\\"}, \\\"CONTAINER_CLI\\\": {\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"CONTAINER_LOG_STDOUT_PATH\\\": {\\\"get_param\\\": \\\"ContainerLogStdoutPath\\\"}, \\\"CONTAINER_HEALTHCHECK_DISABLED\\\": {\\\"get_param\\\": \\\"ContainerHealthcheckDisabled\\\"}, \\\"DOCKER_PUPPET_DEBUG\\\": {\\\"get_param\\\": \\\"DockerPuppetDebug\\\"}, \\\"DOCKER_PUPPET_PROCESS_COUNT\\\": {\\\"get_param\\\": \\\"DockerPuppetProcessCount\\\"}, \\\"DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\": {\\\"get_param\\\": \\\"DockerPuppetMountHostPuppet\\\"}, \\\"SELINUX_MODE\\\": {\\\"get_param\\\": \\\"SELinuxMode\\\"}}, \\\"template\\\": \\\"- import_playbook: common_deploy_steps_playbooks.yaml\\\\n  vars:\\\\n    deploy_source_host: \\\\\\\"DEPLOY_SOURCE_HOST\\\\\\\"\\\\n    deploy_target_host: \\\\\\\"DEPLOY_TARGET_HOST\\\\\\\"\\\\n- hosts: DEPLOY_TARGET_HOST\\\\n  strategy: tripleo_free\\\\n  any_errors_fatal: yes\\\\n  tasks:\\\\n    - include_tasks: post_upgrade_steps_tasks.yaml\\\\n      with_sequence: start=0 end=3\\\\n      vars:\\\\n        bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n        deploy_identifier: DEPLOY_IDENTIFIER\\\\n        enable_debug: ENABLE_DEBUG\\\\n        enable_puppet: ENABLE_PUPPET\\\\n        container_cli: CONTAINER_CLI\\\\n        container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n        container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n        docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n        docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n        docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n      loop_control:\\\\n        loop_var: step\\\\n\\\"}}, \\\"external_upgrade_steps_tasks\\\": {\\\"get_attr\\\": [\\\"ExternalUpgradeTasks\\\", \\\"value\\\"]}, \\\"external_upgrade_steps_playbook\\\": {\\\"str_replace\\\": {\\\"params\\\": {\\\"BOOTSTRAP_SERVER_ID\\\": {\\\"get_attr\\\": [\\\"BootstrapServerId\\\", \\\"value\\\"]}, \\\"DEPLOY_SOURCE_HOST\\\": {\\\"get_param\\\": \\\"deployment_source_hosts\\\"}, \\\"DEPLOY_TARGET_HOST\\\": {\\\"if\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"deployment_target_hosts\\\"}, \\\"\\\"]}, {\\\"get_param\\\": \\\"RootStackName\\\"}, {\\\"get_param\\\": \\\"deployment_target_hosts\\\"}]}, \\\"DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}, \\\"ENABLE_DEBUG\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"ENABLE_PUPPET\\\": {\\\"get_param\\\": \\\"EnablePuppet\\\"}, \\\"CONTAINER_CLI\\\": {\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"CONTAINER_LOG_STDOUT_PATH\\\": {\\\"get_param\\\": \\\"ContainerLogStdoutPath\\\"}, \\\"CONTAINER_HEALTHCHECK_DISABLED\\\": {\\\"get_param\\\": \\\"ContainerHealthcheckDisabled\\\"}, \\\"DOCKER_PUPPET_DEBUG\\\": {\\\"get_param\\\": \\\"DockerPuppetDebug\\\"}, \\\"DOCKER_PUPPET_PROCESS_COUNT\\\": {\\\"get_param\\\": \\\"DockerPuppetProcessCount\\\"}, \\\"DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\": {\\\"get_param\\\": \\\"DockerPuppetMountHostPuppet\\\"}, \\\"SELINUX_MODE\\\": {\\\"get_param\\\": \\\"SELinuxMode\\\"}}, \\\"template\\\": \\\"- import_playbook: common_deploy_steps_playbooks.yaml\\\\n  vars:\\\\n    deploy_source_host: \\\\\\\"DEPLOY_SOURCE_HOST\\\\\\\"\\\\n    deploy_target_host: \\\\\\\"DEPLOY_TARGET_HOST\\\\\\\"\\\\n- hosts: DEPLOY_SOURCE_HOST\\\\n  strategy: tripleo_free\\\\n  name: External upgrade step 0\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  become: false\\\\n  vars:\\\\n    # Explicit ansible_python_interpreter to allow connecting\\\\n    # to different OS releases (EL7/8) while using delegate_to.\\\\n    ansible_python_interpreter: /usr/libexec/platform-python\\\\n    step: \'0\'\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    enable_puppet: ENABLE_PUPPET\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n  tasks:\\\\n    - import_tasks: external_upgrade_steps_tasks.yaml\\\\n  tags:\\\\n    - step0\\\\n    - external\\\\n    - external_upgrade_steps\\\\n- hosts: DEPLOY_SOURCE_HOST\\\\n  strategy: tripleo_free\\\\n  name: External upgrade step 1\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  become: false\\\\n  vars:\\\\n    # Explicit ansible_python_interpreter to allow connecting\\\\n    # to different OS releases (EL7/8) while using delegate_to.\\\\n    ansible_python_interpreter: /usr/libexec/platform-python\\\\n    step: \'1\'\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    enable_puppet: ENABLE_PUPPET\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n  tasks:\\\\n    - import_tasks: external_upgrade_steps_tasks.yaml\\\\n  tags:\\\\n    - step1\\\\n    - external\\\\n    - external_upgrade_steps\\\\n- hosts: DEPLOY_SOURCE_HOST\\\\n  strategy: tripleo_free\\\\n  name: External upgrade step 2\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  become: false\\\\n  vars:\\\\n    # Explicit ansible_python_interpreter to allow connecting\\\\n    # to different OS releases (EL7/8) while using delegate_to.\\\\n    ansible_python_interpreter: /usr/libexec/platform-python\\\\n    step: \'2\'\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    enable_puppet: ENABLE_PUPPET\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n  tasks:\\\\n    - import_tasks: external_upgrade_steps_tasks.yaml\\\\n  tags:\\\\n    - step2\\\\n    - external\\\\n    - external_upgrade_steps\\\\n# putting both upgrade and deploy tasks in the same\\\\n# playbook allows influencing the deploy tasks by\\\\n# variables \\\\\\\"exported\\\\\\\" from upgrade tasks\\\\n- hosts: DEPLOY_SOURCE_HOST\\\\n  name: External deploy step 1\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  become: false\\\\n  vars:\\\\n    # Explicit ansible_python_interpreter to allow connecting\\\\n    # to different OS releases (EL7/8) while using delegate_to.\\\\n    ansible_python_interpreter: /usr/libexec/platform-python\\\\n    step: \'1\'\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    enable_puppet: ENABLE_PUPPET\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n  tasks:\\\\n    - import_tasks: external_deploy_steps_tasks.yaml\\\\n  tags:\\\\n    - step1\\\\n    - external\\\\n    - external_deploy_steps\\\\n# putting both upgrade and deploy tasks in the same\\\\n# playbook allows influencing the deploy tasks by\\\\n# variables \\\\\\\"exported\\\\\\\" from upgrade tasks\\\\n- hosts: DEPLOY_SOURCE_HOST\\\\n  name: External deploy step 2\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  become: false\\\\n  vars:\\\\n    # Explicit ansible_python_interpreter to allow connecting\\\\n    # to different OS releases (EL7/8) while using delegate_to.\\\\n    ansible_python_interpreter: /usr/libexec/platform-python\\\\n    step: \'2\'\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    enable_puppet: ENABLE_PUPPET\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n  tasks:\\\\n    - import_tasks: external_deploy_steps_tasks.yaml\\\\n  tags:\\\\n    - step2\\\\n    - external\\\\n    - external_deploy_steps\\\\n# putting both upgrade and deploy tasks in the same\\\\n# playbook allows influencing the deploy tasks by\\\\n# variables \\\\\\\"exported\\\\\\\" from upgrade tasks\\\\n- hosts: DEPLOY_SOURCE_HOST\\\\n  name: External deploy step 3\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  become: false\\\\n  vars:\\\\n    # Explicit ansible_python_interpreter to allow connecting\\\\n    # to different OS releases (EL7/8) while using delegate_to.\\\\n    ansible_python_interpreter: /usr/libexec/platform-python\\\\n    step: \'3\'\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    enable_puppet: ENABLE_PUPPET\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n  tasks:\\\\n    - import_tasks: external_deploy_steps_tasks.yaml\\\\n  tags:\\\\n    - step3\\\\n    - external\\\\n    - external_deploy_steps\\\\n# putting both upgrade and deploy tasks in the same\\\\n# playbook allows influencing the deploy tasks by\\\\n# variables \\\\\\\"exported\\\\\\\" from upgrade tasks\\\\n- hosts: DEPLOY_SOURCE_HOST\\\\n  name: External deploy step 4\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  become: false\\\\n  vars:\\\\n    # Explicit ansible_python_interpreter to allow connecting\\\\n    # to different OS releases (EL7/8) while using delegate_to.\\\\n    ansible_python_interpreter: /usr/libexec/platform-python\\\\n    step: \'4\'\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    enable_puppet: ENABLE_PUPPET\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n  tasks:\\\\n    - import_tasks: external_deploy_steps_tasks.yaml\\\\n  tags:\\\\n    - step4\\\\n    - external\\\\n    - external_deploy_steps\\\\n# putting both upgrade and deploy tasks in the same\\\\n# playbook allows influencing the deploy tasks by\\\\n# variables \\\\\\\"exported\\\\\\\" from upgrade tasks\\\\n- hosts: DEPLOY_SOURCE_HOST\\\\n  name: External deploy step 5\\\\n  gather_facts: \\\\\\\"{{ gather_facts | default(false) }}\\\\\\\"\\\\n  any_errors_fatal: yes\\\\n  become: false\\\\n  vars:\\\\n    # Explicit ansible_python_interpreter to allow connecting\\\\n    # to different OS releases (EL7/8) while using delegate_to.\\\\n    ansible_python_interpreter: /usr/libexec/platform-python\\\\n    step: \'5\'\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    enable_puppet: ENABLE_PUPPET\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    container_healthcheck_disabled: CONTAINER_HEALTHCHECK_DISABLED\\\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n  tasks:\\\\n    - import_tasks: external_deploy_steps_tasks.yaml\\\\n  tags:\\\\n    - step5\\\\n    - external\\\\n    - external_deploy_steps\\\\n\\\"}}, \\\"scale_steps_tasks\\\": {\\\"get_attr\\\": [\\\"ScaleTasks\\\", \\\"value\\\"]}, \\\"scale_playbook\\\": {\\\"str_replace\\\": {\\\"params\\\": {\\\"BOOTSTRAP_SERVER_ID\\\": {\\\"get_attr\\\": [\\\"BootstrapServerId\\\", \\\"value\\\"]}, \\\"DEPLOY_SOURCE_HOST\\\": {\\\"get_param\\\": \\\"deployment_source_hosts\\\"}, \\\"DEPLOY_TARGET_HOST\\\": {\\\"if\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"deployment_target_hosts\\\"}, \\\"\\\"]}, {\\\"get_param\\\": \\\"RootStackName\\\"}, {\\\"get_param\\\": \\\"deployment_target_hosts\\\"}]}, \\\"DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}, \\\"ENABLE_DEBUG\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"ENABLE_PUPPET\\\": {\\\"get_param\\\": \\\"EnablePuppet\\\"}, \\\"CONTAINER_CLI\\\": {\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"CONTAINER_LOG_STDOUT_PATH\\\": {\\\"get_param\\\": \\\"ContainerLogStdoutPath\\\"}, \\\"CONTAINER_HEALTHCHECK_DISABLED\\\": {\\\"get_param\\\": \\\"ContainerHealthcheckDisabled\\\"}, \\\"DOCKER_PUPPET_DEBUG\\\": {\\\"get_param\\\": \\\"DockerPuppetDebug\\\"}, \\\"DOCKER_PUPPET_PROCESS_COUNT\\\": {\\\"get_param\\\": \\\"DockerPuppetProcessCount\\\"}, \\\"DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\": {\\\"get_param\\\": \\\"DockerPuppetMountHostPuppet\\\"}, \\\"SELINUX_MODE\\\": {\\\"get_param\\\": \\\"SELinuxMode\\\"}}, \\\"template\\\": \\\"# Collect the facts from the overcloud nodes but ignore unreachable\\\\n# nodes in the case of a dead node which needs to be part of the\\\\n# scale-down operation.\\\\n- import_playbook: common_deploy_steps_playbooks.yaml\\\\n  vars:\\\\n    deploy_source_host: \\\\\\\"DEPLOY_SOURCE_HOST\\\\\\\"\\\\n    deploy_target_host: \\\\\\\"DEPLOY_TARGET_HOST\\\\\\\"\\\\n\\\\n- hosts: DEPLOY_TARGET_HOST\\\\n  name: Scaling\\\\n  # NOTE(cloudnull): This is set to true explicitly so that we have up-to-date facts\\\\n  #                  on all DEPLOY_TARGET_HOST when performing a scaling operation.\\\\n  #                  Without up-to-date facts, we\'re creating a potential failure\\\\n  #                  scenario.\\\\n  gather_facts: true\\\\n  ignore_unreachable: true\\\\n  become: false\\\\n  vars:\\\\n    bootstrap_server_id: BOOTSTRAP_SERVER_ID\\\\n    deploy_identifier: DEPLOY_IDENTIFIER\\\\n    enable_debug: ENABLE_DEBUG\\\\n    enable_puppet: ENABLE_PUPPET\\\\n    container_cli: CONTAINER_CLI\\\\n    container_log_stdout_path: CONTAINER_LOG_STDOUT_PATH\\\\n    docker_puppet_debug: DOCKER_PUPPET_DEBUG\\\\n    docker_puppet_process_count: DOCKER_PUPPET_PROCESS_COUNT\\\\n    docker_puppet_mount_host_puppet: DOCKER_PUPPET_MOUNT_HOST_PUPPET\\\\n  tasks:\\\\n    # Only run the scale tasks on the nodes that are alive.\\\\n    # We expect the tasks to work on the nodes that are alive.\\\\n    # If a task is allowed to fail, it needs to be configured at\\\\n    # the task definition level but not here.\\\\n    - include_tasks: scale_steps_tasks.yaml\\\\n      with_sequence: start=1 end=1\\\\n      loop_control:\\\\n        loop_var: step\\\\n      tags: always\\\\n      # we use ansible_facts[\'hostname\'] to determine if the host is alive\\\\n      # or not.\\\\n      when: ansible_facts[\'hostname\'] is defined\\\\n    # We don\'t want to run the scale tasks on dead nodes, to allow\\\\n    # the operator to scale down the cloud no matter the state of\\\\n    # the servers.\\\\n    # However, we notify the operator if the node wasn\'t reachable.\\\\n    # Using fail and not debug module to make it more visible\\\\n    # in the logs.\\\\n    - fail:\\\\n        msg: \\\\\\\"Node is unreachable. No scale tasks will be run.\\\\\\\"\\\\n      ignore_errors: True\\\\n      tags: always\\\\n      # we use ansible_facts[\'hostname\'] to determine if the host is alive\\\\n      # or not.\\\\n      when: ansible_facts[\'hostname\'] is not defined\\\\n  tags:\\\\n    - scale\\\\n\\\"}}, \\\"post_update_steps_tasks\\\": \\\"\\\\n- include_tasks: \\\\\\\"{{ _task_file_path }}\\\\\\\"\\\\n  vars:\\\\n    _task_file_path: \\\\\\\"{{ tripleo_role_name }}/post_update_tasks.yaml\\\\\\\"\\\\n  when: \\\\\\\"\'{{ playbook_dir }}/{{ _task_file_path }}\' is exists\\\\\\\"\\\\n  tags:\\\\n    - always\\\"}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack Controller node configured by Puppet\\\", \\\"parameters\\\": {\\\"OvercloudControlFlavor\\\": {\\\"description\\\": \\\"DEPRECATED Use OvercloudControllerFlavor instead.\\\", \\\"default\\\": \\\"baremetal\\\", \\\"type\\\": \\\"string\\\"}, \\\"OvercloudControllerFlavor\\\": {\\\"description\\\": \\\"Flavor for the Controller node.\\\", \\\"default\\\": \\\"baremetal\\\", \\\"type\\\": \\\"string\\\"}, \\\"controllerImage\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"overcloud-full\\\", \\\"description\\\": \\\"DEPRECATED Use ControllerImage instead\\\"}, \\\"ControllerImage\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"overcloud-full\\\", \\\"description\\\": \\\"The disk image file to use for the role.\\\"}, \\\"ImageUpdatePolicy\\\": {\\\"default\\\": \\\"REBUILD_PRESERVE_EPHEMERAL\\\", \\\"description\\\": \\\"What policy to use when reconstructing instances. REBUILD for rebuilds, REBUILD_PRESERVE_EPHEMERAL to preserve /mnt.\\\", \\\"type\\\": \\\"string\\\"}, \\\"KeyName\\\": {\\\"description\\\": \\\"Name of an existing Nova key pair to enable SSH access to the instances\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"default\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"UpdateIdentifier\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Setting to a previously unused value during stack-update will trigger package update on all nodes\\\\n\\\"}, \\\"Hostname\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\"}, \\\"HostnameMap\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {}, \\\"description\\\": \\\"Optional mapping to override hostnames\\\"}, \\\"ControllerIPs\\\": {\\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}, \\\"SoftwareConfigTransport\\\": {\\\"default\\\": \\\"POLL_SERVER_CFN\\\", \\\"description\\\": \\\"How the server should receive the metadata required for software configuration.\\\\n\\\", \\\"type\\\": \\\"string\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"POLL_SERVER_CFN\\\", \\\"POLL_SERVER_HEAT\\\", \\\"POLL_TEMP_URL\\\", \\\"ZAQAR_MESSAGE\\\"]}]}, \\\"CloudDomain\\\": {\\\"default\\\": \\\"localdomain\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"The DNS domain used for the hosts. This must match the overcloud_domain_name configured on the undercloud.\\\\n\\\"}, \\\"ControllerServerMetadata\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API. This option is role-specific and is merged with the values given to the ServerMetadata parameter.\\\\n\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServerMetadata\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API. This applies to all roles and is merged with a role-specific metadata parameter.\\\\n\\\", \\\"type\\\": \\\"json\\\"}, \\\"ControllerSchedulerHints\\\": {\\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"Optional scheduler hints to pass to nova\\\", \\\"default\\\": {}}, \\\"NodeIndex\\\": {\\\"type\\\": \\\"number\\\", \\\"default\\\": 0}, \\\"ServiceNames\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": []}, \\\"MonitoringSubscriptions\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": []}, \\\"ServiceMetadataSettings\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {}}, \\\"OVNBridgeMappings\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": []}, \\\"ConfigCommand\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Command which will be run whenever configuration data changes\\\", \\\"default\\\": \\\"os-refresh-config --timeout 14400\\\"}, \\\"ConfigCollectSplay\\\": {\\\"type\\\": \\\"number\\\", \\\"default\\\": 30, \\\"description\\\": \\\"Maximum amount of time to possibly to delay configuration collection\\\\npolling. Defaults to 30 seconds. Set to 0 to disable it which will cause\\\\nthe configuration collection to occur as soon as the collection process\\\\nstarts.  This setting is used to prevent the configuration collection\\\\nprocesses from polling all at the exact same time.\\\\n\\\"}, \\\"UpgradeInitCommand\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Command or script snippet to run on all overcloud nodes to\\\\ninitialize the upgrade process. E.g. a repository switch.\\\\n\\\", \\\"default\\\": \\\"\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"UpgradeInitCommonCommand\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Common commands required by the upgrades process. This should not\\\\nnormally be modified by the operator and is set and unset in the\\\\nmajor-upgrade-composable-steps.yaml and major-upgrade-converge.yaml\\\\nenvironment files.\\\\n\\\", \\\"default\\\": \\\"\\\"}, \\\"DeploymentServerBlacklistDict\\\": {\\\"default\\\": {}, \\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"Map of server hostnames to blacklist from any triggered deployments. If the value is 1, the server will be blacklisted. This parameter is generated from the parent template.\\\\n\\\"}, \\\"RoleParameters\\\": {\\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"default\\\": {}}, \\\"ControllerControlPlaneSubnet\\\": {\\\"default\\\": \\\"ctlplane-subnet\\\", \\\"description\\\": \\\"Name of the subnet on ctlplane network for this role.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneSubnetCidr\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"ServerDeletionPolicy\\\": {\\\"description\\\": \\\"Whether to retain or delete servers on deletion of the stack\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"delete\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"delete\\\", \\\"retain\\\"]}]}, \\\"UserData\\\": {\\\"type\\\": \\\"string\\\"}}, \\\"parameter_groups\\\": [{\\\"label\\\": \\\"deprecated\\\", \\\"description\\\": \\\"Do not use deprecated params, they will be removed.\\\", \\\"parameters\\\": [\\\"OvercloudControlFlavor\\\", \\\"controllerImage\\\"]}], \\\"conditions\\\": {\\\"server_blacklisted\\\": {\\\"or\\\": [{\\\"equals\\\": [{\\\"get_param\\\": [\\\"DeploymentServerBlacklistDict\\\", {\\\"get_param\\\": \\\"Hostname\\\"}]}, 1]}, {\\\"equals\\\": [{\\\"get_param\\\": [\\\"DeploymentServerBlacklistDict\\\", {\\\"get_param\\\": [\\\"HostnameMap\\\", {\\\"get_param\\\": \\\"Hostname\\\"}]}]}, 1]}]}, \\\"server_not_blacklisted\\\": {\\\"and\\\": [{\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"DeploymentServerBlacklistDict\\\", {\\\"get_param\\\": \\\"Hostname\\\"}]}, 1]}}, {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"DeploymentServerBlacklistDict\\\", {\\\"get_param\\\": [\\\"HostnameMap\\\", {\\\"get_param\\\": \\\"Hostname\\\"}]}]}, 1]}}]}, \\\"deprecated_param_image_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"controllerImage\\\"}, \\\"overcloud-full\\\"]}}, \\\"deprecated_param_flavor_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"OvercloudControlFlavor\\\"}, \\\"baremetal\\\"]}}, \\\"ctlplane_fixed_ip_set\\\": {\\\"or\\\": [{\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"ControllerIPs\\\", \\\"ctlplane\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}, \\\"\\\"]}}, false]}, \\\"Controller_Storage_fixed_ip_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"ControllerIPs\\\", \\\"storage\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}, \\\"\\\"]}}, \\\"Controller_StorageMgmt_fixed_ip_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"ControllerIPs\\\", \\\"storage_mgmt\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}, \\\"\\\"]}}, \\\"Controller_InternalApi_fixed_ip_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"ControllerIPs\\\", \\\"internal_api\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}, \\\"\\\"]}}, \\\"Controller_Tenant_fixed_ip_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"ControllerIPs\\\", \\\"tenant\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}, \\\"\\\"]}}}, \\\"resources\\\": {\\\"Controller\\\": {\\\"type\\\": \\\"OS::TripleO::ControllerServer\\\", \\\"deletion_policy\\\": {\\\"get_param\\\": \\\"ServerDeletionPolicy\\\"}, \\\"properties\\\": {\\\"image\\\": {\\\"if\\\": [\\\"deprecated_param_image_set\\\", {\\\"get_param\\\": \\\"controllerImage\\\"}, {\\\"get_param\\\": \\\"ControllerImage\\\"}]}, \\\"image_update_policy\\\": {\\\"get_param\\\": \\\"ImageUpdatePolicy\\\"}, \\\"flavor\\\": {\\\"if\\\": [\\\"deprecated_param_flavor_set\\\", {\\\"get_param\\\": \\\"OvercloudControlFlavor\\\"}, {\\\"get_param\\\": \\\"OvercloudControllerFlavor\\\"}]}, \\\"key_name\\\": {\\\"get_param\\\": \\\"KeyName\\\"}, \\\"networks\\\": [{\\\"if\\\": [\\\"ctlplane_fixed_ip_set\\\", {\\\"network\\\": \\\"ctlplane\\\", \\\"subnet\\\": {\\\"get_param\\\": \\\"ControllerControlPlaneSubnet\\\"}, \\\"fixed_ip\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"$.data.where(not isEmpty($)).first()\\\", \\\"data\\\": [{\\\"get_param\\\": [\\\"ControllerIPs\\\", \\\"ctlplane\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}]}}}, {\\\"network\\\": \\\"ctlplane\\\", \\\"subnet\\\": {\\\"get_param\\\": \\\"ControllerControlPlaneSubnet\\\"}}]}], \\\"user_data_format\\\": \\\"SOFTWARE_CONFIG\\\", \\\"user_data\\\": {\\\"get_param\\\": \\\"UserData\\\"}, \\\"name\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"$.data.hostname_map.get($.data.hostname, $.data.hostname).toLower()\\\", \\\"data\\\": {\\\"hostname\\\": {\\\"get_param\\\": \\\"Hostname\\\"}, \\\"hostname_map\\\": {\\\"get_param\\\": \\\"HostnameMap\\\"}}}}, \\\"software_config_transport\\\": {\\\"get_param\\\": \\\"SoftwareConfigTransport\\\"}, \\\"metadata\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"ServerMetadata\\\"}, {\\\"get_param\\\": \\\"ControllerServerMetadata\\\"}, {\\\"get_param\\\": \\\"ServiceMetadataSettings\\\"}]}, \\\"scheduler_hints\\\": {\\\"get_param\\\": \\\"ControllerSchedulerHints\\\"}}}, \\\"StoragePort\\\": {\\\"type\\\": \\\"OS::TripleO::Controller::Ports::StoragePort\\\", \\\"properties\\\": {\\\"PortName\\\": {\\\"list_join\\\": [\\\"_\\\", [{\\\"get_attr\\\": [\\\"Controller\\\", \\\"name\\\"]}, \\\"Storage\\\"]]}, \\\"DnsName\\\": {\\\"get_attr\\\": [\\\"Controller\\\", \\\"name\\\"]}, \\\"ControlPlaneIP\\\": {\\\"get_attr\\\": [\\\"Controller\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"FixedIPs\\\": {\\\"if\\\": [\\\"Controller_Storage_fixed_ip_set\\\", [{\\\"ip_address\\\": {\\\"get_param\\\": [\\\"ControllerIPs\\\", \\\"storage\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}}], [{\\\"subnet\\\": \\\"storage_subnet\\\"}]]}, \\\"ControlPlaneSubnetCidr\\\": {\\\"str_split\\\": [\\\"/\\\", {\\\"get_attr\\\": [\\\"Controller\\\", \\\"addresses\\\", \\\"ctlplane\\\", 0, \\\"subnets\\\", 0, \\\"cidr\\\"]}, -1]}, \\\"IPPool\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"ControllerIPs\\\"}]}, \\\"NodeIndex\\\": {\\\"get_param\\\": \\\"NodeIndex\\\"}, \\\"Role\\\": \\\"Controller\\\"}}, \\\"StorageMgmtPort\\\": {\\\"type\\\": \\\"OS::TripleO::Controller::Ports::StorageMgmtPort\\\", \\\"properties\\\": {\\\"PortName\\\": {\\\"list_join\\\": [\\\"_\\\", [{\\\"get_attr\\\": [\\\"Controller\\\", \\\"name\\\"]}, \\\"StorageMgmt\\\"]]}, \\\"DnsName\\\": {\\\"get_attr\\\": [\\\"Controller\\\", \\\"name\\\"]}, \\\"ControlPlaneIP\\\": {\\\"get_attr\\\": [\\\"Controller\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"FixedIPs\\\": {\\\"if\\\": [\\\"Controller_StorageMgmt_fixed_ip_set\\\", [{\\\"ip_address\\\": {\\\"get_param\\\": [\\\"ControllerIPs\\\", \\\"storage_mgmt\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}}], [{\\\"subnet\\\": \\\"storage_mgmt_subnet\\\"}]]}, \\\"ControlPlaneSubnetCidr\\\": {\\\"str_split\\\": [\\\"/\\\", {\\\"get_attr\\\": [\\\"Controller\\\", \\\"addresses\\\", \\\"ctlplane\\\", 0, \\\"subnets\\\", 0, \\\"cidr\\\"]}, -1]}, \\\"IPPool\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"ControllerIPs\\\"}]}, \\\"NodeIndex\\\": {\\\"get_param\\\": \\\"NodeIndex\\\"}, \\\"Role\\\": \\\"Controller\\\"}}, \\\"InternalApiPort\\\": {\\\"type\\\": \\\"OS::TripleO::Controller::Ports::InternalApiPort\\\", \\\"properties\\\": {\\\"PortName\\\": {\\\"list_join\\\": [\\\"_\\\", [{\\\"get_attr\\\": [\\\"Controller\\\", \\\"name\\\"]}, \\\"InternalApi\\\"]]}, \\\"DnsName\\\": {\\\"get_attr\\\": [\\\"Controller\\\", \\\"name\\\"]}, \\\"ControlPlaneIP\\\": {\\\"get_attr\\\": [\\\"Controller\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"FixedIPs\\\": {\\\"if\\\": [\\\"Controller_InternalApi_fixed_ip_set\\\", [{\\\"ip_address\\\": {\\\"get_param\\\": [\\\"ControllerIPs\\\", \\\"internal_api\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}}], [{\\\"subnet\\\": \\\"internal_api_subnet\\\"}]]}, \\\"ControlPlaneSubnetCidr\\\": {\\\"str_split\\\": [\\\"/\\\", {\\\"get_attr\\\": [\\\"Controller\\\", \\\"addresses\\\", \\\"ctlplane\\\", 0, \\\"subnets\\\", 0, \\\"cidr\\\"]}, -1]}, \\\"IPPool\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"ControllerIPs\\\"}]}, \\\"NodeIndex\\\": {\\\"get_param\\\": \\\"NodeIndex\\\"}, \\\"Role\\\": \\\"Controller\\\"}}, \\\"TenantPort\\\": {\\\"type\\\": \\\"OS::TripleO::Controller::Ports::TenantPort\\\", \\\"properties\\\": {\\\"PortName\\\": {\\\"list_join\\\": [\\\"_\\\", [{\\\"get_attr\\\": [\\\"Controller\\\", \\\"name\\\"]}, \\\"Tenant\\\"]]}, \\\"DnsName\\\": {\\\"get_attr\\\": [\\\"Controller\\\", \\\"name\\\"]}, \\\"ControlPlaneIP\\\": {\\\"get_attr\\\": [\\\"Controller\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"FixedIPs\\\": {\\\"if\\\": [\\\"Controller_Tenant_fixed_ip_set\\\", [{\\\"ip_address\\\": {\\\"get_param\\\": [\\\"ControllerIPs\\\", \\\"tenant\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}}], [{\\\"subnet\\\": \\\"tenant_subnet\\\"}]]}, \\\"ControlPlaneSubnetCidr\\\": {\\\"str_split\\\": [\\\"/\\\", {\\\"get_attr\\\": [\\\"Controller\\\", \\\"addresses\\\", \\\"ctlplane\\\", 0, \\\"subnets\\\", 0, \\\"cidr\\\"]}, -1]}, \\\"IPPool\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"ControllerIPs\\\"}]}, \\\"NodeIndex\\\": {\\\"get_param\\\": \\\"NodeIndex\\\"}, \\\"Role\\\": \\\"Controller\\\"}}, \\\"NetIpMap\\\": {\\\"type\\\": \\\"OS::TripleO::Network::Ports::NetIpMap\\\", \\\"properties\\\": {\\\"ControlPlaneIp\\\": {\\\"get_attr\\\": [\\\"Controller\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"ControlPlaneSubnetCidr\\\": {\\\"str_split\\\": [\\\"/\\\", {\\\"get_attr\\\": [\\\"Controller\\\", \\\"addresses\\\", \\\"ctlplane\\\", 0, \\\"subnets\\\", 0, \\\"cidr\\\"]}, -1]}, \\\"StorageIp\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address\\\"]}, \\\"StorageIpSubnet\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_subnet\\\"]}, \\\"StorageIpUri\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address_uri\\\"]}, \\\"StorageMgmtIp\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_address\\\"]}, \\\"StorageMgmtIpSubnet\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_subnet\\\"]}, \\\"StorageMgmtIpUri\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_address_uri\\\"]}, \\\"InternalApiIp\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address\\\"]}, \\\"InternalApiIpSubnet\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_subnet\\\"]}, \\\"InternalApiIpUri\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address_uri\\\"]}, \\\"TenantIp\\\": {\\\"get_attr\\\": [\\\"TenantPort\\\", \\\"ip_address\\\"]}, \\\"TenantIpSubnet\\\": {\\\"get_attr\\\": [\\\"TenantPort\\\", \\\"ip_subnet\\\"]}, \\\"TenantIpUri\\\": {\\\"get_attr\\\": [\\\"TenantPort\\\", \\\"ip_address_uri\\\"]}}}, \\\"NetHostMap\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"storage\\\": {\\\"fqdn\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"Controller\\\", \\\"name\\\"]}, \\\"storage\\\", {\\\"get_param\\\": \\\"CloudDomain\\\"}]]}, \\\"short\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"Controller\\\", \\\"name\\\"]}, \\\"storage\\\"]]}}, \\\"storage_mgmt\\\": {\\\"fqdn\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"Controller\\\", \\\"name\\\"]}, \\\"storagemgmt\\\", {\\\"get_param\\\": \\\"CloudDomain\\\"}]]}, \\\"short\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"Controller\\\", \\\"name\\\"]}, \\\"storagemgmt\\\"]]}}, \\\"internal_api\\\": {\\\"fqdn\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"Controller\\\", \\\"name\\\"]}, \\\"internalapi\\\", {\\\"get_param\\\": \\\"CloudDomain\\\"}]]}, \\\"short\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"Controller\\\", \\\"name\\\"]}, \\\"internalapi\\\"]]}}, \\\"tenant\\\": {\\\"fqdn\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"Controller\\\", \\\"name\\\"]}, \\\"tenant\\\", {\\\"get_param\\\": \\\"CloudDomain\\\"}]]}, \\\"short\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"Controller\\\", \\\"name\\\"]}, \\\"tenant\\\"]]}}, \\\"ctlplane\\\": {\\\"fqdn\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"Controller\\\", \\\"name\\\"]}, \\\"ctlplane\\\", {\\\"get_param\\\": \\\"CloudDomain\\\"}]]}, \\\"short\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"Controller\\\", \\\"name\\\"]}, \\\"ctlplane\\\"]]}}, \\\"canonical\\\": {\\\"fqdn\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"Controller\\\", \\\"name\\\"]}, {\\\"get_param\\\": \\\"CloudDomain\\\"}]]}, \\\"short\\\": [{\\\"get_attr\\\": [\\\"Controller\\\", \\\"name\\\"]}]}}}}, \\\"PreNetworkConfig\\\": {\\\"type\\\": \\\"OS::TripleO::Controller::PreNetworkConfig\\\", \\\"condition\\\": \\\"server_not_blacklisted\\\", \\\"properties\\\": {\\\"server\\\": {\\\"get_resource\\\": \\\"Controller\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}, \\\"ServiceNames\\\": {\\\"get_param\\\": \\\"ServiceNames\\\"}, \\\"deployment_actions\\\": {\\\"get_attr\\\": [\\\"DeploymentActions\\\", \\\"value\\\"]}}}, \\\"NodeTLSCAData\\\": {\\\"type\\\": \\\"OS::TripleO::NodeTLSCAData\\\", \\\"properties\\\": {\\\"server\\\": {\\\"get_resource\\\": \\\"Controller\\\"}}}, \\\"ControllerExtraConfigPre\\\": {\\\"type\\\": \\\"OS::TripleO::ControllerExtraConfigPre\\\", \\\"condition\\\": \\\"server_not_blacklisted\\\", \\\"properties\\\": {\\\"server\\\": {\\\"get_resource\\\": \\\"Controller\\\"}}}, \\\"NodeExtraConfig\\\": {\\\"depends_on\\\": [\\\"ControllerExtraConfigPre\\\", \\\"NodeTLSCAData\\\"], \\\"type\\\": \\\"OS::TripleO::NodeExtraConfig\\\", \\\"condition\\\": \\\"server_not_blacklisted\\\", \\\"properties\\\": {\\\"server\\\": {\\\"get_resource\\\": \\\"Controller\\\"}}}, \\\"DeploymentActions\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"value\\\": {\\\"if\\\": [\\\"server_not_blacklisted\\\", [\\\"CREATE\\\", \\\"UPDATE\\\"], []]}}}, \\\"ControllerAnsibleHostVars\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"fqdn_storage\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage\\\", \\\"fqdn\\\"]}, \\\"fqdn_storage_mgmt\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage_mgmt\\\", \\\"fqdn\\\"]}, \\\"fqdn_internal_api\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"internal_api\\\", \\\"fqdn\\\"]}, \\\"fqdn_tenant\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"tenant\\\", \\\"fqdn\\\"]}, \\\"fqdn_ctlplane\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"ctlplane\\\", \\\"fqdn\\\"]}, \\\"fqdn_canonical\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"canonical\\\", \\\"fqdn\\\"]}, \\\"hostname_resolve_network\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"ControllerHostnameResolveNetwork\\\"]}}}}}, \\\"outputs\\\": {\\\"ansible_host_vars_map\\\": {\\\"description\\\": \\\"Map of Ansible variables specific per host.\\\\nThis map is used to construct the AnsibleHostVarsMap output for the\\\\nansible vars per host in config-download.\\\\n\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"host\\\": {\\\"get_attr\\\": [\\\"ControllerAnsibleHostVars\\\", \\\"value\\\"]}}, {\\\"keys\\\": {\\\"host\\\": {\\\"get_attr\\\": [\\\"Controller\\\", \\\"name\\\"]}}}]}}, \\\"ip_address\\\": {\\\"description\\\": \\\"IP address of the server in the ctlplane network\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"Controller\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}}, \\\"blacklist_ip_address\\\": {\\\"description\\\": \\\"IP address of the server if the server is blacklisted, otherwise this output will be an empty string\\\", \\\"value\\\": {\\\"if\\\": [\\\"server_blacklisted\\\", {\\\"get_attr\\\": [\\\"Controller\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"\\\"]}}, \\\"blacklist_hostname\\\": {\\\"description\\\": \\\"Hostname of the server if the server is blacklisted, otherwise this output will be an empty string\\\", \\\"value\\\": {\\\"if\\\": [\\\"server_blacklisted\\\", {\\\"get_attr\\\": [\\\"Controller\\\", \\\"name\\\"]}, \\\"\\\"]}}, \\\"hostname\\\": {\\\"description\\\": \\\"Hostname of the server\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"Controller\\\", \\\"name\\\"]}}, \\\"hostname_map\\\": {\\\"description\\\": \\\"Mapping of network names to hostnames\\\", \\\"value\\\": {\\\"storage\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage\\\", \\\"fqdn\\\"]}, \\\"storage_mgmt\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage_mgmt\\\", \\\"fqdn\\\"]}, \\\"internal_api\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"internal_api\\\", \\\"fqdn\\\"]}, \\\"tenant\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"tenant\\\", \\\"fqdn\\\"]}, \\\"ctlplane\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"ctlplane\\\", \\\"fqdn\\\"]}, \\\"canonical\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"canonical\\\", \\\"fqdn\\\"]}}}, \\\"hosts_entry\\\": {\\\"value\\\": [{\\\"str_replace\\\": {\\\"template\\\": \\\"PRIMARYIP PRIMARYHOST.DOMAIN PRIMARYHOST\\\", \\\"params\\\": {\\\"PRIMARYIP\\\": {\\\"get_attr\\\": [\\\"NetIpMap\\\", \\\"net_ip_map\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"ControllerHostnameResolveNetwork\\\"]}]}, \\\"DOMAIN\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"PRIMARYHOST\\\": {\\\"get_attr\\\": [\\\"Controller\\\", \\\"name\\\"]}}}}, {\\\"str_replace\\\": {\\\"template\\\": \\\"StorageIP StorageHOST.DOMAIN StorageHOST\\\", \\\"params\\\": {\\\"DOMAIN\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"StorageIP\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address\\\"]}, \\\"StorageHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage\\\", \\\"short\\\"]}, \\\"StorageMgmtIP\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_address\\\"]}, \\\"StorageMgmtHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage_mgmt\\\", \\\"short\\\"]}, \\\"InternalApiIP\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address\\\"]}, \\\"InternalApiHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"internal_api\\\", \\\"short\\\"]}, \\\"TenantIP\\\": {\\\"get_attr\\\": [\\\"TenantPort\\\", \\\"ip_address\\\"]}, \\\"TenantHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"tenant\\\", \\\"short\\\"]}}}}, {\\\"str_replace\\\": {\\\"template\\\": \\\"StorageMgmtIP StorageMgmtHOST.DOMAIN StorageMgmtHOST\\\", \\\"params\\\": {\\\"DOMAIN\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"StorageIP\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address\\\"]}, \\\"StorageHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage\\\", \\\"short\\\"]}, \\\"StorageMgmtIP\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_address\\\"]}, \\\"StorageMgmtHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage_mgmt\\\", \\\"short\\\"]}, \\\"InternalApiIP\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address\\\"]}, \\\"InternalApiHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"internal_api\\\", \\\"short\\\"]}, \\\"TenantIP\\\": {\\\"get_attr\\\": [\\\"TenantPort\\\", \\\"ip_address\\\"]}, \\\"TenantHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"tenant\\\", \\\"short\\\"]}}}}, {\\\"str_replace\\\": {\\\"template\\\": \\\"InternalApiIP InternalApiHOST.DOMAIN InternalApiHOST\\\", \\\"params\\\": {\\\"DOMAIN\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"StorageIP\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address\\\"]}, \\\"StorageHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage\\\", \\\"short\\\"]}, \\\"StorageMgmtIP\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_address\\\"]}, \\\"StorageMgmtHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage_mgmt\\\", \\\"short\\\"]}, \\\"InternalApiIP\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address\\\"]}, \\\"InternalApiHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"internal_api\\\", \\\"short\\\"]}, \\\"TenantIP\\\": {\\\"get_attr\\\": [\\\"TenantPort\\\", \\\"ip_address\\\"]}, \\\"TenantHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"tenant\\\", \\\"short\\\"]}}}}, {\\\"str_replace\\\": {\\\"template\\\": \\\"TenantIP TenantHOST.DOMAIN TenantHOST\\\", \\\"params\\\": {\\\"DOMAIN\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"StorageIP\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address\\\"]}, \\\"StorageHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage\\\", \\\"short\\\"]}, \\\"StorageMgmtIP\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_address\\\"]}, \\\"StorageMgmtHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage_mgmt\\\", \\\"short\\\"]}, \\\"InternalApiIP\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address\\\"]}, \\\"InternalApiHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"internal_api\\\", \\\"short\\\"]}, \\\"TenantIP\\\": {\\\"get_attr\\\": [\\\"TenantPort\\\", \\\"ip_address\\\"]}, \\\"TenantHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"tenant\\\", \\\"short\\\"]}}}}, {\\\"str_replace\\\": {\\\"template\\\": \\\"CTLPLANEIP CTLPLANEHOST.DOMAIN CTLPLANEHOST\\\", \\\"params\\\": {\\\"DOMAIN\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"CTLPLANEIP\\\": {\\\"get_attr\\\": [\\\"Controller\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"CTLPLANEHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"ctlplane\\\", \\\"short\\\"]}}}}]}, \\\"nova_server_resource\\\": {\\\"description\\\": \\\"Heat resource handle for Controller server\\\", \\\"value\\\": {\\\"get_resource\\\": \\\"Controller\\\"}, \\\"condition\\\": \\\"server_not_blacklisted\\\"}, \\\"deployed_server_port_map\\\": {\\\"description\\\": \\\"Map of Heat created hostname of the server to ip address. This is the\\\\nhostname before it has been mapped with the HostnameMap parameter, and\\\\nthe IP address from the ctlplane network. This map can be used to construct\\\\nthe DeployedServerPortMap parameter when using split-stack.\\\\n\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"hostname\\\": {\\\"fixed_ips\\\": [{\\\"ip_address\\\": {\\\"get_attr\\\": [\\\"Controller\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}}], \\\"subnets\\\": [{\\\"cidr\\\": {\\\"get_attr\\\": [\\\"Controller\\\", \\\"addresses\\\", \\\"ctlplane\\\", 0, \\\"subnets\\\", 0, \\\"cidr\\\"]}}]}}, {\\\"keys\\\": {\\\"hostname\\\": {\\\"list_join\\\": [\\\"-\\\", [{\\\"get_param\\\": \\\"Hostname\\\"}, \\\"ctlplane\\\"]]}}}]}}, \\\"storage_ip_address\\\": {\\\"description\\\": \\\"IP address of the server in the Storage network\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address\\\"]}}, \\\"storage_mgmt_ip_address\\\": {\\\"description\\\": \\\"IP address of the server in the StorageMgmt network\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_address\\\"]}}, \\\"internal_api_ip_address\\\": {\\\"description\\\": \\\"IP address of the server in the InternalApi network\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address\\\"]}}, \\\"tenant_ip_address\\\": {\\\"description\\\": \\\"IP address of the server in the Tenant network\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"TenantPort\\\", \\\"ip_address\\\"]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Noop Extra Pre-Deployment Config\\\", \\\"parameters\\\": {\\\"server\\\": {\\\"type\\\": \\\"string\\\"}}, \\\"outputs\\\": {\\\"deploy_stdout\\\": {\\\"value\\\": \\\"None\\\"}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Returns the control plane port (provisioning network) as the ip_address.\\\\n\\\", \\\"parameters\\\": {\\\"ServiceName\\\": {\\\"description\\\": \\\"Name of the service to lookup\\\", \\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneIP\\\": {\\\"description\\\": \\\"IP address on the control plane\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneNetwork\\\": {\\\"description\\\": \\\"The name of the undercloud Neutron control plane\\\", \\\"default\\\": \\\"ctlplane\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneSubnet\\\": {\\\"description\\\": \\\"The name of the undercloud Neutron control plane subnet\\\", \\\"default\\\": \\\"ctlplane-subnet\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneMtu\\\": {\\\"default\\\": 1500, \\\"description\\\": \\\"The maximum transmission unit (MTU) size(in bytes) that is guaranteed to pass through the data path of the segments in the network. (The parameter is automatically resolved from the ctlplane network\'s mtu attribute.)\\\", \\\"type\\\": \\\"number\\\"}, \\\"PortName\\\": {\\\"description\\\": \\\"Name of the port\\\", \\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"DnsName\\\": {\\\"description\\\": \\\"DNS name of the port\\\", \\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"NetworkName\\\": {\\\"description\\\": \\\"Name of the network where the VIP will be created\\\", \\\"default\\\": \\\"ctlplane\\\", \\\"type\\\": \\\"string\\\"}, \\\"FixedIPs\\\": {\\\"description\\\": \\\"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\\\n\\\", \\\"default\\\": [], \\\"type\\\": \\\"json\\\"}, \\\"ControlPlaneSubnetCidr\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"IPPool\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"A network mapped list of IPs\\\", \\\"type\\\": \\\"json\\\"}, \\\"NodeIndex\\\": {\\\"default\\\": 0, \\\"description\\\": \\\"Index of the IP to get from Pool\\\", \\\"type\\\": \\\"number\\\"}, \\\"IsVirtualIP\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"DefaultRoute\\\": {\\\"description\\\": \\\"Whether this interface is used for the default route\\\\n\\\", \\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"Role\\\": {\\\"description\\\": \\\"The TripleO Role Name\\\\n\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\"}}, \\\"outputs\\\": {\\\"ip_address\\\": {\\\"description\\\": \\\"pass thru network IP\\\", \\\"value\\\": {\\\"get_param\\\": \\\"ControlPlaneIP\\\"}}, \\\"ip_address_uri\\\": {\\\"description\\\": \\\"pass thru network IP (for compatibility with vip_v6.yaml)\\\", \\\"value\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"make_url\\\": {\\\"host\\\": {\\\"get_param\\\": \\\"ControlPlaneIP\\\"}}}, \\\"params\\\": {\\\"//\\\": \\\"\\\"}}}}, \\\"ip_subnet\\\": {\\\"description\\\": \\\"IP/Subnet CIDR for the pass thru network IP\\\", \\\"value\\\": {\\\"list_join\\\": [\\\"\\\", [{\\\"get_param\\\": \\\"ControlPlaneIP\\\"}, \\\"/\\\", {\\\"get_param\\\": \\\"ControlPlaneSubnetCidr\\\"}]]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack CellController node configured by Puppet\\\", \\\"parameters\\\": {\\\"OvercloudControlFlavor\\\": {\\\"description\\\": \\\"DEPRECATED Use OvercloudCellControllerFlavor instead.\\\", \\\"default\\\": \\\"baremetal\\\", \\\"type\\\": \\\"string\\\"}, \\\"OvercloudCellControllerFlavor\\\": {\\\"description\\\": \\\"Flavor for the CellController node.\\\", \\\"default\\\": \\\"baremetal\\\", \\\"type\\\": \\\"string\\\"}, \\\"controllerImage\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"overcloud-full\\\", \\\"description\\\": \\\"DEPRECATED Use CellControllerImage instead\\\"}, \\\"CellControllerImage\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"overcloud-full\\\", \\\"description\\\": \\\"The disk image file to use for the role.\\\"}, \\\"ImageUpdatePolicy\\\": {\\\"default\\\": \\\"REBUILD_PRESERVE_EPHEMERAL\\\", \\\"description\\\": \\\"What policy to use when reconstructing instances. REBUILD for rebuilds, REBUILD_PRESERVE_EPHEMERAL to preserve /mnt.\\\", \\\"type\\\": \\\"string\\\"}, \\\"KeyName\\\": {\\\"description\\\": \\\"Name of an existing Nova key pair to enable SSH access to the instances\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"default\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"UpdateIdentifier\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Setting to a previously unused value during stack-update will trigger package update on all nodes\\\\n\\\"}, \\\"Hostname\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\"}, \\\"HostnameMap\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {}, \\\"description\\\": \\\"Optional mapping to override hostnames\\\"}, \\\"CellControllerIPs\\\": {\\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}, \\\"SoftwareConfigTransport\\\": {\\\"default\\\": \\\"POLL_SERVER_CFN\\\", \\\"description\\\": \\\"How the server should receive the metadata required for software configuration.\\\\n\\\", \\\"type\\\": \\\"string\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"POLL_SERVER_CFN\\\", \\\"POLL_SERVER_HEAT\\\", \\\"POLL_TEMP_URL\\\", \\\"ZAQAR_MESSAGE\\\"]}]}, \\\"CloudDomain\\\": {\\\"default\\\": \\\"localdomain\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"The DNS domain used for the hosts. This must match the overcloud_domain_name configured on the undercloud.\\\\n\\\"}, \\\"CellControllerServerMetadata\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API. This option is role-specific and is merged with the values given to the ServerMetadata parameter.\\\\n\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServerMetadata\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API. This applies to all roles and is merged with a role-specific metadata parameter.\\\\n\\\", \\\"type\\\": \\\"json\\\"}, \\\"CellControllerSchedulerHints\\\": {\\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"Optional scheduler hints to pass to nova\\\", \\\"default\\\": {}}, \\\"NodeIndex\\\": {\\\"type\\\": \\\"number\\\", \\\"default\\\": 0}, \\\"ServiceNames\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": []}, \\\"MonitoringSubscriptions\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": []}, \\\"ServiceMetadataSettings\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {}}, \\\"OVNBridgeMappings\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": []}, \\\"ConfigCommand\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Command which will be run whenever configuration data changes\\\", \\\"default\\\": \\\"os-refresh-config --timeout 14400\\\"}, \\\"ConfigCollectSplay\\\": {\\\"type\\\": \\\"number\\\", \\\"default\\\": 30, \\\"description\\\": \\\"Maximum amount of time to possibly to delay configuration collection\\\\npolling. Defaults to 30 seconds. Set to 0 to disable it which will cause\\\\nthe configuration collection to occur as soon as the collection process\\\\nstarts.  This setting is used to prevent the configuration collection\\\\nprocesses from polling all at the exact same time.\\\\n\\\"}, \\\"UpgradeInitCommand\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Command or script snippet to run on all overcloud nodes to\\\\ninitialize the upgrade process. E.g. a repository switch.\\\\n\\\", \\\"default\\\": \\\"\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"UpgradeInitCommonCommand\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Common commands required by the upgrades process. This should not\\\\nnormally be modified by the operator and is set and unset in the\\\\nmajor-upgrade-composable-steps.yaml and major-upgrade-converge.yaml\\\\nenvironment files.\\\\n\\\", \\\"default\\\": \\\"\\\"}, \\\"DeploymentServerBlacklistDict\\\": {\\\"default\\\": {}, \\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"Map of server hostnames to blacklist from any triggered deployments. If the value is 1, the server will be blacklisted. This parameter is generated from the parent template.\\\\n\\\"}, \\\"RoleParameters\\\": {\\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"default\\\": {}}, \\\"CellControllerControlPlaneSubnet\\\": {\\\"default\\\": \\\"ctlplane-subnet\\\", \\\"description\\\": \\\"Name of the subnet on ctlplane network for this role.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneSubnetCidr\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"ServerDeletionPolicy\\\": {\\\"description\\\": \\\"Whether to retain or delete servers on deletion of the stack\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"delete\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"delete\\\", \\\"retain\\\"]}]}, \\\"UserData\\\": {\\\"type\\\": \\\"string\\\"}}, \\\"parameter_groups\\\": [{\\\"label\\\": \\\"deprecated\\\", \\\"description\\\": \\\"Do not use deprecated params, they will be removed.\\\", \\\"parameters\\\": [\\\"OvercloudControlFlavor\\\", \\\"controllerImage\\\"]}], \\\"conditions\\\": {\\\"server_blacklisted\\\": {\\\"or\\\": [{\\\"equals\\\": [{\\\"get_param\\\": [\\\"DeploymentServerBlacklistDict\\\", {\\\"get_param\\\": \\\"Hostname\\\"}]}, 1]}, {\\\"equals\\\": [{\\\"get_param\\\": [\\\"DeploymentServerBlacklistDict\\\", {\\\"get_param\\\": [\\\"HostnameMap\\\", {\\\"get_param\\\": \\\"Hostname\\\"}]}]}, 1]}]}, \\\"server_not_blacklisted\\\": {\\\"and\\\": [{\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"DeploymentServerBlacklistDict\\\", {\\\"get_param\\\": \\\"Hostname\\\"}]}, 1]}}, {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"DeploymentServerBlacklistDict\\\", {\\\"get_param\\\": [\\\"HostnameMap\\\", {\\\"get_param\\\": \\\"Hostname\\\"}]}]}, 1]}}]}, \\\"deprecated_param_image_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"controllerImage\\\"}, \\\"overcloud-full\\\"]}}, \\\"deprecated_param_flavor_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"OvercloudControlFlavor\\\"}, \\\"baremetal\\\"]}}, \\\"ctlplane_fixed_ip_set\\\": {\\\"or\\\": [{\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"CellControllerIPs\\\", \\\"ctlplane\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}, \\\"\\\"]}}, false]}, \\\"CellController_Storage_fixed_ip_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"CellControllerIPs\\\", \\\"storage\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}, \\\"\\\"]}}, \\\"CellController_StorageMgmt_fixed_ip_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"CellControllerIPs\\\", \\\"storage_mgmt\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}, \\\"\\\"]}}, \\\"CellController_InternalApi_fixed_ip_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"CellControllerIPs\\\", \\\"internal_api\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}, \\\"\\\"]}}, \\\"CellController_Tenant_fixed_ip_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"CellControllerIPs\\\", \\\"tenant\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}, \\\"\\\"]}}}, \\\"resources\\\": {\\\"CellController\\\": {\\\"type\\\": \\\"OS::TripleO::CellControllerServer\\\", \\\"deletion_policy\\\": {\\\"get_param\\\": \\\"ServerDeletionPolicy\\\"}, \\\"properties\\\": {\\\"image\\\": {\\\"if\\\": [\\\"deprecated_param_image_set\\\", {\\\"get_param\\\": \\\"controllerImage\\\"}, {\\\"get_param\\\": \\\"CellControllerImage\\\"}]}, \\\"image_update_policy\\\": {\\\"get_param\\\": \\\"ImageUpdatePolicy\\\"}, \\\"flavor\\\": {\\\"if\\\": [\\\"deprecated_param_flavor_set\\\", {\\\"get_param\\\": \\\"OvercloudControlFlavor\\\"}, {\\\"get_param\\\": \\\"OvercloudCellControllerFlavor\\\"}]}, \\\"key_name\\\": {\\\"get_param\\\": \\\"KeyName\\\"}, \\\"networks\\\": [{\\\"if\\\": [\\\"ctlplane_fixed_ip_set\\\", {\\\"network\\\": \\\"ctlplane\\\", \\\"subnet\\\": {\\\"get_param\\\": \\\"CellControllerControlPlaneSubnet\\\"}, \\\"fixed_ip\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"$.data.where(not isEmpty($)).first()\\\", \\\"data\\\": [{\\\"get_param\\\": [\\\"CellControllerIPs\\\", \\\"ctlplane\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}]}}}, {\\\"network\\\": \\\"ctlplane\\\", \\\"subnet\\\": {\\\"get_param\\\": \\\"CellControllerControlPlaneSubnet\\\"}}]}], \\\"user_data_format\\\": \\\"SOFTWARE_CONFIG\\\", \\\"user_data\\\": {\\\"get_param\\\": \\\"UserData\\\"}, \\\"name\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"$.data.hostname_map.get($.data.hostname, $.data.hostname).toLower()\\\", \\\"data\\\": {\\\"hostname\\\": {\\\"get_param\\\": \\\"Hostname\\\"}, \\\"hostname_map\\\": {\\\"get_param\\\": \\\"HostnameMap\\\"}}}}, \\\"software_config_transport\\\": {\\\"get_param\\\": \\\"SoftwareConfigTransport\\\"}, \\\"metadata\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"ServerMetadata\\\"}, {\\\"get_param\\\": \\\"CellControllerServerMetadata\\\"}, {\\\"get_param\\\": \\\"ServiceMetadataSettings\\\"}]}, \\\"scheduler_hints\\\": {\\\"get_param\\\": \\\"CellControllerSchedulerHints\\\"}}}, \\\"StoragePort\\\": {\\\"type\\\": \\\"OS::TripleO::CellController::Ports::StoragePort\\\", \\\"properties\\\": {\\\"PortName\\\": {\\\"list_join\\\": [\\\"_\\\", [{\\\"get_attr\\\": [\\\"CellController\\\", \\\"name\\\"]}, \\\"Storage\\\"]]}, \\\"DnsName\\\": {\\\"get_attr\\\": [\\\"CellController\\\", \\\"name\\\"]}, \\\"ControlPlaneIP\\\": {\\\"get_attr\\\": [\\\"CellController\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"FixedIPs\\\": {\\\"if\\\": [\\\"CellController_Storage_fixed_ip_set\\\", [{\\\"ip_address\\\": {\\\"get_param\\\": [\\\"CellControllerIPs\\\", \\\"storage\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}}], [{\\\"subnet\\\": \\\"storage_subnet\\\"}]]}, \\\"ControlPlaneSubnetCidr\\\": {\\\"str_split\\\": [\\\"/\\\", {\\\"get_attr\\\": [\\\"CellController\\\", \\\"addresses\\\", \\\"ctlplane\\\", 0, \\\"subnets\\\", 0, \\\"cidr\\\"]}, -1]}, \\\"IPPool\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"CellControllerIPs\\\"}]}, \\\"NodeIndex\\\": {\\\"get_param\\\": \\\"NodeIndex\\\"}, \\\"Role\\\": \\\"CellController\\\"}}, \\\"StorageMgmtPort\\\": {\\\"type\\\": \\\"OS::TripleO::CellController::Ports::StorageMgmtPort\\\", \\\"properties\\\": {\\\"PortName\\\": {\\\"list_join\\\": [\\\"_\\\", [{\\\"get_attr\\\": [\\\"CellController\\\", \\\"name\\\"]}, \\\"StorageMgmt\\\"]]}, \\\"DnsName\\\": {\\\"get_attr\\\": [\\\"CellController\\\", \\\"name\\\"]}, \\\"ControlPlaneIP\\\": {\\\"get_attr\\\": [\\\"CellController\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"FixedIPs\\\": {\\\"if\\\": [\\\"CellController_StorageMgmt_fixed_ip_set\\\", [{\\\"ip_address\\\": {\\\"get_param\\\": [\\\"CellControllerIPs\\\", \\\"storage_mgmt\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}}], [{\\\"subnet\\\": \\\"storage_mgmt_subnet\\\"}]]}, \\\"ControlPlaneSubnetCidr\\\": {\\\"str_split\\\": [\\\"/\\\", {\\\"get_attr\\\": [\\\"CellController\\\", \\\"addresses\\\", \\\"ctlplane\\\", 0, \\\"subnets\\\", 0, \\\"cidr\\\"]}, -1]}, \\\"IPPool\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"CellControllerIPs\\\"}]}, \\\"NodeIndex\\\": {\\\"get_param\\\": \\\"NodeIndex\\\"}, \\\"Role\\\": \\\"CellController\\\"}}, \\\"InternalApiPort\\\": {\\\"type\\\": \\\"OS::TripleO::CellController::Ports::InternalApiPort\\\", \\\"properties\\\": {\\\"PortName\\\": {\\\"list_join\\\": [\\\"_\\\", [{\\\"get_attr\\\": [\\\"CellController\\\", \\\"name\\\"]}, \\\"InternalApi\\\"]]}, \\\"DnsName\\\": {\\\"get_attr\\\": [\\\"CellController\\\", \\\"name\\\"]}, \\\"ControlPlaneIP\\\": {\\\"get_attr\\\": [\\\"CellController\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"FixedIPs\\\": {\\\"if\\\": [\\\"CellController_InternalApi_fixed_ip_set\\\", [{\\\"ip_address\\\": {\\\"get_param\\\": [\\\"CellControllerIPs\\\", \\\"internal_api\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}}], [{\\\"subnet\\\": \\\"internal_api_subnet\\\"}]]}, \\\"ControlPlaneSubnetCidr\\\": {\\\"str_split\\\": [\\\"/\\\", {\\\"get_attr\\\": [\\\"CellController\\\", \\\"addresses\\\", \\\"ctlplane\\\", 0, \\\"subnets\\\", 0, \\\"cidr\\\"]}, -1]}, \\\"IPPool\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"CellControllerIPs\\\"}]}, \\\"NodeIndex\\\": {\\\"get_param\\\": \\\"NodeIndex\\\"}, \\\"Role\\\": \\\"CellController\\\"}}, \\\"TenantPort\\\": {\\\"type\\\": \\\"OS::TripleO::CellController::Ports::TenantPort\\\", \\\"properties\\\": {\\\"PortName\\\": {\\\"list_join\\\": [\\\"_\\\", [{\\\"get_attr\\\": [\\\"CellController\\\", \\\"name\\\"]}, \\\"Tenant\\\"]]}, \\\"DnsName\\\": {\\\"get_attr\\\": [\\\"CellController\\\", \\\"name\\\"]}, \\\"ControlPlaneIP\\\": {\\\"get_attr\\\": [\\\"CellController\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"FixedIPs\\\": {\\\"if\\\": [\\\"CellController_Tenant_fixed_ip_set\\\", [{\\\"ip_address\\\": {\\\"get_param\\\": [\\\"CellControllerIPs\\\", \\\"tenant\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}}], [{\\\"subnet\\\": \\\"tenant_subnet\\\"}]]}, \\\"ControlPlaneSubnetCidr\\\": {\\\"str_split\\\": [\\\"/\\\", {\\\"get_attr\\\": [\\\"CellController\\\", \\\"addresses\\\", \\\"ctlplane\\\", 0, \\\"subnets\\\", 0, \\\"cidr\\\"]}, -1]}, \\\"IPPool\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"CellControllerIPs\\\"}]}, \\\"NodeIndex\\\": {\\\"get_param\\\": \\\"NodeIndex\\\"}, \\\"Role\\\": \\\"CellController\\\"}}, \\\"NetIpMap\\\": {\\\"type\\\": \\\"OS::TripleO::Network::Ports::NetIpMap\\\", \\\"properties\\\": {\\\"ControlPlaneIp\\\": {\\\"get_attr\\\": [\\\"CellController\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"ControlPlaneSubnetCidr\\\": {\\\"str_split\\\": [\\\"/\\\", {\\\"get_attr\\\": [\\\"CellController\\\", \\\"addresses\\\", \\\"ctlplane\\\", 0, \\\"subnets\\\", 0, \\\"cidr\\\"]}, -1]}, \\\"StorageIp\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address\\\"]}, \\\"StorageIpSubnet\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_subnet\\\"]}, \\\"StorageIpUri\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address_uri\\\"]}, \\\"StorageMgmtIp\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_address\\\"]}, \\\"StorageMgmtIpSubnet\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_subnet\\\"]}, \\\"StorageMgmtIpUri\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_address_uri\\\"]}, \\\"InternalApiIp\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address\\\"]}, \\\"InternalApiIpSubnet\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_subnet\\\"]}, \\\"InternalApiIpUri\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address_uri\\\"]}, \\\"TenantIp\\\": {\\\"get_attr\\\": [\\\"TenantPort\\\", \\\"ip_address\\\"]}, \\\"TenantIpSubnet\\\": {\\\"get_attr\\\": [\\\"TenantPort\\\", \\\"ip_subnet\\\"]}, \\\"TenantIpUri\\\": {\\\"get_attr\\\": [\\\"TenantPort\\\", \\\"ip_address_uri\\\"]}}}, \\\"NetHostMap\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"storage\\\": {\\\"fqdn\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"CellController\\\", \\\"name\\\"]}, \\\"storage\\\", {\\\"get_param\\\": \\\"CloudDomain\\\"}]]}, \\\"short\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"CellController\\\", \\\"name\\\"]}, \\\"storage\\\"]]}}, \\\"storage_mgmt\\\": {\\\"fqdn\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"CellController\\\", \\\"name\\\"]}, \\\"storagemgmt\\\", {\\\"get_param\\\": \\\"CloudDomain\\\"}]]}, \\\"short\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"CellController\\\", \\\"name\\\"]}, \\\"storagemgmt\\\"]]}}, \\\"internal_api\\\": {\\\"fqdn\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"CellController\\\", \\\"name\\\"]}, \\\"internalapi\\\", {\\\"get_param\\\": \\\"CloudDomain\\\"}]]}, \\\"short\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"CellController\\\", \\\"name\\\"]}, \\\"internalapi\\\"]]}}, \\\"tenant\\\": {\\\"fqdn\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"CellController\\\", \\\"name\\\"]}, \\\"tenant\\\", {\\\"get_param\\\": \\\"CloudDomain\\\"}]]}, \\\"short\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"CellController\\\", \\\"name\\\"]}, \\\"tenant\\\"]]}}, \\\"ctlplane\\\": {\\\"fqdn\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"CellController\\\", \\\"name\\\"]}, \\\"ctlplane\\\", {\\\"get_param\\\": \\\"CloudDomain\\\"}]]}, \\\"short\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"CellController\\\", \\\"name\\\"]}, \\\"ctlplane\\\"]]}}, \\\"canonical\\\": {\\\"fqdn\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"CellController\\\", \\\"name\\\"]}, {\\\"get_param\\\": \\\"CloudDomain\\\"}]]}, \\\"short\\\": [{\\\"get_attr\\\": [\\\"CellController\\\", \\\"name\\\"]}]}}}}, \\\"PreNetworkConfig\\\": {\\\"type\\\": \\\"OS::TripleO::CellController::PreNetworkConfig\\\", \\\"condition\\\": \\\"server_not_blacklisted\\\", \\\"properties\\\": {\\\"server\\\": {\\\"get_resource\\\": \\\"CellController\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}, \\\"ServiceNames\\\": {\\\"get_param\\\": \\\"ServiceNames\\\"}, \\\"deployment_actions\\\": {\\\"get_attr\\\": [\\\"DeploymentActions\\\", \\\"value\\\"]}}}, \\\"NodeTLSCAData\\\": {\\\"type\\\": \\\"OS::TripleO::NodeTLSCAData\\\", \\\"properties\\\": {\\\"server\\\": {\\\"get_resource\\\": \\\"CellController\\\"}}}, \\\"CellControllerExtraConfigPre\\\": {\\\"type\\\": \\\"OS::TripleO::CellControllerExtraConfigPre\\\", \\\"condition\\\": \\\"server_not_blacklisted\\\", \\\"properties\\\": {\\\"server\\\": {\\\"get_resource\\\": \\\"CellController\\\"}}}, \\\"NodeExtraConfig\\\": {\\\"depends_on\\\": [\\\"CellControllerExtraConfigPre\\\", \\\"NodeTLSCAData\\\"], \\\"type\\\": \\\"OS::TripleO::NodeExtraConfig\\\", \\\"condition\\\": \\\"server_not_blacklisted\\\", \\\"properties\\\": {\\\"server\\\": {\\\"get_resource\\\": \\\"CellController\\\"}}}, \\\"DeploymentActions\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"value\\\": {\\\"if\\\": [\\\"server_not_blacklisted\\\", [\\\"CREATE\\\", \\\"UPDATE\\\"], []]}}}, \\\"CellControllerAnsibleHostVars\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"fqdn_storage\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage\\\", \\\"fqdn\\\"]}, \\\"fqdn_storage_mgmt\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage_mgmt\\\", \\\"fqdn\\\"]}, \\\"fqdn_internal_api\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"internal_api\\\", \\\"fqdn\\\"]}, \\\"fqdn_tenant\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"tenant\\\", \\\"fqdn\\\"]}, \\\"fqdn_ctlplane\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"ctlplane\\\", \\\"fqdn\\\"]}, \\\"fqdn_canonical\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"canonical\\\", \\\"fqdn\\\"]}, \\\"hostname_resolve_network\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CellControllerHostnameResolveNetwork\\\"]}}}}}, \\\"outputs\\\": {\\\"ansible_host_vars_map\\\": {\\\"description\\\": \\\"Map of Ansible variables specific per host.\\\\nThis map is used to construct the AnsibleHostVarsMap output for the\\\\nansible vars per host in config-download.\\\\n\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"host\\\": {\\\"get_attr\\\": [\\\"CellControllerAnsibleHostVars\\\", \\\"value\\\"]}}, {\\\"keys\\\": {\\\"host\\\": {\\\"get_attr\\\": [\\\"CellController\\\", \\\"name\\\"]}}}]}}, \\\"ip_address\\\": {\\\"description\\\": \\\"IP address of the server in the ctlplane network\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"CellController\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}}, \\\"blacklist_ip_address\\\": {\\\"description\\\": \\\"IP address of the server if the server is blacklisted, otherwise this output will be an empty string\\\", \\\"value\\\": {\\\"if\\\": [\\\"server_blacklisted\\\", {\\\"get_attr\\\": [\\\"CellController\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"\\\"]}}, \\\"blacklist_hostname\\\": {\\\"description\\\": \\\"Hostname of the server if the server is blacklisted, otherwise this output will be an empty string\\\", \\\"value\\\": {\\\"if\\\": [\\\"server_blacklisted\\\", {\\\"get_attr\\\": [\\\"CellController\\\", \\\"name\\\"]}, \\\"\\\"]}}, \\\"hostname\\\": {\\\"description\\\": \\\"Hostname of the server\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"CellController\\\", \\\"name\\\"]}}, \\\"hostname_map\\\": {\\\"description\\\": \\\"Mapping of network names to hostnames\\\", \\\"value\\\": {\\\"storage\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage\\\", \\\"fqdn\\\"]}, \\\"storage_mgmt\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage_mgmt\\\", \\\"fqdn\\\"]}, \\\"internal_api\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"internal_api\\\", \\\"fqdn\\\"]}, \\\"tenant\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"tenant\\\", \\\"fqdn\\\"]}, \\\"ctlplane\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"ctlplane\\\", \\\"fqdn\\\"]}, \\\"canonical\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"canonical\\\", \\\"fqdn\\\"]}}}, \\\"hosts_entry\\\": {\\\"value\\\": [{\\\"str_replace\\\": {\\\"template\\\": \\\"PRIMARYIP PRIMARYHOST.DOMAIN PRIMARYHOST\\\", \\\"params\\\": {\\\"PRIMARYIP\\\": {\\\"get_attr\\\": [\\\"NetIpMap\\\", \\\"net_ip_map\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CellControllerHostnameResolveNetwork\\\"]}]}, \\\"DOMAIN\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"PRIMARYHOST\\\": {\\\"get_attr\\\": [\\\"CellController\\\", \\\"name\\\"]}}}}, {\\\"str_replace\\\": {\\\"template\\\": \\\"StorageIP StorageHOST.DOMAIN StorageHOST\\\", \\\"params\\\": {\\\"DOMAIN\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"StorageIP\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address\\\"]}, \\\"StorageHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage\\\", \\\"short\\\"]}, \\\"StorageMgmtIP\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_address\\\"]}, \\\"StorageMgmtHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage_mgmt\\\", \\\"short\\\"]}, \\\"InternalApiIP\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address\\\"]}, \\\"InternalApiHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"internal_api\\\", \\\"short\\\"]}, \\\"TenantIP\\\": {\\\"get_attr\\\": [\\\"TenantPort\\\", \\\"ip_address\\\"]}, \\\"TenantHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"tenant\\\", \\\"short\\\"]}}}}, {\\\"str_replace\\\": {\\\"template\\\": \\\"StorageMgmtIP StorageMgmtHOST.DOMAIN StorageMgmtHOST\\\", \\\"params\\\": {\\\"DOMAIN\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"StorageIP\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address\\\"]}, \\\"StorageHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage\\\", \\\"short\\\"]}, \\\"StorageMgmtIP\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_address\\\"]}, \\\"StorageMgmtHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage_mgmt\\\", \\\"short\\\"]}, \\\"InternalApiIP\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address\\\"]}, \\\"InternalApiHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"internal_api\\\", \\\"short\\\"]}, \\\"TenantIP\\\": {\\\"get_attr\\\": [\\\"TenantPort\\\", \\\"ip_address\\\"]}, \\\"TenantHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"tenant\\\", \\\"short\\\"]}}}}, {\\\"str_replace\\\": {\\\"template\\\": \\\"InternalApiIP InternalApiHOST.DOMAIN InternalApiHOST\\\", \\\"params\\\": {\\\"DOMAIN\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"StorageIP\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address\\\"]}, \\\"StorageHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage\\\", \\\"short\\\"]}, \\\"StorageMgmtIP\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_address\\\"]}, \\\"StorageMgmtHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage_mgmt\\\", \\\"short\\\"]}, \\\"InternalApiIP\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address\\\"]}, \\\"InternalApiHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"internal_api\\\", \\\"short\\\"]}, \\\"TenantIP\\\": {\\\"get_attr\\\": [\\\"TenantPort\\\", \\\"ip_address\\\"]}, \\\"TenantHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"tenant\\\", \\\"short\\\"]}}}}, {\\\"str_replace\\\": {\\\"template\\\": \\\"TenantIP TenantHOST.DOMAIN TenantHOST\\\", \\\"params\\\": {\\\"DOMAIN\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"StorageIP\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address\\\"]}, \\\"StorageHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage\\\", \\\"short\\\"]}, \\\"StorageMgmtIP\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_address\\\"]}, \\\"StorageMgmtHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage_mgmt\\\", \\\"short\\\"]}, \\\"InternalApiIP\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address\\\"]}, \\\"InternalApiHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"internal_api\\\", \\\"short\\\"]}, \\\"TenantIP\\\": {\\\"get_attr\\\": [\\\"TenantPort\\\", \\\"ip_address\\\"]}, \\\"TenantHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"tenant\\\", \\\"short\\\"]}}}}, {\\\"str_replace\\\": {\\\"template\\\": \\\"CTLPLANEIP CTLPLANEHOST.DOMAIN CTLPLANEHOST\\\", \\\"params\\\": {\\\"DOMAIN\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"CTLPLANEIP\\\": {\\\"get_attr\\\": [\\\"CellController\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"CTLPLANEHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"ctlplane\\\", \\\"short\\\"]}}}}]}, \\\"nova_server_resource\\\": {\\\"description\\\": \\\"Heat resource handle for CellController server\\\", \\\"value\\\": {\\\"get_resource\\\": \\\"CellController\\\"}, \\\"condition\\\": \\\"server_not_blacklisted\\\"}, \\\"deployed_server_port_map\\\": {\\\"description\\\": \\\"Map of Heat created hostname of the server to ip address. This is the\\\\nhostname before it has been mapped with the HostnameMap parameter, and\\\\nthe IP address from the ctlplane network. This map can be used to construct\\\\nthe DeployedServerPortMap parameter when using split-stack.\\\\n\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"hostname\\\": {\\\"fixed_ips\\\": [{\\\"ip_address\\\": {\\\"get_attr\\\": [\\\"CellController\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}}], \\\"subnets\\\": [{\\\"cidr\\\": {\\\"get_attr\\\": [\\\"CellController\\\", \\\"addresses\\\", \\\"ctlplane\\\", 0, \\\"subnets\\\", 0, \\\"cidr\\\"]}}]}}, {\\\"keys\\\": {\\\"hostname\\\": {\\\"list_join\\\": [\\\"-\\\", [{\\\"get_param\\\": \\\"Hostname\\\"}, \\\"ctlplane\\\"]]}}}]}}, \\\"storage_ip_address\\\": {\\\"description\\\": \\\"IP address of the server in the Storage network\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address\\\"]}}, \\\"storage_mgmt_ip_address\\\": {\\\"description\\\": \\\"IP address of the server in the StorageMgmt network\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_address\\\"]}}, \\\"internal_api_ip_address\\\": {\\\"description\\\": \\\"IP address of the server in the InternalApi network\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address\\\"]}}, \\\"tenant_ip_address\\\": {\\\"description\\\": \\\"IP address of the server in the Tenant network\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"TenantPort\\\", \\\"ip_address\\\"]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack CellControllerCompute node configured by Puppet\\\", \\\"parameters\\\": {\\\"OvercloudControlFlavor\\\": {\\\"description\\\": \\\"DEPRECATED Use OvercloudCellControllerComputeFlavor instead.\\\", \\\"default\\\": \\\"baremetal\\\", \\\"type\\\": \\\"string\\\"}, \\\"OvercloudCellControllerComputeFlavor\\\": {\\\"description\\\": \\\"Flavor for the CellControllerCompute node.\\\", \\\"default\\\": \\\"baremetal\\\", \\\"type\\\": \\\"string\\\"}, \\\"controllerImage\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"overcloud-full\\\", \\\"description\\\": \\\"DEPRECATED Use CellControllerComputeImage instead\\\"}, \\\"CellControllerComputeImage\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"overcloud-full\\\", \\\"description\\\": \\\"The disk image file to use for the role.\\\"}, \\\"ImageUpdatePolicy\\\": {\\\"default\\\": \\\"REBUILD_PRESERVE_EPHEMERAL\\\", \\\"description\\\": \\\"What policy to use when reconstructing instances. REBUILD for rebuilds, REBUILD_PRESERVE_EPHEMERAL to preserve /mnt.\\\", \\\"type\\\": \\\"string\\\"}, \\\"KeyName\\\": {\\\"description\\\": \\\"Name of an existing Nova key pair to enable SSH access to the instances\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"default\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"UpdateIdentifier\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Setting to a previously unused value during stack-update will trigger package update on all nodes\\\\n\\\"}, \\\"Hostname\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\"}, \\\"HostnameMap\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {}, \\\"description\\\": \\\"Optional mapping to override hostnames\\\"}, \\\"CellControllerComputeIPs\\\": {\\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}, \\\"SoftwareConfigTransport\\\": {\\\"default\\\": \\\"POLL_SERVER_CFN\\\", \\\"description\\\": \\\"How the server should receive the metadata required for software configuration.\\\\n\\\", \\\"type\\\": \\\"string\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"POLL_SERVER_CFN\\\", \\\"POLL_SERVER_HEAT\\\", \\\"POLL_TEMP_URL\\\", \\\"ZAQAR_MESSAGE\\\"]}]}, \\\"CloudDomain\\\": {\\\"default\\\": \\\"localdomain\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"The DNS domain used for the hosts. This must match the overcloud_domain_name configured on the undercloud.\\\\n\\\"}, \\\"CellControllerComputeServerMetadata\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API. This option is role-specific and is merged with the values given to the ServerMetadata parameter.\\\\n\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServerMetadata\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API. This applies to all roles and is merged with a role-specific metadata parameter.\\\\n\\\", \\\"type\\\": \\\"json\\\"}, \\\"CellControllerComputeSchedulerHints\\\": {\\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"Optional scheduler hints to pass to nova\\\", \\\"default\\\": {}}, \\\"NodeIndex\\\": {\\\"type\\\": \\\"number\\\", \\\"default\\\": 0}, \\\"ServiceNames\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": []}, \\\"MonitoringSubscriptions\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": []}, \\\"ServiceMetadataSettings\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {}}, \\\"OVNBridgeMappings\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": []}, \\\"ConfigCommand\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Command which will be run whenever configuration data changes\\\", \\\"default\\\": \\\"os-refresh-config --timeout 14400\\\"}, \\\"ConfigCollectSplay\\\": {\\\"type\\\": \\\"number\\\", \\\"default\\\": 30, \\\"description\\\": \\\"Maximum amount of time to possibly to delay configuration collection\\\\npolling. Defaults to 30 seconds. Set to 0 to disable it which will cause\\\\nthe configuration collection to occur as soon as the collection process\\\\nstarts.  This setting is used to prevent the configuration collection\\\\nprocesses from polling all at the exact same time.\\\\n\\\"}, \\\"UpgradeInitCommand\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Command or script snippet to run on all overcloud nodes to\\\\ninitialize the upgrade process. E.g. a repository switch.\\\\n\\\", \\\"default\\\": \\\"\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"UpgradeInitCommonCommand\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Common commands required by the upgrades process. This should not\\\\nnormally be modified by the operator and is set and unset in the\\\\nmajor-upgrade-composable-steps.yaml and major-upgrade-converge.yaml\\\\nenvironment files.\\\\n\\\", \\\"default\\\": \\\"\\\"}, \\\"DeploymentServerBlacklistDict\\\": {\\\"default\\\": {}, \\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"Map of server hostnames to blacklist from any triggered deployments. If the value is 1, the server will be blacklisted. This parameter is generated from the parent template.\\\\n\\\"}, \\\"RoleParameters\\\": {\\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"default\\\": {}}, \\\"CellControllerComputeControlPlaneSubnet\\\": {\\\"default\\\": \\\"ctlplane-subnet\\\", \\\"description\\\": \\\"Name of the subnet on ctlplane network for this role.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneSubnetCidr\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"ServerDeletionPolicy\\\": {\\\"description\\\": \\\"Whether to retain or delete servers on deletion of the stack\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"delete\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"delete\\\", \\\"retain\\\"]}]}, \\\"UserData\\\": {\\\"type\\\": \\\"string\\\"}}, \\\"parameter_groups\\\": [{\\\"label\\\": \\\"deprecated\\\", \\\"description\\\": \\\"Do not use deprecated params, they will be removed.\\\", \\\"parameters\\\": [\\\"OvercloudControlFlavor\\\", \\\"controllerImage\\\"]}], \\\"conditions\\\": {\\\"server_blacklisted\\\": {\\\"or\\\": [{\\\"equals\\\": [{\\\"get_param\\\": [\\\"DeploymentServerBlacklistDict\\\", {\\\"get_param\\\": \\\"Hostname\\\"}]}, 1]}, {\\\"equals\\\": [{\\\"get_param\\\": [\\\"DeploymentServerBlacklistDict\\\", {\\\"get_param\\\": [\\\"HostnameMap\\\", {\\\"get_param\\\": \\\"Hostname\\\"}]}]}, 1]}]}, \\\"server_not_blacklisted\\\": {\\\"and\\\": [{\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"DeploymentServerBlacklistDict\\\", {\\\"get_param\\\": \\\"Hostname\\\"}]}, 1]}}, {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"DeploymentServerBlacklistDict\\\", {\\\"get_param\\\": [\\\"HostnameMap\\\", {\\\"get_param\\\": \\\"Hostname\\\"}]}]}, 1]}}]}, \\\"deprecated_param_image_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"controllerImage\\\"}, \\\"overcloud-full\\\"]}}, \\\"deprecated_param_flavor_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"OvercloudControlFlavor\\\"}, \\\"baremetal\\\"]}}, \\\"ctlplane_fixed_ip_set\\\": {\\\"or\\\": [{\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"CellControllerComputeIPs\\\", \\\"ctlplane\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}, \\\"\\\"]}}, false]}, \\\"CellControllerCompute_Storage_fixed_ip_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"CellControllerComputeIPs\\\", \\\"storage\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}, \\\"\\\"]}}, \\\"CellControllerCompute_StorageMgmt_fixed_ip_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"CellControllerComputeIPs\\\", \\\"storage_mgmt\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}, \\\"\\\"]}}, \\\"CellControllerCompute_InternalApi_fixed_ip_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"CellControllerComputeIPs\\\", \\\"internal_api\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}, \\\"\\\"]}}, \\\"CellControllerCompute_Tenant_fixed_ip_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"CellControllerComputeIPs\\\", \\\"tenant\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}, \\\"\\\"]}}}, \\\"resources\\\": {\\\"CellControllerCompute\\\": {\\\"type\\\": \\\"OS::TripleO::CellControllerComputeServer\\\", \\\"deletion_policy\\\": {\\\"get_param\\\": \\\"ServerDeletionPolicy\\\"}, \\\"properties\\\": {\\\"image\\\": {\\\"if\\\": [\\\"deprecated_param_image_set\\\", {\\\"get_param\\\": \\\"controllerImage\\\"}, {\\\"get_param\\\": \\\"CellControllerComputeImage\\\"}]}, \\\"image_update_policy\\\": {\\\"get_param\\\": \\\"ImageUpdatePolicy\\\"}, \\\"flavor\\\": {\\\"if\\\": [\\\"deprecated_param_flavor_set\\\", {\\\"get_param\\\": \\\"OvercloudControlFlavor\\\"}, {\\\"get_param\\\": \\\"OvercloudCellControllerComputeFlavor\\\"}]}, \\\"key_name\\\": {\\\"get_param\\\": \\\"KeyName\\\"}, \\\"networks\\\": [{\\\"if\\\": [\\\"ctlplane_fixed_ip_set\\\", {\\\"network\\\": \\\"ctlplane\\\", \\\"subnet\\\": {\\\"get_param\\\": \\\"CellControllerComputeControlPlaneSubnet\\\"}, \\\"fixed_ip\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"$.data.where(not isEmpty($)).first()\\\", \\\"data\\\": [{\\\"get_param\\\": [\\\"CellControllerComputeIPs\\\", \\\"ctlplane\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}]}}}, {\\\"network\\\": \\\"ctlplane\\\", \\\"subnet\\\": {\\\"get_param\\\": \\\"CellControllerComputeControlPlaneSubnet\\\"}}]}], \\\"user_data_format\\\": \\\"SOFTWARE_CONFIG\\\", \\\"user_data\\\": {\\\"get_param\\\": \\\"UserData\\\"}, \\\"name\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"$.data.hostname_map.get($.data.hostname, $.data.hostname).toLower()\\\", \\\"data\\\": {\\\"hostname\\\": {\\\"get_param\\\": \\\"Hostname\\\"}, \\\"hostname_map\\\": {\\\"get_param\\\": \\\"HostnameMap\\\"}}}}, \\\"software_config_transport\\\": {\\\"get_param\\\": \\\"SoftwareConfigTransport\\\"}, \\\"metadata\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"ServerMetadata\\\"}, {\\\"get_param\\\": \\\"CellControllerComputeServerMetadata\\\"}, {\\\"get_param\\\": \\\"ServiceMetadataSettings\\\"}]}, \\\"scheduler_hints\\\": {\\\"get_param\\\": \\\"CellControllerComputeSchedulerHints\\\"}}}, \\\"StoragePort\\\": {\\\"type\\\": \\\"OS::TripleO::CellControllerCompute::Ports::StoragePort\\\", \\\"properties\\\": {\\\"PortName\\\": {\\\"list_join\\\": [\\\"_\\\", [{\\\"get_attr\\\": [\\\"CellControllerCompute\\\", \\\"name\\\"]}, \\\"Storage\\\"]]}, \\\"DnsName\\\": {\\\"get_attr\\\": [\\\"CellControllerCompute\\\", \\\"name\\\"]}, \\\"ControlPlaneIP\\\": {\\\"get_attr\\\": [\\\"CellControllerCompute\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"FixedIPs\\\": {\\\"if\\\": [\\\"CellControllerCompute_Storage_fixed_ip_set\\\", [{\\\"ip_address\\\": {\\\"get_param\\\": [\\\"CellControllerComputeIPs\\\", \\\"storage\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}}], [{\\\"subnet\\\": \\\"storage_subnet\\\"}]]}, \\\"ControlPlaneSubnetCidr\\\": {\\\"str_split\\\": [\\\"/\\\", {\\\"get_attr\\\": [\\\"CellControllerCompute\\\", \\\"addresses\\\", \\\"ctlplane\\\", 0, \\\"subnets\\\", 0, \\\"cidr\\\"]}, -1]}, \\\"IPPool\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"CellControllerComputeIPs\\\"}]}, \\\"NodeIndex\\\": {\\\"get_param\\\": \\\"NodeIndex\\\"}, \\\"Role\\\": \\\"CellControllerCompute\\\"}}, \\\"StorageMgmtPort\\\": {\\\"type\\\": \\\"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\\\", \\\"properties\\\": {\\\"PortName\\\": {\\\"list_join\\\": [\\\"_\\\", [{\\\"get_attr\\\": [\\\"CellControllerCompute\\\", \\\"name\\\"]}, \\\"StorageMgmt\\\"]]}, \\\"DnsName\\\": {\\\"get_attr\\\": [\\\"CellControllerCompute\\\", \\\"name\\\"]}, \\\"ControlPlaneIP\\\": {\\\"get_attr\\\": [\\\"CellControllerCompute\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"FixedIPs\\\": {\\\"if\\\": [\\\"CellControllerCompute_StorageMgmt_fixed_ip_set\\\", [{\\\"ip_address\\\": {\\\"get_param\\\": [\\\"CellControllerComputeIPs\\\", \\\"storage_mgmt\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}}], [{\\\"subnet\\\": \\\"storage_mgmt_subnet\\\"}]]}, \\\"ControlPlaneSubnetCidr\\\": {\\\"str_split\\\": [\\\"/\\\", {\\\"get_attr\\\": [\\\"CellControllerCompute\\\", \\\"addresses\\\", \\\"ctlplane\\\", 0, \\\"subnets\\\", 0, \\\"cidr\\\"]}, -1]}, \\\"IPPool\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"CellControllerComputeIPs\\\"}]}, \\\"NodeIndex\\\": {\\\"get_param\\\": \\\"NodeIndex\\\"}, \\\"Role\\\": \\\"CellControllerCompute\\\"}}, \\\"InternalApiPort\\\": {\\\"type\\\": \\\"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\\\", \\\"properties\\\": {\\\"PortName\\\": {\\\"list_join\\\": [\\\"_\\\", [{\\\"get_attr\\\": [\\\"CellControllerCompute\\\", \\\"name\\\"]}, \\\"InternalApi\\\"]]}, \\\"DnsName\\\": {\\\"get_attr\\\": [\\\"CellControllerCompute\\\", \\\"name\\\"]}, \\\"ControlPlaneIP\\\": {\\\"get_attr\\\": [\\\"CellControllerCompute\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"FixedIPs\\\": {\\\"if\\\": [\\\"CellControllerCompute_InternalApi_fixed_ip_set\\\", [{\\\"ip_address\\\": {\\\"get_param\\\": [\\\"CellControllerComputeIPs\\\", \\\"internal_api\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}}], [{\\\"subnet\\\": \\\"internal_api_subnet\\\"}]]}, \\\"ControlPlaneSubnetCidr\\\": {\\\"str_split\\\": [\\\"/\\\", {\\\"get_attr\\\": [\\\"CellControllerCompute\\\", \\\"addresses\\\", \\\"ctlplane\\\", 0, \\\"subnets\\\", 0, \\\"cidr\\\"]}, -1]}, \\\"IPPool\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"CellControllerComputeIPs\\\"}]}, \\\"NodeIndex\\\": {\\\"get_param\\\": \\\"NodeIndex\\\"}, \\\"Role\\\": \\\"CellControllerCompute\\\"}}, \\\"TenantPort\\\": {\\\"type\\\": \\\"OS::TripleO::CellControllerCompute::Ports::TenantPort\\\", \\\"properties\\\": {\\\"PortName\\\": {\\\"list_join\\\": [\\\"_\\\", [{\\\"get_attr\\\": [\\\"CellControllerCompute\\\", \\\"name\\\"]}, \\\"Tenant\\\"]]}, \\\"DnsName\\\": {\\\"get_attr\\\": [\\\"CellControllerCompute\\\", \\\"name\\\"]}, \\\"ControlPlaneIP\\\": {\\\"get_attr\\\": [\\\"CellControllerCompute\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"FixedIPs\\\": {\\\"if\\\": [\\\"CellControllerCompute_Tenant_fixed_ip_set\\\", [{\\\"ip_address\\\": {\\\"get_param\\\": [\\\"CellControllerComputeIPs\\\", \\\"tenant\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}}], [{\\\"subnet\\\": \\\"tenant_subnet\\\"}]]}, \\\"ControlPlaneSubnetCidr\\\": {\\\"str_split\\\": [\\\"/\\\", {\\\"get_attr\\\": [\\\"CellControllerCompute\\\", \\\"addresses\\\", \\\"ctlplane\\\", 0, \\\"subnets\\\", 0, \\\"cidr\\\"]}, -1]}, \\\"IPPool\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"CellControllerComputeIPs\\\"}]}, \\\"NodeIndex\\\": {\\\"get_param\\\": \\\"NodeIndex\\\"}, \\\"Role\\\": \\\"CellControllerCompute\\\"}}, \\\"NetIpMap\\\": {\\\"type\\\": \\\"OS::TripleO::Network::Ports::NetIpMap\\\", \\\"properties\\\": {\\\"ControlPlaneIp\\\": {\\\"get_attr\\\": [\\\"CellControllerCompute\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"ControlPlaneSubnetCidr\\\": {\\\"str_split\\\": [\\\"/\\\", {\\\"get_attr\\\": [\\\"CellControllerCompute\\\", \\\"addresses\\\", \\\"ctlplane\\\", 0, \\\"subnets\\\", 0, \\\"cidr\\\"]}, -1]}, \\\"StorageIp\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address\\\"]}, \\\"StorageIpSubnet\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_subnet\\\"]}, \\\"StorageIpUri\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address_uri\\\"]}, \\\"StorageMgmtIp\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_address\\\"]}, \\\"StorageMgmtIpSubnet\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_subnet\\\"]}, \\\"StorageMgmtIpUri\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_address_uri\\\"]}, \\\"InternalApiIp\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address\\\"]}, \\\"InternalApiIpSubnet\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_subnet\\\"]}, \\\"InternalApiIpUri\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address_uri\\\"]}, \\\"TenantIp\\\": {\\\"get_attr\\\": [\\\"TenantPort\\\", \\\"ip_address\\\"]}, \\\"TenantIpSubnet\\\": {\\\"get_attr\\\": [\\\"TenantPort\\\", \\\"ip_subnet\\\"]}, \\\"TenantIpUri\\\": {\\\"get_attr\\\": [\\\"TenantPort\\\", \\\"ip_address_uri\\\"]}}}, \\\"NetHostMap\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"storage\\\": {\\\"fqdn\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"CellControllerCompute\\\", \\\"name\\\"]}, \\\"storage\\\", {\\\"get_param\\\": \\\"CloudDomain\\\"}]]}, \\\"short\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"CellControllerCompute\\\", \\\"name\\\"]}, \\\"storage\\\"]]}}, \\\"storage_mgmt\\\": {\\\"fqdn\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"CellControllerCompute\\\", \\\"name\\\"]}, \\\"storagemgmt\\\", {\\\"get_param\\\": \\\"CloudDomain\\\"}]]}, \\\"short\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"CellControllerCompute\\\", \\\"name\\\"]}, \\\"storagemgmt\\\"]]}}, \\\"internal_api\\\": {\\\"fqdn\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"CellControllerCompute\\\", \\\"name\\\"]}, \\\"internalapi\\\", {\\\"get_param\\\": \\\"CloudDomain\\\"}]]}, \\\"short\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"CellControllerCompute\\\", \\\"name\\\"]}, \\\"internalapi\\\"]]}}, \\\"tenant\\\": {\\\"fqdn\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"CellControllerCompute\\\", \\\"name\\\"]}, \\\"tenant\\\", {\\\"get_param\\\": \\\"CloudDomain\\\"}]]}, \\\"short\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"CellControllerCompute\\\", \\\"name\\\"]}, \\\"tenant\\\"]]}}, \\\"ctlplane\\\": {\\\"fqdn\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"CellControllerCompute\\\", \\\"name\\\"]}, \\\"ctlplane\\\", {\\\"get_param\\\": \\\"CloudDomain\\\"}]]}, \\\"short\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"CellControllerCompute\\\", \\\"name\\\"]}, \\\"ctlplane\\\"]]}}, \\\"canonical\\\": {\\\"fqdn\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"CellControllerCompute\\\", \\\"name\\\"]}, {\\\"get_param\\\": \\\"CloudDomain\\\"}]]}, \\\"short\\\": [{\\\"get_attr\\\": [\\\"CellControllerCompute\\\", \\\"name\\\"]}]}}}}, \\\"PreNetworkConfig\\\": {\\\"type\\\": \\\"OS::TripleO::CellControllerCompute::PreNetworkConfig\\\", \\\"condition\\\": \\\"server_not_blacklisted\\\", \\\"properties\\\": {\\\"server\\\": {\\\"get_resource\\\": \\\"CellControllerCompute\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}, \\\"ServiceNames\\\": {\\\"get_param\\\": \\\"ServiceNames\\\"}, \\\"deployment_actions\\\": {\\\"get_attr\\\": [\\\"DeploymentActions\\\", \\\"value\\\"]}}}, \\\"NodeTLSCAData\\\": {\\\"type\\\": \\\"OS::TripleO::NodeTLSCAData\\\", \\\"properties\\\": {\\\"server\\\": {\\\"get_resource\\\": \\\"CellControllerCompute\\\"}}}, \\\"CellControllerComputeExtraConfigPre\\\": {\\\"type\\\": \\\"OS::TripleO::CellControllerComputeExtraConfigPre\\\", \\\"condition\\\": \\\"server_not_blacklisted\\\", \\\"properties\\\": {\\\"server\\\": {\\\"get_resource\\\": \\\"CellControllerCompute\\\"}}}, \\\"NodeExtraConfig\\\": {\\\"depends_on\\\": [\\\"CellControllerComputeExtraConfigPre\\\", \\\"NodeTLSCAData\\\"], \\\"type\\\": \\\"OS::TripleO::NodeExtraConfig\\\", \\\"condition\\\": \\\"server_not_blacklisted\\\", \\\"properties\\\": {\\\"server\\\": {\\\"get_resource\\\": \\\"CellControllerCompute\\\"}}}, \\\"DeploymentActions\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"value\\\": {\\\"if\\\": [\\\"server_not_blacklisted\\\", [\\\"CREATE\\\", \\\"UPDATE\\\"], []]}}}, \\\"CellControllerComputeAnsibleHostVars\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"fqdn_storage\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage\\\", \\\"fqdn\\\"]}, \\\"fqdn_storage_mgmt\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage_mgmt\\\", \\\"fqdn\\\"]}, \\\"fqdn_internal_api\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"internal_api\\\", \\\"fqdn\\\"]}, \\\"fqdn_tenant\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"tenant\\\", \\\"fqdn\\\"]}, \\\"fqdn_ctlplane\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"ctlplane\\\", \\\"fqdn\\\"]}, \\\"fqdn_canonical\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"canonical\\\", \\\"fqdn\\\"]}, \\\"hostname_resolve_network\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CellControllerComputeHostnameResolveNetwork\\\"]}}}}}, \\\"outputs\\\": {\\\"ansible_host_vars_map\\\": {\\\"description\\\": \\\"Map of Ansible variables specific per host.\\\\nThis map is used to construct the AnsibleHostVarsMap output for the\\\\nansible vars per host in config-download.\\\\n\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"host\\\": {\\\"get_attr\\\": [\\\"CellControllerComputeAnsibleHostVars\\\", \\\"value\\\"]}}, {\\\"keys\\\": {\\\"host\\\": {\\\"get_attr\\\": [\\\"CellControllerCompute\\\", \\\"name\\\"]}}}]}}, \\\"ip_address\\\": {\\\"description\\\": \\\"IP address of the server in the ctlplane network\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"CellControllerCompute\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}}, \\\"blacklist_ip_address\\\": {\\\"description\\\": \\\"IP address of the server if the server is blacklisted, otherwise this output will be an empty string\\\", \\\"value\\\": {\\\"if\\\": [\\\"server_blacklisted\\\", {\\\"get_attr\\\": [\\\"CellControllerCompute\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"\\\"]}}, \\\"blacklist_hostname\\\": {\\\"description\\\": \\\"Hostname of the server if the server is blacklisted, otherwise this output will be an empty string\\\", \\\"value\\\": {\\\"if\\\": [\\\"server_blacklisted\\\", {\\\"get_attr\\\": [\\\"CellControllerCompute\\\", \\\"name\\\"]}, \\\"\\\"]}}, \\\"hostname\\\": {\\\"description\\\": \\\"Hostname of the server\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"CellControllerCompute\\\", \\\"name\\\"]}}, \\\"hostname_map\\\": {\\\"description\\\": \\\"Mapping of network names to hostnames\\\", \\\"value\\\": {\\\"storage\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage\\\", \\\"fqdn\\\"]}, \\\"storage_mgmt\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage_mgmt\\\", \\\"fqdn\\\"]}, \\\"internal_api\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"internal_api\\\", \\\"fqdn\\\"]}, \\\"tenant\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"tenant\\\", \\\"fqdn\\\"]}, \\\"ctlplane\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"ctlplane\\\", \\\"fqdn\\\"]}, \\\"canonical\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"canonical\\\", \\\"fqdn\\\"]}}}, \\\"hosts_entry\\\": {\\\"value\\\": [{\\\"str_replace\\\": {\\\"template\\\": \\\"PRIMARYIP PRIMARYHOST.DOMAIN PRIMARYHOST\\\", \\\"params\\\": {\\\"PRIMARYIP\\\": {\\\"get_attr\\\": [\\\"NetIpMap\\\", \\\"net_ip_map\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CellControllerComputeHostnameResolveNetwork\\\"]}]}, \\\"DOMAIN\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"PRIMARYHOST\\\": {\\\"get_attr\\\": [\\\"CellControllerCompute\\\", \\\"name\\\"]}}}}, {\\\"str_replace\\\": {\\\"template\\\": \\\"StorageIP StorageHOST.DOMAIN StorageHOST\\\", \\\"params\\\": {\\\"DOMAIN\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"StorageIP\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address\\\"]}, \\\"StorageHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage\\\", \\\"short\\\"]}, \\\"StorageMgmtIP\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_address\\\"]}, \\\"StorageMgmtHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage_mgmt\\\", \\\"short\\\"]}, \\\"InternalApiIP\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address\\\"]}, \\\"InternalApiHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"internal_api\\\", \\\"short\\\"]}, \\\"TenantIP\\\": {\\\"get_attr\\\": [\\\"TenantPort\\\", \\\"ip_address\\\"]}, \\\"TenantHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"tenant\\\", \\\"short\\\"]}}}}, {\\\"str_replace\\\": {\\\"template\\\": \\\"StorageMgmtIP StorageMgmtHOST.DOMAIN StorageMgmtHOST\\\", \\\"params\\\": {\\\"DOMAIN\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"StorageIP\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address\\\"]}, \\\"StorageHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage\\\", \\\"short\\\"]}, \\\"StorageMgmtIP\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_address\\\"]}, \\\"StorageMgmtHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage_mgmt\\\", \\\"short\\\"]}, \\\"InternalApiIP\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address\\\"]}, \\\"InternalApiHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"internal_api\\\", \\\"short\\\"]}, \\\"TenantIP\\\": {\\\"get_attr\\\": [\\\"TenantPort\\\", \\\"ip_address\\\"]}, \\\"TenantHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"tenant\\\", \\\"short\\\"]}}}}, {\\\"str_replace\\\": {\\\"template\\\": \\\"InternalApiIP InternalApiHOST.DOMAIN InternalApiHOST\\\", \\\"params\\\": {\\\"DOMAIN\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"StorageIP\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address\\\"]}, \\\"StorageHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage\\\", \\\"short\\\"]}, \\\"StorageMgmtIP\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_address\\\"]}, \\\"StorageMgmtHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage_mgmt\\\", \\\"short\\\"]}, \\\"InternalApiIP\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address\\\"]}, \\\"InternalApiHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"internal_api\\\", \\\"short\\\"]}, \\\"TenantIP\\\": {\\\"get_attr\\\": [\\\"TenantPort\\\", \\\"ip_address\\\"]}, \\\"TenantHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"tenant\\\", \\\"short\\\"]}}}}, {\\\"str_replace\\\": {\\\"template\\\": \\\"TenantIP TenantHOST.DOMAIN TenantHOST\\\", \\\"params\\\": {\\\"DOMAIN\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"StorageIP\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address\\\"]}, \\\"StorageHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage\\\", \\\"short\\\"]}, \\\"StorageMgmtIP\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_address\\\"]}, \\\"StorageMgmtHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage_mgmt\\\", \\\"short\\\"]}, \\\"InternalApiIP\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address\\\"]}, \\\"InternalApiHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"internal_api\\\", \\\"short\\\"]}, \\\"TenantIP\\\": {\\\"get_attr\\\": [\\\"TenantPort\\\", \\\"ip_address\\\"]}, \\\"TenantHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"tenant\\\", \\\"short\\\"]}}}}, {\\\"str_replace\\\": {\\\"template\\\": \\\"CTLPLANEIP CTLPLANEHOST.DOMAIN CTLPLANEHOST\\\", \\\"params\\\": {\\\"DOMAIN\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"CTLPLANEIP\\\": {\\\"get_attr\\\": [\\\"CellControllerCompute\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"CTLPLANEHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"ctlplane\\\", \\\"short\\\"]}}}}]}, \\\"nova_server_resource\\\": {\\\"description\\\": \\\"Heat resource handle for CellControllerCompute server\\\", \\\"value\\\": {\\\"get_resource\\\": \\\"CellControllerCompute\\\"}, \\\"condition\\\": \\\"server_not_blacklisted\\\"}, \\\"deployed_server_port_map\\\": {\\\"description\\\": \\\"Map of Heat created hostname of the server to ip address. This is the\\\\nhostname before it has been mapped with the HostnameMap parameter, and\\\\nthe IP address from the ctlplane network. This map can be used to construct\\\\nthe DeployedServerPortMap parameter when using split-stack.\\\\n\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"hostname\\\": {\\\"fixed_ips\\\": [{\\\"ip_address\\\": {\\\"get_attr\\\": [\\\"CellControllerCompute\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}}], \\\"subnets\\\": [{\\\"cidr\\\": {\\\"get_attr\\\": [\\\"CellControllerCompute\\\", \\\"addresses\\\", \\\"ctlplane\\\", 0, \\\"subnets\\\", 0, \\\"cidr\\\"]}}]}}, {\\\"keys\\\": {\\\"hostname\\\": {\\\"list_join\\\": [\\\"-\\\", [{\\\"get_param\\\": \\\"Hostname\\\"}, \\\"ctlplane\\\"]]}}}]}}, \\\"storage_ip_address\\\": {\\\"description\\\": \\\"IP address of the server in the Storage network\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address\\\"]}}, \\\"storage_mgmt_ip_address\\\": {\\\"description\\\": \\\"IP address of the server in the StorageMgmt network\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_address\\\"]}}, \\\"internal_api_ip_address\\\": {\\\"description\\\": \\\"IP address of the server in the InternalApi network\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address\\\"]}}, \\\"tenant_ip_address\\\": {\\\"description\\\": \\\"IP address of the server in the Tenant network\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"TenantPort\\\", \\\"ip_address\\\"]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack Compute node configured by Puppet\\\", \\\"parameters\\\": {\\\"OvercloudComputeFlavor\\\": {\\\"description\\\": \\\"Flavor for the Compute node.\\\", \\\"default\\\": \\\"baremetal\\\", \\\"type\\\": \\\"string\\\"}, \\\"NovaImage\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"overcloud-full\\\", \\\"description\\\": \\\"DEPRECATED Use ComputeImage instead\\\"}, \\\"ComputeImage\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"overcloud-full\\\", \\\"description\\\": \\\"The disk image file to use for the role.\\\"}, \\\"ImageUpdatePolicy\\\": {\\\"default\\\": \\\"REBUILD_PRESERVE_EPHEMERAL\\\", \\\"description\\\": \\\"What policy to use when reconstructing instances. REBUILD for rebuilds, REBUILD_PRESERVE_EPHEMERAL to preserve /mnt.\\\", \\\"type\\\": \\\"string\\\"}, \\\"KeyName\\\": {\\\"description\\\": \\\"Name of an existing Nova key pair to enable SSH access to the instances\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"default\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"UpdateIdentifier\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Setting to a previously unused value during stack-update will trigger package update on all nodes\\\\n\\\"}, \\\"Hostname\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\"}, \\\"HostnameMap\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {}, \\\"description\\\": \\\"Optional mapping to override hostnames\\\"}, \\\"ComputeIPs\\\": {\\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}, \\\"NovaComputeIPs\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"DEPRECATED - use ComputeIPs instead\\\", \\\"type\\\": \\\"json\\\"}, \\\"SoftwareConfigTransport\\\": {\\\"default\\\": \\\"POLL_SERVER_CFN\\\", \\\"description\\\": \\\"How the server should receive the metadata required for software configuration.\\\\n\\\", \\\"type\\\": \\\"string\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"POLL_SERVER_CFN\\\", \\\"POLL_SERVER_HEAT\\\", \\\"POLL_TEMP_URL\\\", \\\"ZAQAR_MESSAGE\\\"]}]}, \\\"CloudDomain\\\": {\\\"default\\\": \\\"localdomain\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"The DNS domain used for the hosts. This must match the overcloud_domain_name configured on the undercloud.\\\\n\\\"}, \\\"ComputeServerMetadata\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API. This option is role-specific and is merged with the values given to the ServerMetadata parameter.\\\\n\\\", \\\"type\\\": \\\"json\\\"}, \\\"NovaComputeServerMetadata\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"DEPRECATED - use ComputeServerMetadata instead\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServerMetadata\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API. This applies to all roles and is merged with a role-specific metadata parameter.\\\\n\\\", \\\"type\\\": \\\"json\\\"}, \\\"ComputeSchedulerHints\\\": {\\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"Optional scheduler hints to pass to nova\\\", \\\"default\\\": {}}, \\\"NodeIndex\\\": {\\\"type\\\": \\\"number\\\", \\\"default\\\": 0}, \\\"ServiceNames\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": []}, \\\"MonitoringSubscriptions\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": []}, \\\"ServiceMetadataSettings\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {}}, \\\"OVNBridgeMappings\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": []}, \\\"ConfigCommand\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Command which will be run whenever configuration data changes\\\", \\\"default\\\": \\\"os-refresh-config --timeout 14400\\\"}, \\\"ConfigCollectSplay\\\": {\\\"type\\\": \\\"number\\\", \\\"default\\\": 30, \\\"description\\\": \\\"Maximum amount of time to possibly to delay configuration collection\\\\npolling. Defaults to 30 seconds. Set to 0 to disable it which will cause\\\\nthe configuration collection to occur as soon as the collection process\\\\nstarts.  This setting is used to prevent the configuration collection\\\\nprocesses from polling all at the exact same time.\\\\n\\\"}, \\\"UpgradeInitCommand\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Command or script snippet to run on all overcloud nodes to\\\\ninitialize the upgrade process. E.g. a repository switch.\\\\n\\\", \\\"default\\\": \\\"\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"UpgradeInitCommonCommand\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Common commands required by the upgrades process. This should not\\\\nnormally be modified by the operator and is set and unset in the\\\\nmajor-upgrade-composable-steps.yaml and major-upgrade-converge.yaml\\\\nenvironment files.\\\\n\\\", \\\"default\\\": \\\"\\\"}, \\\"DeploymentServerBlacklistDict\\\": {\\\"default\\\": {}, \\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"Map of server hostnames to blacklist from any triggered deployments. If the value is 1, the server will be blacklisted. This parameter is generated from the parent template.\\\\n\\\"}, \\\"RoleParameters\\\": {\\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"default\\\": {}}, \\\"ComputeControlPlaneSubnet\\\": {\\\"default\\\": \\\"ctlplane-subnet\\\", \\\"description\\\": \\\"Name of the subnet on ctlplane network for this role.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneSubnetCidr\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"ServerDeletionPolicy\\\": {\\\"description\\\": \\\"Whether to retain or delete servers on deletion of the stack\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"delete\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"delete\\\", \\\"retain\\\"]}]}, \\\"UserData\\\": {\\\"type\\\": \\\"string\\\"}}, \\\"parameter_groups\\\": [{\\\"label\\\": \\\"deprecated\\\", \\\"description\\\": \\\"Do not use deprecated params, they will be removed.\\\", \\\"parameters\\\": [\\\"NovaImage\\\", \\\"NovaComputeServerMetadata\\\", \\\"NovaComputeIPs\\\"]}], \\\"conditions\\\": {\\\"server_blacklisted\\\": {\\\"or\\\": [{\\\"equals\\\": [{\\\"get_param\\\": [\\\"DeploymentServerBlacklistDict\\\", {\\\"get_param\\\": \\\"Hostname\\\"}]}, 1]}, {\\\"equals\\\": [{\\\"get_param\\\": [\\\"DeploymentServerBlacklistDict\\\", {\\\"get_param\\\": [\\\"HostnameMap\\\", {\\\"get_param\\\": \\\"Hostname\\\"}]}]}, 1]}]}, \\\"server_not_blacklisted\\\": {\\\"and\\\": [{\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"DeploymentServerBlacklistDict\\\", {\\\"get_param\\\": \\\"Hostname\\\"}]}, 1]}}, {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"DeploymentServerBlacklistDict\\\", {\\\"get_param\\\": [\\\"HostnameMap\\\", {\\\"get_param\\\": \\\"Hostname\\\"}]}]}, 1]}}]}, \\\"deprecated_param_image_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"NovaImage\\\"}, \\\"overcloud-full\\\"]}}, \\\"ctlplane_fixed_ip_set\\\": {\\\"or\\\": [{\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"ComputeIPs\\\", \\\"ctlplane\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}, \\\"\\\"]}}, {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"NovaComputeIPs\\\", \\\"ctlplane\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}, \\\"\\\"]}}, false]}, \\\"Compute_Storage_fixed_ip_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"ComputeIPs\\\", \\\"storage\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}, \\\"\\\"]}}, \\\"Compute_InternalApi_fixed_ip_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"ComputeIPs\\\", \\\"internal_api\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}, \\\"\\\"]}}, \\\"Compute_Tenant_fixed_ip_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"ComputeIPs\\\", \\\"tenant\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}, \\\"\\\"]}}}, \\\"resources\\\": {\\\"NovaCompute\\\": {\\\"type\\\": \\\"OS::TripleO::ComputeServer\\\", \\\"deletion_policy\\\": {\\\"get_param\\\": \\\"ServerDeletionPolicy\\\"}, \\\"properties\\\": {\\\"image\\\": {\\\"if\\\": [\\\"deprecated_param_image_set\\\", {\\\"get_param\\\": \\\"NovaImage\\\"}, {\\\"get_param\\\": \\\"ComputeImage\\\"}]}, \\\"image_update_policy\\\": {\\\"get_param\\\": \\\"ImageUpdatePolicy\\\"}, \\\"flavor\\\": {\\\"get_param\\\": \\\"OvercloudComputeFlavor\\\"}, \\\"key_name\\\": {\\\"get_param\\\": \\\"KeyName\\\"}, \\\"networks\\\": [{\\\"if\\\": [\\\"ctlplane_fixed_ip_set\\\", {\\\"network\\\": \\\"ctlplane\\\", \\\"subnet\\\": {\\\"get_param\\\": \\\"ComputeControlPlaneSubnet\\\"}, \\\"fixed_ip\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"$.data.where(not isEmpty($)).first()\\\", \\\"data\\\": [{\\\"get_param\\\": [\\\"ComputeIPs\\\", \\\"ctlplane\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}, {\\\"get_param\\\": [\\\"NovaComputeIPs\\\", \\\"ctlplane\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}]}}}, {\\\"network\\\": \\\"ctlplane\\\", \\\"subnet\\\": {\\\"get_param\\\": \\\"ComputeControlPlaneSubnet\\\"}}]}], \\\"user_data_format\\\": \\\"SOFTWARE_CONFIG\\\", \\\"user_data\\\": {\\\"get_param\\\": \\\"UserData\\\"}, \\\"name\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"$.data.hostname_map.get($.data.hostname, $.data.hostname).toLower()\\\", \\\"data\\\": {\\\"hostname\\\": {\\\"get_param\\\": \\\"Hostname\\\"}, \\\"hostname_map\\\": {\\\"get_param\\\": \\\"HostnameMap\\\"}}}}, \\\"software_config_transport\\\": {\\\"get_param\\\": \\\"SoftwareConfigTransport\\\"}, \\\"metadata\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"ServerMetadata\\\"}, {\\\"get_param\\\": \\\"NovaComputeServerMetadata\\\"}, {\\\"get_param\\\": \\\"ComputeServerMetadata\\\"}, {\\\"get_param\\\": \\\"ServiceMetadataSettings\\\"}]}, \\\"scheduler_hints\\\": {\\\"get_param\\\": \\\"ComputeSchedulerHints\\\"}}}, \\\"StoragePort\\\": {\\\"type\\\": \\\"OS::TripleO::Compute::Ports::StoragePort\\\", \\\"properties\\\": {\\\"PortName\\\": {\\\"list_join\\\": [\\\"_\\\", [{\\\"get_attr\\\": [\\\"NovaCompute\\\", \\\"name\\\"]}, \\\"Storage\\\"]]}, \\\"DnsName\\\": {\\\"get_attr\\\": [\\\"NovaCompute\\\", \\\"name\\\"]}, \\\"ControlPlaneIP\\\": {\\\"get_attr\\\": [\\\"NovaCompute\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"FixedIPs\\\": {\\\"if\\\": [\\\"Compute_Storage_fixed_ip_set\\\", [{\\\"ip_address\\\": {\\\"get_param\\\": [\\\"ComputeIPs\\\", \\\"storage\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}}], [{\\\"subnet\\\": \\\"storage_subnet\\\"}]]}, \\\"ControlPlaneSubnetCidr\\\": {\\\"str_split\\\": [\\\"/\\\", {\\\"get_attr\\\": [\\\"NovaCompute\\\", \\\"addresses\\\", \\\"ctlplane\\\", 0, \\\"subnets\\\", 0, \\\"cidr\\\"]}, -1]}, \\\"IPPool\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"NovaComputeIPs\\\"}, {\\\"get_param\\\": \\\"ComputeIPs\\\"}]}, \\\"NodeIndex\\\": {\\\"get_param\\\": \\\"NodeIndex\\\"}, \\\"Role\\\": \\\"Compute\\\"}}, \\\"InternalApiPort\\\": {\\\"type\\\": \\\"OS::TripleO::Compute::Ports::InternalApiPort\\\", \\\"properties\\\": {\\\"PortName\\\": {\\\"list_join\\\": [\\\"_\\\", [{\\\"get_attr\\\": [\\\"NovaCompute\\\", \\\"name\\\"]}, \\\"InternalApi\\\"]]}, \\\"DnsName\\\": {\\\"get_attr\\\": [\\\"NovaCompute\\\", \\\"name\\\"]}, \\\"ControlPlaneIP\\\": {\\\"get_attr\\\": [\\\"NovaCompute\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"FixedIPs\\\": {\\\"if\\\": [\\\"Compute_InternalApi_fixed_ip_set\\\", [{\\\"ip_address\\\": {\\\"get_param\\\": [\\\"ComputeIPs\\\", \\\"internal_api\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}}], [{\\\"subnet\\\": \\\"internal_api_subnet\\\"}]]}, \\\"ControlPlaneSubnetCidr\\\": {\\\"str_split\\\": [\\\"/\\\", {\\\"get_attr\\\": [\\\"NovaCompute\\\", \\\"addresses\\\", \\\"ctlplane\\\", 0, \\\"subnets\\\", 0, \\\"cidr\\\"]}, -1]}, \\\"IPPool\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"NovaComputeIPs\\\"}, {\\\"get_param\\\": \\\"ComputeIPs\\\"}]}, \\\"NodeIndex\\\": {\\\"get_param\\\": \\\"NodeIndex\\\"}, \\\"Role\\\": \\\"Compute\\\"}}, \\\"TenantPort\\\": {\\\"type\\\": \\\"OS::TripleO::Compute::Ports::TenantPort\\\", \\\"properties\\\": {\\\"PortName\\\": {\\\"list_join\\\": [\\\"_\\\", [{\\\"get_attr\\\": [\\\"NovaCompute\\\", \\\"name\\\"]}, \\\"Tenant\\\"]]}, \\\"DnsName\\\": {\\\"get_attr\\\": [\\\"NovaCompute\\\", \\\"name\\\"]}, \\\"ControlPlaneIP\\\": {\\\"get_attr\\\": [\\\"NovaCompute\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"FixedIPs\\\": {\\\"if\\\": [\\\"Compute_Tenant_fixed_ip_set\\\", [{\\\"ip_address\\\": {\\\"get_param\\\": [\\\"ComputeIPs\\\", \\\"tenant\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}}], [{\\\"subnet\\\": \\\"tenant_subnet\\\"}]]}, \\\"ControlPlaneSubnetCidr\\\": {\\\"str_split\\\": [\\\"/\\\", {\\\"get_attr\\\": [\\\"NovaCompute\\\", \\\"addresses\\\", \\\"ctlplane\\\", 0, \\\"subnets\\\", 0, \\\"cidr\\\"]}, -1]}, \\\"IPPool\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"NovaComputeIPs\\\"}, {\\\"get_param\\\": \\\"ComputeIPs\\\"}]}, \\\"NodeIndex\\\": {\\\"get_param\\\": \\\"NodeIndex\\\"}, \\\"Role\\\": \\\"Compute\\\"}}, \\\"NetIpMap\\\": {\\\"type\\\": \\\"OS::TripleO::Network::Ports::NetIpMap\\\", \\\"properties\\\": {\\\"ControlPlaneIp\\\": {\\\"get_attr\\\": [\\\"NovaCompute\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"ControlPlaneSubnetCidr\\\": {\\\"str_split\\\": [\\\"/\\\", {\\\"get_attr\\\": [\\\"NovaCompute\\\", \\\"addresses\\\", \\\"ctlplane\\\", 0, \\\"subnets\\\", 0, \\\"cidr\\\"]}, -1]}, \\\"StorageIp\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address\\\"]}, \\\"StorageIpSubnet\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_subnet\\\"]}, \\\"StorageIpUri\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address_uri\\\"]}, \\\"InternalApiIp\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address\\\"]}, \\\"InternalApiIpSubnet\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_subnet\\\"]}, \\\"InternalApiIpUri\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address_uri\\\"]}, \\\"TenantIp\\\": {\\\"get_attr\\\": [\\\"TenantPort\\\", \\\"ip_address\\\"]}, \\\"TenantIpSubnet\\\": {\\\"get_attr\\\": [\\\"TenantPort\\\", \\\"ip_subnet\\\"]}, \\\"TenantIpUri\\\": {\\\"get_attr\\\": [\\\"TenantPort\\\", \\\"ip_address_uri\\\"]}}}, \\\"NetHostMap\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"storage\\\": {\\\"fqdn\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"NovaCompute\\\", \\\"name\\\"]}, \\\"storage\\\", {\\\"get_param\\\": \\\"CloudDomain\\\"}]]}, \\\"short\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"NovaCompute\\\", \\\"name\\\"]}, \\\"storage\\\"]]}}, \\\"internal_api\\\": {\\\"fqdn\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"NovaCompute\\\", \\\"name\\\"]}, \\\"internalapi\\\", {\\\"get_param\\\": \\\"CloudDomain\\\"}]]}, \\\"short\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"NovaCompute\\\", \\\"name\\\"]}, \\\"internalapi\\\"]]}}, \\\"tenant\\\": {\\\"fqdn\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"NovaCompute\\\", \\\"name\\\"]}, \\\"tenant\\\", {\\\"get_param\\\": \\\"CloudDomain\\\"}]]}, \\\"short\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"NovaCompute\\\", \\\"name\\\"]}, \\\"tenant\\\"]]}}, \\\"ctlplane\\\": {\\\"fqdn\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"NovaCompute\\\", \\\"name\\\"]}, \\\"ctlplane\\\", {\\\"get_param\\\": \\\"CloudDomain\\\"}]]}, \\\"short\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"NovaCompute\\\", \\\"name\\\"]}, \\\"ctlplane\\\"]]}}, \\\"canonical\\\": {\\\"fqdn\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"NovaCompute\\\", \\\"name\\\"]}, {\\\"get_param\\\": \\\"CloudDomain\\\"}]]}, \\\"short\\\": [{\\\"get_attr\\\": [\\\"NovaCompute\\\", \\\"name\\\"]}]}}}}, \\\"PreNetworkConfig\\\": {\\\"type\\\": \\\"OS::TripleO::Compute::PreNetworkConfig\\\", \\\"condition\\\": \\\"server_not_blacklisted\\\", \\\"properties\\\": {\\\"server\\\": {\\\"get_resource\\\": \\\"NovaCompute\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}, \\\"ServiceNames\\\": {\\\"get_param\\\": \\\"ServiceNames\\\"}, \\\"deployment_actions\\\": {\\\"get_attr\\\": [\\\"DeploymentActions\\\", \\\"value\\\"]}}}, \\\"NodeTLSCAData\\\": {\\\"type\\\": \\\"OS::TripleO::NodeTLSCAData\\\", \\\"properties\\\": {\\\"server\\\": {\\\"get_resource\\\": \\\"NovaCompute\\\"}}}, \\\"ComputeExtraConfigPre\\\": {\\\"type\\\": \\\"OS::TripleO::ComputeExtraConfigPre\\\", \\\"condition\\\": \\\"server_not_blacklisted\\\", \\\"properties\\\": {\\\"server\\\": {\\\"get_resource\\\": \\\"NovaCompute\\\"}}}, \\\"NodeExtraConfig\\\": {\\\"depends_on\\\": [\\\"ComputeExtraConfigPre\\\", \\\"NodeTLSCAData\\\"], \\\"type\\\": \\\"OS::TripleO::NodeExtraConfig\\\", \\\"condition\\\": \\\"server_not_blacklisted\\\", \\\"properties\\\": {\\\"server\\\": {\\\"get_resource\\\": \\\"NovaCompute\\\"}}}, \\\"DeploymentActions\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"value\\\": {\\\"if\\\": [\\\"server_not_blacklisted\\\", [\\\"CREATE\\\", \\\"UPDATE\\\"], []]}}}, \\\"NovaComputeAnsibleHostVars\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"fqdn_storage\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage\\\", \\\"fqdn\\\"]}, \\\"fqdn_internal_api\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"internal_api\\\", \\\"fqdn\\\"]}, \\\"fqdn_tenant\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"tenant\\\", \\\"fqdn\\\"]}, \\\"fqdn_ctlplane\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"ctlplane\\\", \\\"fqdn\\\"]}, \\\"fqdn_canonical\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"canonical\\\", \\\"fqdn\\\"]}, \\\"hostname_resolve_network\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"ComputeHostnameResolveNetwork\\\"]}}}}}, \\\"outputs\\\": {\\\"ansible_host_vars_map\\\": {\\\"description\\\": \\\"Map of Ansible variables specific per host.\\\\nThis map is used to construct the AnsibleHostVarsMap output for the\\\\nansible vars per host in config-download.\\\\n\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"host\\\": {\\\"get_attr\\\": [\\\"NovaComputeAnsibleHostVars\\\", \\\"value\\\"]}}, {\\\"keys\\\": {\\\"host\\\": {\\\"get_attr\\\": [\\\"NovaCompute\\\", \\\"name\\\"]}}}]}}, \\\"ip_address\\\": {\\\"description\\\": \\\"IP address of the server in the ctlplane network\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"NovaCompute\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}}, \\\"blacklist_ip_address\\\": {\\\"description\\\": \\\"IP address of the server if the server is blacklisted, otherwise this output will be an empty string\\\", \\\"value\\\": {\\\"if\\\": [\\\"server_blacklisted\\\", {\\\"get_attr\\\": [\\\"NovaCompute\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"\\\"]}}, \\\"blacklist_hostname\\\": {\\\"description\\\": \\\"Hostname of the server if the server is blacklisted, otherwise this output will be an empty string\\\", \\\"value\\\": {\\\"if\\\": [\\\"server_blacklisted\\\", {\\\"get_attr\\\": [\\\"NovaCompute\\\", \\\"name\\\"]}, \\\"\\\"]}}, \\\"hostname\\\": {\\\"description\\\": \\\"Hostname of the server\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"NovaCompute\\\", \\\"name\\\"]}}, \\\"hostname_map\\\": {\\\"description\\\": \\\"Mapping of network names to hostnames\\\", \\\"value\\\": {\\\"storage\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage\\\", \\\"fqdn\\\"]}, \\\"internal_api\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"internal_api\\\", \\\"fqdn\\\"]}, \\\"tenant\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"tenant\\\", \\\"fqdn\\\"]}, \\\"ctlplane\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"ctlplane\\\", \\\"fqdn\\\"]}, \\\"canonical\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"canonical\\\", \\\"fqdn\\\"]}}}, \\\"hosts_entry\\\": {\\\"value\\\": [{\\\"str_replace\\\": {\\\"template\\\": \\\"PRIMARYIP PRIMARYHOST.DOMAIN PRIMARYHOST\\\", \\\"params\\\": {\\\"PRIMARYIP\\\": {\\\"get_attr\\\": [\\\"NetIpMap\\\", \\\"net_ip_map\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"ComputeHostnameResolveNetwork\\\"]}]}, \\\"DOMAIN\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"PRIMARYHOST\\\": {\\\"get_attr\\\": [\\\"NovaCompute\\\", \\\"name\\\"]}}}}, {\\\"str_replace\\\": {\\\"template\\\": \\\"StorageIP StorageHOST.DOMAIN StorageHOST\\\", \\\"params\\\": {\\\"DOMAIN\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"StorageIP\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address\\\"]}, \\\"StorageHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage\\\", \\\"short\\\"]}, \\\"InternalApiIP\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address\\\"]}, \\\"InternalApiHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"internal_api\\\", \\\"short\\\"]}, \\\"TenantIP\\\": {\\\"get_attr\\\": [\\\"TenantPort\\\", \\\"ip_address\\\"]}, \\\"TenantHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"tenant\\\", \\\"short\\\"]}}}}, {\\\"str_replace\\\": {\\\"template\\\": \\\"InternalApiIP InternalApiHOST.DOMAIN InternalApiHOST\\\", \\\"params\\\": {\\\"DOMAIN\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"StorageIP\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address\\\"]}, \\\"StorageHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage\\\", \\\"short\\\"]}, \\\"InternalApiIP\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address\\\"]}, \\\"InternalApiHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"internal_api\\\", \\\"short\\\"]}, \\\"TenantIP\\\": {\\\"get_attr\\\": [\\\"TenantPort\\\", \\\"ip_address\\\"]}, \\\"TenantHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"tenant\\\", \\\"short\\\"]}}}}, {\\\"str_replace\\\": {\\\"template\\\": \\\"TenantIP TenantHOST.DOMAIN TenantHOST\\\", \\\"params\\\": {\\\"DOMAIN\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"StorageIP\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address\\\"]}, \\\"StorageHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage\\\", \\\"short\\\"]}, \\\"InternalApiIP\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address\\\"]}, \\\"InternalApiHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"internal_api\\\", \\\"short\\\"]}, \\\"TenantIP\\\": {\\\"get_attr\\\": [\\\"TenantPort\\\", \\\"ip_address\\\"]}, \\\"TenantHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"tenant\\\", \\\"short\\\"]}}}}, {\\\"str_replace\\\": {\\\"template\\\": \\\"CTLPLANEIP CTLPLANEHOST.DOMAIN CTLPLANEHOST\\\", \\\"params\\\": {\\\"DOMAIN\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"CTLPLANEIP\\\": {\\\"get_attr\\\": [\\\"NovaCompute\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"CTLPLANEHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"ctlplane\\\", \\\"short\\\"]}}}}]}, \\\"nova_server_resource\\\": {\\\"description\\\": \\\"Heat resource handle for Compute server\\\", \\\"value\\\": {\\\"get_resource\\\": \\\"NovaCompute\\\"}, \\\"condition\\\": \\\"server_not_blacklisted\\\"}, \\\"deployed_server_port_map\\\": {\\\"description\\\": \\\"Map of Heat created hostname of the server to ip address. This is the\\\\nhostname before it has been mapped with the HostnameMap parameter, and\\\\nthe IP address from the ctlplane network. This map can be used to construct\\\\nthe DeployedServerPortMap parameter when using split-stack.\\\\n\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"hostname\\\": {\\\"fixed_ips\\\": [{\\\"ip_address\\\": {\\\"get_attr\\\": [\\\"NovaCompute\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}}], \\\"subnets\\\": [{\\\"cidr\\\": {\\\"get_attr\\\": [\\\"NovaCompute\\\", \\\"addresses\\\", \\\"ctlplane\\\", 0, \\\"subnets\\\", 0, \\\"cidr\\\"]}}]}}, {\\\"keys\\\": {\\\"hostname\\\": {\\\"list_join\\\": [\\\"-\\\", [{\\\"get_param\\\": \\\"Hostname\\\"}, \\\"ctlplane\\\"]]}}}]}}, \\\"storage_ip_address\\\": {\\\"description\\\": \\\"IP address of the server in the Storage network\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address\\\"]}}, \\\"internal_api_ip_address\\\": {\\\"description\\\": \\\"IP address of the server in the InternalApi network\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address\\\"]}}, \\\"tenant_ip_address\\\": {\\\"description\\\": \\\"IP address of the server in the Tenant network\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"TenantPort\\\", \\\"ip_address\\\"]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack BlockStorage node configured by Puppet\\\", \\\"parameters\\\": {\\\"OvercloudBlockStorageFlavor\\\": {\\\"description\\\": \\\"Flavor for the BlockStorage node.\\\", \\\"default\\\": \\\"baremetal\\\", \\\"type\\\": \\\"string\\\"}, \\\"BlockStorageImage\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"overcloud-full\\\", \\\"description\\\": \\\"The disk image file to use for the role.\\\"}, \\\"ImageUpdatePolicy\\\": {\\\"default\\\": \\\"REBUILD_PRESERVE_EPHEMERAL\\\", \\\"description\\\": \\\"What policy to use when reconstructing instances. REBUILD for rebuilds, REBUILD_PRESERVE_EPHEMERAL to preserve /mnt.\\\", \\\"type\\\": \\\"string\\\"}, \\\"KeyName\\\": {\\\"description\\\": \\\"Name of an existing Nova key pair to enable SSH access to the instances\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"default\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"UpdateIdentifier\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Setting to a previously unused value during stack-update will trigger package update on all nodes\\\\n\\\"}, \\\"Hostname\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\"}, \\\"HostnameMap\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {}, \\\"description\\\": \\\"Optional mapping to override hostnames\\\"}, \\\"BlockStorageIPs\\\": {\\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}, \\\"SoftwareConfigTransport\\\": {\\\"default\\\": \\\"POLL_SERVER_CFN\\\", \\\"description\\\": \\\"How the server should receive the metadata required for software configuration.\\\\n\\\", \\\"type\\\": \\\"string\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"POLL_SERVER_CFN\\\", \\\"POLL_SERVER_HEAT\\\", \\\"POLL_TEMP_URL\\\", \\\"ZAQAR_MESSAGE\\\"]}]}, \\\"CloudDomain\\\": {\\\"default\\\": \\\"localdomain\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"The DNS domain used for the hosts. This must match the overcloud_domain_name configured on the undercloud.\\\\n\\\"}, \\\"BlockStorageServerMetadata\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API. This option is role-specific and is merged with the values given to the ServerMetadata parameter.\\\\n\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServerMetadata\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API. This applies to all roles and is merged with a role-specific metadata parameter.\\\\n\\\", \\\"type\\\": \\\"json\\\"}, \\\"BlockStorageSchedulerHints\\\": {\\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"Optional scheduler hints to pass to nova\\\", \\\"default\\\": {}}, \\\"NodeIndex\\\": {\\\"type\\\": \\\"number\\\", \\\"default\\\": 0}, \\\"ServiceNames\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": []}, \\\"MonitoringSubscriptions\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": []}, \\\"ServiceMetadataSettings\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {}}, \\\"OVNBridgeMappings\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": []}, \\\"ConfigCommand\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Command which will be run whenever configuration data changes\\\", \\\"default\\\": \\\"os-refresh-config --timeout 14400\\\"}, \\\"ConfigCollectSplay\\\": {\\\"type\\\": \\\"number\\\", \\\"default\\\": 30, \\\"description\\\": \\\"Maximum amount of time to possibly to delay configuration collection\\\\npolling. Defaults to 30 seconds. Set to 0 to disable it which will cause\\\\nthe configuration collection to occur as soon as the collection process\\\\nstarts.  This setting is used to prevent the configuration collection\\\\nprocesses from polling all at the exact same time.\\\\n\\\"}, \\\"UpgradeInitCommand\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Command or script snippet to run on all overcloud nodes to\\\\ninitialize the upgrade process. E.g. a repository switch.\\\\n\\\", \\\"default\\\": \\\"\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"UpgradeInitCommonCommand\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Common commands required by the upgrades process. This should not\\\\nnormally be modified by the operator and is set and unset in the\\\\nmajor-upgrade-composable-steps.yaml and major-upgrade-converge.yaml\\\\nenvironment files.\\\\n\\\", \\\"default\\\": \\\"\\\"}, \\\"DeploymentServerBlacklistDict\\\": {\\\"default\\\": {}, \\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"Map of server hostnames to blacklist from any triggered deployments. If the value is 1, the server will be blacklisted. This parameter is generated from the parent template.\\\\n\\\"}, \\\"RoleParameters\\\": {\\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"default\\\": {}}, \\\"BlockStorageControlPlaneSubnet\\\": {\\\"default\\\": \\\"ctlplane-subnet\\\", \\\"description\\\": \\\"Name of the subnet on ctlplane network for this role.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneSubnetCidr\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"ServerDeletionPolicy\\\": {\\\"description\\\": \\\"Whether to retain or delete servers on deletion of the stack\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"delete\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"delete\\\", \\\"retain\\\"]}]}, \\\"UserData\\\": {\\\"type\\\": \\\"string\\\"}}, \\\"conditions\\\": {\\\"server_blacklisted\\\": {\\\"or\\\": [{\\\"equals\\\": [{\\\"get_param\\\": [\\\"DeploymentServerBlacklistDict\\\", {\\\"get_param\\\": \\\"Hostname\\\"}]}, 1]}, {\\\"equals\\\": [{\\\"get_param\\\": [\\\"DeploymentServerBlacklistDict\\\", {\\\"get_param\\\": [\\\"HostnameMap\\\", {\\\"get_param\\\": \\\"Hostname\\\"}]}]}, 1]}]}, \\\"server_not_blacklisted\\\": {\\\"and\\\": [{\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"DeploymentServerBlacklistDict\\\", {\\\"get_param\\\": \\\"Hostname\\\"}]}, 1]}}, {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"DeploymentServerBlacklistDict\\\", {\\\"get_param\\\": [\\\"HostnameMap\\\", {\\\"get_param\\\": \\\"Hostname\\\"}]}]}, 1]}}]}, \\\"ctlplane_fixed_ip_set\\\": {\\\"or\\\": [{\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"BlockStorageIPs\\\", \\\"ctlplane\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}, \\\"\\\"]}}, false]}, \\\"BlockStorage_Storage_fixed_ip_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"BlockStorageIPs\\\", \\\"storage\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}, \\\"\\\"]}}, \\\"BlockStorage_StorageMgmt_fixed_ip_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"BlockStorageIPs\\\", \\\"storage_mgmt\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}, \\\"\\\"]}}, \\\"BlockStorage_InternalApi_fixed_ip_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"BlockStorageIPs\\\", \\\"internal_api\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}, \\\"\\\"]}}}, \\\"resources\\\": {\\\"BlockStorage\\\": {\\\"type\\\": \\\"OS::TripleO::BlockStorageServer\\\", \\\"deletion_policy\\\": {\\\"get_param\\\": \\\"ServerDeletionPolicy\\\"}, \\\"properties\\\": {\\\"image\\\": {\\\"get_param\\\": \\\"BlockStorageImage\\\"}, \\\"image_update_policy\\\": {\\\"get_param\\\": \\\"ImageUpdatePolicy\\\"}, \\\"flavor\\\": {\\\"get_param\\\": \\\"OvercloudBlockStorageFlavor\\\"}, \\\"key_name\\\": {\\\"get_param\\\": \\\"KeyName\\\"}, \\\"networks\\\": [{\\\"if\\\": [\\\"ctlplane_fixed_ip_set\\\", {\\\"network\\\": \\\"ctlplane\\\", \\\"subnet\\\": {\\\"get_param\\\": \\\"BlockStorageControlPlaneSubnet\\\"}, \\\"fixed_ip\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"$.data.where(not isEmpty($)).first()\\\", \\\"data\\\": [{\\\"get_param\\\": [\\\"BlockStorageIPs\\\", \\\"ctlplane\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}]}}}, {\\\"network\\\": \\\"ctlplane\\\", \\\"subnet\\\": {\\\"get_param\\\": \\\"BlockStorageControlPlaneSubnet\\\"}}]}], \\\"user_data_format\\\": \\\"SOFTWARE_CONFIG\\\", \\\"user_data\\\": {\\\"get_param\\\": \\\"UserData\\\"}, \\\"name\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"$.data.hostname_map.get($.data.hostname, $.data.hostname).toLower()\\\", \\\"data\\\": {\\\"hostname\\\": {\\\"get_param\\\": \\\"Hostname\\\"}, \\\"hostname_map\\\": {\\\"get_param\\\": \\\"HostnameMap\\\"}}}}, \\\"software_config_transport\\\": {\\\"get_param\\\": \\\"SoftwareConfigTransport\\\"}, \\\"metadata\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"ServerMetadata\\\"}, {\\\"get_param\\\": \\\"BlockStorageServerMetadata\\\"}, {\\\"get_param\\\": \\\"ServiceMetadataSettings\\\"}]}, \\\"scheduler_hints\\\": {\\\"get_param\\\": \\\"BlockStorageSchedulerHints\\\"}}}, \\\"StoragePort\\\": {\\\"type\\\": \\\"OS::TripleO::BlockStorage::Ports::StoragePort\\\", \\\"properties\\\": {\\\"PortName\\\": {\\\"list_join\\\": [\\\"_\\\", [{\\\"get_attr\\\": [\\\"BlockStorage\\\", \\\"name\\\"]}, \\\"Storage\\\"]]}, \\\"DnsName\\\": {\\\"get_attr\\\": [\\\"BlockStorage\\\", \\\"name\\\"]}, \\\"ControlPlaneIP\\\": {\\\"get_attr\\\": [\\\"BlockStorage\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"FixedIPs\\\": {\\\"if\\\": [\\\"BlockStorage_Storage_fixed_ip_set\\\", [{\\\"ip_address\\\": {\\\"get_param\\\": [\\\"BlockStorageIPs\\\", \\\"storage\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}}], [{\\\"subnet\\\": \\\"storage_subnet\\\"}]]}, \\\"ControlPlaneSubnetCidr\\\": {\\\"str_split\\\": [\\\"/\\\", {\\\"get_attr\\\": [\\\"BlockStorage\\\", \\\"addresses\\\", \\\"ctlplane\\\", 0, \\\"subnets\\\", 0, \\\"cidr\\\"]}, -1]}, \\\"IPPool\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"BlockStorageIPs\\\"}]}, \\\"NodeIndex\\\": {\\\"get_param\\\": \\\"NodeIndex\\\"}, \\\"Role\\\": \\\"BlockStorage\\\"}}, \\\"StorageMgmtPort\\\": {\\\"type\\\": \\\"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\\\", \\\"properties\\\": {\\\"PortName\\\": {\\\"list_join\\\": [\\\"_\\\", [{\\\"get_attr\\\": [\\\"BlockStorage\\\", \\\"name\\\"]}, \\\"StorageMgmt\\\"]]}, \\\"DnsName\\\": {\\\"get_attr\\\": [\\\"BlockStorage\\\", \\\"name\\\"]}, \\\"ControlPlaneIP\\\": {\\\"get_attr\\\": [\\\"BlockStorage\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"FixedIPs\\\": {\\\"if\\\": [\\\"BlockStorage_StorageMgmt_fixed_ip_set\\\", [{\\\"ip_address\\\": {\\\"get_param\\\": [\\\"BlockStorageIPs\\\", \\\"storage_mgmt\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}}], [{\\\"subnet\\\": \\\"storage_mgmt_subnet\\\"}]]}, \\\"ControlPlaneSubnetCidr\\\": {\\\"str_split\\\": [\\\"/\\\", {\\\"get_attr\\\": [\\\"BlockStorage\\\", \\\"addresses\\\", \\\"ctlplane\\\", 0, \\\"subnets\\\", 0, \\\"cidr\\\"]}, -1]}, \\\"IPPool\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"BlockStorageIPs\\\"}]}, \\\"NodeIndex\\\": {\\\"get_param\\\": \\\"NodeIndex\\\"}, \\\"Role\\\": \\\"BlockStorage\\\"}}, \\\"InternalApiPort\\\": {\\\"type\\\": \\\"OS::TripleO::BlockStorage::Ports::InternalApiPort\\\", \\\"properties\\\": {\\\"PortName\\\": {\\\"list_join\\\": [\\\"_\\\", [{\\\"get_attr\\\": [\\\"BlockStorage\\\", \\\"name\\\"]}, \\\"InternalApi\\\"]]}, \\\"DnsName\\\": {\\\"get_attr\\\": [\\\"BlockStorage\\\", \\\"name\\\"]}, \\\"ControlPlaneIP\\\": {\\\"get_attr\\\": [\\\"BlockStorage\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"FixedIPs\\\": {\\\"if\\\": [\\\"BlockStorage_InternalApi_fixed_ip_set\\\", [{\\\"ip_address\\\": {\\\"get_param\\\": [\\\"BlockStorageIPs\\\", \\\"internal_api\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}}], [{\\\"subnet\\\": \\\"internal_api_subnet\\\"}]]}, \\\"ControlPlaneSubnetCidr\\\": {\\\"str_split\\\": [\\\"/\\\", {\\\"get_attr\\\": [\\\"BlockStorage\\\", \\\"addresses\\\", \\\"ctlplane\\\", 0, \\\"subnets\\\", 0, \\\"cidr\\\"]}, -1]}, \\\"IPPool\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"BlockStorageIPs\\\"}]}, \\\"NodeIndex\\\": {\\\"get_param\\\": \\\"NodeIndex\\\"}, \\\"Role\\\": \\\"BlockStorage\\\"}}, \\\"NetIpMap\\\": {\\\"type\\\": \\\"OS::TripleO::Network::Ports::NetIpMap\\\", \\\"properties\\\": {\\\"ControlPlaneIp\\\": {\\\"get_attr\\\": [\\\"BlockStorage\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"ControlPlaneSubnetCidr\\\": {\\\"str_split\\\": [\\\"/\\\", {\\\"get_attr\\\": [\\\"BlockStorage\\\", \\\"addresses\\\", \\\"ctlplane\\\", 0, \\\"subnets\\\", 0, \\\"cidr\\\"]}, -1]}, \\\"StorageIp\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address\\\"]}, \\\"StorageIpSubnet\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_subnet\\\"]}, \\\"StorageIpUri\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address_uri\\\"]}, \\\"StorageMgmtIp\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_address\\\"]}, \\\"StorageMgmtIpSubnet\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_subnet\\\"]}, \\\"StorageMgmtIpUri\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_address_uri\\\"]}, \\\"InternalApiIp\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address\\\"]}, \\\"InternalApiIpSubnet\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_subnet\\\"]}, \\\"InternalApiIpUri\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address_uri\\\"]}}}, \\\"NetHostMap\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"storage\\\": {\\\"fqdn\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"BlockStorage\\\", \\\"name\\\"]}, \\\"storage\\\", {\\\"get_param\\\": \\\"CloudDomain\\\"}]]}, \\\"short\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"BlockStorage\\\", \\\"name\\\"]}, \\\"storage\\\"]]}}, \\\"storage_mgmt\\\": {\\\"fqdn\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"BlockStorage\\\", \\\"name\\\"]}, \\\"storagemgmt\\\", {\\\"get_param\\\": \\\"CloudDomain\\\"}]]}, \\\"short\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"BlockStorage\\\", \\\"name\\\"]}, \\\"storagemgmt\\\"]]}}, \\\"internal_api\\\": {\\\"fqdn\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"BlockStorage\\\", \\\"name\\\"]}, \\\"internalapi\\\", {\\\"get_param\\\": \\\"CloudDomain\\\"}]]}, \\\"short\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"BlockStorage\\\", \\\"name\\\"]}, \\\"internalapi\\\"]]}}, \\\"ctlplane\\\": {\\\"fqdn\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"BlockStorage\\\", \\\"name\\\"]}, \\\"ctlplane\\\", {\\\"get_param\\\": \\\"CloudDomain\\\"}]]}, \\\"short\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"BlockStorage\\\", \\\"name\\\"]}, \\\"ctlplane\\\"]]}}, \\\"canonical\\\": {\\\"fqdn\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"BlockStorage\\\", \\\"name\\\"]}, {\\\"get_param\\\": \\\"CloudDomain\\\"}]]}, \\\"short\\\": [{\\\"get_attr\\\": [\\\"BlockStorage\\\", \\\"name\\\"]}]}}}}, \\\"PreNetworkConfig\\\": {\\\"type\\\": \\\"OS::TripleO::BlockStorage::PreNetworkConfig\\\", \\\"condition\\\": \\\"server_not_blacklisted\\\", \\\"properties\\\": {\\\"server\\\": {\\\"get_resource\\\": \\\"BlockStorage\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}, \\\"ServiceNames\\\": {\\\"get_param\\\": \\\"ServiceNames\\\"}, \\\"deployment_actions\\\": {\\\"get_attr\\\": [\\\"DeploymentActions\\\", \\\"value\\\"]}}}, \\\"NodeTLSCAData\\\": {\\\"type\\\": \\\"OS::TripleO::NodeTLSCAData\\\", \\\"properties\\\": {\\\"server\\\": {\\\"get_resource\\\": \\\"BlockStorage\\\"}}}, \\\"BlockStorageExtraConfigPre\\\": {\\\"type\\\": \\\"OS::TripleO::BlockStorageExtraConfigPre\\\", \\\"condition\\\": \\\"server_not_blacklisted\\\", \\\"properties\\\": {\\\"server\\\": {\\\"get_resource\\\": \\\"BlockStorage\\\"}}}, \\\"NodeExtraConfig\\\": {\\\"depends_on\\\": [\\\"BlockStorageExtraConfigPre\\\", \\\"NodeTLSCAData\\\"], \\\"type\\\": \\\"OS::TripleO::NodeExtraConfig\\\", \\\"condition\\\": \\\"server_not_blacklisted\\\", \\\"properties\\\": {\\\"server\\\": {\\\"get_resource\\\": \\\"BlockStorage\\\"}}}, \\\"DeploymentActions\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"value\\\": {\\\"if\\\": [\\\"server_not_blacklisted\\\", [\\\"CREATE\\\", \\\"UPDATE\\\"], []]}}}, \\\"BlockStorageAnsibleHostVars\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"fqdn_storage\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage\\\", \\\"fqdn\\\"]}, \\\"fqdn_storage_mgmt\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage_mgmt\\\", \\\"fqdn\\\"]}, \\\"fqdn_internal_api\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"internal_api\\\", \\\"fqdn\\\"]}, \\\"fqdn_ctlplane\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"ctlplane\\\", \\\"fqdn\\\"]}, \\\"fqdn_canonical\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"canonical\\\", \\\"fqdn\\\"]}, \\\"hostname_resolve_network\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"BlockStorageHostnameResolveNetwork\\\"]}}}}}, \\\"outputs\\\": {\\\"ansible_host_vars_map\\\": {\\\"description\\\": \\\"Map of Ansible variables specific per host.\\\\nThis map is used to construct the AnsibleHostVarsMap output for the\\\\nansible vars per host in config-download.\\\\n\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"host\\\": {\\\"get_attr\\\": [\\\"BlockStorageAnsibleHostVars\\\", \\\"value\\\"]}}, {\\\"keys\\\": {\\\"host\\\": {\\\"get_attr\\\": [\\\"BlockStorage\\\", \\\"name\\\"]}}}]}}, \\\"ip_address\\\": {\\\"description\\\": \\\"IP address of the server in the ctlplane network\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"BlockStorage\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}}, \\\"blacklist_ip_address\\\": {\\\"description\\\": \\\"IP address of the server if the server is blacklisted, otherwise this output will be an empty string\\\", \\\"value\\\": {\\\"if\\\": [\\\"server_blacklisted\\\", {\\\"get_attr\\\": [\\\"BlockStorage\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"\\\"]}}, \\\"blacklist_hostname\\\": {\\\"description\\\": \\\"Hostname of the server if the server is blacklisted, otherwise this output will be an empty string\\\", \\\"value\\\": {\\\"if\\\": [\\\"server_blacklisted\\\", {\\\"get_attr\\\": [\\\"BlockStorage\\\", \\\"name\\\"]}, \\\"\\\"]}}, \\\"hostname\\\": {\\\"description\\\": \\\"Hostname of the server\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"BlockStorage\\\", \\\"name\\\"]}}, \\\"hostname_map\\\": {\\\"description\\\": \\\"Mapping of network names to hostnames\\\", \\\"value\\\": {\\\"storage\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage\\\", \\\"fqdn\\\"]}, \\\"storage_mgmt\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage_mgmt\\\", \\\"fqdn\\\"]}, \\\"internal_api\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"internal_api\\\", \\\"fqdn\\\"]}, \\\"ctlplane\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"ctlplane\\\", \\\"fqdn\\\"]}, \\\"canonical\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"canonical\\\", \\\"fqdn\\\"]}}}, \\\"hosts_entry\\\": {\\\"value\\\": [{\\\"str_replace\\\": {\\\"template\\\": \\\"PRIMARYIP PRIMARYHOST.DOMAIN PRIMARYHOST\\\", \\\"params\\\": {\\\"PRIMARYIP\\\": {\\\"get_attr\\\": [\\\"NetIpMap\\\", \\\"net_ip_map\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"BlockStorageHostnameResolveNetwork\\\"]}]}, \\\"DOMAIN\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"PRIMARYHOST\\\": {\\\"get_attr\\\": [\\\"BlockStorage\\\", \\\"name\\\"]}}}}, {\\\"str_replace\\\": {\\\"template\\\": \\\"StorageIP StorageHOST.DOMAIN StorageHOST\\\", \\\"params\\\": {\\\"DOMAIN\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"StorageIP\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address\\\"]}, \\\"StorageHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage\\\", \\\"short\\\"]}, \\\"StorageMgmtIP\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_address\\\"]}, \\\"StorageMgmtHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage_mgmt\\\", \\\"short\\\"]}, \\\"InternalApiIP\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address\\\"]}, \\\"InternalApiHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"internal_api\\\", \\\"short\\\"]}}}}, {\\\"str_replace\\\": {\\\"template\\\": \\\"StorageMgmtIP StorageMgmtHOST.DOMAIN StorageMgmtHOST\\\", \\\"params\\\": {\\\"DOMAIN\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"StorageIP\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address\\\"]}, \\\"StorageHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage\\\", \\\"short\\\"]}, \\\"StorageMgmtIP\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_address\\\"]}, \\\"StorageMgmtHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage_mgmt\\\", \\\"short\\\"]}, \\\"InternalApiIP\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address\\\"]}, \\\"InternalApiHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"internal_api\\\", \\\"short\\\"]}}}}, {\\\"str_replace\\\": {\\\"template\\\": \\\"InternalApiIP InternalApiHOST.DOMAIN InternalApiHOST\\\", \\\"params\\\": {\\\"DOMAIN\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"StorageIP\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address\\\"]}, \\\"StorageHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage\\\", \\\"short\\\"]}, \\\"StorageMgmtIP\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_address\\\"]}, \\\"StorageMgmtHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage_mgmt\\\", \\\"short\\\"]}, \\\"InternalApiIP\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address\\\"]}, \\\"InternalApiHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"internal_api\\\", \\\"short\\\"]}}}}, {\\\"str_replace\\\": {\\\"template\\\": \\\"CTLPLANEIP CTLPLANEHOST.DOMAIN CTLPLANEHOST\\\", \\\"params\\\": {\\\"DOMAIN\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"CTLPLANEIP\\\": {\\\"get_attr\\\": [\\\"BlockStorage\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"CTLPLANEHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"ctlplane\\\", \\\"short\\\"]}}}}]}, \\\"nova_server_resource\\\": {\\\"description\\\": \\\"Heat resource handle for BlockStorage server\\\", \\\"value\\\": {\\\"get_resource\\\": \\\"BlockStorage\\\"}, \\\"condition\\\": \\\"server_not_blacklisted\\\"}, \\\"deployed_server_port_map\\\": {\\\"description\\\": \\\"Map of Heat created hostname of the server to ip address. This is the\\\\nhostname before it has been mapped with the HostnameMap parameter, and\\\\nthe IP address from the ctlplane network. This map can be used to construct\\\\nthe DeployedServerPortMap parameter when using split-stack.\\\\n\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"hostname\\\": {\\\"fixed_ips\\\": [{\\\"ip_address\\\": {\\\"get_attr\\\": [\\\"BlockStorage\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}}], \\\"subnets\\\": [{\\\"cidr\\\": {\\\"get_attr\\\": [\\\"BlockStorage\\\", \\\"addresses\\\", \\\"ctlplane\\\", 0, \\\"subnets\\\", 0, \\\"cidr\\\"]}}]}}, {\\\"keys\\\": {\\\"hostname\\\": {\\\"list_join\\\": [\\\"-\\\", [{\\\"get_param\\\": \\\"Hostname\\\"}, \\\"ctlplane\\\"]]}}}]}}, \\\"storage_ip_address\\\": {\\\"description\\\": \\\"IP address of the server in the Storage network\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address\\\"]}}, \\\"storage_mgmt_ip_address\\\": {\\\"description\\\": \\\"IP address of the server in the StorageMgmt network\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_address\\\"]}}, \\\"internal_api_ip_address\\\": {\\\"description\\\": \\\"IP address of the server in the InternalApi network\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address\\\"]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack ObjectStorage node configured by Puppet\\\", \\\"parameters\\\": {\\\"OvercloudSwiftStorageFlavor\\\": {\\\"description\\\": \\\"DEPRECATED Use OvercloudObjectStorageFlavor instead.\\\", \\\"default\\\": \\\"baremetal\\\", \\\"type\\\": \\\"string\\\"}, \\\"OvercloudObjectStorageFlavor\\\": {\\\"description\\\": \\\"Flavor for the ObjectStorage node.\\\", \\\"default\\\": \\\"baremetal\\\", \\\"type\\\": \\\"string\\\"}, \\\"SwiftStorageImage\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"overcloud-full\\\", \\\"description\\\": \\\"DEPRECATED Use ObjectStorageImage instead\\\"}, \\\"ObjectStorageImage\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"overcloud-full\\\", \\\"description\\\": \\\"The disk image file to use for the role.\\\"}, \\\"ImageUpdatePolicy\\\": {\\\"default\\\": \\\"REBUILD_PRESERVE_EPHEMERAL\\\", \\\"description\\\": \\\"What policy to use when reconstructing instances. REBUILD for rebuilds, REBUILD_PRESERVE_EPHEMERAL to preserve /mnt.\\\", \\\"type\\\": \\\"string\\\"}, \\\"KeyName\\\": {\\\"description\\\": \\\"Name of an existing Nova key pair to enable SSH access to the instances\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"default\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"UpdateIdentifier\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Setting to a previously unused value during stack-update will trigger package update on all nodes\\\\n\\\"}, \\\"Hostname\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\"}, \\\"HostnameMap\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {}, \\\"description\\\": \\\"Optional mapping to override hostnames\\\"}, \\\"ObjectStorageIPs\\\": {\\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}, \\\"SwiftStorageIPs\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"DEPRECATED - use ObjectStorageIPs instead\\\", \\\"type\\\": \\\"json\\\"}, \\\"SoftwareConfigTransport\\\": {\\\"default\\\": \\\"POLL_SERVER_CFN\\\", \\\"description\\\": \\\"How the server should receive the metadata required for software configuration.\\\\n\\\", \\\"type\\\": \\\"string\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"POLL_SERVER_CFN\\\", \\\"POLL_SERVER_HEAT\\\", \\\"POLL_TEMP_URL\\\", \\\"ZAQAR_MESSAGE\\\"]}]}, \\\"CloudDomain\\\": {\\\"default\\\": \\\"localdomain\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"The DNS domain used for the hosts. This must match the overcloud_domain_name configured on the undercloud.\\\\n\\\"}, \\\"ObjectStorageServerMetadata\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API. This option is role-specific and is merged with the values given to the ServerMetadata parameter.\\\\n\\\", \\\"type\\\": \\\"json\\\"}, \\\"SwiftStorageServerMetadata\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"DEPRECATED - use ObjectStorageServerMetadata instead\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServerMetadata\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API. This applies to all roles and is merged with a role-specific metadata parameter.\\\\n\\\", \\\"type\\\": \\\"json\\\"}, \\\"ObjectStorageSchedulerHints\\\": {\\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"Optional scheduler hints to pass to nova\\\", \\\"default\\\": {}}, \\\"NodeIndex\\\": {\\\"type\\\": \\\"number\\\", \\\"default\\\": 0}, \\\"ServiceNames\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": []}, \\\"MonitoringSubscriptions\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": []}, \\\"ServiceMetadataSettings\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {}}, \\\"OVNBridgeMappings\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": []}, \\\"ConfigCommand\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Command which will be run whenever configuration data changes\\\", \\\"default\\\": \\\"os-refresh-config --timeout 14400\\\"}, \\\"ConfigCollectSplay\\\": {\\\"type\\\": \\\"number\\\", \\\"default\\\": 30, \\\"description\\\": \\\"Maximum amount of time to possibly to delay configuration collection\\\\npolling. Defaults to 30 seconds. Set to 0 to disable it which will cause\\\\nthe configuration collection to occur as soon as the collection process\\\\nstarts.  This setting is used to prevent the configuration collection\\\\nprocesses from polling all at the exact same time.\\\\n\\\"}, \\\"UpgradeInitCommand\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Command or script snippet to run on all overcloud nodes to\\\\ninitialize the upgrade process. E.g. a repository switch.\\\\n\\\", \\\"default\\\": \\\"\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"UpgradeInitCommonCommand\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Common commands required by the upgrades process. This should not\\\\nnormally be modified by the operator and is set and unset in the\\\\nmajor-upgrade-composable-steps.yaml and major-upgrade-converge.yaml\\\\nenvironment files.\\\\n\\\", \\\"default\\\": \\\"\\\"}, \\\"DeploymentServerBlacklistDict\\\": {\\\"default\\\": {}, \\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"Map of server hostnames to blacklist from any triggered deployments. If the value is 1, the server will be blacklisted. This parameter is generated from the parent template.\\\\n\\\"}, \\\"RoleParameters\\\": {\\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"default\\\": {}}, \\\"ObjectStorageControlPlaneSubnet\\\": {\\\"default\\\": \\\"ctlplane-subnet\\\", \\\"description\\\": \\\"Name of the subnet on ctlplane network for this role.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneSubnetCidr\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"ServerDeletionPolicy\\\": {\\\"description\\\": \\\"Whether to retain or delete servers on deletion of the stack\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"delete\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"delete\\\", \\\"retain\\\"]}]}, \\\"UserData\\\": {\\\"type\\\": \\\"string\\\"}}, \\\"parameter_groups\\\": [{\\\"label\\\": \\\"deprecated\\\", \\\"description\\\": \\\"Do not use deprecated params, they will be removed.\\\", \\\"parameters\\\": [\\\"SwiftStorageServerMetadata\\\", \\\"SwiftStorageIPs\\\", \\\"SwiftStorageImage\\\", \\\"OvercloudSwiftStorageFlavor\\\"]}], \\\"conditions\\\": {\\\"server_blacklisted\\\": {\\\"or\\\": [{\\\"equals\\\": [{\\\"get_param\\\": [\\\"DeploymentServerBlacklistDict\\\", {\\\"get_param\\\": \\\"Hostname\\\"}]}, 1]}, {\\\"equals\\\": [{\\\"get_param\\\": [\\\"DeploymentServerBlacklistDict\\\", {\\\"get_param\\\": [\\\"HostnameMap\\\", {\\\"get_param\\\": \\\"Hostname\\\"}]}]}, 1]}]}, \\\"server_not_blacklisted\\\": {\\\"and\\\": [{\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"DeploymentServerBlacklistDict\\\", {\\\"get_param\\\": \\\"Hostname\\\"}]}, 1]}}, {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"DeploymentServerBlacklistDict\\\", {\\\"get_param\\\": [\\\"HostnameMap\\\", {\\\"get_param\\\": \\\"Hostname\\\"}]}]}, 1]}}]}, \\\"deprecated_param_image_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"SwiftStorageImage\\\"}, \\\"overcloud-full\\\"]}}, \\\"deprecated_param_flavor_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"OvercloudSwiftStorageFlavor\\\"}, \\\"baremetal\\\"]}}, \\\"ctlplane_fixed_ip_set\\\": {\\\"or\\\": [{\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"ObjectStorageIPs\\\", \\\"ctlplane\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}, \\\"\\\"]}}, {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"SwiftStorageIPs\\\", \\\"ctlplane\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}, \\\"\\\"]}}, false]}, \\\"ObjectStorage_Storage_fixed_ip_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"ObjectStorageIPs\\\", \\\"storage\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}, \\\"\\\"]}}, \\\"ObjectStorage_StorageMgmt_fixed_ip_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"ObjectStorageIPs\\\", \\\"storage_mgmt\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}, \\\"\\\"]}}, \\\"ObjectStorage_InternalApi_fixed_ip_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"ObjectStorageIPs\\\", \\\"internal_api\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}, \\\"\\\"]}}}, \\\"resources\\\": {\\\"SwiftStorage\\\": {\\\"type\\\": \\\"OS::TripleO::ObjectStorageServer\\\", \\\"deletion_policy\\\": {\\\"get_param\\\": \\\"ServerDeletionPolicy\\\"}, \\\"properties\\\": {\\\"image\\\": {\\\"if\\\": [\\\"deprecated_param_image_set\\\", {\\\"get_param\\\": \\\"SwiftStorageImage\\\"}, {\\\"get_param\\\": \\\"ObjectStorageImage\\\"}]}, \\\"image_update_policy\\\": {\\\"get_param\\\": \\\"ImageUpdatePolicy\\\"}, \\\"flavor\\\": {\\\"if\\\": [\\\"deprecated_param_flavor_set\\\", {\\\"get_param\\\": \\\"OvercloudSwiftStorageFlavor\\\"}, {\\\"get_param\\\": \\\"OvercloudObjectStorageFlavor\\\"}]}, \\\"key_name\\\": {\\\"get_param\\\": \\\"KeyName\\\"}, \\\"networks\\\": [{\\\"if\\\": [\\\"ctlplane_fixed_ip_set\\\", {\\\"network\\\": \\\"ctlplane\\\", \\\"subnet\\\": {\\\"get_param\\\": \\\"ObjectStorageControlPlaneSubnet\\\"}, \\\"fixed_ip\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"$.data.where(not isEmpty($)).first()\\\", \\\"data\\\": [{\\\"get_param\\\": [\\\"ObjectStorageIPs\\\", \\\"ctlplane\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}, {\\\"get_param\\\": [\\\"SwiftStorageIPs\\\", \\\"ctlplane\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}]}}}, {\\\"network\\\": \\\"ctlplane\\\", \\\"subnet\\\": {\\\"get_param\\\": \\\"ObjectStorageControlPlaneSubnet\\\"}}]}], \\\"user_data_format\\\": \\\"SOFTWARE_CONFIG\\\", \\\"user_data\\\": {\\\"get_param\\\": \\\"UserData\\\"}, \\\"name\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"$.data.hostname_map.get($.data.hostname, $.data.hostname).toLower()\\\", \\\"data\\\": {\\\"hostname\\\": {\\\"get_param\\\": \\\"Hostname\\\"}, \\\"hostname_map\\\": {\\\"get_param\\\": \\\"HostnameMap\\\"}}}}, \\\"software_config_transport\\\": {\\\"get_param\\\": \\\"SoftwareConfigTransport\\\"}, \\\"metadata\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"ServerMetadata\\\"}, {\\\"get_param\\\": \\\"SwiftStorageServerMetadata\\\"}, {\\\"get_param\\\": \\\"ObjectStorageServerMetadata\\\"}, {\\\"get_param\\\": \\\"ServiceMetadataSettings\\\"}]}, \\\"scheduler_hints\\\": {\\\"get_param\\\": \\\"ObjectStorageSchedulerHints\\\"}}}, \\\"StoragePort\\\": {\\\"type\\\": \\\"OS::TripleO::ObjectStorage::Ports::StoragePort\\\", \\\"properties\\\": {\\\"PortName\\\": {\\\"list_join\\\": [\\\"_\\\", [{\\\"get_attr\\\": [\\\"SwiftStorage\\\", \\\"name\\\"]}, \\\"Storage\\\"]]}, \\\"DnsName\\\": {\\\"get_attr\\\": [\\\"SwiftStorage\\\", \\\"name\\\"]}, \\\"ControlPlaneIP\\\": {\\\"get_attr\\\": [\\\"SwiftStorage\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"FixedIPs\\\": {\\\"if\\\": [\\\"ObjectStorage_Storage_fixed_ip_set\\\", [{\\\"ip_address\\\": {\\\"get_param\\\": [\\\"ObjectStorageIPs\\\", \\\"storage\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}}], [{\\\"subnet\\\": \\\"storage_subnet\\\"}]]}, \\\"ControlPlaneSubnetCidr\\\": {\\\"str_split\\\": [\\\"/\\\", {\\\"get_attr\\\": [\\\"SwiftStorage\\\", \\\"addresses\\\", \\\"ctlplane\\\", 0, \\\"subnets\\\", 0, \\\"cidr\\\"]}, -1]}, \\\"IPPool\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"SwiftStorageIPs\\\"}, {\\\"get_param\\\": \\\"ObjectStorageIPs\\\"}]}, \\\"NodeIndex\\\": {\\\"get_param\\\": \\\"NodeIndex\\\"}, \\\"Role\\\": \\\"ObjectStorage\\\"}}, \\\"StorageMgmtPort\\\": {\\\"type\\\": \\\"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\\\", \\\"properties\\\": {\\\"PortName\\\": {\\\"list_join\\\": [\\\"_\\\", [{\\\"get_attr\\\": [\\\"SwiftStorage\\\", \\\"name\\\"]}, \\\"StorageMgmt\\\"]]}, \\\"DnsName\\\": {\\\"get_attr\\\": [\\\"SwiftStorage\\\", \\\"name\\\"]}, \\\"ControlPlaneIP\\\": {\\\"get_attr\\\": [\\\"SwiftStorage\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"FixedIPs\\\": {\\\"if\\\": [\\\"ObjectStorage_StorageMgmt_fixed_ip_set\\\", [{\\\"ip_address\\\": {\\\"get_param\\\": [\\\"ObjectStorageIPs\\\", \\\"storage_mgmt\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}}], [{\\\"subnet\\\": \\\"storage_mgmt_subnet\\\"}]]}, \\\"ControlPlaneSubnetCidr\\\": {\\\"str_split\\\": [\\\"/\\\", {\\\"get_attr\\\": [\\\"SwiftStorage\\\", \\\"addresses\\\", \\\"ctlplane\\\", 0, \\\"subnets\\\", 0, \\\"cidr\\\"]}, -1]}, \\\"IPPool\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"SwiftStorageIPs\\\"}, {\\\"get_param\\\": \\\"ObjectStorageIPs\\\"}]}, \\\"NodeIndex\\\": {\\\"get_param\\\": \\\"NodeIndex\\\"}, \\\"Role\\\": \\\"ObjectStorage\\\"}}, \\\"InternalApiPort\\\": {\\\"type\\\": \\\"OS::TripleO::ObjectStorage::Ports::InternalApiPort\\\", \\\"properties\\\": {\\\"PortName\\\": {\\\"list_join\\\": [\\\"_\\\", [{\\\"get_attr\\\": [\\\"SwiftStorage\\\", \\\"name\\\"]}, \\\"InternalApi\\\"]]}, \\\"DnsName\\\": {\\\"get_attr\\\": [\\\"SwiftStorage\\\", \\\"name\\\"]}, \\\"ControlPlaneIP\\\": {\\\"get_attr\\\": [\\\"SwiftStorage\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"FixedIPs\\\": {\\\"if\\\": [\\\"ObjectStorage_InternalApi_fixed_ip_set\\\", [{\\\"ip_address\\\": {\\\"get_param\\\": [\\\"ObjectStorageIPs\\\", \\\"internal_api\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}}], [{\\\"subnet\\\": \\\"internal_api_subnet\\\"}]]}, \\\"ControlPlaneSubnetCidr\\\": {\\\"str_split\\\": [\\\"/\\\", {\\\"get_attr\\\": [\\\"SwiftStorage\\\", \\\"addresses\\\", \\\"ctlplane\\\", 0, \\\"subnets\\\", 0, \\\"cidr\\\"]}, -1]}, \\\"IPPool\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"SwiftStorageIPs\\\"}, {\\\"get_param\\\": \\\"ObjectStorageIPs\\\"}]}, \\\"NodeIndex\\\": {\\\"get_param\\\": \\\"NodeIndex\\\"}, \\\"Role\\\": \\\"ObjectStorage\\\"}}, \\\"NetIpMap\\\": {\\\"type\\\": \\\"OS::TripleO::Network::Ports::NetIpMap\\\", \\\"properties\\\": {\\\"ControlPlaneIp\\\": {\\\"get_attr\\\": [\\\"SwiftStorage\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"ControlPlaneSubnetCidr\\\": {\\\"str_split\\\": [\\\"/\\\", {\\\"get_attr\\\": [\\\"SwiftStorage\\\", \\\"addresses\\\", \\\"ctlplane\\\", 0, \\\"subnets\\\", 0, \\\"cidr\\\"]}, -1]}, \\\"StorageIp\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address\\\"]}, \\\"StorageIpSubnet\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_subnet\\\"]}, \\\"StorageIpUri\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address_uri\\\"]}, \\\"StorageMgmtIp\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_address\\\"]}, \\\"StorageMgmtIpSubnet\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_subnet\\\"]}, \\\"StorageMgmtIpUri\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_address_uri\\\"]}, \\\"InternalApiIp\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address\\\"]}, \\\"InternalApiIpSubnet\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_subnet\\\"]}, \\\"InternalApiIpUri\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address_uri\\\"]}}}, \\\"NetHostMap\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"storage\\\": {\\\"fqdn\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"SwiftStorage\\\", \\\"name\\\"]}, \\\"storage\\\", {\\\"get_param\\\": \\\"CloudDomain\\\"}]]}, \\\"short\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"SwiftStorage\\\", \\\"name\\\"]}, \\\"storage\\\"]]}}, \\\"storage_mgmt\\\": {\\\"fqdn\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"SwiftStorage\\\", \\\"name\\\"]}, \\\"storagemgmt\\\", {\\\"get_param\\\": \\\"CloudDomain\\\"}]]}, \\\"short\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"SwiftStorage\\\", \\\"name\\\"]}, \\\"storagemgmt\\\"]]}}, \\\"internal_api\\\": {\\\"fqdn\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"SwiftStorage\\\", \\\"name\\\"]}, \\\"internalapi\\\", {\\\"get_param\\\": \\\"CloudDomain\\\"}]]}, \\\"short\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"SwiftStorage\\\", \\\"name\\\"]}, \\\"internalapi\\\"]]}}, \\\"ctlplane\\\": {\\\"fqdn\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"SwiftStorage\\\", \\\"name\\\"]}, \\\"ctlplane\\\", {\\\"get_param\\\": \\\"CloudDomain\\\"}]]}, \\\"short\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"SwiftStorage\\\", \\\"name\\\"]}, \\\"ctlplane\\\"]]}}, \\\"canonical\\\": {\\\"fqdn\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"SwiftStorage\\\", \\\"name\\\"]}, {\\\"get_param\\\": \\\"CloudDomain\\\"}]]}, \\\"short\\\": [{\\\"get_attr\\\": [\\\"SwiftStorage\\\", \\\"name\\\"]}]}}}}, \\\"PreNetworkConfig\\\": {\\\"type\\\": \\\"OS::TripleO::ObjectStorage::PreNetworkConfig\\\", \\\"condition\\\": \\\"server_not_blacklisted\\\", \\\"properties\\\": {\\\"server\\\": {\\\"get_resource\\\": \\\"SwiftStorage\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}, \\\"ServiceNames\\\": {\\\"get_param\\\": \\\"ServiceNames\\\"}, \\\"deployment_actions\\\": {\\\"get_attr\\\": [\\\"DeploymentActions\\\", \\\"value\\\"]}}}, \\\"NodeTLSCAData\\\": {\\\"type\\\": \\\"OS::TripleO::NodeTLSCAData\\\", \\\"properties\\\": {\\\"server\\\": {\\\"get_resource\\\": \\\"SwiftStorage\\\"}}}, \\\"ObjectStorageExtraConfigPre\\\": {\\\"type\\\": \\\"OS::TripleO::ObjectStorageExtraConfigPre\\\", \\\"condition\\\": \\\"server_not_blacklisted\\\", \\\"properties\\\": {\\\"server\\\": {\\\"get_resource\\\": \\\"SwiftStorage\\\"}}}, \\\"NodeExtraConfig\\\": {\\\"depends_on\\\": [\\\"ObjectStorageExtraConfigPre\\\", \\\"NodeTLSCAData\\\"], \\\"type\\\": \\\"OS::TripleO::NodeExtraConfig\\\", \\\"condition\\\": \\\"server_not_blacklisted\\\", \\\"properties\\\": {\\\"server\\\": {\\\"get_resource\\\": \\\"SwiftStorage\\\"}}}, \\\"DeploymentActions\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"value\\\": {\\\"if\\\": [\\\"server_not_blacklisted\\\", [\\\"CREATE\\\", \\\"UPDATE\\\"], []]}}}, \\\"SwiftStorageAnsibleHostVars\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"fqdn_storage\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage\\\", \\\"fqdn\\\"]}, \\\"fqdn_storage_mgmt\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage_mgmt\\\", \\\"fqdn\\\"]}, \\\"fqdn_internal_api\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"internal_api\\\", \\\"fqdn\\\"]}, \\\"fqdn_ctlplane\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"ctlplane\\\", \\\"fqdn\\\"]}, \\\"fqdn_canonical\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"canonical\\\", \\\"fqdn\\\"]}, \\\"hostname_resolve_network\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"ObjectStorageHostnameResolveNetwork\\\"]}}}}}, \\\"outputs\\\": {\\\"ansible_host_vars_map\\\": {\\\"description\\\": \\\"Map of Ansible variables specific per host.\\\\nThis map is used to construct the AnsibleHostVarsMap output for the\\\\nansible vars per host in config-download.\\\\n\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"host\\\": {\\\"get_attr\\\": [\\\"SwiftStorageAnsibleHostVars\\\", \\\"value\\\"]}}, {\\\"keys\\\": {\\\"host\\\": {\\\"get_attr\\\": [\\\"SwiftStorage\\\", \\\"name\\\"]}}}]}}, \\\"ip_address\\\": {\\\"description\\\": \\\"IP address of the server in the ctlplane network\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"SwiftStorage\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}}, \\\"blacklist_ip_address\\\": {\\\"description\\\": \\\"IP address of the server if the server is blacklisted, otherwise this output will be an empty string\\\", \\\"value\\\": {\\\"if\\\": [\\\"server_blacklisted\\\", {\\\"get_attr\\\": [\\\"SwiftStorage\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"\\\"]}}, \\\"blacklist_hostname\\\": {\\\"description\\\": \\\"Hostname of the server if the server is blacklisted, otherwise this output will be an empty string\\\", \\\"value\\\": {\\\"if\\\": [\\\"server_blacklisted\\\", {\\\"get_attr\\\": [\\\"SwiftStorage\\\", \\\"name\\\"]}, \\\"\\\"]}}, \\\"hostname\\\": {\\\"description\\\": \\\"Hostname of the server\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"SwiftStorage\\\", \\\"name\\\"]}}, \\\"hostname_map\\\": {\\\"description\\\": \\\"Mapping of network names to hostnames\\\", \\\"value\\\": {\\\"storage\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage\\\", \\\"fqdn\\\"]}, \\\"storage_mgmt\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage_mgmt\\\", \\\"fqdn\\\"]}, \\\"internal_api\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"internal_api\\\", \\\"fqdn\\\"]}, \\\"ctlplane\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"ctlplane\\\", \\\"fqdn\\\"]}, \\\"canonical\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"canonical\\\", \\\"fqdn\\\"]}}}, \\\"hosts_entry\\\": {\\\"value\\\": [{\\\"str_replace\\\": {\\\"template\\\": \\\"PRIMARYIP PRIMARYHOST.DOMAIN PRIMARYHOST\\\", \\\"params\\\": {\\\"PRIMARYIP\\\": {\\\"get_attr\\\": [\\\"NetIpMap\\\", \\\"net_ip_map\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"ObjectStorageHostnameResolveNetwork\\\"]}]}, \\\"DOMAIN\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"PRIMARYHOST\\\": {\\\"get_attr\\\": [\\\"SwiftStorage\\\", \\\"name\\\"]}}}}, {\\\"str_replace\\\": {\\\"template\\\": \\\"StorageIP StorageHOST.DOMAIN StorageHOST\\\", \\\"params\\\": {\\\"DOMAIN\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"StorageIP\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address\\\"]}, \\\"StorageHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage\\\", \\\"short\\\"]}, \\\"StorageMgmtIP\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_address\\\"]}, \\\"StorageMgmtHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage_mgmt\\\", \\\"short\\\"]}, \\\"InternalApiIP\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address\\\"]}, \\\"InternalApiHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"internal_api\\\", \\\"short\\\"]}}}}, {\\\"str_replace\\\": {\\\"template\\\": \\\"StorageMgmtIP StorageMgmtHOST.DOMAIN StorageMgmtHOST\\\", \\\"params\\\": {\\\"DOMAIN\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"StorageIP\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address\\\"]}, \\\"StorageHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage\\\", \\\"short\\\"]}, \\\"StorageMgmtIP\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_address\\\"]}, \\\"StorageMgmtHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage_mgmt\\\", \\\"short\\\"]}, \\\"InternalApiIP\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address\\\"]}, \\\"InternalApiHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"internal_api\\\", \\\"short\\\"]}}}}, {\\\"str_replace\\\": {\\\"template\\\": \\\"InternalApiIP InternalApiHOST.DOMAIN InternalApiHOST\\\", \\\"params\\\": {\\\"DOMAIN\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"StorageIP\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address\\\"]}, \\\"StorageHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage\\\", \\\"short\\\"]}, \\\"StorageMgmtIP\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_address\\\"]}, \\\"StorageMgmtHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage_mgmt\\\", \\\"short\\\"]}, \\\"InternalApiIP\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address\\\"]}, \\\"InternalApiHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"internal_api\\\", \\\"short\\\"]}}}}, {\\\"str_replace\\\": {\\\"template\\\": \\\"CTLPLANEIP CTLPLANEHOST.DOMAIN CTLPLANEHOST\\\", \\\"params\\\": {\\\"DOMAIN\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"CTLPLANEIP\\\": {\\\"get_attr\\\": [\\\"SwiftStorage\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"CTLPLANEHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"ctlplane\\\", \\\"short\\\"]}}}}]}, \\\"nova_server_resource\\\": {\\\"description\\\": \\\"Heat resource handle for ObjectStorage server\\\", \\\"value\\\": {\\\"get_resource\\\": \\\"SwiftStorage\\\"}, \\\"condition\\\": \\\"server_not_blacklisted\\\"}, \\\"deployed_server_port_map\\\": {\\\"description\\\": \\\"Map of Heat created hostname of the server to ip address. This is the\\\\nhostname before it has been mapped with the HostnameMap parameter, and\\\\nthe IP address from the ctlplane network. This map can be used to construct\\\\nthe DeployedServerPortMap parameter when using split-stack.\\\\n\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"hostname\\\": {\\\"fixed_ips\\\": [{\\\"ip_address\\\": {\\\"get_attr\\\": [\\\"SwiftStorage\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}}], \\\"subnets\\\": [{\\\"cidr\\\": {\\\"get_attr\\\": [\\\"SwiftStorage\\\", \\\"addresses\\\", \\\"ctlplane\\\", 0, \\\"subnets\\\", 0, \\\"cidr\\\"]}}]}}, {\\\"keys\\\": {\\\"hostname\\\": {\\\"list_join\\\": [\\\"-\\\", [{\\\"get_param\\\": \\\"Hostname\\\"}, \\\"ctlplane\\\"]]}}}]}}, \\\"storage_ip_address\\\": {\\\"description\\\": \\\"IP address of the server in the Storage network\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address\\\"]}}, \\\"storage_mgmt_ip_address\\\": {\\\"description\\\": \\\"IP address of the server in the StorageMgmt network\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_address\\\"]}}, \\\"internal_api_ip_address\\\": {\\\"description\\\": \\\"IP address of the server in the InternalApi network\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address\\\"]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack CephStorage node configured by Puppet\\\", \\\"parameters\\\": {\\\"OvercloudCephStorageFlavor\\\": {\\\"description\\\": \\\"Flavor for the CephStorage node.\\\", \\\"default\\\": \\\"baremetal\\\", \\\"type\\\": \\\"string\\\"}, \\\"CephStorageImage\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"overcloud-full\\\", \\\"description\\\": \\\"The disk image file to use for the role.\\\"}, \\\"ImageUpdatePolicy\\\": {\\\"default\\\": \\\"REBUILD_PRESERVE_EPHEMERAL\\\", \\\"description\\\": \\\"What policy to use when reconstructing instances. REBUILD for rebuilds, REBUILD_PRESERVE_EPHEMERAL to preserve /mnt.\\\", \\\"type\\\": \\\"string\\\"}, \\\"KeyName\\\": {\\\"description\\\": \\\"Name of an existing Nova key pair to enable SSH access to the instances\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"default\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"UpdateIdentifier\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Setting to a previously unused value during stack-update will trigger package update on all nodes\\\\n\\\"}, \\\"Hostname\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\"}, \\\"HostnameMap\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {}, \\\"description\\\": \\\"Optional mapping to override hostnames\\\"}, \\\"CephStorageIPs\\\": {\\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}, \\\"SoftwareConfigTransport\\\": {\\\"default\\\": \\\"POLL_SERVER_CFN\\\", \\\"description\\\": \\\"How the server should receive the metadata required for software configuration.\\\\n\\\", \\\"type\\\": \\\"string\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"POLL_SERVER_CFN\\\", \\\"POLL_SERVER_HEAT\\\", \\\"POLL_TEMP_URL\\\", \\\"ZAQAR_MESSAGE\\\"]}]}, \\\"CloudDomain\\\": {\\\"default\\\": \\\"localdomain\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"The DNS domain used for the hosts. This must match the overcloud_domain_name configured on the undercloud.\\\\n\\\"}, \\\"CephStorageServerMetadata\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API. This option is role-specific and is merged with the values given to the ServerMetadata parameter.\\\\n\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServerMetadata\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API. This applies to all roles and is merged with a role-specific metadata parameter.\\\\n\\\", \\\"type\\\": \\\"json\\\"}, \\\"CephStorageSchedulerHints\\\": {\\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"Optional scheduler hints to pass to nova\\\", \\\"default\\\": {}}, \\\"NodeIndex\\\": {\\\"type\\\": \\\"number\\\", \\\"default\\\": 0}, \\\"ServiceNames\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": []}, \\\"MonitoringSubscriptions\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": []}, \\\"ServiceMetadataSettings\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {}}, \\\"OVNBridgeMappings\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": []}, \\\"ConfigCommand\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Command which will be run whenever configuration data changes\\\", \\\"default\\\": \\\"os-refresh-config --timeout 14400\\\"}, \\\"ConfigCollectSplay\\\": {\\\"type\\\": \\\"number\\\", \\\"default\\\": 30, \\\"description\\\": \\\"Maximum amount of time to possibly to delay configuration collection\\\\npolling. Defaults to 30 seconds. Set to 0 to disable it which will cause\\\\nthe configuration collection to occur as soon as the collection process\\\\nstarts.  This setting is used to prevent the configuration collection\\\\nprocesses from polling all at the exact same time.\\\\n\\\"}, \\\"UpgradeInitCommand\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Command or script snippet to run on all overcloud nodes to\\\\ninitialize the upgrade process. E.g. a repository switch.\\\\n\\\", \\\"default\\\": \\\"\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"UpgradeInitCommonCommand\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Common commands required by the upgrades process. This should not\\\\nnormally be modified by the operator and is set and unset in the\\\\nmajor-upgrade-composable-steps.yaml and major-upgrade-converge.yaml\\\\nenvironment files.\\\\n\\\", \\\"default\\\": \\\"\\\"}, \\\"DeploymentServerBlacklistDict\\\": {\\\"default\\\": {}, \\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"Map of server hostnames to blacklist from any triggered deployments. If the value is 1, the server will be blacklisted. This parameter is generated from the parent template.\\\\n\\\"}, \\\"RoleParameters\\\": {\\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"default\\\": {}}, \\\"CephStorageControlPlaneSubnet\\\": {\\\"default\\\": \\\"ctlplane-subnet\\\", \\\"description\\\": \\\"Name of the subnet on ctlplane network for this role.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneSubnetCidr\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"ServerDeletionPolicy\\\": {\\\"description\\\": \\\"Whether to retain or delete servers on deletion of the stack\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"delete\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"delete\\\", \\\"retain\\\"]}]}, \\\"UserData\\\": {\\\"type\\\": \\\"string\\\"}}, \\\"conditions\\\": {\\\"server_blacklisted\\\": {\\\"or\\\": [{\\\"equals\\\": [{\\\"get_param\\\": [\\\"DeploymentServerBlacklistDict\\\", {\\\"get_param\\\": \\\"Hostname\\\"}]}, 1]}, {\\\"equals\\\": [{\\\"get_param\\\": [\\\"DeploymentServerBlacklistDict\\\", {\\\"get_param\\\": [\\\"HostnameMap\\\", {\\\"get_param\\\": \\\"Hostname\\\"}]}]}, 1]}]}, \\\"server_not_blacklisted\\\": {\\\"and\\\": [{\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"DeploymentServerBlacklistDict\\\", {\\\"get_param\\\": \\\"Hostname\\\"}]}, 1]}}, {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"DeploymentServerBlacklistDict\\\", {\\\"get_param\\\": [\\\"HostnameMap\\\", {\\\"get_param\\\": \\\"Hostname\\\"}]}]}, 1]}}]}, \\\"ctlplane_fixed_ip_set\\\": {\\\"or\\\": [{\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"CephStorageIPs\\\", \\\"ctlplane\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}, \\\"\\\"]}}, false]}, \\\"CephStorage_Storage_fixed_ip_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"CephStorageIPs\\\", \\\"storage\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}, \\\"\\\"]}}, \\\"CephStorage_StorageMgmt_fixed_ip_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"CephStorageIPs\\\", \\\"storage_mgmt\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}, \\\"\\\"]}}}, \\\"resources\\\": {\\\"CephStorage\\\": {\\\"type\\\": \\\"OS::TripleO::CephStorageServer\\\", \\\"deletion_policy\\\": {\\\"get_param\\\": \\\"ServerDeletionPolicy\\\"}, \\\"properties\\\": {\\\"image\\\": {\\\"get_param\\\": \\\"CephStorageImage\\\"}, \\\"image_update_policy\\\": {\\\"get_param\\\": \\\"ImageUpdatePolicy\\\"}, \\\"flavor\\\": {\\\"get_param\\\": \\\"OvercloudCephStorageFlavor\\\"}, \\\"key_name\\\": {\\\"get_param\\\": \\\"KeyName\\\"}, \\\"networks\\\": [{\\\"if\\\": [\\\"ctlplane_fixed_ip_set\\\", {\\\"network\\\": \\\"ctlplane\\\", \\\"subnet\\\": {\\\"get_param\\\": \\\"CephStorageControlPlaneSubnet\\\"}, \\\"fixed_ip\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"$.data.where(not isEmpty($)).first()\\\", \\\"data\\\": [{\\\"get_param\\\": [\\\"CephStorageIPs\\\", \\\"ctlplane\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}]}}}, {\\\"network\\\": \\\"ctlplane\\\", \\\"subnet\\\": {\\\"get_param\\\": \\\"CephStorageControlPlaneSubnet\\\"}}]}], \\\"user_data_format\\\": \\\"SOFTWARE_CONFIG\\\", \\\"user_data\\\": {\\\"get_param\\\": \\\"UserData\\\"}, \\\"name\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"$.data.hostname_map.get($.data.hostname, $.data.hostname).toLower()\\\", \\\"data\\\": {\\\"hostname\\\": {\\\"get_param\\\": \\\"Hostname\\\"}, \\\"hostname_map\\\": {\\\"get_param\\\": \\\"HostnameMap\\\"}}}}, \\\"software_config_transport\\\": {\\\"get_param\\\": \\\"SoftwareConfigTransport\\\"}, \\\"metadata\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"ServerMetadata\\\"}, {\\\"get_param\\\": \\\"CephStorageServerMetadata\\\"}, {\\\"get_param\\\": \\\"ServiceMetadataSettings\\\"}]}, \\\"scheduler_hints\\\": {\\\"get_param\\\": \\\"CephStorageSchedulerHints\\\"}}}, \\\"StoragePort\\\": {\\\"type\\\": \\\"OS::TripleO::CephStorage::Ports::StoragePort\\\", \\\"properties\\\": {\\\"PortName\\\": {\\\"list_join\\\": [\\\"_\\\", [{\\\"get_attr\\\": [\\\"CephStorage\\\", \\\"name\\\"]}, \\\"Storage\\\"]]}, \\\"DnsName\\\": {\\\"get_attr\\\": [\\\"CephStorage\\\", \\\"name\\\"]}, \\\"ControlPlaneIP\\\": {\\\"get_attr\\\": [\\\"CephStorage\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"FixedIPs\\\": {\\\"if\\\": [\\\"CephStorage_Storage_fixed_ip_set\\\", [{\\\"ip_address\\\": {\\\"get_param\\\": [\\\"CephStorageIPs\\\", \\\"storage\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}}], [{\\\"subnet\\\": \\\"storage_subnet\\\"}]]}, \\\"ControlPlaneSubnetCidr\\\": {\\\"str_split\\\": [\\\"/\\\", {\\\"get_attr\\\": [\\\"CephStorage\\\", \\\"addresses\\\", \\\"ctlplane\\\", 0, \\\"subnets\\\", 0, \\\"cidr\\\"]}, -1]}, \\\"IPPool\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"CephStorageIPs\\\"}]}, \\\"NodeIndex\\\": {\\\"get_param\\\": \\\"NodeIndex\\\"}, \\\"Role\\\": \\\"CephStorage\\\"}}, \\\"StorageMgmtPort\\\": {\\\"type\\\": \\\"OS::TripleO::CephStorage::Ports::StorageMgmtPort\\\", \\\"properties\\\": {\\\"PortName\\\": {\\\"list_join\\\": [\\\"_\\\", [{\\\"get_attr\\\": [\\\"CephStorage\\\", \\\"name\\\"]}, \\\"StorageMgmt\\\"]]}, \\\"DnsName\\\": {\\\"get_attr\\\": [\\\"CephStorage\\\", \\\"name\\\"]}, \\\"ControlPlaneIP\\\": {\\\"get_attr\\\": [\\\"CephStorage\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"FixedIPs\\\": {\\\"if\\\": [\\\"CephStorage_StorageMgmt_fixed_ip_set\\\", [{\\\"ip_address\\\": {\\\"get_param\\\": [\\\"CephStorageIPs\\\", \\\"storage_mgmt\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}}], [{\\\"subnet\\\": \\\"storage_mgmt_subnet\\\"}]]}, \\\"ControlPlaneSubnetCidr\\\": {\\\"str_split\\\": [\\\"/\\\", {\\\"get_attr\\\": [\\\"CephStorage\\\", \\\"addresses\\\", \\\"ctlplane\\\", 0, \\\"subnets\\\", 0, \\\"cidr\\\"]}, -1]}, \\\"IPPool\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"CephStorageIPs\\\"}]}, \\\"NodeIndex\\\": {\\\"get_param\\\": \\\"NodeIndex\\\"}, \\\"Role\\\": \\\"CephStorage\\\"}}, \\\"NetIpMap\\\": {\\\"type\\\": \\\"OS::TripleO::Network::Ports::NetIpMap\\\", \\\"properties\\\": {\\\"ControlPlaneIp\\\": {\\\"get_attr\\\": [\\\"CephStorage\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"ControlPlaneSubnetCidr\\\": {\\\"str_split\\\": [\\\"/\\\", {\\\"get_attr\\\": [\\\"CephStorage\\\", \\\"addresses\\\", \\\"ctlplane\\\", 0, \\\"subnets\\\", 0, \\\"cidr\\\"]}, -1]}, \\\"StorageIp\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address\\\"]}, \\\"StorageIpSubnet\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_subnet\\\"]}, \\\"StorageIpUri\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address_uri\\\"]}, \\\"StorageMgmtIp\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_address\\\"]}, \\\"StorageMgmtIpSubnet\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_subnet\\\"]}, \\\"StorageMgmtIpUri\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_address_uri\\\"]}}}, \\\"NetHostMap\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"storage\\\": {\\\"fqdn\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"CephStorage\\\", \\\"name\\\"]}, \\\"storage\\\", {\\\"get_param\\\": \\\"CloudDomain\\\"}]]}, \\\"short\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"CephStorage\\\", \\\"name\\\"]}, \\\"storage\\\"]]}}, \\\"storage_mgmt\\\": {\\\"fqdn\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"CephStorage\\\", \\\"name\\\"]}, \\\"storagemgmt\\\", {\\\"get_param\\\": \\\"CloudDomain\\\"}]]}, \\\"short\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"CephStorage\\\", \\\"name\\\"]}, \\\"storagemgmt\\\"]]}}, \\\"ctlplane\\\": {\\\"fqdn\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"CephStorage\\\", \\\"name\\\"]}, \\\"ctlplane\\\", {\\\"get_param\\\": \\\"CloudDomain\\\"}]]}, \\\"short\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"CephStorage\\\", \\\"name\\\"]}, \\\"ctlplane\\\"]]}}, \\\"canonical\\\": {\\\"fqdn\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"CephStorage\\\", \\\"name\\\"]}, {\\\"get_param\\\": \\\"CloudDomain\\\"}]]}, \\\"short\\\": [{\\\"get_attr\\\": [\\\"CephStorage\\\", \\\"name\\\"]}]}}}}, \\\"PreNetworkConfig\\\": {\\\"type\\\": \\\"OS::TripleO::CephStorage::PreNetworkConfig\\\", \\\"condition\\\": \\\"server_not_blacklisted\\\", \\\"properties\\\": {\\\"server\\\": {\\\"get_resource\\\": \\\"CephStorage\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}, \\\"ServiceNames\\\": {\\\"get_param\\\": \\\"ServiceNames\\\"}, \\\"deployment_actions\\\": {\\\"get_attr\\\": [\\\"DeploymentActions\\\", \\\"value\\\"]}}}, \\\"NodeTLSCAData\\\": {\\\"type\\\": \\\"OS::TripleO::NodeTLSCAData\\\", \\\"properties\\\": {\\\"server\\\": {\\\"get_resource\\\": \\\"CephStorage\\\"}}}, \\\"CephStorageExtraConfigPre\\\": {\\\"type\\\": \\\"OS::TripleO::CephStorageExtraConfigPre\\\", \\\"condition\\\": \\\"server_not_blacklisted\\\", \\\"properties\\\": {\\\"server\\\": {\\\"get_resource\\\": \\\"CephStorage\\\"}}}, \\\"NodeExtraConfig\\\": {\\\"depends_on\\\": [\\\"CephStorageExtraConfigPre\\\", \\\"NodeTLSCAData\\\"], \\\"type\\\": \\\"OS::TripleO::NodeExtraConfig\\\", \\\"condition\\\": \\\"server_not_blacklisted\\\", \\\"properties\\\": {\\\"server\\\": {\\\"get_resource\\\": \\\"CephStorage\\\"}}}, \\\"DeploymentActions\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"value\\\": {\\\"if\\\": [\\\"server_not_blacklisted\\\", [\\\"CREATE\\\", \\\"UPDATE\\\"], []]}}}, \\\"CephStorageAnsibleHostVars\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"fqdn_storage\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage\\\", \\\"fqdn\\\"]}, \\\"fqdn_storage_mgmt\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage_mgmt\\\", \\\"fqdn\\\"]}, \\\"fqdn_ctlplane\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"ctlplane\\\", \\\"fqdn\\\"]}, \\\"fqdn_canonical\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"canonical\\\", \\\"fqdn\\\"]}, \\\"hostname_resolve_network\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CephStorageHostnameResolveNetwork\\\"]}}}}}, \\\"outputs\\\": {\\\"ansible_host_vars_map\\\": {\\\"description\\\": \\\"Map of Ansible variables specific per host.\\\\nThis map is used to construct the AnsibleHostVarsMap output for the\\\\nansible vars per host in config-download.\\\\n\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"host\\\": {\\\"get_attr\\\": [\\\"CephStorageAnsibleHostVars\\\", \\\"value\\\"]}}, {\\\"keys\\\": {\\\"host\\\": {\\\"get_attr\\\": [\\\"CephStorage\\\", \\\"name\\\"]}}}]}}, \\\"ip_address\\\": {\\\"description\\\": \\\"IP address of the server in the ctlplane network\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"CephStorage\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}}, \\\"blacklist_ip_address\\\": {\\\"description\\\": \\\"IP address of the server if the server is blacklisted, otherwise this output will be an empty string\\\", \\\"value\\\": {\\\"if\\\": [\\\"server_blacklisted\\\", {\\\"get_attr\\\": [\\\"CephStorage\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"\\\"]}}, \\\"blacklist_hostname\\\": {\\\"description\\\": \\\"Hostname of the server if the server is blacklisted, otherwise this output will be an empty string\\\", \\\"value\\\": {\\\"if\\\": [\\\"server_blacklisted\\\", {\\\"get_attr\\\": [\\\"CephStorage\\\", \\\"name\\\"]}, \\\"\\\"]}}, \\\"hostname\\\": {\\\"description\\\": \\\"Hostname of the server\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"CephStorage\\\", \\\"name\\\"]}}, \\\"hostname_map\\\": {\\\"description\\\": \\\"Mapping of network names to hostnames\\\", \\\"value\\\": {\\\"storage\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage\\\", \\\"fqdn\\\"]}, \\\"storage_mgmt\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage_mgmt\\\", \\\"fqdn\\\"]}, \\\"ctlplane\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"ctlplane\\\", \\\"fqdn\\\"]}, \\\"canonical\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"canonical\\\", \\\"fqdn\\\"]}}}, \\\"hosts_entry\\\": {\\\"value\\\": [{\\\"str_replace\\\": {\\\"template\\\": \\\"PRIMARYIP PRIMARYHOST.DOMAIN PRIMARYHOST\\\", \\\"params\\\": {\\\"PRIMARYIP\\\": {\\\"get_attr\\\": [\\\"NetIpMap\\\", \\\"net_ip_map\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CephStorageHostnameResolveNetwork\\\"]}]}, \\\"DOMAIN\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"PRIMARYHOST\\\": {\\\"get_attr\\\": [\\\"CephStorage\\\", \\\"name\\\"]}}}}, {\\\"str_replace\\\": {\\\"template\\\": \\\"StorageIP StorageHOST.DOMAIN StorageHOST\\\", \\\"params\\\": {\\\"DOMAIN\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"StorageIP\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address\\\"]}, \\\"StorageHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage\\\", \\\"short\\\"]}, \\\"StorageMgmtIP\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_address\\\"]}, \\\"StorageMgmtHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage_mgmt\\\", \\\"short\\\"]}}}}, {\\\"str_replace\\\": {\\\"template\\\": \\\"StorageMgmtIP StorageMgmtHOST.DOMAIN StorageMgmtHOST\\\", \\\"params\\\": {\\\"DOMAIN\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"StorageIP\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address\\\"]}, \\\"StorageHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage\\\", \\\"short\\\"]}, \\\"StorageMgmtIP\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_address\\\"]}, \\\"StorageMgmtHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"storage_mgmt\\\", \\\"short\\\"]}}}}, {\\\"str_replace\\\": {\\\"template\\\": \\\"CTLPLANEIP CTLPLANEHOST.DOMAIN CTLPLANEHOST\\\", \\\"params\\\": {\\\"DOMAIN\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"CTLPLANEIP\\\": {\\\"get_attr\\\": [\\\"CephStorage\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"CTLPLANEHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"ctlplane\\\", \\\"short\\\"]}}}}]}, \\\"nova_server_resource\\\": {\\\"description\\\": \\\"Heat resource handle for CephStorage server\\\", \\\"value\\\": {\\\"get_resource\\\": \\\"CephStorage\\\"}, \\\"condition\\\": \\\"server_not_blacklisted\\\"}, \\\"deployed_server_port_map\\\": {\\\"description\\\": \\\"Map of Heat created hostname of the server to ip address. This is the\\\\nhostname before it has been mapped with the HostnameMap parameter, and\\\\nthe IP address from the ctlplane network. This map can be used to construct\\\\nthe DeployedServerPortMap parameter when using split-stack.\\\\n\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"hostname\\\": {\\\"fixed_ips\\\": [{\\\"ip_address\\\": {\\\"get_attr\\\": [\\\"CephStorage\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}}], \\\"subnets\\\": [{\\\"cidr\\\": {\\\"get_attr\\\": [\\\"CephStorage\\\", \\\"addresses\\\", \\\"ctlplane\\\", 0, \\\"subnets\\\", 0, \\\"cidr\\\"]}}]}}, {\\\"keys\\\": {\\\"hostname\\\": {\\\"list_join\\\": [\\\"-\\\", [{\\\"get_param\\\": \\\"Hostname\\\"}, \\\"ctlplane\\\"]]}}}]}}, \\\"storage_ip_address\\\": {\\\"description\\\": \\\"IP address of the server in the Storage network\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"StoragePort\\\", \\\"ip_address\\\"]}}, \\\"storage_mgmt_ip_address\\\": {\\\"description\\\": \\\"IP address of the server in the StorageMgmt network\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"StorageMgmtPort\\\", \\\"ip_address\\\"]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack Networker node configured by Puppet\\\", \\\"parameters\\\": {\\\"OvercloudNetworkerFlavor\\\": {\\\"description\\\": \\\"Flavor for the Networker node.\\\", \\\"default\\\": \\\"baremetal\\\", \\\"type\\\": \\\"string\\\"}, \\\"NetworkerImage\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"overcloud-full\\\", \\\"description\\\": \\\"The disk image file to use for the role.\\\"}, \\\"ImageUpdatePolicy\\\": {\\\"default\\\": \\\"REBUILD_PRESERVE_EPHEMERAL\\\", \\\"description\\\": \\\"What policy to use when reconstructing instances. REBUILD for rebuilds, REBUILD_PRESERVE_EPHEMERAL to preserve /mnt.\\\", \\\"type\\\": \\\"string\\\"}, \\\"KeyName\\\": {\\\"description\\\": \\\"Name of an existing Nova key pair to enable SSH access to the instances\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"default\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"UpdateIdentifier\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Setting to a previously unused value during stack-update will trigger package update on all nodes\\\\n\\\"}, \\\"Hostname\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\"}, \\\"HostnameMap\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {}, \\\"description\\\": \\\"Optional mapping to override hostnames\\\"}, \\\"NetworkerIPs\\\": {\\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}, \\\"SoftwareConfigTransport\\\": {\\\"default\\\": \\\"POLL_SERVER_CFN\\\", \\\"description\\\": \\\"How the server should receive the metadata required for software configuration.\\\\n\\\", \\\"type\\\": \\\"string\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"POLL_SERVER_CFN\\\", \\\"POLL_SERVER_HEAT\\\", \\\"POLL_TEMP_URL\\\", \\\"ZAQAR_MESSAGE\\\"]}]}, \\\"CloudDomain\\\": {\\\"default\\\": \\\"localdomain\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"The DNS domain used for the hosts. This must match the overcloud_domain_name configured on the undercloud.\\\\n\\\"}, \\\"NetworkerServerMetadata\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API. This option is role-specific and is merged with the values given to the ServerMetadata parameter.\\\\n\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServerMetadata\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API. This applies to all roles and is merged with a role-specific metadata parameter.\\\\n\\\", \\\"type\\\": \\\"json\\\"}, \\\"NetworkerSchedulerHints\\\": {\\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"Optional scheduler hints to pass to nova\\\", \\\"default\\\": {}}, \\\"NodeIndex\\\": {\\\"type\\\": \\\"number\\\", \\\"default\\\": 0}, \\\"ServiceNames\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": []}, \\\"MonitoringSubscriptions\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": []}, \\\"ServiceMetadataSettings\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {}}, \\\"OVNBridgeMappings\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": []}, \\\"ConfigCommand\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Command which will be run whenever configuration data changes\\\", \\\"default\\\": \\\"os-refresh-config --timeout 14400\\\"}, \\\"ConfigCollectSplay\\\": {\\\"type\\\": \\\"number\\\", \\\"default\\\": 30, \\\"description\\\": \\\"Maximum amount of time to possibly to delay configuration collection\\\\npolling. Defaults to 30 seconds. Set to 0 to disable it which will cause\\\\nthe configuration collection to occur as soon as the collection process\\\\nstarts.  This setting is used to prevent the configuration collection\\\\nprocesses from polling all at the exact same time.\\\\n\\\"}, \\\"UpgradeInitCommand\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Command or script snippet to run on all overcloud nodes to\\\\ninitialize the upgrade process. E.g. a repository switch.\\\\n\\\", \\\"default\\\": \\\"\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"UpgradeInitCommonCommand\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Common commands required by the upgrades process. This should not\\\\nnormally be modified by the operator and is set and unset in the\\\\nmajor-upgrade-composable-steps.yaml and major-upgrade-converge.yaml\\\\nenvironment files.\\\\n\\\", \\\"default\\\": \\\"\\\"}, \\\"DeploymentServerBlacklistDict\\\": {\\\"default\\\": {}, \\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"Map of server hostnames to blacklist from any triggered deployments. If the value is 1, the server will be blacklisted. This parameter is generated from the parent template.\\\\n\\\"}, \\\"RoleParameters\\\": {\\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"default\\\": {}}, \\\"NetworkerControlPlaneSubnet\\\": {\\\"default\\\": \\\"ctlplane-subnet\\\", \\\"description\\\": \\\"Name of the subnet on ctlplane network for this role.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneSubnetCidr\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"ServerDeletionPolicy\\\": {\\\"description\\\": \\\"Whether to retain or delete servers on deletion of the stack\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"delete\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"delete\\\", \\\"retain\\\"]}]}, \\\"UserData\\\": {\\\"type\\\": \\\"string\\\"}}, \\\"conditions\\\": {\\\"server_blacklisted\\\": {\\\"or\\\": [{\\\"equals\\\": [{\\\"get_param\\\": [\\\"DeploymentServerBlacklistDict\\\", {\\\"get_param\\\": \\\"Hostname\\\"}]}, 1]}, {\\\"equals\\\": [{\\\"get_param\\\": [\\\"DeploymentServerBlacklistDict\\\", {\\\"get_param\\\": [\\\"HostnameMap\\\", {\\\"get_param\\\": \\\"Hostname\\\"}]}]}, 1]}]}, \\\"server_not_blacklisted\\\": {\\\"and\\\": [{\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"DeploymentServerBlacklistDict\\\", {\\\"get_param\\\": \\\"Hostname\\\"}]}, 1]}}, {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"DeploymentServerBlacklistDict\\\", {\\\"get_param\\\": [\\\"HostnameMap\\\", {\\\"get_param\\\": \\\"Hostname\\\"}]}]}, 1]}}]}, \\\"ctlplane_fixed_ip_set\\\": {\\\"or\\\": [{\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"NetworkerIPs\\\", \\\"ctlplane\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}, \\\"\\\"]}}, false]}, \\\"Networker_InternalApi_fixed_ip_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"NetworkerIPs\\\", \\\"internal_api\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}, \\\"\\\"]}}, \\\"Networker_Tenant_fixed_ip_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"NetworkerIPs\\\", \\\"tenant\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}, \\\"\\\"]}}}, \\\"resources\\\": {\\\"Networker\\\": {\\\"type\\\": \\\"OS::TripleO::NetworkerServer\\\", \\\"deletion_policy\\\": {\\\"get_param\\\": \\\"ServerDeletionPolicy\\\"}, \\\"properties\\\": {\\\"image\\\": {\\\"get_param\\\": \\\"NetworkerImage\\\"}, \\\"image_update_policy\\\": {\\\"get_param\\\": \\\"ImageUpdatePolicy\\\"}, \\\"flavor\\\": {\\\"get_param\\\": \\\"OvercloudNetworkerFlavor\\\"}, \\\"key_name\\\": {\\\"get_param\\\": \\\"KeyName\\\"}, \\\"networks\\\": [{\\\"if\\\": [\\\"ctlplane_fixed_ip_set\\\", {\\\"network\\\": \\\"ctlplane\\\", \\\"subnet\\\": {\\\"get_param\\\": \\\"NetworkerControlPlaneSubnet\\\"}, \\\"fixed_ip\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"$.data.where(not isEmpty($)).first()\\\", \\\"data\\\": [{\\\"get_param\\\": [\\\"NetworkerIPs\\\", \\\"ctlplane\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}]}}}, {\\\"network\\\": \\\"ctlplane\\\", \\\"subnet\\\": {\\\"get_param\\\": \\\"NetworkerControlPlaneSubnet\\\"}}]}], \\\"user_data_format\\\": \\\"SOFTWARE_CONFIG\\\", \\\"user_data\\\": {\\\"get_param\\\": \\\"UserData\\\"}, \\\"name\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"$.data.hostname_map.get($.data.hostname, $.data.hostname).toLower()\\\", \\\"data\\\": {\\\"hostname\\\": {\\\"get_param\\\": \\\"Hostname\\\"}, \\\"hostname_map\\\": {\\\"get_param\\\": \\\"HostnameMap\\\"}}}}, \\\"software_config_transport\\\": {\\\"get_param\\\": \\\"SoftwareConfigTransport\\\"}, \\\"metadata\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"ServerMetadata\\\"}, {\\\"get_param\\\": \\\"NetworkerServerMetadata\\\"}, {\\\"get_param\\\": \\\"ServiceMetadataSettings\\\"}]}, \\\"scheduler_hints\\\": {\\\"get_param\\\": \\\"NetworkerSchedulerHints\\\"}}}, \\\"InternalApiPort\\\": {\\\"type\\\": \\\"OS::TripleO::Networker::Ports::InternalApiPort\\\", \\\"properties\\\": {\\\"PortName\\\": {\\\"list_join\\\": [\\\"_\\\", [{\\\"get_attr\\\": [\\\"Networker\\\", \\\"name\\\"]}, \\\"InternalApi\\\"]]}, \\\"DnsName\\\": {\\\"get_attr\\\": [\\\"Networker\\\", \\\"name\\\"]}, \\\"ControlPlaneIP\\\": {\\\"get_attr\\\": [\\\"Networker\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"FixedIPs\\\": {\\\"if\\\": [\\\"Networker_InternalApi_fixed_ip_set\\\", [{\\\"ip_address\\\": {\\\"get_param\\\": [\\\"NetworkerIPs\\\", \\\"internal_api\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}}], [{\\\"subnet\\\": \\\"internal_api_subnet\\\"}]]}, \\\"ControlPlaneSubnetCidr\\\": {\\\"str_split\\\": [\\\"/\\\", {\\\"get_attr\\\": [\\\"Networker\\\", \\\"addresses\\\", \\\"ctlplane\\\", 0, \\\"subnets\\\", 0, \\\"cidr\\\"]}, -1]}, \\\"IPPool\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"NetworkerIPs\\\"}]}, \\\"NodeIndex\\\": {\\\"get_param\\\": \\\"NodeIndex\\\"}, \\\"Role\\\": \\\"Networker\\\"}}, \\\"TenantPort\\\": {\\\"type\\\": \\\"OS::TripleO::Networker::Ports::TenantPort\\\", \\\"properties\\\": {\\\"PortName\\\": {\\\"list_join\\\": [\\\"_\\\", [{\\\"get_attr\\\": [\\\"Networker\\\", \\\"name\\\"]}, \\\"Tenant\\\"]]}, \\\"DnsName\\\": {\\\"get_attr\\\": [\\\"Networker\\\", \\\"name\\\"]}, \\\"ControlPlaneIP\\\": {\\\"get_attr\\\": [\\\"Networker\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"FixedIPs\\\": {\\\"if\\\": [\\\"Networker_Tenant_fixed_ip_set\\\", [{\\\"ip_address\\\": {\\\"get_param\\\": [\\\"NetworkerIPs\\\", \\\"tenant\\\", {\\\"get_param\\\": \\\"NodeIndex\\\"}]}}], [{\\\"subnet\\\": \\\"tenant_subnet\\\"}]]}, \\\"ControlPlaneSubnetCidr\\\": {\\\"str_split\\\": [\\\"/\\\", {\\\"get_attr\\\": [\\\"Networker\\\", \\\"addresses\\\", \\\"ctlplane\\\", 0, \\\"subnets\\\", 0, \\\"cidr\\\"]}, -1]}, \\\"IPPool\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"NetworkerIPs\\\"}]}, \\\"NodeIndex\\\": {\\\"get_param\\\": \\\"NodeIndex\\\"}, \\\"Role\\\": \\\"Networker\\\"}}, \\\"NetIpMap\\\": {\\\"type\\\": \\\"OS::TripleO::Network::Ports::NetIpMap\\\", \\\"properties\\\": {\\\"ControlPlaneIp\\\": {\\\"get_attr\\\": [\\\"Networker\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"ControlPlaneSubnetCidr\\\": {\\\"str_split\\\": [\\\"/\\\", {\\\"get_attr\\\": [\\\"Networker\\\", \\\"addresses\\\", \\\"ctlplane\\\", 0, \\\"subnets\\\", 0, \\\"cidr\\\"]}, -1]}, \\\"InternalApiIp\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address\\\"]}, \\\"InternalApiIpSubnet\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_subnet\\\"]}, \\\"InternalApiIpUri\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address_uri\\\"]}, \\\"TenantIp\\\": {\\\"get_attr\\\": [\\\"TenantPort\\\", \\\"ip_address\\\"]}, \\\"TenantIpSubnet\\\": {\\\"get_attr\\\": [\\\"TenantPort\\\", \\\"ip_subnet\\\"]}, \\\"TenantIpUri\\\": {\\\"get_attr\\\": [\\\"TenantPort\\\", \\\"ip_address_uri\\\"]}}}, \\\"NetHostMap\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"internal_api\\\": {\\\"fqdn\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"Networker\\\", \\\"name\\\"]}, \\\"internalapi\\\", {\\\"get_param\\\": \\\"CloudDomain\\\"}]]}, \\\"short\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"Networker\\\", \\\"name\\\"]}, \\\"internalapi\\\"]]}}, \\\"tenant\\\": {\\\"fqdn\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"Networker\\\", \\\"name\\\"]}, \\\"tenant\\\", {\\\"get_param\\\": \\\"CloudDomain\\\"}]]}, \\\"short\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"Networker\\\", \\\"name\\\"]}, \\\"tenant\\\"]]}}, \\\"ctlplane\\\": {\\\"fqdn\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"Networker\\\", \\\"name\\\"]}, \\\"ctlplane\\\", {\\\"get_param\\\": \\\"CloudDomain\\\"}]]}, \\\"short\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"Networker\\\", \\\"name\\\"]}, \\\"ctlplane\\\"]]}}, \\\"canonical\\\": {\\\"fqdn\\\": {\\\"list_join\\\": [\\\".\\\", [{\\\"get_attr\\\": [\\\"Networker\\\", \\\"name\\\"]}, {\\\"get_param\\\": \\\"CloudDomain\\\"}]]}, \\\"short\\\": [{\\\"get_attr\\\": [\\\"Networker\\\", \\\"name\\\"]}]}}}}, \\\"PreNetworkConfig\\\": {\\\"type\\\": \\\"OS::TripleO::Networker::PreNetworkConfig\\\", \\\"condition\\\": \\\"server_not_blacklisted\\\", \\\"properties\\\": {\\\"server\\\": {\\\"get_resource\\\": \\\"Networker\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}, \\\"ServiceNames\\\": {\\\"get_param\\\": \\\"ServiceNames\\\"}, \\\"deployment_actions\\\": {\\\"get_attr\\\": [\\\"DeploymentActions\\\", \\\"value\\\"]}}}, \\\"NodeTLSCAData\\\": {\\\"type\\\": \\\"OS::TripleO::NodeTLSCAData\\\", \\\"properties\\\": {\\\"server\\\": {\\\"get_resource\\\": \\\"Networker\\\"}}}, \\\"NetworkerExtraConfigPre\\\": {\\\"type\\\": \\\"OS::TripleO::NetworkerExtraConfigPre\\\", \\\"condition\\\": \\\"server_not_blacklisted\\\", \\\"properties\\\": {\\\"server\\\": {\\\"get_resource\\\": \\\"Networker\\\"}}}, \\\"NodeExtraConfig\\\": {\\\"depends_on\\\": [\\\"NetworkerExtraConfigPre\\\", \\\"NodeTLSCAData\\\"], \\\"type\\\": \\\"OS::TripleO::NodeExtraConfig\\\", \\\"condition\\\": \\\"server_not_blacklisted\\\", \\\"properties\\\": {\\\"server\\\": {\\\"get_resource\\\": \\\"Networker\\\"}}}, \\\"DeploymentActions\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"value\\\": {\\\"if\\\": [\\\"server_not_blacklisted\\\", [\\\"CREATE\\\", \\\"UPDATE\\\"], []]}}}, \\\"NetworkerAnsibleHostVars\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"fqdn_internal_api\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"internal_api\\\", \\\"fqdn\\\"]}, \\\"fqdn_tenant\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"tenant\\\", \\\"fqdn\\\"]}, \\\"fqdn_ctlplane\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"ctlplane\\\", \\\"fqdn\\\"]}, \\\"fqdn_canonical\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"canonical\\\", \\\"fqdn\\\"]}, \\\"hostname_resolve_network\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NetworkerHostnameResolveNetwork\\\"]}}}}}, \\\"outputs\\\": {\\\"ansible_host_vars_map\\\": {\\\"description\\\": \\\"Map of Ansible variables specific per host.\\\\nThis map is used to construct the AnsibleHostVarsMap output for the\\\\nansible vars per host in config-download.\\\\n\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"host\\\": {\\\"get_attr\\\": [\\\"NetworkerAnsibleHostVars\\\", \\\"value\\\"]}}, {\\\"keys\\\": {\\\"host\\\": {\\\"get_attr\\\": [\\\"Networker\\\", \\\"name\\\"]}}}]}}, \\\"ip_address\\\": {\\\"description\\\": \\\"IP address of the server in the ctlplane network\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"Networker\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}}, \\\"blacklist_ip_address\\\": {\\\"description\\\": \\\"IP address of the server if the server is blacklisted, otherwise this output will be an empty string\\\", \\\"value\\\": {\\\"if\\\": [\\\"server_blacklisted\\\", {\\\"get_attr\\\": [\\\"Networker\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"\\\"]}}, \\\"blacklist_hostname\\\": {\\\"description\\\": \\\"Hostname of the server if the server is blacklisted, otherwise this output will be an empty string\\\", \\\"value\\\": {\\\"if\\\": [\\\"server_blacklisted\\\", {\\\"get_attr\\\": [\\\"Networker\\\", \\\"name\\\"]}, \\\"\\\"]}}, \\\"hostname\\\": {\\\"description\\\": \\\"Hostname of the server\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"Networker\\\", \\\"name\\\"]}}, \\\"hostname_map\\\": {\\\"description\\\": \\\"Mapping of network names to hostnames\\\", \\\"value\\\": {\\\"internal_api\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"internal_api\\\", \\\"fqdn\\\"]}, \\\"tenant\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"tenant\\\", \\\"fqdn\\\"]}, \\\"ctlplane\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"ctlplane\\\", \\\"fqdn\\\"]}, \\\"canonical\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"canonical\\\", \\\"fqdn\\\"]}}}, \\\"hosts_entry\\\": {\\\"value\\\": [{\\\"str_replace\\\": {\\\"template\\\": \\\"PRIMARYIP PRIMARYHOST.DOMAIN PRIMARYHOST\\\", \\\"params\\\": {\\\"PRIMARYIP\\\": {\\\"get_attr\\\": [\\\"NetIpMap\\\", \\\"net_ip_map\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NetworkerHostnameResolveNetwork\\\"]}]}, \\\"DOMAIN\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"PRIMARYHOST\\\": {\\\"get_attr\\\": [\\\"Networker\\\", \\\"name\\\"]}}}}, {\\\"str_replace\\\": {\\\"template\\\": \\\"InternalApiIP InternalApiHOST.DOMAIN InternalApiHOST\\\", \\\"params\\\": {\\\"DOMAIN\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"InternalApiIP\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address\\\"]}, \\\"InternalApiHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"internal_api\\\", \\\"short\\\"]}, \\\"TenantIP\\\": {\\\"get_attr\\\": [\\\"TenantPort\\\", \\\"ip_address\\\"]}, \\\"TenantHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"tenant\\\", \\\"short\\\"]}}}}, {\\\"str_replace\\\": {\\\"template\\\": \\\"TenantIP TenantHOST.DOMAIN TenantHOST\\\", \\\"params\\\": {\\\"DOMAIN\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"InternalApiIP\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address\\\"]}, \\\"InternalApiHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"internal_api\\\", \\\"short\\\"]}, \\\"TenantIP\\\": {\\\"get_attr\\\": [\\\"TenantPort\\\", \\\"ip_address\\\"]}, \\\"TenantHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"tenant\\\", \\\"short\\\"]}}}}, {\\\"str_replace\\\": {\\\"template\\\": \\\"CTLPLANEIP CTLPLANEHOST.DOMAIN CTLPLANEHOST\\\", \\\"params\\\": {\\\"DOMAIN\\\": {\\\"get_param\\\": \\\"CloudDomain\\\"}, \\\"CTLPLANEIP\\\": {\\\"get_attr\\\": [\\\"Networker\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}, \\\"CTLPLANEHOST\\\": {\\\"get_attr\\\": [\\\"NetHostMap\\\", \\\"value\\\", \\\"ctlplane\\\", \\\"short\\\"]}}}}]}, \\\"nova_server_resource\\\": {\\\"description\\\": \\\"Heat resource handle for Networker server\\\", \\\"value\\\": {\\\"get_resource\\\": \\\"Networker\\\"}, \\\"condition\\\": \\\"server_not_blacklisted\\\"}, \\\"deployed_server_port_map\\\": {\\\"description\\\": \\\"Map of Heat created hostname of the server to ip address. This is the\\\\nhostname before it has been mapped with the HostnameMap parameter, and\\\\nthe IP address from the ctlplane network. This map can be used to construct\\\\nthe DeployedServerPortMap parameter when using split-stack.\\\\n\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"hostname\\\": {\\\"fixed_ips\\\": [{\\\"ip_address\\\": {\\\"get_attr\\\": [\\\"Networker\\\", \\\"networks\\\", \\\"ctlplane\\\", 0]}}], \\\"subnets\\\": [{\\\"cidr\\\": {\\\"get_attr\\\": [\\\"Networker\\\", \\\"addresses\\\", \\\"ctlplane\\\", 0, \\\"subnets\\\", 0, \\\"cidr\\\"]}}]}}, {\\\"keys\\\": {\\\"hostname\\\": {\\\"list_join\\\": [\\\"-\\\", [{\\\"get_param\\\": \\\"Hostname\\\"}, \\\"ctlplane\\\"]]}}}]}}, \\\"internal_api_ip_address\\\": {\\\"description\\\": \\\"IP address of the server in the InternalApi network\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"InternalApiPort\\\", \\\"ip_address\\\"]}}, \\\"tenant_ip_address\\\": {\\\"description\\\": \\\"IP address of the server in the Tenant network\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"TenantPort\\\", \\\"ip_address\\\"]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"parameters\\\": {\\\"node_admin_username\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"heat-admin\\\"}, \\\"node_admin_extra_ssh_keys\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": []}}, \\\"description\\\": \\\"Uses cloud-init to create an additional user with a known name, in addition to the distro-default user created by the cloud-init default.\\\\n\\\", \\\"resources\\\": {\\\"userdata\\\": {\\\"type\\\": \\\"OS::Heat::MultipartMime\\\", \\\"properties\\\": {\\\"parts\\\": [{\\\"config\\\": {\\\"get_resource\\\": \\\"user_config\\\"}}]}}, \\\"user_config\\\": {\\\"type\\\": \\\"OS::Heat::CloudConfig\\\", \\\"properties\\\": {\\\"cloud_config\\\": {\\\"user\\\": {\\\"get_param\\\": \\\"node_admin_username\\\"}, \\\"ssh_authorized_keys\\\": {\\\"get_param\\\": \\\"node_admin_extra_ssh_keys\\\"}}}}}, \\\"outputs\\\": {\\\"OS::stack_id\\\": {\\\"value\\\": {\\\"get_resource\\\": \\\"userdata\\\"}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"parameters\\\": {\\\"NtpServer\\\": {\\\"default\\\": [\\\"0.pool.ntp.org\\\", \\\"1.pool.ntp.org\\\", \\\"2.pool.ntp.org\\\", \\\"3.pool.ntp.org\\\"], \\\"description\\\": \\\"NTP servers list. Defaulted to a set of pool.ntp.org servers in order to have a sane default for Pacemaker deployments when not configuring this parameter by default.\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"NtpPool\\\": {\\\"default\\\": [], \\\"description\\\": \\\"NTP pool list.  Defaults to [], so only NtpServer is used by default.\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"NtpService\\\": {\\\"default\\\": \\\"chrony\\\", \\\"description\\\": \\\"NTP Service to use for the timesync bootstrap.\\\", \\\"type\\\": \\\"string\\\"}}, \\\"description\\\": \\\"Uses cloud-init to bootstrap timesync configuration to ensure it is done as soon as possible. We do additional and more complex configurations as part of the deployment itself.\\\\n\\\", \\\"conditions\\\": {\\\"use_chrony\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"NtpService\\\"}, \\\"chrony\\\"]}}, \\\"resources\\\": {\\\"userdata\\\": {\\\"type\\\": \\\"OS::Heat::MultipartMime\\\", \\\"properties\\\": {\\\"parts\\\": [{\\\"config\\\": {\\\"get_resource\\\": \\\"timesync_chrony\\\"}}, {\\\"config\\\": {\\\"get_resource\\\": \\\"timesync_sync\\\"}}]}}, \\\"timesync_chrony\\\": {\\\"type\\\": \\\"OS::Heat::SoftwareConfig\\\", \\\"properties\\\": {\\\"config\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"#!/bin/bash\\\\nif [ \\\\\\\"$service\\\\\\\" != \\\\\\\"chrony\\\\\\\" ]; then\\\\n  exit 0\\\\nfi\\\\nset -x\\\\nSERVERS=\\\\\\\"$ntp_servers\\\\\\\"\\\\nPOOLS=\\\\\\\"$ntp_pools\\\\\\\"\\\\nsystemctl is-active --quiet chronyd || systemctl start chronyd\\\\nfor server in $SERVERS; do\\\\n  chronyc add server \\\\\\\"${server}\\\\\\\" iburst\\\\ndone\\\\nfor pool in $POOLS; do\\\\n  chronyc add server \\\\\\\"${pool}\\\\\\\" iburst\\\\ndone\\\\nchronyc sources\\\\n\\\", \\\"params\\\": {\\\"$ntp_servers\\\": {\\\"list_join\\\": [\\\" \\\", {\\\"get_param\\\": \\\"NtpServer\\\"}]}, \\\"$ntp_pools\\\": {\\\"list_join\\\": [\\\" \\\", {\\\"get_param\\\": \\\"NtpPool\\\"}]}, \\\"$service\\\": {\\\"get_param\\\": \\\"NtpService\\\"}}}}}}, \\\"timesync_sync\\\": {\\\"type\\\": \\\"OS::Heat::SoftwareConfig\\\", \\\"properties\\\": {\\\"config\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"#!/bin/bash\\\\nset -x\\\\nif [ \\\\\\\"$service\\\\\\\" = \\\\\\\"chrony\\\\\\\" ]; then\\\\n    if command -v chronyc >/dev/null; then\\\\n        chronyc makestep\\\\n        chronyc waitsync 30\\\\n    else\\\\n        echo \\\\\\\"No chronyc available, skipping sync\\\\\\\"\\\\n    fi\\\\nelif [ \\\\\\\"$service\\\\\\\" = \\\\\\\"ntp\\\\\\\" ]; then\\\\n    if command -v ntpdate >/dev/null; then\\\\n        ntpdate -u $ntp_servers\\\\n    else\\\\n        echo \\\\\\\"No ntpdate available, skipping sync\\\\\\\"\\\\n    fi\\\\nfi\\\\nhwclock --systohc --utc\\\\n\\\", \\\"params\\\": {\\\"$service\\\": {\\\"get_param\\\": \\\"NtpService\\\"}, \\\"$ntp_servers\\\": {\\\"list_join\\\": [\\\" \\\", {\\\"get_param\\\": \\\"NtpServer\\\"}]}}}}}}}, \\\"outputs\\\": {\\\"OS::stack_id\\\": {\\\"value\\\": {\\\"get_resource\\\": \\\"userdata\\\"}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\\\n\\\", \\\"resources\\\": {\\\"userdata\\\": {\\\"type\\\": \\\"OS::Heat::MultipartMime\\\"}}, \\\"outputs\\\": {\\\"OS::stack_id\\\": {\\\"value\\\": {\\\"get_resource\\\": \\\"userdata\\\"}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Extra Post Deployment Config\\\", \\\"parameters\\\": {\\\"servers\\\": {\\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/networks.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Create networks to split out Overcloud traffic\\\", \\\"parameters\\\": {\\\"CtlplaneNetworkCidrs\\\": {\\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"Cidrs for the ctlplane network.\\\"}, \\\"CtlplaneNetworkAttributes\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {}, \\\"description\\\": \\\"A map containing attributes of the undercloud ctlplane network and subnets. NOTE: The value for this parameter is automatically populated in the plan environment by tripleoclient.\\\\n\\\"}}, \\\"resources\\\": {\\\"StorageNetwork\\\": {\\\"type\\\": \\\"OS::TripleO::Network::Storage\\\"}, \\\"StorageMgmtNetwork\\\": {\\\"type\\\": \\\"OS::TripleO::Network::StorageMgmt\\\"}, \\\"InternalApiNetwork\\\": {\\\"type\\\": \\\"OS::TripleO::Network::InternalApi\\\"}, \\\"TenantNetwork\\\": {\\\"type\\\": \\\"OS::TripleO::Network::Tenant\\\"}, \\\"ExternalNetwork\\\": {\\\"type\\\": \\\"OS::TripleO::Network::External\\\"}, \\\"NetworkExtraConfig\\\": {\\\"type\\\": \\\"OS::TripleO::Network::ExtraConfig\\\"}}, \\\"outputs\\\": {\\\"net_cidr_map\\\": {\\\"value\\\": {\\\"storage\\\": {\\\"yaql\\\": {\\\"data\\\": {\\\"network_cidrs\\\": {\\\"get_attr\\\": [\\\"StorageNetwork\\\", \\\"network_cidrs\\\"]}, \\\"ctlplane_cidrs\\\": {\\\"get_param\\\": \\\"CtlplaneNetworkCidrs\\\"}}, \\\"expression\\\": \\\"switch(not isList($.data.network_cidrs) => $.data.ctlplane_cidrs, $.data.network_cidrs => $.data.network_cidrs)\\\"}}, \\\"storage_mgmt\\\": {\\\"yaql\\\": {\\\"data\\\": {\\\"network_cidrs\\\": {\\\"get_attr\\\": [\\\"StorageMgmtNetwork\\\", \\\"network_cidrs\\\"]}, \\\"ctlplane_cidrs\\\": {\\\"get_param\\\": \\\"CtlplaneNetworkCidrs\\\"}}, \\\"expression\\\": \\\"switch(not isList($.data.network_cidrs) => $.data.ctlplane_cidrs, $.data.network_cidrs => $.data.network_cidrs)\\\"}}, \\\"internal_api\\\": {\\\"yaql\\\": {\\\"data\\\": {\\\"network_cidrs\\\": {\\\"get_attr\\\": [\\\"InternalApiNetwork\\\", \\\"network_cidrs\\\"]}, \\\"ctlplane_cidrs\\\": {\\\"get_param\\\": \\\"CtlplaneNetworkCidrs\\\"}}, \\\"expression\\\": \\\"switch(not isList($.data.network_cidrs) => $.data.ctlplane_cidrs, $.data.network_cidrs => $.data.network_cidrs)\\\"}}, \\\"tenant\\\": {\\\"yaql\\\": {\\\"data\\\": {\\\"network_cidrs\\\": {\\\"get_attr\\\": [\\\"TenantNetwork\\\", \\\"network_cidrs\\\"]}, \\\"ctlplane_cidrs\\\": {\\\"get_param\\\": \\\"CtlplaneNetworkCidrs\\\"}}, \\\"expression\\\": \\\"switch(not isList($.data.network_cidrs) => $.data.ctlplane_cidrs, $.data.network_cidrs => $.data.network_cidrs)\\\"}}, \\\"external\\\": {\\\"yaql\\\": {\\\"data\\\": {\\\"network_cidrs\\\": {\\\"get_attr\\\": [\\\"ExternalNetwork\\\", \\\"network_cidrs\\\"]}, \\\"ctlplane_cidrs\\\": {\\\"get_param\\\": \\\"CtlplaneNetworkCidrs\\\"}}, \\\"expression\\\": \\\"switch(not isList($.data.network_cidrs) => $.data.ctlplane_cidrs, $.data.network_cidrs => $.data.network_cidrs)\\\"}}}}, \\\"net_ip_version_map\\\": {\\\"value\\\": {\\\"storage\\\": {\\\"get_attr\\\": [\\\"StorageNetwork\\\", \\\"ip_version\\\"]}, \\\"storage_mgmt\\\": {\\\"get_attr\\\": [\\\"StorageMgmtNetwork\\\", \\\"ip_version\\\"]}, \\\"internal_api\\\": {\\\"get_attr\\\": [\\\"InternalApiNetwork\\\", \\\"ip_version\\\"]}, \\\"tenant\\\": {\\\"get_attr\\\": [\\\"TenantNetwork\\\", \\\"ip_version\\\"]}, \\\"external\\\": {\\\"get_attr\\\": [\\\"ExternalNetwork\\\", \\\"ip_version\\\"]}}}, \\\"net_attributes_map\\\": {\\\"value\\\": {\\\"ctlplane\\\": {\\\"get_param\\\": \\\"CtlplaneNetworkAttributes\\\"}, \\\"storage\\\": {\\\"network\\\": {\\\"get_attr\\\": [\\\"StorageNetwork\\\", \\\"network_attrs\\\"]}, \\\"subnets\\\": {\\\"get_attr\\\": [\\\"StorageNetwork\\\", \\\"subnet_attrs\\\"]}}, \\\"storage_mgmt\\\": {\\\"network\\\": {\\\"get_attr\\\": [\\\"StorageMgmtNetwork\\\", \\\"network_attrs\\\"]}, \\\"subnets\\\": {\\\"get_attr\\\": [\\\"StorageMgmtNetwork\\\", \\\"subnet_attrs\\\"]}}, \\\"internal_api\\\": {\\\"network\\\": {\\\"get_attr\\\": [\\\"InternalApiNetwork\\\", \\\"network_attrs\\\"]}, \\\"subnets\\\": {\\\"get_attr\\\": [\\\"InternalApiNetwork\\\", \\\"subnet_attrs\\\"]}}, \\\"tenant\\\": {\\\"network\\\": {\\\"get_attr\\\": [\\\"TenantNetwork\\\", \\\"network_attrs\\\"]}, \\\"subnets\\\": {\\\"get_attr\\\": [\\\"TenantNetwork\\\", \\\"subnet_attrs\\\"]}}, \\\"external\\\": {\\\"network\\\": {\\\"get_attr\\\": [\\\"ExternalNetwork\\\", \\\"network_attrs\\\"]}, \\\"subnets\\\": {\\\"get_attr\\\": [\\\"ExternalNetwork\\\", \\\"subnet_attrs\\\"]}}}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"parameters\\\": {\\\"ControlPlaneIp\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneSubnetCidr\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"StorageIp\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"StorageIpSubnet\\\": {\\\"description\\\": \\\"IP address/subnet on the storage network\\\", \\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"StorageIpUri\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"IP address with brackets in case of IPv6\\\"}, \\\"StorageNetName\\\": {\\\"default\\\": \\\"storage\\\", \\\"description\\\": \\\"The name of the storage network.\\\", \\\"type\\\": \\\"string\\\"}, \\\"StorageMgmtIp\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"StorageMgmtIpSubnet\\\": {\\\"description\\\": \\\"IP address/subnet on the storage_mgmt network\\\", \\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"StorageMgmtIpUri\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"IP address with brackets in case of IPv6\\\"}, \\\"StorageMgmtNetName\\\": {\\\"default\\\": \\\"storage_mgmt\\\", \\\"description\\\": \\\"The name of the storage_mgmt network.\\\", \\\"type\\\": \\\"string\\\"}, \\\"InternalApiIp\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"InternalApiIpSubnet\\\": {\\\"description\\\": \\\"IP address/subnet on the internal_api network\\\", \\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"InternalApiIpUri\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"IP address with brackets in case of IPv6\\\"}, \\\"InternalApiNetName\\\": {\\\"default\\\": \\\"internal_api\\\", \\\"description\\\": \\\"The name of the internal_api network.\\\", \\\"type\\\": \\\"string\\\"}, \\\"TenantIp\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"TenantIpSubnet\\\": {\\\"description\\\": \\\"IP address/subnet on the tenant network\\\", \\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"TenantIpUri\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"IP address with brackets in case of IPv6\\\"}, \\\"TenantNetName\\\": {\\\"default\\\": \\\"tenant\\\", \\\"description\\\": \\\"The name of the tenant network.\\\", \\\"type\\\": \\\"string\\\"}, \\\"ExternalIp\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"ExternalIpSubnet\\\": {\\\"description\\\": \\\"IP address/subnet on the external network\\\", \\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"ExternalIpUri\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"IP address with brackets in case of IPv6\\\"}, \\\"ExternalNetName\\\": {\\\"default\\\": \\\"external\\\", \\\"description\\\": \\\"The name of the external network.\\\", \\\"type\\\": \\\"string\\\"}}, \\\"resources\\\": {\\\"NetIpMapValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"ctlplane\\\": {\\\"get_param\\\": \\\"ControlPlaneIp\\\"}, \\\"ctlplane_subnet\\\": {\\\"list_join\\\": [\\\"\\\", [{\\\"get_param\\\": \\\"ControlPlaneIp\\\"}, \\\"/\\\", {\\\"get_param\\\": \\\"ControlPlaneSubnetCidr\\\"}]]}, \\\"ctlplane_uri\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"make_url\\\": {\\\"host\\\": {\\\"get_param\\\": \\\"ControlPlaneIp\\\"}}}, \\\"params\\\": {\\\"//\\\": \\\"\\\"}}}, \\\"storage\\\": {\\\"get_param\\\": \\\"StorageIp\\\"}, \\\"storage_subnet\\\": {\\\"get_param\\\": \\\"StorageIpSubnet\\\"}, \\\"storage_uri\\\": {\\\"get_param\\\": \\\"StorageIpUri\\\"}, \\\"storage_mgmt\\\": {\\\"get_param\\\": \\\"StorageMgmtIp\\\"}, \\\"storage_mgmt_subnet\\\": {\\\"get_param\\\": \\\"StorageMgmtIpSubnet\\\"}, \\\"storage_mgmt_uri\\\": {\\\"get_param\\\": \\\"StorageMgmtIpUri\\\"}, \\\"internal_api\\\": {\\\"get_param\\\": \\\"InternalApiIp\\\"}, \\\"internal_api_subnet\\\": {\\\"get_param\\\": \\\"InternalApiIpSubnet\\\"}, \\\"internal_api_uri\\\": {\\\"get_param\\\": \\\"InternalApiIpUri\\\"}, \\\"tenant\\\": {\\\"get_param\\\": \\\"TenantIp\\\"}, \\\"tenant_subnet\\\": {\\\"get_param\\\": \\\"TenantIpSubnet\\\"}, \\\"tenant_uri\\\": {\\\"get_param\\\": \\\"TenantIpUri\\\"}, \\\"external\\\": {\\\"get_param\\\": \\\"ExternalIp\\\"}, \\\"external_subnet\\\": {\\\"get_param\\\": \\\"ExternalIpSubnet\\\"}, \\\"external_uri\\\": {\\\"get_param\\\": \\\"ExternalIpUri\\\"}}, {\\\"keys\\\": {\\\"ctlplane\\\": \\\"ctlplane\\\", \\\"storage\\\": {\\\"get_param\\\": \\\"StorageNetName\\\"}, \\\"storage_subnet\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"NAME_subnet\\\", \\\"params\\\": {\\\"NAME\\\": {\\\"get_param\\\": \\\"StorageNetName\\\"}}}}, \\\"storage_uri\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"NAME_uri\\\", \\\"params\\\": {\\\"NAME\\\": {\\\"get_param\\\": \\\"StorageNetName\\\"}}}}, \\\"storage_mgmt\\\": {\\\"get_param\\\": \\\"StorageMgmtNetName\\\"}, \\\"storage_mgmt_subnet\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"NAME_subnet\\\", \\\"params\\\": {\\\"NAME\\\": {\\\"get_param\\\": \\\"StorageMgmtNetName\\\"}}}}, \\\"storage_mgmt_uri\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"NAME_uri\\\", \\\"params\\\": {\\\"NAME\\\": {\\\"get_param\\\": \\\"StorageMgmtNetName\\\"}}}}, \\\"internal_api\\\": {\\\"get_param\\\": \\\"InternalApiNetName\\\"}, \\\"internal_api_subnet\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"NAME_subnet\\\", \\\"params\\\": {\\\"NAME\\\": {\\\"get_param\\\": \\\"InternalApiNetName\\\"}}}}, \\\"internal_api_uri\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"NAME_uri\\\", \\\"params\\\": {\\\"NAME\\\": {\\\"get_param\\\": \\\"InternalApiNetName\\\"}}}}, \\\"tenant\\\": {\\\"get_param\\\": \\\"TenantNetName\\\"}, \\\"tenant_subnet\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"NAME_subnet\\\", \\\"params\\\": {\\\"NAME\\\": {\\\"get_param\\\": \\\"TenantNetName\\\"}}}}, \\\"tenant_uri\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"NAME_uri\\\", \\\"params\\\": {\\\"NAME\\\": {\\\"get_param\\\": \\\"TenantNetName\\\"}}}}, \\\"external\\\": {\\\"get_param\\\": \\\"ExternalNetName\\\"}, \\\"external_subnet\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"NAME_subnet\\\", \\\"params\\\": {\\\"NAME\\\": {\\\"get_param\\\": \\\"ExternalNetName\\\"}}}}, \\\"external_uri\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"NAME_uri\\\", \\\"params\\\": {\\\"NAME\\\": {\\\"get_param\\\": \\\"ExternalNetName\\\"}}}}}}]}}}}, \\\"outputs\\\": {\\\"net_ip_map\\\": {\\\"description\\\": \\\"A Hash containing a mapping of network names to assigned IPs for a specific machine.\\\\n\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"NetIpMapValue\\\", \\\"value\\\"]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"parameters\\\": {\\\"ControlPlaneIpList\\\": {\\\"default\\\": [], \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"StorageIpList\\\": {\\\"default\\\": [], \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"StorageNetName\\\": {\\\"default\\\": \\\"storage\\\", \\\"description\\\": \\\"The name of the storage network.\\\", \\\"type\\\": \\\"string\\\"}, \\\"StorageMgmtIpList\\\": {\\\"default\\\": [], \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"StorageMgmtNetName\\\": {\\\"default\\\": \\\"storage_mgmt\\\", \\\"description\\\": \\\"The name of the storage_mgmt network.\\\", \\\"type\\\": \\\"string\\\"}, \\\"InternalApiIpList\\\": {\\\"default\\\": [], \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"InternalApiNetName\\\": {\\\"default\\\": \\\"internal_api\\\", \\\"description\\\": \\\"The name of the internal_api network.\\\", \\\"type\\\": \\\"string\\\"}, \\\"TenantIpList\\\": {\\\"default\\\": [], \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"TenantNetName\\\": {\\\"default\\\": \\\"tenant\\\", \\\"description\\\": \\\"The name of the tenant network.\\\", \\\"type\\\": \\\"string\\\"}, \\\"ExternalIpList\\\": {\\\"default\\\": [], \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"ExternalNetName\\\": {\\\"default\\\": \\\"external\\\", \\\"description\\\": \\\"The name of the external network.\\\", \\\"type\\\": \\\"string\\\"}, \\\"EnabledServices\\\": {\\\"default\\\": [], \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}, \\\"ServiceHostnameList\\\": {\\\"default\\\": [], \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"NetworkHostnameMap\\\": {\\\"default\\\": [], \\\"type\\\": \\\"json\\\"}, \\\"NovaAdditionalCell\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether this is an cell additional to the default cell.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"RoleNetworks\\\": {\\\"default\\\": \\\"ctlplane\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}}, \\\"conditions\\\": {\\\"is_cell\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"NovaAdditionalCell\\\"}, true]}}, \\\"resources\\\": {\\\"EnabledServicesValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\\\", \\\"data\\\": {\\\"enabled_services\\\": {\\\"get_param\\\": \\\"EnabledServices\\\"}, \\\"extra_services\\\": {\\\"keystone\\\": [\\\"keystone_admin_api\\\", \\\"keystone_public_api\\\"]}}}}}}, \\\"NetIpMapValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"yaql\\\": {\\\"expression\\\": \\\"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\\\", \\\"data\\\": {\\\"role_networks\\\": {\\\"get_param\\\": \\\"RoleNetworks\\\"}, \\\"net_ip_map\\\": {\\\"ctlplane\\\": {\\\"get_param\\\": \\\"ControlPlaneIpList\\\"}, \\\"storage\\\": {\\\"get_param\\\": \\\"StorageIpList\\\"}, \\\"storage_mgmt\\\": {\\\"get_param\\\": \\\"StorageMgmtIpList\\\"}, \\\"internal_api\\\": {\\\"get_param\\\": \\\"InternalApiIpList\\\"}, \\\"tenant\\\": {\\\"get_param\\\": \\\"TenantIpList\\\"}, \\\"external\\\": {\\\"get_param\\\": \\\"ExternalIpList\\\"}}}}}, {\\\"keys\\\": {\\\"ctlplane\\\": \\\"ctlplane\\\", \\\"storage\\\": {\\\"get_param\\\": \\\"StorageNetName\\\"}, \\\"storage_mgmt\\\": {\\\"get_param\\\": \\\"StorageMgmtNetName\\\"}, \\\"internal_api\\\": {\\\"get_param\\\": \\\"InternalApiNetName\\\"}, \\\"tenant\\\": {\\\"get_param\\\": \\\"TenantNetName\\\"}, \\\"external\\\": {\\\"get_param\\\": \\\"ExternalNetName\\\"}}}]}}}}, \\\"outputs\\\": {\\\"net_ip_map\\\": {\\\"description\\\": \\\"A Hash containing a mapping of network names to assigned lists of IP addresses.\\\\n\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"NetIpMapValue\\\", \\\"value\\\"]}}, \\\"ctlplane_service_ips\\\": {\\\"description\\\": \\\"Map of enabled services to a list of their ctlplane IP addresses\\\\n\\\", \\\"value\\\": {\\\"map_merge\\\": {\\\"repeat\\\": {\\\"template\\\": {\\\"SERVICE_ctlplane_node_ips\\\": \\\"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\\\"}, \\\"for_each\\\": {\\\"SERVICE\\\": {\\\"get_attr\\\": [\\\"EnabledServicesValue\\\", \\\"value\\\"]}}}}}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Mapping of service_name_network -> network name\\\\n\\\", \\\"parameters\\\": {\\\"ServiceNetMap\\\": {\\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults. Note that the key in this map must match the service_name in the service template, e.g if the service_name is heat_api the key must be either heat_api_network, or optionally HeatApiNetwork (which will be internally converted to transform captalization to underscores).\\\", \\\"type\\\": \\\"json\\\"}, \\\"ControlPlaneSubnet\\\": {\\\"description\\\": \\\"The name of the undercloud Neutron control plane subnet\\\", \\\"default\\\": \\\"ctlplane-subnet\\\", \\\"type\\\": \\\"string\\\"}, \\\"VipSubnetMap\\\": {\\\"description\\\": \\\"Map of (network_name or service_name) -> subnet_name that defines which subnet to host the VIP. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMapDeprecatedMapping\\\": {\\\"default\\\": {\\\"RabbitMqNetwork\\\": \\\"RabbitmqNetwork\\\", \\\"CephPublicNetwork\\\": \\\"CephMonNetwork\\\", \\\"SwiftMgmtNetwork\\\": \\\"SwiftStorageNetwork\\\"}, \\\"description\\\": \\\"Mapping older deprecated service names, intended for internal use only, this will be removed in future.\\\", \\\"type\\\": \\\"json\\\"}, \\\"StorageNetName\\\": {\\\"default\\\": \\\"storage\\\", \\\"description\\\": \\\"The name of the storage network.\\\", \\\"type\\\": \\\"string\\\"}, \\\"StorageMgmtNetName\\\": {\\\"default\\\": \\\"storage_mgmt\\\", \\\"description\\\": \\\"The name of the storage_mgmt network.\\\", \\\"type\\\": \\\"string\\\"}, \\\"InternalApiNetName\\\": {\\\"default\\\": \\\"internal_api\\\", \\\"description\\\": \\\"The name of the internal_api network.\\\", \\\"type\\\": \\\"string\\\"}, \\\"TenantNetName\\\": {\\\"default\\\": \\\"tenant\\\", \\\"description\\\": \\\"The name of the tenant network.\\\", \\\"type\\\": \\\"string\\\"}, \\\"ExternalNetName\\\": {\\\"default\\\": \\\"external\\\", \\\"description\\\": \\\"The name of the external network.\\\", \\\"type\\\": \\\"string\\\"}}, \\\"parameter_groups\\\": [{\\\"label\\\": \\\"deprecated\\\", \\\"description\\\": \\\"Do not use deprecated params, they will be removed.\\\", \\\"parameters\\\": [\\\"ServiceNetMapDeprecatedMapping\\\"]}], \\\"resources\\\": {\\\"ServiceNetMapValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_merge\\\": [{\\\"map_replace\\\": [{\\\"get_param\\\": \\\"ServiceNetMap\\\"}, {\\\"values\\\": {\\\"storage\\\": {\\\"get_param\\\": \\\"StorageNetName\\\"}, \\\"storage_mgmt\\\": {\\\"get_param\\\": \\\"StorageMgmtNetName\\\"}, \\\"internal_api\\\": {\\\"get_param\\\": \\\"InternalApiNetName\\\"}, \\\"tenant\\\": {\\\"get_param\\\": \\\"TenantNetName\\\"}, \\\"external\\\": {\\\"get_param\\\": \\\"ExternalNetName\\\"}}, \\\"keys\\\": {\\\"get_param\\\": \\\"ServiceNetMapDeprecatedMapping\\\"}}]}, {\\\"NovaVncProxyNetwork\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaLibvirtNetwork\\\"]}}]}}}}, \\\"outputs\\\": {\\\"service_net_map\\\": {\\\"value\\\": {\\\"get_attr\\\": [\\\"ServiceNetMapValue\\\", \\\"value\\\"]}}, \\\"service_net_map_lower\\\": {\\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\\\\\\\\\1_\\\\\\\\\\\\\\\\2\').toLower(), $[1]]))\\\", \\\"data\\\": {\\\"map\\\": {\\\"get_attr\\\": [\\\"ServiceNetMapValue\\\", \\\"value\\\"]}}}}}, \\\"vip_subnet_map\\\": {\\\"value\\\": {\\\"map_replace\\\": [{\\\"get_param\\\": \\\"VipSubnetMap\\\"}, {\\\"values\\\": {\\\"ctlplane-subnet\\\": {\\\"get_param\\\": \\\"ControlPlaneSubnet\\\"}}}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"A map of OpenStack endpoints. Since the endpoints are URLs, we need to have brackets around IPv6 IP addresses. The inputs to these parameters come from net_ip_uri_map, which will include these brackets in IPv6 addresses.\\\", \\\"parameters\\\": {\\\"NetIpMap\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {}, \\\"description\\\": \\\"The Net IP map\\\"}, \\\"ServiceNetMap\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {}, \\\"description\\\": \\\"The Service Net map\\\"}, \\\"EndpointMap\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {\\\"AodhAdmin\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"8042\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"AodhInternal\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"8042\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"AodhPublic\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"8042\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"BarbicanAdmin\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"9311\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"BarbicanInternal\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"9311\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"BarbicanPublic\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"9311\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"CephDashboardInternal\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"8444\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"CephGrafanaInternal\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"3100\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"CephRgwAdmin\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"8080\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"CephRgwInternal\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"8080\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"CephRgwPublic\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"8080\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"CinderAdmin\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"8776\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"CinderInternal\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"8776\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"CinderPublic\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"8776\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"DesignateAdmin\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"9001\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"DesignateInternal\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"9001\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"DesignatePublic\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"9001\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"DockerRegistryInternal\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"8787\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"GaneshaInternal\\\": {\\\"protocol\\\": \\\"nfs\\\", \\\"port\\\": \\\"2049\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"GlanceAdmin\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"9293\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"GlanceInternal\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"9293\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"GlancePublic\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"9292\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"GnocchiAdmin\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"8041\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"GnocchiInternal\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"8041\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"GnocchiPublic\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"8041\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"HeatAdmin\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"8004\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"HeatInternal\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"8004\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"HeatPublic\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"8004\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"HeatCfnAdmin\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"8000\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"HeatCfnInternal\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"8000\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"HeatCfnPublic\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"8000\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"HorizonPublic\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"80\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"IronicAdmin\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"6385\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"IronicInternal\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"6385\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"IronicPublic\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"6385\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"IronicInspectorAdmin\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"5050\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"IronicInspectorInternal\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"5050\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"IronicInspectorPublic\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"5050\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"KeystoneAdmin\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"35357\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"KeystoneInternal\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"5000\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"KeystonePublic\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"5000\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"ManilaAdmin\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"8786\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"ManilaInternal\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"8786\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"ManilaPublic\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"8786\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"MetricsQdrPublic\\\": {\\\"protocol\\\": \\\"amqp\\\", \\\"port\\\": \\\"5666\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"MysqlInternal\\\": {\\\"protocol\\\": \\\"mysql+pymysql\\\", \\\"port\\\": \\\"3306\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"NeutronAdmin\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"9696\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"NeutronInternal\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"9696\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"NeutronPublic\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"9696\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"NovaAdmin\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"8774\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"NovaInternal\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"8774\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"NovaPublic\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"8774\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"NovaMetadataInternal\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"8775\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"NovaVNCProxyAdmin\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"6080\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"NovaVNCProxyInternal\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"6080\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"NovaVNCProxyPublic\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"6080\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"NovajoinAdmin\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"9090\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"NovajoinInternal\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"9090\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"NovajoinPublic\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"9090\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"OctaviaAdmin\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"9876\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"OctaviaInternal\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"9876\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"OctaviaPublic\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"9876\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"PlacementAdmin\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"8778\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"PlacementInternal\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"8778\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"PlacementPublic\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"8778\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"SwiftAdmin\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"8080\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"SwiftInternal\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"8080\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}, \\\"SwiftPublic\\\": {\\\"protocol\\\": \\\"http\\\", \\\"port\\\": \\\"8080\\\", \\\"host\\\": \\\"IP_ADDRESS\\\"}}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\"}, \\\"CloudEndpoints\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {}, \\\"description\\\": \\\"A map containing the DNS names for the different endpoints (external, internal_api, etc.)\\\"}}, \\\"outputs\\\": {\\\"endpoint_map\\\": {\\\"value\\\": {\\\"AodhAdmin\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"AodhAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"AodhApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"AodhApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"AodhAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"AodhApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"AodhApiNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"AodhAdmin\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"AodhAdmin\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"AodhAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"AodhAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"AodhApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"AodhApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"AodhAdmin\\\", \\\"port\\\"]}}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"AodhAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"AodhAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"AodhApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"AodhApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"AodhAdmin\\\", \\\"port\\\"]}}}}, \\\"AodhInternal\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"AodhInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"AodhApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"AodhApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"AodhInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"AodhApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"AodhApiNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"AodhInternal\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"AodhInternal\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"AodhInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"AodhInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"AodhApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"AodhApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"AodhInternal\\\", \\\"port\\\"]}}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"AodhInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"AodhInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"AodhApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"AodhApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"AodhInternal\\\", \\\"port\\\"]}}}}, \\\"AodhPublic\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"AodhPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"AodhPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"AodhPublic\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"AodhPublic\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"AodhPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"AodhPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"AodhPublic\\\", \\\"port\\\"]}}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"AodhPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"AodhPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"AodhPublic\\\", \\\"port\\\"]}}}}, \\\"BarbicanAdmin\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"BarbicanAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"BarbicanApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"BarbicanApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"BarbicanAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"BarbicanApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"BarbicanApiNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"BarbicanAdmin\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"BarbicanAdmin\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"BarbicanAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"BarbicanAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"BarbicanApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"BarbicanApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"BarbicanAdmin\\\", \\\"port\\\"]}}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"BarbicanAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"BarbicanAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"BarbicanApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"BarbicanApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"BarbicanAdmin\\\", \\\"port\\\"]}}}}, \\\"BarbicanInternal\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"BarbicanInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"BarbicanApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"BarbicanApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"BarbicanInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"BarbicanApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"BarbicanApiNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"BarbicanInternal\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"BarbicanInternal\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"BarbicanInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"BarbicanInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"BarbicanApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"BarbicanApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"BarbicanInternal\\\", \\\"port\\\"]}}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"BarbicanInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"BarbicanInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"BarbicanApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"BarbicanApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"BarbicanInternal\\\", \\\"port\\\"]}}}}, \\\"BarbicanPublic\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"BarbicanPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"BarbicanPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"BarbicanPublic\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"BarbicanPublic\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"BarbicanPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"BarbicanPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"BarbicanPublic\\\", \\\"port\\\"]}}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"BarbicanPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"BarbicanPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"BarbicanPublic\\\", \\\"port\\\"]}}}}, \\\"CephDashboardInternal\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephDashboardInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CephDashboardNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CephDashboardNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephDashboardInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CephDashboardNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CephDashboardNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephDashboardInternal\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephDashboardInternal\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephDashboardInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephDashboardInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CephDashboardNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CephDashboardNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephDashboardInternal\\\", \\\"port\\\"]}}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephDashboardInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephDashboardInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CephDashboardNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CephDashboardNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephDashboardInternal\\\", \\\"port\\\"]}}}}, \\\"CephGrafanaInternal\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephGrafanaInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CephGrafanaNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CephGrafanaNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephGrafanaInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CephGrafanaNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CephGrafanaNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephGrafanaInternal\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephGrafanaInternal\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephGrafanaInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephGrafanaInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CephGrafanaNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CephGrafanaNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephGrafanaInternal\\\", \\\"port\\\"]}}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephGrafanaInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephGrafanaInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CephGrafanaNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CephGrafanaNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephGrafanaInternal\\\", \\\"port\\\"]}}}}, \\\"CephRgwAdmin\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephRgwAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CephRgwNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CephRgwNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephRgwAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CephRgwNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CephRgwNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephRgwAdmin\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephRgwAdmin\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"list_join\\\": [\\\"\\\", [{\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephRgwAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephRgwAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CephRgwNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CephRgwNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephRgwAdmin\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/swift/v1/AUTH_\\\"}}, \\\"%(project_id)s\\\"]]}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephRgwAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephRgwAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CephRgwNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CephRgwNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephRgwAdmin\\\", \\\"port\\\"]}}}}, \\\"CephRgwInternal\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephRgwInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CephRgwNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CephRgwNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephRgwInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CephRgwNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CephRgwNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephRgwInternal\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephRgwInternal\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"list_join\\\": [\\\"\\\", [{\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephRgwInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephRgwInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CephRgwNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CephRgwNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephRgwInternal\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/swift/v1/AUTH_\\\"}}, \\\"%(project_id)s\\\"]]}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephRgwInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephRgwInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CephRgwNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CephRgwNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephRgwInternal\\\", \\\"port\\\"]}}}}, \\\"CephRgwPublic\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephRgwPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephRgwPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephRgwPublic\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephRgwPublic\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"list_join\\\": [\\\"\\\", [{\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephRgwPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephRgwPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephRgwPublic\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/swift/v1/AUTH_\\\"}}, \\\"%(project_id)s\\\"]]}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephRgwPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephRgwPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CephRgwPublic\\\", \\\"port\\\"]}}}}, \\\"CinderAdmin\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderAdmin\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderAdmin\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"list_join\\\": [\\\"\\\", [{\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderAdmin\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/v1/\\\"}}, \\\"%(tenant_id)s\\\"]]}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderAdmin\\\", \\\"port\\\"]}}}}, \\\"CinderInternal\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderInternal\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderInternal\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"list_join\\\": [\\\"\\\", [{\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderInternal\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/v1/\\\"}}, \\\"%(tenant_id)s\\\"]]}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderInternal\\\", \\\"port\\\"]}}}}, \\\"CinderPublic\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderPublic\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderPublic\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"list_join\\\": [\\\"\\\", [{\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderPublic\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/v1/\\\"}}, \\\"%(tenant_id)s\\\"]]}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderPublic\\\", \\\"port\\\"]}}}}, \\\"CinderV2Admin\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderAdmin\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderAdmin\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"list_join\\\": [\\\"\\\", [{\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderAdmin\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/v2/\\\"}}, \\\"%(tenant_id)s\\\"]]}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderAdmin\\\", \\\"port\\\"]}}}}, \\\"CinderV2Internal\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderInternal\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderInternal\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"list_join\\\": [\\\"\\\", [{\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderInternal\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/v2/\\\"}}, \\\"%(tenant_id)s\\\"]]}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderInternal\\\", \\\"port\\\"]}}}}, \\\"CinderV2Public\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderPublic\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderPublic\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"list_join\\\": [\\\"\\\", [{\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderPublic\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/v2/\\\"}}, \\\"%(tenant_id)s\\\"]]}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderPublic\\\", \\\"port\\\"]}}}}, \\\"CinderV3Admin\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderAdmin\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderAdmin\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"list_join\\\": [\\\"\\\", [{\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderAdmin\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/v3/\\\"}}, \\\"%(tenant_id)s\\\"]]}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderAdmin\\\", \\\"port\\\"]}}}}, \\\"CinderV3Internal\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderInternal\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderInternal\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"list_join\\\": [\\\"\\\", [{\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderInternal\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/v3/\\\"}}, \\\"%(tenant_id)s\\\"]]}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderInternal\\\", \\\"port\\\"]}}}}, \\\"CinderV3Public\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderPublic\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderPublic\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"list_join\\\": [\\\"\\\", [{\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderPublic\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/v3/\\\"}}, \\\"%(tenant_id)s\\\"]]}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderPublic\\\", \\\"port\\\"]}}}}, \\\"DesignateAdmin\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"DesignateAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"DesignateApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"DesignateApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"DesignateAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"DesignateApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"DesignateApiNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"DesignateAdmin\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"DesignateAdmin\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"DesignateAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"DesignateAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"DesignateApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"DesignateApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"DesignateAdmin\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/v2\\\"}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"DesignateAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"DesignateAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"DesignateApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"DesignateApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"DesignateAdmin\\\", \\\"port\\\"]}}}}, \\\"DesignateInternal\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"DesignateInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"DesignateApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"DesignateApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"DesignateInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"DesignateApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"DesignateApiNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"DesignateInternal\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"DesignateInternal\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"DesignateInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"DesignateInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"DesignateApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"DesignateApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"DesignateInternal\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/v2\\\"}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"DesignateInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"DesignateInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"DesignateApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"DesignateApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"DesignateInternal\\\", \\\"port\\\"]}}}}, \\\"DesignatePublic\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"DesignatePublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"DesignatePublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"DesignatePublic\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"DesignatePublic\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"DesignatePublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"DesignatePublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"DesignatePublic\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/v2\\\"}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"DesignatePublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"DesignatePublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"DesignatePublic\\\", \\\"port\\\"]}}}}, \\\"DockerRegistryInternal\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"DockerRegistryInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"DockerRegistryNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"DockerRegistryNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"DockerRegistryInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"DockerRegistryNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"DockerRegistryNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"DockerRegistryInternal\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"DockerRegistryInternal\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"DockerRegistryInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"DockerRegistryInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"DockerRegistryNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"DockerRegistryNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"DockerRegistryInternal\\\", \\\"port\\\"]}}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"DockerRegistryInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"DockerRegistryInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"DockerRegistryNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"DockerRegistryNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"DockerRegistryInternal\\\", \\\"port\\\"]}}}}, \\\"GaneshaInternal\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GaneshaInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GaneshaNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GaneshaNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GaneshaInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GaneshaNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GaneshaNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GaneshaInternal\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GaneshaInternal\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GaneshaInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GaneshaInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GaneshaNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GaneshaNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GaneshaInternal\\\", \\\"port\\\"]}}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GaneshaInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GaneshaInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GaneshaNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GaneshaNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GaneshaInternal\\\", \\\"port\\\"]}}}}, \\\"GlanceAdmin\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GlanceAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GlanceApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GlanceApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GlanceAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GlanceApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GlanceApiNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GlanceAdmin\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GlanceAdmin\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GlanceAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GlanceAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GlanceApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GlanceApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GlanceAdmin\\\", \\\"port\\\"]}}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GlanceAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GlanceAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GlanceApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GlanceApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GlanceAdmin\\\", \\\"port\\\"]}}}}, \\\"GlanceInternal\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GlanceInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GlanceApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GlanceApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GlanceInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GlanceApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GlanceApiNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GlanceInternal\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GlanceInternal\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GlanceInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GlanceInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GlanceApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GlanceApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GlanceInternal\\\", \\\"port\\\"]}}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GlanceInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GlanceInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GlanceApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GlanceApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GlanceInternal\\\", \\\"port\\\"]}}}}, \\\"GlancePublic\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GlancePublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GlancePublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GlancePublic\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GlancePublic\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GlancePublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GlancePublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GlancePublic\\\", \\\"port\\\"]}}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GlancePublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GlancePublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GlancePublic\\\", \\\"port\\\"]}}}}, \\\"GnocchiAdmin\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GnocchiAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GnocchiApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GnocchiApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GnocchiAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GnocchiApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GnocchiApiNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GnocchiAdmin\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GnocchiAdmin\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GnocchiAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GnocchiAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GnocchiApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GnocchiApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GnocchiAdmin\\\", \\\"port\\\"]}}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GnocchiAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GnocchiAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GnocchiApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GnocchiApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GnocchiAdmin\\\", \\\"port\\\"]}}}}, \\\"GnocchiInternal\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GnocchiInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GnocchiApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GnocchiApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GnocchiInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GnocchiApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GnocchiApiNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GnocchiInternal\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GnocchiInternal\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GnocchiInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GnocchiInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GnocchiApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GnocchiApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GnocchiInternal\\\", \\\"port\\\"]}}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GnocchiInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GnocchiInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GnocchiApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GnocchiApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GnocchiInternal\\\", \\\"port\\\"]}}}}, \\\"GnocchiPublic\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GnocchiPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GnocchiPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GnocchiPublic\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GnocchiPublic\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GnocchiPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GnocchiPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GnocchiPublic\\\", \\\"port\\\"]}}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GnocchiPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GnocchiPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GnocchiPublic\\\", \\\"port\\\"]}}}}, \\\"HeatAdmin\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HeatApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HeatApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HeatApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HeatApiNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatAdmin\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatAdmin\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"list_join\\\": [\\\"\\\", [{\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HeatApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HeatApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatAdmin\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/v1/\\\"}}, \\\"%(tenant_id)s\\\"]]}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HeatApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HeatApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatAdmin\\\", \\\"port\\\"]}}}}, \\\"HeatInternal\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HeatApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HeatApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HeatApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HeatApiNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatInternal\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatInternal\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"list_join\\\": [\\\"\\\", [{\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HeatApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HeatApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatInternal\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/v1/\\\"}}, \\\"%(tenant_id)s\\\"]]}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HeatApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HeatApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatInternal\\\", \\\"port\\\"]}}}}, \\\"HeatPublic\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatPublic\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatPublic\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"list_join\\\": [\\\"\\\", [{\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatPublic\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/v1/\\\"}}, \\\"%(tenant_id)s\\\"]]}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatPublic\\\", \\\"port\\\"]}}}}, \\\"HeatCfnAdmin\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatCfnAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HeatApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HeatApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatCfnAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HeatApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HeatApiNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatCfnAdmin\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatCfnAdmin\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatCfnAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatCfnAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HeatApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HeatApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatCfnAdmin\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/v1\\\"}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatCfnAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatCfnAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HeatApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HeatApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatCfnAdmin\\\", \\\"port\\\"]}}}}, \\\"HeatCfnInternal\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatCfnInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HeatApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HeatApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatCfnInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HeatApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HeatApiNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatCfnInternal\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatCfnInternal\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatCfnInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatCfnInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HeatApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HeatApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatCfnInternal\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/v1\\\"}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatCfnInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatCfnInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HeatApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HeatApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatCfnInternal\\\", \\\"port\\\"]}}}}, \\\"HeatCfnPublic\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatCfnPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatCfnPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatCfnPublic\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatCfnPublic\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatCfnPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatCfnPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatCfnPublic\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/v1\\\"}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatCfnPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatCfnPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatCfnPublic\\\", \\\"port\\\"]}}}}, \\\"HorizonPublic\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HorizonPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HorizonPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HorizonPublic\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HorizonPublic\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HorizonPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HorizonPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HorizonPublic\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/dashboard\\\"}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HorizonPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HorizonPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HorizonPublic\\\", \\\"port\\\"]}}}}, \\\"IronicAdmin\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"IronicApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"IronicApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"IronicApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"IronicApiNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicAdmin\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicAdmin\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"IronicApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"IronicApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicAdmin\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/v1\\\"}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"IronicApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"IronicApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicAdmin\\\", \\\"port\\\"]}}}}, \\\"IronicInternal\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"IronicApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"IronicApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"IronicApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"IronicApiNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicInternal\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicInternal\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"IronicApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"IronicApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicInternal\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/v1\\\"}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"IronicApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"IronicApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicInternal\\\", \\\"port\\\"]}}}}, \\\"IronicPublic\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicPublic\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicPublic\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicPublic\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/v1\\\"}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicPublic\\\", \\\"port\\\"]}}}}, \\\"IronicInspectorAdmin\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicInspectorAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"IronicInspectorNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"IronicInspectorNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicInspectorAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"IronicInspectorNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"IronicInspectorNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicInspectorAdmin\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicInspectorAdmin\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicInspectorAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicInspectorAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"IronicInspectorNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"IronicInspectorNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicInspectorAdmin\\\", \\\"port\\\"]}}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicInspectorAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicInspectorAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"IronicInspectorNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"IronicInspectorNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicInspectorAdmin\\\", \\\"port\\\"]}}}}, \\\"IronicInspectorInternal\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicInspectorInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"IronicInspectorNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"IronicInspectorNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicInspectorInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"IronicInspectorNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"IronicInspectorNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicInspectorInternal\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicInspectorInternal\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicInspectorInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicInspectorInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"IronicInspectorNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"IronicInspectorNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicInspectorInternal\\\", \\\"port\\\"]}}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicInspectorInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicInspectorInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"IronicInspectorNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"IronicInspectorNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicInspectorInternal\\\", \\\"port\\\"]}}}}, \\\"IronicInspectorPublic\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicInspectorPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicInspectorPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicInspectorPublic\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicInspectorPublic\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicInspectorPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicInspectorPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicInspectorPublic\\\", \\\"port\\\"]}}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicInspectorPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicInspectorPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"IronicInspectorPublic\\\", \\\"port\\\"]}}}}, \\\"KeystoneAdmin\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"KeystoneAdminApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"KeystoneAdminApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"KeystoneAdminApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"KeystoneAdminApiNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneAdmin\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneAdmin\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"KeystoneAdminApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"KeystoneAdminApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneAdmin\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/\\\"}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"KeystoneAdminApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"KeystoneAdminApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneAdmin\\\", \\\"port\\\"]}}}}, \\\"KeystoneInternal\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"KeystonePublicApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"KeystonePublicApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"KeystonePublicApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"KeystonePublicApiNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"KeystonePublicApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"KeystonePublicApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/\\\"}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"KeystonePublicApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"KeystonePublicApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"port\\\"]}}}}, \\\"KeystonePublic\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystonePublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystonePublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystonePublic\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystonePublic\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystonePublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystonePublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystonePublic\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/\\\"}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystonePublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystonePublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystonePublic\\\", \\\"port\\\"]}}}}, \\\"KeystoneV3Admin\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"KeystoneAdminApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"KeystoneAdminApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"KeystoneAdminApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"KeystoneAdminApiNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneAdmin\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneAdmin\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"KeystoneAdminApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"KeystoneAdminApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneAdmin\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/v3\\\"}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"KeystoneAdminApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"KeystoneAdminApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneAdmin\\\", \\\"port\\\"]}}}}, \\\"KeystoneV3Internal\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"KeystonePublicApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"KeystonePublicApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"KeystonePublicApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"KeystonePublicApiNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"KeystonePublicApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"KeystonePublicApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/v3\\\"}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"KeystonePublicApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"KeystonePublicApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"port\\\"]}}}}, \\\"KeystoneV3Public\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystonePublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystonePublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystonePublic\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystonePublic\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystonePublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystonePublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystonePublic\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/v3\\\"}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystonePublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystonePublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystonePublic\\\", \\\"port\\\"]}}}}, \\\"ManilaAdmin\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"ManilaApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"ManilaApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"ManilaApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"ManilaApiNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaAdmin\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaAdmin\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"ManilaApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"ManilaApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaAdmin\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/v2\\\"}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"ManilaApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"ManilaApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaAdmin\\\", \\\"port\\\"]}}}}, \\\"ManilaInternal\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"ManilaApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"ManilaApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"ManilaApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"ManilaApiNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaInternal\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaInternal\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"ManilaApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"ManilaApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaInternal\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/v2\\\"}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"ManilaApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"ManilaApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaInternal\\\", \\\"port\\\"]}}}}, \\\"ManilaPublic\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaPublic\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaPublic\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaPublic\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/v2\\\"}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaPublic\\\", \\\"port\\\"]}}}}, \\\"ManilaV1Admin\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"ManilaApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"ManilaApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"ManilaApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"ManilaApiNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaAdmin\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaAdmin\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"list_join\\\": [\\\"\\\", [{\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"ManilaApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"ManilaApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaAdmin\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/v1/\\\"}}, \\\"%(tenant_id)s\\\"]]}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"ManilaApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"ManilaApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaAdmin\\\", \\\"port\\\"]}}}}, \\\"ManilaV1Internal\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"ManilaApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"ManilaApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"ManilaApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"ManilaApiNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaInternal\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaInternal\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"list_join\\\": [\\\"\\\", [{\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"ManilaApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"ManilaApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaInternal\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/v1/\\\"}}, \\\"%(tenant_id)s\\\"]]}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"ManilaApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"ManilaApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaInternal\\\", \\\"port\\\"]}}}}, \\\"ManilaV1Public\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaPublic\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaPublic\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"list_join\\\": [\\\"\\\", [{\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaPublic\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/v1/\\\"}}, \\\"%(tenant_id)s\\\"]]}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"ManilaPublic\\\", \\\"port\\\"]}}}}, \\\"MetricsQdrPublic\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"MetricsQdrPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"MetricsQdrPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"MetricsQdrPublic\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"MetricsQdrPublic\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"MetricsQdrPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"MetricsQdrPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"MetricsQdrPublic\\\", \\\"port\\\"]}}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"MetricsQdrPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"MetricsQdrPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"MetricsQdrPublic\\\", \\\"port\\\"]}}}}, \\\"MysqlInternal\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"MysqlInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MysqlNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MysqlNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"MysqlInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MysqlNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MysqlNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"MysqlInternal\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"MysqlInternal\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"MysqlInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"MysqlInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MysqlNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MysqlNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"MysqlInternal\\\", \\\"port\\\"]}}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"MysqlInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"MysqlInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MysqlNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MysqlNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"MysqlInternal\\\", \\\"port\\\"]}}}}, \\\"NeutronAdmin\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NeutronAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NeutronApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NeutronApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NeutronAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NeutronApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NeutronApiNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NeutronAdmin\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NeutronAdmin\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NeutronAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NeutronAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NeutronApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NeutronApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NeutronAdmin\\\", \\\"port\\\"]}}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NeutronAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NeutronAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NeutronApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NeutronApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NeutronAdmin\\\", \\\"port\\\"]}}}}, \\\"NeutronInternal\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NeutronInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NeutronApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NeutronApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NeutronInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NeutronApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NeutronApiNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NeutronInternal\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NeutronInternal\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NeutronInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NeutronInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NeutronApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NeutronApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NeutronInternal\\\", \\\"port\\\"]}}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NeutronInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NeutronInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NeutronApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NeutronApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NeutronInternal\\\", \\\"port\\\"]}}}}, \\\"NeutronPublic\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NeutronPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NeutronPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NeutronPublic\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NeutronPublic\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NeutronPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NeutronPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NeutronPublic\\\", \\\"port\\\"]}}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NeutronPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NeutronPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NeutronPublic\\\", \\\"port\\\"]}}}}, \\\"NovaAdmin\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaApiNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaAdmin\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaAdmin\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaAdmin\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/v2.1\\\"}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaAdmin\\\", \\\"port\\\"]}}}}, \\\"NovaInternal\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaApiNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaInternal\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaInternal\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaInternal\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/v2.1\\\"}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaInternal\\\", \\\"port\\\"]}}}}, \\\"NovaPublic\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaPublic\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaPublic\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaPublic\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/v2.1\\\"}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaPublic\\\", \\\"port\\\"]}}}}, \\\"NovaMetadataInternal\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaMetadataInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaMetadataNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaMetadataNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaMetadataInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaMetadataNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaMetadataNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaMetadataInternal\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaMetadataInternal\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaMetadataInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaMetadataInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaMetadataNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaMetadataNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaMetadataInternal\\\", \\\"port\\\"]}}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaMetadataInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaMetadataInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaMetadataNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaMetadataNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaMetadataInternal\\\", \\\"port\\\"]}}}}, \\\"NovaVNCProxyAdmin\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaVNCProxyAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaVNCProxyAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaApiNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaVNCProxyAdmin\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaVNCProxyAdmin\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaVNCProxyAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaVNCProxyAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaVNCProxyAdmin\\\", \\\"port\\\"]}}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaVNCProxyAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaVNCProxyAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaVNCProxyAdmin\\\", \\\"port\\\"]}}}}, \\\"NovaVNCProxyInternal\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaVNCProxyInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaVNCProxyInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaApiNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaVNCProxyInternal\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaVNCProxyInternal\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaVNCProxyInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaVNCProxyInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaVNCProxyInternal\\\", \\\"port\\\"]}}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaVNCProxyInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaVNCProxyInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaVNCProxyInternal\\\", \\\"port\\\"]}}}}, \\\"NovaVNCProxyPublic\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaVNCProxyPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaVNCProxyPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaVNCProxyPublic\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaVNCProxyPublic\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaVNCProxyPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaVNCProxyPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaVNCProxyPublic\\\", \\\"port\\\"]}}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaVNCProxyPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaVNCProxyPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaVNCProxyPublic\\\", \\\"port\\\"]}}}}, \\\"NovajoinAdmin\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovajoinAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovajoinNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovajoinNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovajoinAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovajoinNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovajoinNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovajoinAdmin\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovajoinAdmin\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovajoinAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovajoinAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovajoinNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovajoinNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovajoinAdmin\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/v1\\\"}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovajoinAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovajoinAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovajoinNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovajoinNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovajoinAdmin\\\", \\\"port\\\"]}}}}, \\\"NovajoinInternal\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovajoinInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovajoinNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovajoinNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovajoinInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovajoinNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovajoinNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovajoinInternal\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovajoinInternal\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovajoinInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovajoinInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovajoinNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovajoinNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovajoinInternal\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/v1\\\"}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovajoinInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovajoinInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovajoinNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovajoinNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovajoinInternal\\\", \\\"port\\\"]}}}}, \\\"NovajoinPublic\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovajoinPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovajoinPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovajoinPublic\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovajoinPublic\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovajoinPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovajoinPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovajoinPublic\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/v1\\\"}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovajoinPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovajoinPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovajoinPublic\\\", \\\"port\\\"]}}}}, \\\"OctaviaAdmin\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"OctaviaAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OctaviaApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OctaviaApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"OctaviaAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OctaviaApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OctaviaApiNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"OctaviaAdmin\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"OctaviaAdmin\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"OctaviaAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"OctaviaAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OctaviaApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OctaviaApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"OctaviaAdmin\\\", \\\"port\\\"]}}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"OctaviaAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"OctaviaAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OctaviaApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OctaviaApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"OctaviaAdmin\\\", \\\"port\\\"]}}}}, \\\"OctaviaInternal\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"OctaviaInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OctaviaApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OctaviaApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"OctaviaInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OctaviaApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OctaviaApiNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"OctaviaInternal\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"OctaviaInternal\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"OctaviaInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"OctaviaInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OctaviaApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OctaviaApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"OctaviaInternal\\\", \\\"port\\\"]}}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"OctaviaInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"OctaviaInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OctaviaApiNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OctaviaApiNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"OctaviaInternal\\\", \\\"port\\\"]}}}}, \\\"OctaviaPublic\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"OctaviaPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"OctaviaPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"OctaviaPublic\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"OctaviaPublic\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"OctaviaPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"OctaviaPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"OctaviaPublic\\\", \\\"port\\\"]}}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"OctaviaPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"OctaviaPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"OctaviaPublic\\\", \\\"port\\\"]}}}}, \\\"PlacementAdmin\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"PlacementAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PlacementNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PlacementNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"PlacementAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PlacementNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PlacementNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"PlacementAdmin\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"PlacementAdmin\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"PlacementAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"PlacementAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PlacementNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PlacementNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"PlacementAdmin\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/placement\\\"}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"PlacementAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"PlacementAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PlacementNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PlacementNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"PlacementAdmin\\\", \\\"port\\\"]}}}}, \\\"PlacementInternal\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"PlacementInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PlacementNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PlacementNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"PlacementInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PlacementNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PlacementNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"PlacementInternal\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"PlacementInternal\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"PlacementInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"PlacementInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PlacementNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PlacementNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"PlacementInternal\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/placement\\\"}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"PlacementInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"PlacementInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PlacementNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PlacementNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"PlacementInternal\\\", \\\"port\\\"]}}}}, \\\"PlacementPublic\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"PlacementPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"PlacementPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"PlacementPublic\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"PlacementPublic\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"PlacementPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"PlacementPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"PlacementPublic\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/placement\\\"}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"PlacementPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"PlacementPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"PlacementPublic\\\", \\\"port\\\"]}}}}, \\\"SwiftAdmin\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"SwiftProxyNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"SwiftProxyNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"SwiftProxyNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"SwiftProxyNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftAdmin\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftAdmin\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"SwiftProxyNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"SwiftProxyNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftAdmin\\\", \\\"port\\\"]}}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"SwiftProxyNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"SwiftProxyNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftAdmin\\\", \\\"port\\\"]}}}}, \\\"SwiftInternal\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"SwiftProxyNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"SwiftProxyNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"SwiftProxyNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"SwiftProxyNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftInternal\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftInternal\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"list_join\\\": [\\\"\\\", [{\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"SwiftProxyNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"SwiftProxyNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftInternal\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/v1/AUTH_\\\"}}, \\\"%(tenant_id)s\\\"]]}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"SwiftProxyNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"SwiftProxyNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftInternal\\\", \\\"port\\\"]}}}}, \\\"SwiftPublic\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftPublic\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftPublic\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"list_join\\\": [\\\"\\\", [{\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftPublic\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/v1/AUTH_\\\"}}, \\\"%(tenant_id)s\\\"]]}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftPublic\\\", \\\"port\\\"]}}}}, \\\"SwiftS3Admin\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"SwiftProxyNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"SwiftProxyNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"SwiftProxyNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"SwiftProxyNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftAdmin\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftAdmin\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"SwiftProxyNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"SwiftProxyNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftAdmin\\\", \\\"port\\\"]}}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftAdmin\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftAdmin\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"SwiftProxyNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"SwiftProxyNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftAdmin\\\", \\\"port\\\"]}}}}, \\\"SwiftS3Internal\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"SwiftProxyNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"SwiftProxyNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"SwiftProxyNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"SwiftProxyNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftInternal\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftInternal\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"SwiftProxyNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"SwiftProxyNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftInternal\\\", \\\"port\\\"]}}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftInternal\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftInternal\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"SwiftProxyNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"SwiftProxyNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftInternal\\\", \\\"port\\\"]}}}}, \\\"SwiftS3Public\\\": {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"host_nobrackets\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftPublic\\\", \\\"port\\\"]}, \\\"protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftPublic\\\", \\\"protocol\\\"]}, \\\"uri\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftPublic\\\", \\\"port\\\"]}}}, \\\"uri_no_suffix\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftPublic\\\", \\\"host\\\"]}, \\\"params\\\": {\\\"CLOUDNAME\\\": {\\\"get_param\\\": [\\\"CloudEndpoints\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}]}, \\\"IP_ADDRESS\\\": {\\\"get_param\\\": [\\\"NetIpMap\\\", {\\\"str_replace\\\": {\\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PublicNetwork\\\"]}}, \\\"template\\\": \\\"NETWORK_uri\\\"}}]}}}}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftPublic\\\", \\\"port\\\"]}}}}}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Utility stack to convert an array of services into a set of combined role configs.\\\\n\\\", \\\"parameters\\\": {\\\"Services\\\": {\\\"default\\\": [], \\\"description\\\": \\\"List nested stack service templates.\\\\n\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"description\\\": \\\"Parameters specific to the role\\\", \\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}}, \\\"resources\\\": {\\\"ServiceChain\\\": {\\\"type\\\": \\\"OS::Heat::ResourceChain\\\", \\\"properties\\\": {\\\"resources\\\": {\\\"get_param\\\": \\\"Services\\\"}, \\\"concurrent\\\": true, \\\"resource_properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}}, \\\"ServiceServerMetadataHook\\\": {\\\"type\\\": \\\"OS::TripleO::ControllerServiceServerMetadataHook\\\", \\\"properties\\\": {\\\"RoleData\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}, \\\"PuppetStepConfig\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"string\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\\\\\"\\\\\\\\n\\\\\\\")\\\", \\\"data\\\": {\\\"service_names\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"service_name\\\"]}, \\\"step_config\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"step_config\\\"]}, \\\"docker_config\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"docker_config\\\"]}}}}}}, \\\"DockerConfig\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\\\", \\\"data\\\": {\\\"service_names\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"service_names\\\"]}, \\\"docker_config\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"docker_config\\\"]}}}}}}, \\\"DockerConfigScripts\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\\\", \\\"data\\\": {\\\"service_names\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"service_names\\\"]}, \\\"container_config_scripts\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"container_config_scripts\\\"]}}}}}}, \\\"MonitoringSubscriptionsConfig\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}, \\\"ServiceNames\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"filter\\\": [[null], {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"service_name\\\"]}]}}}, \\\"GlobalConfigSettings\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}}, \\\"KeystoneResourcesConfigs\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}}, \\\"ServiceConfigSettings\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}, \\\"DeployStepsTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ExternalDeployTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ExternalPostDeployTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ScaleTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ExternalUpdateTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ExternalUpgradeTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"PreUpgradeRollingTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"UpgradeTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"PostUpgradeTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"UpdateTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"PostUpdateTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"UpgradeBatchTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"PuppetConfig\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"KollaConfig\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}, \\\"DockerPuppetTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ContainerPuppetTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"HostFirewallTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"HostPrepTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"PreDeployStepTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"IpaRegistrationTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"AnsibleGroupVars\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}}, \\\"FirewallRules\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}}, \\\"FirewallFrontendRules\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"frontend\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ssl_frontend\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"edge_frontend\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"edge_sslfrontend\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Combined Role data for this set of services.\\\", \\\"value\\\": {\\\"service_names\\\": {\\\"get_attr\\\": [\\\"ServiceNames\\\", \\\"value\\\"]}, \\\"monitoring_subscriptions\\\": {\\\"get_attr\\\": [\\\"MonitoringSubscriptionsConfig\\\", \\\"value\\\"]}, \\\"config_settings\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"$.data.where($ != null).reduce($1.mergeWith($2), {})\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"config_settings\\\"]}}}, \\\"global_config_settings\\\": {\\\"get_attr\\\": [\\\"GlobalConfigSettings\\\", \\\"value\\\"]}, \\\"service_config_settings\\\": {\\\"get_attr\\\": [\\\"ServiceConfigSettings\\\", \\\"value\\\"]}, \\\"step_config\\\": {\\\"get_attr\\\": [\\\"PuppetStepConfig\\\", \\\"value\\\"]}, \\\"deploy_steps_tasks\\\": {\\\"get_attr\\\": [\\\"DeployStepsTasks\\\", \\\"value\\\"]}, \\\"external_deploy_tasks\\\": {\\\"get_attr\\\": [\\\"ExternalDeployTasks\\\", \\\"value\\\"]}, \\\"external_post_deploy_tasks\\\": {\\\"get_attr\\\": [\\\"ExternalPostDeployTasks\\\", \\\"value\\\"]}, \\\"external_update_tasks\\\": {\\\"get_attr\\\": [\\\"ExternalUpdateTasks\\\", \\\"value\\\"]}, \\\"external_upgrade_tasks\\\": {\\\"get_attr\\\": [\\\"ExternalUpgradeTasks\\\", \\\"value\\\"]}, \\\"scale_tasks\\\": {\\\"get_attr\\\": [\\\"ScaleTasks\\\", \\\"value\\\"]}, \\\"pre_upgrade_rolling_tasks\\\": {\\\"get_attr\\\": [\\\"PreUpgradeRollingTasks\\\", \\\"value\\\"]}, \\\"upgrade_tasks\\\": {\\\"get_attr\\\": [\\\"UpgradeTasks\\\", \\\"value\\\"]}, \\\"post_upgrade_tasks\\\": {\\\"get_attr\\\": [\\\"PostUpgradeTasks\\\", \\\"value\\\"]}, \\\"update_tasks\\\": {\\\"get_attr\\\": [\\\"UpdateTasks\\\", \\\"value\\\"]}, \\\"post_update_tasks\\\": {\\\"get_attr\\\": [\\\"PostUpdateTasks\\\", \\\"value\\\"]}, \\\"upgrade_batch_tasks\\\": {\\\"get_attr\\\": [\\\"UpgradeBatchTasks\\\", \\\"value\\\"]}, \\\"service_metadata_settings\\\": {\\\"get_attr\\\": [\\\"ServiceServerMetadataHook\\\", \\\"metadata\\\"]}, \\\"ansible_group_vars\\\": {\\\"map_merge\\\": [{\\\"ansible_async_dir\\\": \\\"/tmp/.ansible_async\\\"}, {\\\"get_attr\\\": [\\\"AnsibleGroupVars\\\", \\\"value\\\"]}]}, \\\"keystone_resources\\\": {\\\"get_attr\\\": [\\\"KeystoneResourcesConfigs\\\", \\\"value\\\"]}, \\\"firewall_rules\\\": {\\\"get_attr\\\": [\\\"FirewallRules\\\", \\\"value\\\"]}, \\\"firewall_frontend_rules\\\": {\\\"get_attr\\\": [\\\"FirewallFrontendRules\\\", \\\"value\\\", \\\"frontend\\\"]}, \\\"firewall_ssl_frontend_rules\\\": {\\\"get_attr\\\": [\\\"FirewallFrontendRules\\\", \\\"value\\\", \\\"ssl_frontend\\\"]}, \\\"firewall_edge_frontend_rules\\\": {\\\"get_attr\\\": [\\\"FirewallFrontendRules\\\", \\\"value\\\", \\\"edge_frontend\\\"]}, \\\"firewall_edge_ssl_frontend_rules\\\": {\\\"get_attr\\\": [\\\"FirewallFrontendRules\\\", \\\"value\\\", \\\"edge_ssl_frontend\\\"]}, \\\"puppet_config\\\": {\\\"get_attr\\\": [\\\"PuppetConfig\\\", \\\"value\\\"]}, \\\"kolla_config\\\": {\\\"get_attr\\\": [\\\"KollaConfig\\\", \\\"value\\\"]}, \\\"docker_config\\\": {\\\"get_attr\\\": [\\\"DockerConfig\\\", \\\"value\\\"]}, \\\"container_config_scripts\\\": {\\\"get_attr\\\": [\\\"DockerConfigScripts\\\", \\\"value\\\"]}, \\\"container_puppet_tasks\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"ContainerPuppetTasks\\\", \\\"value\\\"]}, {\\\"get_attr\\\": [\\\"DockerPuppetTasks\\\", \\\"value\\\"]}]}, \\\"host_prep_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"HostFirewallTasks\\\", \\\"value\\\"]}, {\\\"get_attr\\\": [\\\"HostPrepTasks\\\", \\\"value\\\"]}]}, \\\"pre_deploy_step_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"PreDeployStepTasks\\\", \\\"value\\\"]}, {\\\"get_attr\\\": [\\\"IpaRegistrationTasks\\\", \\\"value\\\"]}]}}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Utility stack to convert an array of services into a set of combined role configs.\\\\n\\\", \\\"parameters\\\": {\\\"Services\\\": {\\\"default\\\": [], \\\"description\\\": \\\"List nested stack service templates.\\\\n\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"description\\\": \\\"Parameters specific to the role\\\", \\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}}, \\\"resources\\\": {\\\"ServiceChain\\\": {\\\"type\\\": \\\"OS::Heat::ResourceChain\\\", \\\"properties\\\": {\\\"resources\\\": {\\\"get_param\\\": \\\"Services\\\"}, \\\"concurrent\\\": true, \\\"resource_properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}}, \\\"ServiceServerMetadataHook\\\": {\\\"type\\\": \\\"OS::TripleO::CellControllerServiceServerMetadataHook\\\", \\\"properties\\\": {\\\"RoleData\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}, \\\"PuppetStepConfig\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"string\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\\\\\"\\\\\\\\n\\\\\\\")\\\", \\\"data\\\": {\\\"service_names\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"service_name\\\"]}, \\\"step_config\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"step_config\\\"]}, \\\"docker_config\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"docker_config\\\"]}}}}}}, \\\"DockerConfig\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\\\", \\\"data\\\": {\\\"service_names\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"service_names\\\"]}, \\\"docker_config\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"docker_config\\\"]}}}}}}, \\\"DockerConfigScripts\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\\\", \\\"data\\\": {\\\"service_names\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"service_names\\\"]}, \\\"container_config_scripts\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"container_config_scripts\\\"]}}}}}}, \\\"MonitoringSubscriptionsConfig\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}, \\\"ServiceNames\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"filter\\\": [[null], {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"service_name\\\"]}]}}}, \\\"GlobalConfigSettings\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}}, \\\"KeystoneResourcesConfigs\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}}, \\\"ServiceConfigSettings\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}, \\\"DeployStepsTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ExternalDeployTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ExternalPostDeployTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ScaleTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ExternalUpdateTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ExternalUpgradeTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"PreUpgradeRollingTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"UpgradeTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"PostUpgradeTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"UpdateTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"PostUpdateTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"UpgradeBatchTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"PuppetConfig\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"KollaConfig\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}, \\\"DockerPuppetTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ContainerPuppetTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"HostFirewallTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"HostPrepTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"PreDeployStepTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"IpaRegistrationTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"AnsibleGroupVars\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}}, \\\"FirewallRules\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}}, \\\"FirewallFrontendRules\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"frontend\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ssl_frontend\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"edge_frontend\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"edge_sslfrontend\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Combined Role data for this set of services.\\\", \\\"value\\\": {\\\"service_names\\\": {\\\"get_attr\\\": [\\\"ServiceNames\\\", \\\"value\\\"]}, \\\"monitoring_subscriptions\\\": {\\\"get_attr\\\": [\\\"MonitoringSubscriptionsConfig\\\", \\\"value\\\"]}, \\\"config_settings\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"$.data.where($ != null).reduce($1.mergeWith($2), {})\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"config_settings\\\"]}}}, \\\"global_config_settings\\\": {\\\"get_attr\\\": [\\\"GlobalConfigSettings\\\", \\\"value\\\"]}, \\\"service_config_settings\\\": {\\\"get_attr\\\": [\\\"ServiceConfigSettings\\\", \\\"value\\\"]}, \\\"step_config\\\": {\\\"get_attr\\\": [\\\"PuppetStepConfig\\\", \\\"value\\\"]}, \\\"deploy_steps_tasks\\\": {\\\"get_attr\\\": [\\\"DeployStepsTasks\\\", \\\"value\\\"]}, \\\"external_deploy_tasks\\\": {\\\"get_attr\\\": [\\\"ExternalDeployTasks\\\", \\\"value\\\"]}, \\\"external_post_deploy_tasks\\\": {\\\"get_attr\\\": [\\\"ExternalPostDeployTasks\\\", \\\"value\\\"]}, \\\"external_update_tasks\\\": {\\\"get_attr\\\": [\\\"ExternalUpdateTasks\\\", \\\"value\\\"]}, \\\"external_upgrade_tasks\\\": {\\\"get_attr\\\": [\\\"ExternalUpgradeTasks\\\", \\\"value\\\"]}, \\\"scale_tasks\\\": {\\\"get_attr\\\": [\\\"ScaleTasks\\\", \\\"value\\\"]}, \\\"pre_upgrade_rolling_tasks\\\": {\\\"get_attr\\\": [\\\"PreUpgradeRollingTasks\\\", \\\"value\\\"]}, \\\"upgrade_tasks\\\": {\\\"get_attr\\\": [\\\"UpgradeTasks\\\", \\\"value\\\"]}, \\\"post_upgrade_tasks\\\": {\\\"get_attr\\\": [\\\"PostUpgradeTasks\\\", \\\"value\\\"]}, \\\"update_tasks\\\": {\\\"get_attr\\\": [\\\"UpdateTasks\\\", \\\"value\\\"]}, \\\"post_update_tasks\\\": {\\\"get_attr\\\": [\\\"PostUpdateTasks\\\", \\\"value\\\"]}, \\\"upgrade_batch_tasks\\\": {\\\"get_attr\\\": [\\\"UpgradeBatchTasks\\\", \\\"value\\\"]}, \\\"service_metadata_settings\\\": {\\\"get_attr\\\": [\\\"ServiceServerMetadataHook\\\", \\\"metadata\\\"]}, \\\"ansible_group_vars\\\": {\\\"map_merge\\\": [{\\\"ansible_async_dir\\\": \\\"/tmp/.ansible_async\\\"}, {\\\"get_attr\\\": [\\\"AnsibleGroupVars\\\", \\\"value\\\"]}]}, \\\"keystone_resources\\\": {\\\"get_attr\\\": [\\\"KeystoneResourcesConfigs\\\", \\\"value\\\"]}, \\\"firewall_rules\\\": {\\\"get_attr\\\": [\\\"FirewallRules\\\", \\\"value\\\"]}, \\\"firewall_frontend_rules\\\": {\\\"get_attr\\\": [\\\"FirewallFrontendRules\\\", \\\"value\\\", \\\"frontend\\\"]}, \\\"firewall_ssl_frontend_rules\\\": {\\\"get_attr\\\": [\\\"FirewallFrontendRules\\\", \\\"value\\\", \\\"ssl_frontend\\\"]}, \\\"firewall_edge_frontend_rules\\\": {\\\"get_attr\\\": [\\\"FirewallFrontendRules\\\", \\\"value\\\", \\\"edge_frontend\\\"]}, \\\"firewall_edge_ssl_frontend_rules\\\": {\\\"get_attr\\\": [\\\"FirewallFrontendRules\\\", \\\"value\\\", \\\"edge_ssl_frontend\\\"]}, \\\"puppet_config\\\": {\\\"get_attr\\\": [\\\"PuppetConfig\\\", \\\"value\\\"]}, \\\"kolla_config\\\": {\\\"get_attr\\\": [\\\"KollaConfig\\\", \\\"value\\\"]}, \\\"docker_config\\\": {\\\"get_attr\\\": [\\\"DockerConfig\\\", \\\"value\\\"]}, \\\"container_config_scripts\\\": {\\\"get_attr\\\": [\\\"DockerConfigScripts\\\", \\\"value\\\"]}, \\\"container_puppet_tasks\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"ContainerPuppetTasks\\\", \\\"value\\\"]}, {\\\"get_attr\\\": [\\\"DockerPuppetTasks\\\", \\\"value\\\"]}]}, \\\"host_prep_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"HostFirewallTasks\\\", \\\"value\\\"]}, {\\\"get_attr\\\": [\\\"HostPrepTasks\\\", \\\"value\\\"]}]}, \\\"pre_deploy_step_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"PreDeployStepTasks\\\", \\\"value\\\"]}, {\\\"get_attr\\\": [\\\"IpaRegistrationTasks\\\", \\\"value\\\"]}]}}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Utility stack to convert an array of services into a set of combined role configs.\\\\n\\\", \\\"parameters\\\": {\\\"Services\\\": {\\\"default\\\": [], \\\"description\\\": \\\"List nested stack service templates.\\\\n\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"description\\\": \\\"Parameters specific to the role\\\", \\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}}, \\\"resources\\\": {\\\"ServiceChain\\\": {\\\"type\\\": \\\"OS::Heat::ResourceChain\\\", \\\"properties\\\": {\\\"resources\\\": {\\\"get_param\\\": \\\"Services\\\"}, \\\"concurrent\\\": true, \\\"resource_properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}}, \\\"ServiceServerMetadataHook\\\": {\\\"type\\\": \\\"OS::TripleO::CellControllerComputeServiceServerMetadataHook\\\", \\\"properties\\\": {\\\"RoleData\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}, \\\"PuppetStepConfig\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"string\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\\\\\"\\\\\\\\n\\\\\\\")\\\", \\\"data\\\": {\\\"service_names\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"service_name\\\"]}, \\\"step_config\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"step_config\\\"]}, \\\"docker_config\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"docker_config\\\"]}}}}}}, \\\"DockerConfig\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\\\", \\\"data\\\": {\\\"service_names\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"service_names\\\"]}, \\\"docker_config\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"docker_config\\\"]}}}}}}, \\\"DockerConfigScripts\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\\\", \\\"data\\\": {\\\"service_names\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"service_names\\\"]}, \\\"container_config_scripts\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"container_config_scripts\\\"]}}}}}}, \\\"MonitoringSubscriptionsConfig\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}, \\\"ServiceNames\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"filter\\\": [[null], {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"service_name\\\"]}]}}}, \\\"GlobalConfigSettings\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}}, \\\"KeystoneResourcesConfigs\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}}, \\\"ServiceConfigSettings\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}, \\\"DeployStepsTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ExternalDeployTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ExternalPostDeployTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ScaleTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ExternalUpdateTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ExternalUpgradeTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"PreUpgradeRollingTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"UpgradeTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"PostUpgradeTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"UpdateTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"PostUpdateTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"UpgradeBatchTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"PuppetConfig\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"KollaConfig\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}, \\\"DockerPuppetTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ContainerPuppetTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"HostFirewallTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"HostPrepTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"PreDeployStepTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"IpaRegistrationTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"AnsibleGroupVars\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}}, \\\"FirewallRules\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}}, \\\"FirewallFrontendRules\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"frontend\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ssl_frontend\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"edge_frontend\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"edge_sslfrontend\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Combined Role data for this set of services.\\\", \\\"value\\\": {\\\"service_names\\\": {\\\"get_attr\\\": [\\\"ServiceNames\\\", \\\"value\\\"]}, \\\"monitoring_subscriptions\\\": {\\\"get_attr\\\": [\\\"MonitoringSubscriptionsConfig\\\", \\\"value\\\"]}, \\\"config_settings\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"$.data.where($ != null).reduce($1.mergeWith($2), {})\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"config_settings\\\"]}}}, \\\"global_config_settings\\\": {\\\"get_attr\\\": [\\\"GlobalConfigSettings\\\", \\\"value\\\"]}, \\\"service_config_settings\\\": {\\\"get_attr\\\": [\\\"ServiceConfigSettings\\\", \\\"value\\\"]}, \\\"step_config\\\": {\\\"get_attr\\\": [\\\"PuppetStepConfig\\\", \\\"value\\\"]}, \\\"deploy_steps_tasks\\\": {\\\"get_attr\\\": [\\\"DeployStepsTasks\\\", \\\"value\\\"]}, \\\"external_deploy_tasks\\\": {\\\"get_attr\\\": [\\\"ExternalDeployTasks\\\", \\\"value\\\"]}, \\\"external_post_deploy_tasks\\\": {\\\"get_attr\\\": [\\\"ExternalPostDeployTasks\\\", \\\"value\\\"]}, \\\"external_update_tasks\\\": {\\\"get_attr\\\": [\\\"ExternalUpdateTasks\\\", \\\"value\\\"]}, \\\"external_upgrade_tasks\\\": {\\\"get_attr\\\": [\\\"ExternalUpgradeTasks\\\", \\\"value\\\"]}, \\\"scale_tasks\\\": {\\\"get_attr\\\": [\\\"ScaleTasks\\\", \\\"value\\\"]}, \\\"pre_upgrade_rolling_tasks\\\": {\\\"get_attr\\\": [\\\"PreUpgradeRollingTasks\\\", \\\"value\\\"]}, \\\"upgrade_tasks\\\": {\\\"get_attr\\\": [\\\"UpgradeTasks\\\", \\\"value\\\"]}, \\\"post_upgrade_tasks\\\": {\\\"get_attr\\\": [\\\"PostUpgradeTasks\\\", \\\"value\\\"]}, \\\"update_tasks\\\": {\\\"get_attr\\\": [\\\"UpdateTasks\\\", \\\"value\\\"]}, \\\"post_update_tasks\\\": {\\\"get_attr\\\": [\\\"PostUpdateTasks\\\", \\\"value\\\"]}, \\\"upgrade_batch_tasks\\\": {\\\"get_attr\\\": [\\\"UpgradeBatchTasks\\\", \\\"value\\\"]}, \\\"service_metadata_settings\\\": {\\\"get_attr\\\": [\\\"ServiceServerMetadataHook\\\", \\\"metadata\\\"]}, \\\"ansible_group_vars\\\": {\\\"map_merge\\\": [{\\\"ansible_async_dir\\\": \\\"/tmp/.ansible_async\\\"}, {\\\"get_attr\\\": [\\\"AnsibleGroupVars\\\", \\\"value\\\"]}]}, \\\"keystone_resources\\\": {\\\"get_attr\\\": [\\\"KeystoneResourcesConfigs\\\", \\\"value\\\"]}, \\\"firewall_rules\\\": {\\\"get_attr\\\": [\\\"FirewallRules\\\", \\\"value\\\"]}, \\\"firewall_frontend_rules\\\": {\\\"get_attr\\\": [\\\"FirewallFrontendRules\\\", \\\"value\\\", \\\"frontend\\\"]}, \\\"firewall_ssl_frontend_rules\\\": {\\\"get_attr\\\": [\\\"FirewallFrontendRules\\\", \\\"value\\\", \\\"ssl_frontend\\\"]}, \\\"firewall_edge_frontend_rules\\\": {\\\"get_attr\\\": [\\\"FirewallFrontendRules\\\", \\\"value\\\", \\\"edge_frontend\\\"]}, \\\"firewall_edge_ssl_frontend_rules\\\": {\\\"get_attr\\\": [\\\"FirewallFrontendRules\\\", \\\"value\\\", \\\"edge_ssl_frontend\\\"]}, \\\"puppet_config\\\": {\\\"get_attr\\\": [\\\"PuppetConfig\\\", \\\"value\\\"]}, \\\"kolla_config\\\": {\\\"get_attr\\\": [\\\"KollaConfig\\\", \\\"value\\\"]}, \\\"docker_config\\\": {\\\"get_attr\\\": [\\\"DockerConfig\\\", \\\"value\\\"]}, \\\"container_config_scripts\\\": {\\\"get_attr\\\": [\\\"DockerConfigScripts\\\", \\\"value\\\"]}, \\\"container_puppet_tasks\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"ContainerPuppetTasks\\\", \\\"value\\\"]}, {\\\"get_attr\\\": [\\\"DockerPuppetTasks\\\", \\\"value\\\"]}]}, \\\"host_prep_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"HostFirewallTasks\\\", \\\"value\\\"]}, {\\\"get_attr\\\": [\\\"HostPrepTasks\\\", \\\"value\\\"]}]}, \\\"pre_deploy_step_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"PreDeployStepTasks\\\", \\\"value\\\"]}, {\\\"get_attr\\\": [\\\"IpaRegistrationTasks\\\", \\\"value\\\"]}]}}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Utility stack to convert an array of services into a set of combined role configs.\\\\n\\\", \\\"parameters\\\": {\\\"Services\\\": {\\\"default\\\": [], \\\"description\\\": \\\"List nested stack service templates.\\\\n\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"description\\\": \\\"Parameters specific to the role\\\", \\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}}, \\\"resources\\\": {\\\"ServiceChain\\\": {\\\"type\\\": \\\"OS::Heat::ResourceChain\\\", \\\"properties\\\": {\\\"resources\\\": {\\\"get_param\\\": \\\"Services\\\"}, \\\"concurrent\\\": true, \\\"resource_properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}}, \\\"ServiceServerMetadataHook\\\": {\\\"type\\\": \\\"OS::TripleO::ComputeServiceServerMetadataHook\\\", \\\"properties\\\": {\\\"RoleData\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}, \\\"PuppetStepConfig\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"string\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\\\\\"\\\\\\\\n\\\\\\\")\\\", \\\"data\\\": {\\\"service_names\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"service_name\\\"]}, \\\"step_config\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"step_config\\\"]}, \\\"docker_config\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"docker_config\\\"]}}}}}}, \\\"DockerConfig\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\\\", \\\"data\\\": {\\\"service_names\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"service_names\\\"]}, \\\"docker_config\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"docker_config\\\"]}}}}}}, \\\"DockerConfigScripts\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\\\", \\\"data\\\": {\\\"service_names\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"service_names\\\"]}, \\\"container_config_scripts\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"container_config_scripts\\\"]}}}}}}, \\\"MonitoringSubscriptionsConfig\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}, \\\"ServiceNames\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"filter\\\": [[null], {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"service_name\\\"]}]}}}, \\\"GlobalConfigSettings\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}}, \\\"KeystoneResourcesConfigs\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}}, \\\"ServiceConfigSettings\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}, \\\"DeployStepsTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ExternalDeployTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ExternalPostDeployTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ScaleTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ExternalUpdateTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ExternalUpgradeTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"PreUpgradeRollingTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"UpgradeTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"PostUpgradeTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"UpdateTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"PostUpdateTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"UpgradeBatchTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"PuppetConfig\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"KollaConfig\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}, \\\"DockerPuppetTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ContainerPuppetTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"HostFirewallTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"HostPrepTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"PreDeployStepTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"IpaRegistrationTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"AnsibleGroupVars\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}}, \\\"FirewallRules\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}}, \\\"FirewallFrontendRules\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"frontend\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ssl_frontend\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"edge_frontend\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"edge_sslfrontend\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Combined Role data for this set of services.\\\", \\\"value\\\": {\\\"service_names\\\": {\\\"get_attr\\\": [\\\"ServiceNames\\\", \\\"value\\\"]}, \\\"monitoring_subscriptions\\\": {\\\"get_attr\\\": [\\\"MonitoringSubscriptionsConfig\\\", \\\"value\\\"]}, \\\"config_settings\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"$.data.where($ != null).reduce($1.mergeWith($2), {})\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"config_settings\\\"]}}}, \\\"global_config_settings\\\": {\\\"get_attr\\\": [\\\"GlobalConfigSettings\\\", \\\"value\\\"]}, \\\"service_config_settings\\\": {\\\"get_attr\\\": [\\\"ServiceConfigSettings\\\", \\\"value\\\"]}, \\\"step_config\\\": {\\\"get_attr\\\": [\\\"PuppetStepConfig\\\", \\\"value\\\"]}, \\\"deploy_steps_tasks\\\": {\\\"get_attr\\\": [\\\"DeployStepsTasks\\\", \\\"value\\\"]}, \\\"external_deploy_tasks\\\": {\\\"get_attr\\\": [\\\"ExternalDeployTasks\\\", \\\"value\\\"]}, \\\"external_post_deploy_tasks\\\": {\\\"get_attr\\\": [\\\"ExternalPostDeployTasks\\\", \\\"value\\\"]}, \\\"external_update_tasks\\\": {\\\"get_attr\\\": [\\\"ExternalUpdateTasks\\\", \\\"value\\\"]}, \\\"external_upgrade_tasks\\\": {\\\"get_attr\\\": [\\\"ExternalUpgradeTasks\\\", \\\"value\\\"]}, \\\"scale_tasks\\\": {\\\"get_attr\\\": [\\\"ScaleTasks\\\", \\\"value\\\"]}, \\\"pre_upgrade_rolling_tasks\\\": {\\\"get_attr\\\": [\\\"PreUpgradeRollingTasks\\\", \\\"value\\\"]}, \\\"upgrade_tasks\\\": {\\\"get_attr\\\": [\\\"UpgradeTasks\\\", \\\"value\\\"]}, \\\"post_upgrade_tasks\\\": {\\\"get_attr\\\": [\\\"PostUpgradeTasks\\\", \\\"value\\\"]}, \\\"update_tasks\\\": {\\\"get_attr\\\": [\\\"UpdateTasks\\\", \\\"value\\\"]}, \\\"post_update_tasks\\\": {\\\"get_attr\\\": [\\\"PostUpdateTasks\\\", \\\"value\\\"]}, \\\"upgrade_batch_tasks\\\": {\\\"get_attr\\\": [\\\"UpgradeBatchTasks\\\", \\\"value\\\"]}, \\\"service_metadata_settings\\\": {\\\"get_attr\\\": [\\\"ServiceServerMetadataHook\\\", \\\"metadata\\\"]}, \\\"ansible_group_vars\\\": {\\\"map_merge\\\": [{\\\"ansible_async_dir\\\": \\\"/tmp/.ansible_async\\\"}, {\\\"get_attr\\\": [\\\"AnsibleGroupVars\\\", \\\"value\\\"]}]}, \\\"keystone_resources\\\": {\\\"get_attr\\\": [\\\"KeystoneResourcesConfigs\\\", \\\"value\\\"]}, \\\"firewall_rules\\\": {\\\"get_attr\\\": [\\\"FirewallRules\\\", \\\"value\\\"]}, \\\"firewall_frontend_rules\\\": {\\\"get_attr\\\": [\\\"FirewallFrontendRules\\\", \\\"value\\\", \\\"frontend\\\"]}, \\\"firewall_ssl_frontend_rules\\\": {\\\"get_attr\\\": [\\\"FirewallFrontendRules\\\", \\\"value\\\", \\\"ssl_frontend\\\"]}, \\\"firewall_edge_frontend_rules\\\": {\\\"get_attr\\\": [\\\"FirewallFrontendRules\\\", \\\"value\\\", \\\"edge_frontend\\\"]}, \\\"firewall_edge_ssl_frontend_rules\\\": {\\\"get_attr\\\": [\\\"FirewallFrontendRules\\\", \\\"value\\\", \\\"edge_ssl_frontend\\\"]}, \\\"puppet_config\\\": {\\\"get_attr\\\": [\\\"PuppetConfig\\\", \\\"value\\\"]}, \\\"kolla_config\\\": {\\\"get_attr\\\": [\\\"KollaConfig\\\", \\\"value\\\"]}, \\\"docker_config\\\": {\\\"get_attr\\\": [\\\"DockerConfig\\\", \\\"value\\\"]}, \\\"container_config_scripts\\\": {\\\"get_attr\\\": [\\\"DockerConfigScripts\\\", \\\"value\\\"]}, \\\"container_puppet_tasks\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"ContainerPuppetTasks\\\", \\\"value\\\"]}, {\\\"get_attr\\\": [\\\"DockerPuppetTasks\\\", \\\"value\\\"]}]}, \\\"host_prep_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"HostFirewallTasks\\\", \\\"value\\\"]}, {\\\"get_attr\\\": [\\\"HostPrepTasks\\\", \\\"value\\\"]}]}, \\\"pre_deploy_step_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"PreDeployStepTasks\\\", \\\"value\\\"]}, {\\\"get_attr\\\": [\\\"IpaRegistrationTasks\\\", \\\"value\\\"]}]}}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Utility stack to convert an array of services into a set of combined role configs.\\\\n\\\", \\\"parameters\\\": {\\\"Services\\\": {\\\"default\\\": [], \\\"description\\\": \\\"List nested stack service templates.\\\\n\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"description\\\": \\\"Parameters specific to the role\\\", \\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}}, \\\"resources\\\": {\\\"ServiceChain\\\": {\\\"type\\\": \\\"OS::Heat::ResourceChain\\\", \\\"properties\\\": {\\\"resources\\\": {\\\"get_param\\\": \\\"Services\\\"}, \\\"concurrent\\\": true, \\\"resource_properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}}, \\\"ServiceServerMetadataHook\\\": {\\\"type\\\": \\\"OS::TripleO::BlockStorageServiceServerMetadataHook\\\", \\\"properties\\\": {\\\"RoleData\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}, \\\"PuppetStepConfig\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"string\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\\\\\"\\\\\\\\n\\\\\\\")\\\", \\\"data\\\": {\\\"service_names\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"service_name\\\"]}, \\\"step_config\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"step_config\\\"]}, \\\"docker_config\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"docker_config\\\"]}}}}}}, \\\"DockerConfig\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\\\", \\\"data\\\": {\\\"service_names\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"service_names\\\"]}, \\\"docker_config\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"docker_config\\\"]}}}}}}, \\\"DockerConfigScripts\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\\\", \\\"data\\\": {\\\"service_names\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"service_names\\\"]}, \\\"container_config_scripts\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"container_config_scripts\\\"]}}}}}}, \\\"MonitoringSubscriptionsConfig\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}, \\\"ServiceNames\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"filter\\\": [[null], {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"service_name\\\"]}]}}}, \\\"GlobalConfigSettings\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}}, \\\"KeystoneResourcesConfigs\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}}, \\\"ServiceConfigSettings\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}, \\\"DeployStepsTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ExternalDeployTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ExternalPostDeployTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ScaleTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ExternalUpdateTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ExternalUpgradeTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"PreUpgradeRollingTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"UpgradeTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"PostUpgradeTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"UpdateTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"PostUpdateTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"UpgradeBatchTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"PuppetConfig\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"KollaConfig\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}, \\\"DockerPuppetTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ContainerPuppetTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"HostFirewallTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"HostPrepTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"PreDeployStepTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"IpaRegistrationTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"AnsibleGroupVars\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}}, \\\"FirewallRules\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}}, \\\"FirewallFrontendRules\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"frontend\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ssl_frontend\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"edge_frontend\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"edge_sslfrontend\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Combined Role data for this set of services.\\\", \\\"value\\\": {\\\"service_names\\\": {\\\"get_attr\\\": [\\\"ServiceNames\\\", \\\"value\\\"]}, \\\"monitoring_subscriptions\\\": {\\\"get_attr\\\": [\\\"MonitoringSubscriptionsConfig\\\", \\\"value\\\"]}, \\\"config_settings\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"$.data.where($ != null).reduce($1.mergeWith($2), {})\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"config_settings\\\"]}}}, \\\"global_config_settings\\\": {\\\"get_attr\\\": [\\\"GlobalConfigSettings\\\", \\\"value\\\"]}, \\\"service_config_settings\\\": {\\\"get_attr\\\": [\\\"ServiceConfigSettings\\\", \\\"value\\\"]}, \\\"step_config\\\": {\\\"get_attr\\\": [\\\"PuppetStepConfig\\\", \\\"value\\\"]}, \\\"deploy_steps_tasks\\\": {\\\"get_attr\\\": [\\\"DeployStepsTasks\\\", \\\"value\\\"]}, \\\"external_deploy_tasks\\\": {\\\"get_attr\\\": [\\\"ExternalDeployTasks\\\", \\\"value\\\"]}, \\\"external_post_deploy_tasks\\\": {\\\"get_attr\\\": [\\\"ExternalPostDeployTasks\\\", \\\"value\\\"]}, \\\"external_update_tasks\\\": {\\\"get_attr\\\": [\\\"ExternalUpdateTasks\\\", \\\"value\\\"]}, \\\"external_upgrade_tasks\\\": {\\\"get_attr\\\": [\\\"ExternalUpgradeTasks\\\", \\\"value\\\"]}, \\\"scale_tasks\\\": {\\\"get_attr\\\": [\\\"ScaleTasks\\\", \\\"value\\\"]}, \\\"pre_upgrade_rolling_tasks\\\": {\\\"get_attr\\\": [\\\"PreUpgradeRollingTasks\\\", \\\"value\\\"]}, \\\"upgrade_tasks\\\": {\\\"get_attr\\\": [\\\"UpgradeTasks\\\", \\\"value\\\"]}, \\\"post_upgrade_tasks\\\": {\\\"get_attr\\\": [\\\"PostUpgradeTasks\\\", \\\"value\\\"]}, \\\"update_tasks\\\": {\\\"get_attr\\\": [\\\"UpdateTasks\\\", \\\"value\\\"]}, \\\"post_update_tasks\\\": {\\\"get_attr\\\": [\\\"PostUpdateTasks\\\", \\\"value\\\"]}, \\\"upgrade_batch_tasks\\\": {\\\"get_attr\\\": [\\\"UpgradeBatchTasks\\\", \\\"value\\\"]}, \\\"service_metadata_settings\\\": {\\\"get_attr\\\": [\\\"ServiceServerMetadataHook\\\", \\\"metadata\\\"]}, \\\"ansible_group_vars\\\": {\\\"map_merge\\\": [{\\\"ansible_async_dir\\\": \\\"/tmp/.ansible_async\\\"}, {\\\"get_attr\\\": [\\\"AnsibleGroupVars\\\", \\\"value\\\"]}]}, \\\"keystone_resources\\\": {\\\"get_attr\\\": [\\\"KeystoneResourcesConfigs\\\", \\\"value\\\"]}, \\\"firewall_rules\\\": {\\\"get_attr\\\": [\\\"FirewallRules\\\", \\\"value\\\"]}, \\\"firewall_frontend_rules\\\": {\\\"get_attr\\\": [\\\"FirewallFrontendRules\\\", \\\"value\\\", \\\"frontend\\\"]}, \\\"firewall_ssl_frontend_rules\\\": {\\\"get_attr\\\": [\\\"FirewallFrontendRules\\\", \\\"value\\\", \\\"ssl_frontend\\\"]}, \\\"firewall_edge_frontend_rules\\\": {\\\"get_attr\\\": [\\\"FirewallFrontendRules\\\", \\\"value\\\", \\\"edge_frontend\\\"]}, \\\"firewall_edge_ssl_frontend_rules\\\": {\\\"get_attr\\\": [\\\"FirewallFrontendRules\\\", \\\"value\\\", \\\"edge_ssl_frontend\\\"]}, \\\"puppet_config\\\": {\\\"get_attr\\\": [\\\"PuppetConfig\\\", \\\"value\\\"]}, \\\"kolla_config\\\": {\\\"get_attr\\\": [\\\"KollaConfig\\\", \\\"value\\\"]}, \\\"docker_config\\\": {\\\"get_attr\\\": [\\\"DockerConfig\\\", \\\"value\\\"]}, \\\"container_config_scripts\\\": {\\\"get_attr\\\": [\\\"DockerConfigScripts\\\", \\\"value\\\"]}, \\\"container_puppet_tasks\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"ContainerPuppetTasks\\\", \\\"value\\\"]}, {\\\"get_attr\\\": [\\\"DockerPuppetTasks\\\", \\\"value\\\"]}]}, \\\"host_prep_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"HostFirewallTasks\\\", \\\"value\\\"]}, {\\\"get_attr\\\": [\\\"HostPrepTasks\\\", \\\"value\\\"]}]}, \\\"pre_deploy_step_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"PreDeployStepTasks\\\", \\\"value\\\"]}, {\\\"get_attr\\\": [\\\"IpaRegistrationTasks\\\", \\\"value\\\"]}]}}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Utility stack to convert an array of services into a set of combined role configs.\\\\n\\\", \\\"parameters\\\": {\\\"Services\\\": {\\\"default\\\": [], \\\"description\\\": \\\"List nested stack service templates.\\\\n\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"description\\\": \\\"Parameters specific to the role\\\", \\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}}, \\\"resources\\\": {\\\"ServiceChain\\\": {\\\"type\\\": \\\"OS::Heat::ResourceChain\\\", \\\"properties\\\": {\\\"resources\\\": {\\\"get_param\\\": \\\"Services\\\"}, \\\"concurrent\\\": true, \\\"resource_properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}}, \\\"ServiceServerMetadataHook\\\": {\\\"type\\\": \\\"OS::TripleO::ObjectStorageServiceServerMetadataHook\\\", \\\"properties\\\": {\\\"RoleData\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}, \\\"PuppetStepConfig\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"string\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\\\\\"\\\\\\\\n\\\\\\\")\\\", \\\"data\\\": {\\\"service_names\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"service_name\\\"]}, \\\"step_config\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"step_config\\\"]}, \\\"docker_config\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"docker_config\\\"]}}}}}}, \\\"DockerConfig\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\\\", \\\"data\\\": {\\\"service_names\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"service_names\\\"]}, \\\"docker_config\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"docker_config\\\"]}}}}}}, \\\"DockerConfigScripts\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\\\", \\\"data\\\": {\\\"service_names\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"service_names\\\"]}, \\\"container_config_scripts\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"container_config_scripts\\\"]}}}}}}, \\\"MonitoringSubscriptionsConfig\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}, \\\"ServiceNames\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"filter\\\": [[null], {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"service_name\\\"]}]}}}, \\\"GlobalConfigSettings\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}}, \\\"KeystoneResourcesConfigs\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}}, \\\"ServiceConfigSettings\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}, \\\"DeployStepsTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ExternalDeployTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ExternalPostDeployTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ScaleTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ExternalUpdateTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ExternalUpgradeTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"PreUpgradeRollingTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"UpgradeTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"PostUpgradeTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"UpdateTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"PostUpdateTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"UpgradeBatchTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"PuppetConfig\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"KollaConfig\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}, \\\"DockerPuppetTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ContainerPuppetTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"HostFirewallTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"HostPrepTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"PreDeployStepTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"IpaRegistrationTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"AnsibleGroupVars\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}}, \\\"FirewallRules\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}}, \\\"FirewallFrontendRules\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"frontend\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ssl_frontend\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"edge_frontend\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"edge_sslfrontend\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Combined Role data for this set of services.\\\", \\\"value\\\": {\\\"service_names\\\": {\\\"get_attr\\\": [\\\"ServiceNames\\\", \\\"value\\\"]}, \\\"monitoring_subscriptions\\\": {\\\"get_attr\\\": [\\\"MonitoringSubscriptionsConfig\\\", \\\"value\\\"]}, \\\"config_settings\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"$.data.where($ != null).reduce($1.mergeWith($2), {})\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"config_settings\\\"]}}}, \\\"global_config_settings\\\": {\\\"get_attr\\\": [\\\"GlobalConfigSettings\\\", \\\"value\\\"]}, \\\"service_config_settings\\\": {\\\"get_attr\\\": [\\\"ServiceConfigSettings\\\", \\\"value\\\"]}, \\\"step_config\\\": {\\\"get_attr\\\": [\\\"PuppetStepConfig\\\", \\\"value\\\"]}, \\\"deploy_steps_tasks\\\": {\\\"get_attr\\\": [\\\"DeployStepsTasks\\\", \\\"value\\\"]}, \\\"external_deploy_tasks\\\": {\\\"get_attr\\\": [\\\"ExternalDeployTasks\\\", \\\"value\\\"]}, \\\"external_post_deploy_tasks\\\": {\\\"get_attr\\\": [\\\"ExternalPostDeployTasks\\\", \\\"value\\\"]}, \\\"external_update_tasks\\\": {\\\"get_attr\\\": [\\\"ExternalUpdateTasks\\\", \\\"value\\\"]}, \\\"external_upgrade_tasks\\\": {\\\"get_attr\\\": [\\\"ExternalUpgradeTasks\\\", \\\"value\\\"]}, \\\"scale_tasks\\\": {\\\"get_attr\\\": [\\\"ScaleTasks\\\", \\\"value\\\"]}, \\\"pre_upgrade_rolling_tasks\\\": {\\\"get_attr\\\": [\\\"PreUpgradeRollingTasks\\\", \\\"value\\\"]}, \\\"upgrade_tasks\\\": {\\\"get_attr\\\": [\\\"UpgradeTasks\\\", \\\"value\\\"]}, \\\"post_upgrade_tasks\\\": {\\\"get_attr\\\": [\\\"PostUpgradeTasks\\\", \\\"value\\\"]}, \\\"update_tasks\\\": {\\\"get_attr\\\": [\\\"UpdateTasks\\\", \\\"value\\\"]}, \\\"post_update_tasks\\\": {\\\"get_attr\\\": [\\\"PostUpdateTasks\\\", \\\"value\\\"]}, \\\"upgrade_batch_tasks\\\": {\\\"get_attr\\\": [\\\"UpgradeBatchTasks\\\", \\\"value\\\"]}, \\\"service_metadata_settings\\\": {\\\"get_attr\\\": [\\\"ServiceServerMetadataHook\\\", \\\"metadata\\\"]}, \\\"ansible_group_vars\\\": {\\\"map_merge\\\": [{\\\"ansible_async_dir\\\": \\\"/tmp/.ansible_async\\\"}, {\\\"get_attr\\\": [\\\"AnsibleGroupVars\\\", \\\"value\\\"]}]}, \\\"keystone_resources\\\": {\\\"get_attr\\\": [\\\"KeystoneResourcesConfigs\\\", \\\"value\\\"]}, \\\"firewall_rules\\\": {\\\"get_attr\\\": [\\\"FirewallRules\\\", \\\"value\\\"]}, \\\"firewall_frontend_rules\\\": {\\\"get_attr\\\": [\\\"FirewallFrontendRules\\\", \\\"value\\\", \\\"frontend\\\"]}, \\\"firewall_ssl_frontend_rules\\\": {\\\"get_attr\\\": [\\\"FirewallFrontendRules\\\", \\\"value\\\", \\\"ssl_frontend\\\"]}, \\\"firewall_edge_frontend_rules\\\": {\\\"get_attr\\\": [\\\"FirewallFrontendRules\\\", \\\"value\\\", \\\"edge_frontend\\\"]}, \\\"firewall_edge_ssl_frontend_rules\\\": {\\\"get_attr\\\": [\\\"FirewallFrontendRules\\\", \\\"value\\\", \\\"edge_ssl_frontend\\\"]}, \\\"puppet_config\\\": {\\\"get_attr\\\": [\\\"PuppetConfig\\\", \\\"value\\\"]}, \\\"kolla_config\\\": {\\\"get_attr\\\": [\\\"KollaConfig\\\", \\\"value\\\"]}, \\\"docker_config\\\": {\\\"get_attr\\\": [\\\"DockerConfig\\\", \\\"value\\\"]}, \\\"container_config_scripts\\\": {\\\"get_attr\\\": [\\\"DockerConfigScripts\\\", \\\"value\\\"]}, \\\"container_puppet_tasks\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"ContainerPuppetTasks\\\", \\\"value\\\"]}, {\\\"get_attr\\\": [\\\"DockerPuppetTasks\\\", \\\"value\\\"]}]}, \\\"host_prep_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"HostFirewallTasks\\\", \\\"value\\\"]}, {\\\"get_attr\\\": [\\\"HostPrepTasks\\\", \\\"value\\\"]}]}, \\\"pre_deploy_step_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"PreDeployStepTasks\\\", \\\"value\\\"]}, {\\\"get_attr\\\": [\\\"IpaRegistrationTasks\\\", \\\"value\\\"]}]}}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Utility stack to convert an array of services into a set of combined role configs.\\\\n\\\", \\\"parameters\\\": {\\\"Services\\\": {\\\"default\\\": [], \\\"description\\\": \\\"List nested stack service templates.\\\\n\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"description\\\": \\\"Parameters specific to the role\\\", \\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}}, \\\"resources\\\": {\\\"ServiceChain\\\": {\\\"type\\\": \\\"OS::Heat::ResourceChain\\\", \\\"properties\\\": {\\\"resources\\\": {\\\"get_param\\\": \\\"Services\\\"}, \\\"concurrent\\\": true, \\\"resource_properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}}, \\\"ServiceServerMetadataHook\\\": {\\\"type\\\": \\\"OS::TripleO::CephStorageServiceServerMetadataHook\\\", \\\"properties\\\": {\\\"RoleData\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}, \\\"PuppetStepConfig\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"string\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\\\\\"\\\\\\\\n\\\\\\\")\\\", \\\"data\\\": {\\\"service_names\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"service_name\\\"]}, \\\"step_config\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"step_config\\\"]}, \\\"docker_config\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"docker_config\\\"]}}}}}}, \\\"DockerConfig\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\\\", \\\"data\\\": {\\\"service_names\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"service_names\\\"]}, \\\"docker_config\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"docker_config\\\"]}}}}}}, \\\"DockerConfigScripts\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\\\", \\\"data\\\": {\\\"service_names\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"service_names\\\"]}, \\\"container_config_scripts\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"container_config_scripts\\\"]}}}}}}, \\\"MonitoringSubscriptionsConfig\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}, \\\"ServiceNames\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"filter\\\": [[null], {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"service_name\\\"]}]}}}, \\\"GlobalConfigSettings\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}}, \\\"KeystoneResourcesConfigs\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}}, \\\"ServiceConfigSettings\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}, \\\"DeployStepsTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ExternalDeployTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ExternalPostDeployTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ScaleTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ExternalUpdateTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ExternalUpgradeTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"PreUpgradeRollingTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"UpgradeTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"PostUpgradeTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"UpdateTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"PostUpdateTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"UpgradeBatchTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"PuppetConfig\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"KollaConfig\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}, \\\"DockerPuppetTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ContainerPuppetTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"HostFirewallTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"HostPrepTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"PreDeployStepTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"IpaRegistrationTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"AnsibleGroupVars\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}}, \\\"FirewallRules\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}}, \\\"FirewallFrontendRules\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"frontend\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ssl_frontend\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"edge_frontend\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"edge_sslfrontend\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Combined Role data for this set of services.\\\", \\\"value\\\": {\\\"service_names\\\": {\\\"get_attr\\\": [\\\"ServiceNames\\\", \\\"value\\\"]}, \\\"monitoring_subscriptions\\\": {\\\"get_attr\\\": [\\\"MonitoringSubscriptionsConfig\\\", \\\"value\\\"]}, \\\"config_settings\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"$.data.where($ != null).reduce($1.mergeWith($2), {})\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"config_settings\\\"]}}}, \\\"global_config_settings\\\": {\\\"get_attr\\\": [\\\"GlobalConfigSettings\\\", \\\"value\\\"]}, \\\"service_config_settings\\\": {\\\"get_attr\\\": [\\\"ServiceConfigSettings\\\", \\\"value\\\"]}, \\\"step_config\\\": {\\\"get_attr\\\": [\\\"PuppetStepConfig\\\", \\\"value\\\"]}, \\\"deploy_steps_tasks\\\": {\\\"get_attr\\\": [\\\"DeployStepsTasks\\\", \\\"value\\\"]}, \\\"external_deploy_tasks\\\": {\\\"get_attr\\\": [\\\"ExternalDeployTasks\\\", \\\"value\\\"]}, \\\"external_post_deploy_tasks\\\": {\\\"get_attr\\\": [\\\"ExternalPostDeployTasks\\\", \\\"value\\\"]}, \\\"external_update_tasks\\\": {\\\"get_attr\\\": [\\\"ExternalUpdateTasks\\\", \\\"value\\\"]}, \\\"external_upgrade_tasks\\\": {\\\"get_attr\\\": [\\\"ExternalUpgradeTasks\\\", \\\"value\\\"]}, \\\"scale_tasks\\\": {\\\"get_attr\\\": [\\\"ScaleTasks\\\", \\\"value\\\"]}, \\\"pre_upgrade_rolling_tasks\\\": {\\\"get_attr\\\": [\\\"PreUpgradeRollingTasks\\\", \\\"value\\\"]}, \\\"upgrade_tasks\\\": {\\\"get_attr\\\": [\\\"UpgradeTasks\\\", \\\"value\\\"]}, \\\"post_upgrade_tasks\\\": {\\\"get_attr\\\": [\\\"PostUpgradeTasks\\\", \\\"value\\\"]}, \\\"update_tasks\\\": {\\\"get_attr\\\": [\\\"UpdateTasks\\\", \\\"value\\\"]}, \\\"post_update_tasks\\\": {\\\"get_attr\\\": [\\\"PostUpdateTasks\\\", \\\"value\\\"]}, \\\"upgrade_batch_tasks\\\": {\\\"get_attr\\\": [\\\"UpgradeBatchTasks\\\", \\\"value\\\"]}, \\\"service_metadata_settings\\\": {\\\"get_attr\\\": [\\\"ServiceServerMetadataHook\\\", \\\"metadata\\\"]}, \\\"ansible_group_vars\\\": {\\\"map_merge\\\": [{\\\"ansible_async_dir\\\": \\\"/tmp/.ansible_async\\\"}, {\\\"get_attr\\\": [\\\"AnsibleGroupVars\\\", \\\"value\\\"]}]}, \\\"keystone_resources\\\": {\\\"get_attr\\\": [\\\"KeystoneResourcesConfigs\\\", \\\"value\\\"]}, \\\"firewall_rules\\\": {\\\"get_attr\\\": [\\\"FirewallRules\\\", \\\"value\\\"]}, \\\"firewall_frontend_rules\\\": {\\\"get_attr\\\": [\\\"FirewallFrontendRules\\\", \\\"value\\\", \\\"frontend\\\"]}, \\\"firewall_ssl_frontend_rules\\\": {\\\"get_attr\\\": [\\\"FirewallFrontendRules\\\", \\\"value\\\", \\\"ssl_frontend\\\"]}, \\\"firewall_edge_frontend_rules\\\": {\\\"get_attr\\\": [\\\"FirewallFrontendRules\\\", \\\"value\\\", \\\"edge_frontend\\\"]}, \\\"firewall_edge_ssl_frontend_rules\\\": {\\\"get_attr\\\": [\\\"FirewallFrontendRules\\\", \\\"value\\\", \\\"edge_ssl_frontend\\\"]}, \\\"puppet_config\\\": {\\\"get_attr\\\": [\\\"PuppetConfig\\\", \\\"value\\\"]}, \\\"kolla_config\\\": {\\\"get_attr\\\": [\\\"KollaConfig\\\", \\\"value\\\"]}, \\\"docker_config\\\": {\\\"get_attr\\\": [\\\"DockerConfig\\\", \\\"value\\\"]}, \\\"container_config_scripts\\\": {\\\"get_attr\\\": [\\\"DockerConfigScripts\\\", \\\"value\\\"]}, \\\"container_puppet_tasks\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"ContainerPuppetTasks\\\", \\\"value\\\"]}, {\\\"get_attr\\\": [\\\"DockerPuppetTasks\\\", \\\"value\\\"]}]}, \\\"host_prep_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"HostFirewallTasks\\\", \\\"value\\\"]}, {\\\"get_attr\\\": [\\\"HostPrepTasks\\\", \\\"value\\\"]}]}, \\\"pre_deploy_step_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"PreDeployStepTasks\\\", \\\"value\\\"]}, {\\\"get_attr\\\": [\\\"IpaRegistrationTasks\\\", \\\"value\\\"]}]}}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Utility stack to convert an array of services into a set of combined role configs.\\\\n\\\", \\\"parameters\\\": {\\\"Services\\\": {\\\"default\\\": [], \\\"description\\\": \\\"List nested stack service templates.\\\\n\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"description\\\": \\\"Parameters specific to the role\\\", \\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}}, \\\"resources\\\": {\\\"ServiceChain\\\": {\\\"type\\\": \\\"OS::Heat::ResourceChain\\\", \\\"properties\\\": {\\\"resources\\\": {\\\"get_param\\\": \\\"Services\\\"}, \\\"concurrent\\\": true, \\\"resource_properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}}, \\\"ServiceServerMetadataHook\\\": {\\\"type\\\": \\\"OS::TripleO::NetworkerServiceServerMetadataHook\\\", \\\"properties\\\": {\\\"RoleData\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}, \\\"PuppetStepConfig\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"string\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\\\\\"\\\\\\\\n\\\\\\\")\\\", \\\"data\\\": {\\\"service_names\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"service_name\\\"]}, \\\"step_config\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"step_config\\\"]}, \\\"docker_config\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"docker_config\\\"]}}}}}}, \\\"DockerConfig\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\\\", \\\"data\\\": {\\\"service_names\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"service_names\\\"]}, \\\"docker_config\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"docker_config\\\"]}}}}}}, \\\"DockerConfigScripts\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\\\", \\\"data\\\": {\\\"service_names\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"service_names\\\"]}, \\\"container_config_scripts\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"container_config_scripts\\\"]}}}}}}, \\\"MonitoringSubscriptionsConfig\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}, \\\"ServiceNames\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"filter\\\": [[null], {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"service_name\\\"]}]}}}, \\\"GlobalConfigSettings\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}}, \\\"KeystoneResourcesConfigs\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}}, \\\"ServiceConfigSettings\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}, \\\"DeployStepsTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ExternalDeployTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ExternalPostDeployTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ScaleTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ExternalUpdateTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ExternalUpgradeTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"PreUpgradeRollingTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"UpgradeTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"PostUpgradeTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"UpdateTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"PostUpdateTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"UpgradeBatchTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"PuppetConfig\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"KollaConfig\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}, \\\"DockerPuppetTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ContainerPuppetTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"HostFirewallTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"HostPrepTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"PreDeployStepTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"IpaRegistrationTasks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"value\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"AnsibleGroupVars\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}}, \\\"FirewallRules\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}}, \\\"FirewallFrontendRules\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"frontend\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"ssl_frontend\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"edge_frontend\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}, \\\"edge_sslfrontend\\\": {\\\"map_merge\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\\\", \\\"data\\\": {\\\"role_data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\"]}}}}}}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Combined Role data for this set of services.\\\", \\\"value\\\": {\\\"service_names\\\": {\\\"get_attr\\\": [\\\"ServiceNames\\\", \\\"value\\\"]}, \\\"monitoring_subscriptions\\\": {\\\"get_attr\\\": [\\\"MonitoringSubscriptionsConfig\\\", \\\"value\\\"]}, \\\"config_settings\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"$.data.where($ != null).reduce($1.mergeWith($2), {})\\\", \\\"data\\\": {\\\"get_attr\\\": [\\\"ServiceChain\\\", \\\"role_data\\\", \\\"config_settings\\\"]}}}, \\\"global_config_settings\\\": {\\\"get_attr\\\": [\\\"GlobalConfigSettings\\\", \\\"value\\\"]}, \\\"service_config_settings\\\": {\\\"get_attr\\\": [\\\"ServiceConfigSettings\\\", \\\"value\\\"]}, \\\"step_config\\\": {\\\"get_attr\\\": [\\\"PuppetStepConfig\\\", \\\"value\\\"]}, \\\"deploy_steps_tasks\\\": {\\\"get_attr\\\": [\\\"DeployStepsTasks\\\", \\\"value\\\"]}, \\\"external_deploy_tasks\\\": {\\\"get_attr\\\": [\\\"ExternalDeployTasks\\\", \\\"value\\\"]}, \\\"external_post_deploy_tasks\\\": {\\\"get_attr\\\": [\\\"ExternalPostDeployTasks\\\", \\\"value\\\"]}, \\\"external_update_tasks\\\": {\\\"get_attr\\\": [\\\"ExternalUpdateTasks\\\", \\\"value\\\"]}, \\\"external_upgrade_tasks\\\": {\\\"get_attr\\\": [\\\"ExternalUpgradeTasks\\\", \\\"value\\\"]}, \\\"scale_tasks\\\": {\\\"get_attr\\\": [\\\"ScaleTasks\\\", \\\"value\\\"]}, \\\"pre_upgrade_rolling_tasks\\\": {\\\"get_attr\\\": [\\\"PreUpgradeRollingTasks\\\", \\\"value\\\"]}, \\\"upgrade_tasks\\\": {\\\"get_attr\\\": [\\\"UpgradeTasks\\\", \\\"value\\\"]}, \\\"post_upgrade_tasks\\\": {\\\"get_attr\\\": [\\\"PostUpgradeTasks\\\", \\\"value\\\"]}, \\\"update_tasks\\\": {\\\"get_attr\\\": [\\\"UpdateTasks\\\", \\\"value\\\"]}, \\\"post_update_tasks\\\": {\\\"get_attr\\\": [\\\"PostUpdateTasks\\\", \\\"value\\\"]}, \\\"upgrade_batch_tasks\\\": {\\\"get_attr\\\": [\\\"UpgradeBatchTasks\\\", \\\"value\\\"]}, \\\"service_metadata_settings\\\": {\\\"get_attr\\\": [\\\"ServiceServerMetadataHook\\\", \\\"metadata\\\"]}, \\\"ansible_group_vars\\\": {\\\"map_merge\\\": [{\\\"ansible_async_dir\\\": \\\"/tmp/.ansible_async\\\"}, {\\\"get_attr\\\": [\\\"AnsibleGroupVars\\\", \\\"value\\\"]}]}, \\\"keystone_resources\\\": {\\\"get_attr\\\": [\\\"KeystoneResourcesConfigs\\\", \\\"value\\\"]}, \\\"firewall_rules\\\": {\\\"get_attr\\\": [\\\"FirewallRules\\\", \\\"value\\\"]}, \\\"firewall_frontend_rules\\\": {\\\"get_attr\\\": [\\\"FirewallFrontendRules\\\", \\\"value\\\", \\\"frontend\\\"]}, \\\"firewall_ssl_frontend_rules\\\": {\\\"get_attr\\\": [\\\"FirewallFrontendRules\\\", \\\"value\\\", \\\"ssl_frontend\\\"]}, \\\"firewall_edge_frontend_rules\\\": {\\\"get_attr\\\": [\\\"FirewallFrontendRules\\\", \\\"value\\\", \\\"edge_frontend\\\"]}, \\\"firewall_edge_ssl_frontend_rules\\\": {\\\"get_attr\\\": [\\\"FirewallFrontendRules\\\", \\\"value\\\", \\\"edge_ssl_frontend\\\"]}, \\\"puppet_config\\\": {\\\"get_attr\\\": [\\\"PuppetConfig\\\", \\\"value\\\"]}, \\\"kolla_config\\\": {\\\"get_attr\\\": [\\\"KollaConfig\\\", \\\"value\\\"]}, \\\"docker_config\\\": {\\\"get_attr\\\": [\\\"DockerConfig\\\", \\\"value\\\"]}, \\\"container_config_scripts\\\": {\\\"get_attr\\\": [\\\"DockerConfigScripts\\\", \\\"value\\\"]}, \\\"container_puppet_tasks\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"ContainerPuppetTasks\\\", \\\"value\\\"]}, {\\\"get_attr\\\": [\\\"DockerPuppetTasks\\\", \\\"value\\\"]}]}, \\\"host_prep_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"HostFirewallTasks\\\", \\\"value\\\"]}, {\\\"get_attr\\\": [\\\"HostPrepTasks\\\", \\\"value\\\"]}]}, \\\"pre_deploy_step_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"PreDeployStepTasks\\\", \\\"value\\\"]}, {\\\"get_attr\\\": [\\\"IpaRegistrationTasks\\\", \\\"value\\\"]}]}}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Apache service configured with Puppet. Note this is typically included automatically via other services which run via Apache.\\\\n\\\", \\\"parameters\\\": {\\\"ApacheMaxRequestWorkers\\\": {\\\"default\\\": 256, \\\"description\\\": \\\"Maximum number of simultaneously processed requests.\\\", \\\"type\\\": \\\"number\\\"}, \\\"ApacheServerLimit\\\": {\\\"default\\\": 256, \\\"description\\\": \\\"Maximum number of Apache processes.\\\", \\\"type\\\": \\\"number\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"InternalTLSCAFile\\\": {\\\"default\\\": \\\"/etc/ipa/ca.crt\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Specifies the default CA cert to use if TLS is used for services in the internal network.\\\"}, \\\"CertificateKeySize\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"2048\\\", \\\"description\\\": \\\"Specifies the private key size used when creating the certificate.\\\"}, \\\"ApacheCertificateKeySize\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Override the private key size used when creating the certificate for this service\\\"}, \\\"ApacheTimeout\\\": {\\\"type\\\": \\\"number\\\", \\\"default\\\": 90, \\\"description\\\": \\\"The timeout in seconds for Apache, which defines duration Apache waits for I/O operations\\\"}}, \\\"conditions\\\": {\\\"key_size_override_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"ApacheCertificateKeySize\\\"}, \\\"\\\"]}}}, \\\"resources\\\": {\\\"ApacheNetworks\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"value\\\": {\\\"Controller\\\": [\\\"ctlplane\\\", \\\"storage\\\", \\\"storage_mgmt\\\", \\\"internal_api\\\"], \\\"CellController\\\": [\\\"ctlplane\\\", \\\"storage\\\", \\\"storage_mgmt\\\", \\\"internal_api\\\"], \\\"CellControllerCompute\\\": [\\\"ctlplane\\\", \\\"storage\\\", \\\"storage_mgmt\\\", \\\"internal_api\\\"], \\\"Compute\\\": [\\\"ctlplane\\\", \\\"storage\\\", \\\"internal_api\\\"], \\\"BlockStorage\\\": [\\\"ctlplane\\\", \\\"storage\\\", \\\"storage_mgmt\\\", \\\"internal_api\\\"], \\\"ObjectStorage\\\": [\\\"ctlplane\\\", \\\"storage\\\", \\\"storage_mgmt\\\", \\\"internal_api\\\"], \\\"CephStorage\\\": [\\\"ctlplane\\\", \\\"storage\\\", \\\"storage_mgmt\\\"], \\\"Networker\\\": [\\\"ctlplane\\\", \\\"internal_api\\\"]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Apache role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"apache\\\", \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"apache::ip\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"ApacheNetwork\\\"]}}}}, \\\"apache::default_vhost\\\": false, \\\"apache::trace_enable\\\": \\\"Off\\\", \\\"apache::server_signature\\\": \\\"Off\\\", \\\"apache::server_tokens\\\": \\\"Prod\\\", \\\"apache::timeout\\\": {\\\"get_param\\\": \\\"ApacheTimeout\\\"}, \\\"apache::default_mods\\\": false, \\\"apache::mod::prefork::maxrequestworkers\\\": {\\\"get_param\\\": \\\"ApacheMaxRequestWorkers\\\"}, \\\"apache::mod::prefork::serverlimit\\\": {\\\"get_param\\\": \\\"ApacheServerLimit\\\"}, \\\"apache::mod::remoteip::proxy_ips\\\": {\\\"get_param\\\": [\\\"ServiceData\\\", \\\"net_cidr_map\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"ApacheNetwork\\\"]}]}, \\\"apache::mod::alias::icons_options\\\": \\\"None\\\"}, {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, {\\\"apache::mod::ssl::ssl_ca\\\": {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, \\\"apache::mod::ssl::ssl_protocol\\\": [\\\"all\\\", \\\"-SSLv2\\\", \\\"-SSLv3\\\", \\\"-TLSv1\\\"], \\\"apache_certificates_specs\\\": {\\\"map_merge\\\": {\\\"repeat\\\": {\\\"template\\\": {\\\"httpd-NETWORK\\\": {\\\"service_certificate\\\": \\\"/etc/pki/tls/certs/httpd/httpd-NETWORK.crt\\\", \\\"service_key\\\": \\\"/etc/pki/tls/private/httpd/httpd-NETWORK.key\\\"}}, \\\"for_each\\\": {\\\"NETWORK\\\": {\\\"get_attr\\\": [\\\"ApacheNetworks\\\", \\\"value\\\", {\\\"get_param\\\": \\\"RoleName\\\"}]}}}}}}]}]}, \\\"metadata_settings\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, {\\\"repeat\\\": {\\\"template\\\": [{\\\"service\\\": \\\"HTTP\\\", \\\"network\\\": \\\"$NETWORK\\\", \\\"type\\\": \\\"node\\\"}], \\\"for_each\\\": {\\\"$NETWORK\\\": {\\\"get_attr\\\": [\\\"ApacheNetworks\\\", \\\"value\\\", {\\\"get_param\\\": \\\"RoleName\\\"}]}}}}]}, \\\"upgrade_tasks\\\": [], \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Certificate generation\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"enable_internal_tls\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Create dirs for certificates and keys\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item }}\\\", \\\"state\\\": \\\"directory\\\", \\\"serole\\\": \\\"object_r\\\", \\\"setype\\\": \\\"cert_t\\\", \\\"seuser\\\": \\\"system_u\\\"}, \\\"with_items\\\": [\\\"/etc/pki/tls/certs/httpd\\\", \\\"/etc/pki/tls/private/httpd\\\"]}, {\\\"include_role\\\": {\\\"name\\\": \\\"linux-system-roles.certificate\\\"}, \\\"vars\\\": {\\\"certificate_requests\\\": {\\\"repeat\\\": {\\\"template\\\": {\\\"name\\\": \\\"httpd-NETWORK\\\", \\\"dns\\\": \\\"{{ fqdn_NETWORK }}\\\", \\\"principal\\\": \\\"HTTP/{{ fqdn_NETWORK }}@{{ idm_realm }}\\\", \\\"run_after\\\": \\\"cp /etc/pki/tls/certs/httpd-NETWORK.crt /etc/pki/tls/certs/httpd/httpd-NETWORK.crt\\\\ncp /etc/pki/tls/private/httpd-NETWORK.key /etc/pki/tls/private/httpd/httpd-NETWORK.key\\\\npkill -USR1 httpd\\\\n\\\", \\\"key_size\\\": {\\\"if\\\": [\\\"key_size_override_set\\\", {\\\"get_param\\\": \\\"ApacheCertificateKeySize\\\"}, {\\\"get_param\\\": \\\"CertificateKeySize\\\"}]}, \\\"ca\\\": \\\"ipa\\\"}, \\\"for_each\\\": {\\\"NETWORK\\\": {\\\"get_attr\\\": [\\\"ApacheNetworks\\\", \\\"value\\\", {\\\"get_param\\\": \\\"RoleName\\\"}]}}}}}}]}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"HAproxy service configured with Puppet\\\\n\\\", \\\"parameters\\\": {\\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"CAMap\\\": {\\\"description\\\": \\\"Map containing the CA certs and information needed for deploying them.\\\\n\\\", \\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for injecting CA certificates.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"ca_certs\\\", \\\"config_settings\\\": {\\\"tripleo::trusted_cas::ca_map\\\": {\\\"get_param\\\": \\\"CAMap\\\"}}, \\\"step_config\\\": \\\"include tripleo::trusted_cas\\\"}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pyshim.sh\": \"#!/usr/bin/bash\\n# Copyright 2018 Red Hat Inc.\\n#\\n# Licensed under the Apache License, Version 2.0 (the \\\"License\\\"); you may\\n# not use this file except in compliance with the License. You may obtain\\n# a copy of the License at\\n#\\n#      http://www.apache.org/licenses/LICENSE-2.0\\n#\\n# Unless required by applicable law or agreed to in writing, software\\n# distributed under the License is distributed on an \\\"AS IS\\\" BASIS, WITHOUT\\n# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the\\n# License for the specific language governing permissions and limitations\\n# under the License.\\n#\\n# Usage: pyshim.sh <script and/or arguments>\\n#\\n# Unfortunately THT doesn\'t know which version of python might be in a\\n# container so we need this script to be able to try python3 or python2\\n# depending on availability.  Since this is a temporary shim until we\'ve\\n# fully cut over to python3, we check for the existence of python3 first\\n# before falling back to python2. This will help in the transition from\\n# python2 based containers to python3.\\n\\nshow_usage() {\\n    echo \\\"Usage: pyshim.sh <script and/or arguments>\\\"\\n}\\n\\nif [ $# -lt 1 ]\\nthen\\n    show_usage\\n    exit 1\\nfi\\n\\nset -x\\nif command -v python3 >/dev/null; then\\n    python3 \\\"$@\\\"\\nelif command -v python2 >/dev/null; then\\n    python2 \\\"$@\\\"\\nelif command -v python >/dev/null; then\\n    python \\\"$@\\\"\\nelse\\n    echo \\\"ERROR: python is not available!\\\"\\n    exit 1\\nfi\\n\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\": \"#!/usr/bin/bash\\n\\nset -u\\n\\n# ./pacemaker_restart_bundle.sh mysql galera galera-bundle Master _\\n# ./pacemaker_restart_bundle.sh redis redis redis-bundle Slave Master\\n# ./pacemaker_restart_bundle.sh ovn_dbs ovndb_servers ovn-dbs-bundle Slave Master\\nRESTART_SCRIPTS_DIR=$(dirname $0)\\nTRIPLEO_SERVICE=$1\\nRESOURCE_NAME=$2\\nBUNDLE_NAME=$3\\nWAIT_TARGET_LOCAL=$4\\nWAIT_TARGET_ANYWHERE=${5:-_}\\nTRIPLEO_MINOR_UPDATE=\\\"${TRIPLEO_MINOR_UPDATE:-false}\\\"\\nTRIPLEO_HA_WRAPPER_RESOURCE_EXISTS=\\\"${TRIPLEO_HA_WRAPPER_RESOURCE_EXISTS:-false}\\\"\\n\\nbundle_can_be_restarted() {\\n    local bundle=$1\\n    # As long as the resource bundle is managed by pacemaker and is\\n    # not meant to stay stopped, no matter the state of any inner\\n    # pcmk_remote or ocf resource, we should restart it to give it a\\n    # chance to read the new config.\\n    [ \\\"$(crm_resource --meta -r $1 -g is-managed 2>/dev/null)\\\" != \\\"false\\\" ] && \\\\\\n    [ \\\"$(crm_resource --meta -r $1 -g target-role 2>/dev/null)\\\" != \\\"Stopped\\\" ]\\n}\\n\\nlog() {\\n    local msg=$1\\n    logger -t pcmkrestart \\\"$1\\\"\\n}\\n\\nHOSTNAME=$(/bin/hostname -s)\\nif [ x\\\"${TRIPLEO_MINOR_UPDATE,,}\\\" != x\\\"true\\\" ]; then\\n    if [ x\\\"${TRIPLEO_HA_WRAPPER_RESOURCE_EXISTS,,}\\\" = x\\\"false\\\" ]; then\\n        # Do not restart during initial deployment, as the resource\\n        # has just been created.\\n        SERVICE_NODEID=$(/bin/hiera -c /etc/puppet/hiera.yaml \\\"${TRIPLEO_SERVICE}_short_bootstrap_node_name\\\")\\n        if [[ \\\"${HOSTNAME,,}\\\" == \\\"${SERVICE_NODEID,,}\\\" ]]; then\\n            log \\\"Initial deployment, skipping the restart of ${BUNDLE_NAME}\\\"\\n\\tfi\\n        exit 0\\n    else\\n        # During a stack update, this script is called in parallel on\\n        # every node the resource runs on, after the service\'s configs\\n        # have been updated on all nodes. So we need to run pcs only\\n        # once (e.g. on the service\'s boostrap node).\\n        if bundle_can_be_restarted ${BUNDLE_NAME}; then\\n            SERVICE_NODEID=$(/bin/hiera -c /etc/puppet/hiera.yaml \\\"${TRIPLEO_SERVICE}_short_bootstrap_node_name\\\")\\n            if [[ \\\"${HOSTNAME,,}\\\" == \\\"${SERVICE_NODEID,,}\\\" ]]; then\\n                replicas_running=$(crm_resource -Q -r $BUNDLE_NAME --locate 2>&1 | wc -l)\\n                if [ \\\"$replicas_running\\\" != \\\"0\\\" ]; then\\n                    log \\\"Restarting ${BUNDLE_NAME} globally. Stopping:\\\"\\n                    /sbin/pcs resource disable --wait=__PCMKTIMEOUT__ $BUNDLE_NAME\\n                    log \\\"Restarting ${BUNDLE_NAME} globally. Starting:\\\"\\n                    /sbin/pcs resource enable --wait=__PCMKTIMEOUT__ $BUNDLE_NAME\\n                else\\n                    log \\\"${BUNDLE_NAME} is not running anywhere,\\\" \\\\\\n                         \\\"cleaning up to restart it globally if necessary\\\"\\n                    /sbin/pcs resource cleanup $BUNDLE_NAME\\n                fi\\n            else\\n                log \\\"Skipping global restart of ${BUNDLE_NAME} on ${HOSTNAME} it will be restarted by node ${SERVICE_NODEID}\\\"\\n            fi\\n\\n        else\\n            log \\\"No global restart needed for ${BUNDLE_NAME}.\\\"\\n        fi\\n    fi\\nelse\\n    # During a minor update workflow however, a host gets fully\\n    # updated before updating the next one. So unlike stack\\n    # update, at the time this script is called, the service\'s\\n    # configs aren\'t updated on all nodes yet. So only restart the\\n    # resource locally, where it\'s guaranteed that the config is\\n    # up to date.\\n    HOST=$(facter hostname)\\n\\n    if bundle_can_be_restarted ${BUNDLE_NAME}; then\\n\\t# if the resource is running locally, restart it\\n\\tif crm_resource -r $BUNDLE_NAME --locate 2>&1 | grep -w -q \\\"${HOST}\\\"; then\\n            log \\\"Restarting ${BUNDLE_NAME} locally on \'${HOST}\'\\\"\\n            /sbin/pcs resource restart $BUNDLE_NAME \\\"${HOST}\\\"\\n\\n\\telse\\n\\t    # At this point, if no resource is running locally, it\'s\\n\\t    # either because a) it has failed previously, or b) because\\n\\t    # it\'s an A/P resource running elsewhere.\\n\\t    # By cleaning up resource, we ensure that a) it will try to\\n\\t    # restart, or b) it won\'t do anything if the resource is\\n\\t    # already running elsewhere.\\n            log \\\"${BUNDLE_NAME} is currently not running on \'${HOST}\',\\\" \\\\\\n                 \\\"cleaning up its state to restart it if necessary\\\"\\n            /sbin/pcs resource cleanup $BUNDLE_NAME node=\\\"${HOST}\\\"\\n\\tfi\\n\\n\\t# Wait until the resource is in the expected target state\\n\\t$RESTART_SCRIPTS_DIR/pacemaker_wait_bundle.sh \\\\\\n            $RESOURCE_NAME $BUNDLE_NAME \\\\\\n            \\\"$WAIT_TARGET_LOCAL\\\" \\\"$WAIT_TARGET_ANYWHERE\\\" \\\\\\n\\t    \\\"${HOST}\\\" __PCMKTIMEOUT__\\n    else\\n        log \\\"No restart needed for ${BUNDLE_NAME}.\\\"\\n    fi\\nfi\\n\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\": \"#!/usr/bin/bash\\n\\n# ----\\n# Wait for an OCF resource or a bundle to be restarted\\n# ----\\n# e.g.:\\n# M/S OCF:      $0 galera galera-bundle Master\\n# clone OCF:    $0 rabbitmq rabbitmq-bundle Started\\n# A/P M/S OCF:  $0 redis redis-bundle Slave Master\\n# A/P bundle:   $0 openstack-cinder-volume openstack-cinder-volume _ Started\\n# clone bundle: $0 haproxy-bundle haproxy-bundle Started\\n\\n# design note 1:\\n#  - this script is called during a minor update; it is called\\n#    once per node that hosts a service replica.\\n#  - the purpose of this script is to ensure that restarting the\\n#    service replica locally won\'t disrupt the service availability\\n#    for the end user. To reach that goal, the script waits until the\\n#    service is restarted locally or globallu and reaches a given\\n#    target state (i.e. Started, Slave or Master).\\n# design note 2:\\n#   - we don\'t want to track restart error: our only job is to ensure\\n#     service restart synchronization, not service health.\\n#   - In particular, we don\'t want to error out in case the resource\\n#     cannot be restarted locally, because that would make the minor\\n#     update fail, even if potentially other replicas still provide\\n#     the service.\\n# design note 3:\\n#   - we can bail out early if we determine that the resource can\'t\\n#     be restarted automatically by pacemaker (e.g. its \\\"blocked\\\",\\n#     unmanaged or disabled).\\n\\nlog() {\\n    local msg=$1\\n    echo \\\"$(date -u): $1\\\"\\n}\\n\\nusage() {\\n    echo 2>&1 \\\"Usage: $0 NAME BUNDLE_NAME ROLE_LOCAL [ROLE_ANYWHERE] [HOST] [TIMEOUT]\\\"\\n    exit 1\\n}\\n\\npacemaker_supports_promoted() {\\n    # The Promoted token is only matched in recent pacemaker versions\\n    grep -wq \\\"<value>Promoted</value>\\\" /usr/share/pacemaker/resources-*.rng\\n}\\n\\n#\\n# Utility functions to detect stuck resources\\n#\\n\\nbundle_failures_locally() {\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\n    local replicas=$BUNDLE_REPLICAS\\n    local last=$(($replicas - 1))\\n    local replica_name\\n    for i in $(seq 0 $last); do\\n\\treplica_name=${BUNDLE_NAME}-${engine}-${i}\\n\\tcrm_failcount -q -G -r $replica_name -N $HOST\\n    done\\n}\\n\\nbundle_failures_globally() {\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\n    local replicas=$BUNDLE_REPLICAS\\n    local last=$(($replicas - 1))\\n    for i in $(seq 0 $last); do\\n\\tcrm_failcount -q -G -r ${BUNDLE_NAME}-${engine}-${i}\\n    done\\n}\\n\\nbundle_running_globally() {\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\n    # return the number of running bundles replica, i.e. the number of\\n    # docker/podman resource replicas currently running in the cluster\\n    crm_mon --as-xml | xmllint --xpath \\\"count(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource[@resource_agent=\'${OCF}:heartbeat:${engine}\']/node)\\\" -\\n}\\n\\nocf_failures_globally() {\\n    local replicas=$BUNDLE_REPLICAS\\n    local last=$(($replicas - 1))\\n    local bundle_node\\n    for i in $(seq 0 $last); do\\n\\tbundle_node=${BUNDLE_NAME}-${i}\\n\\tcrm_failcount -q -G -r $NAME -N $bundle_node\\n    done\\n}\\n\\ndid_resource_failed_locally() {\\n    local failures\\n    local running\\n    local remotehost\\n    if [ \\\"${NAME}\\\" != \\\"${BUNDLE_NAME}\\\" ]; then\\n\\t# if we\'re dealing with an ocf resource, it is running on a\\n\\t# pacemaker_remote rather that on the real host, and the\\n\\t# failcounts are thus associated to the pcmk remote. Replace\\n\\t# the host\'s name with the pcmk remote\'s name.\\n        remotehost=$(crm_mon --as-xml | xmllint --xpath \\\"string(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource/node[@name=\'${HOST}\']/../../resource[@resource_agent=\'${OCF}:pacemaker:remote\']/@id)\\\" -)\\n\\tif [ -n \\\"${remotehost}\\\" ]; then\\n\\t    crm_failcount -q -G -r $NAME -N $remotehost | grep -q -w INFINITY\\n\\t    return $?\\n\\tfi\\n\\t# If no pcmk remote is currently running, the failcount from\\n\\t# the ocf resource is useless, compute the failcount from the\\n\\t# bundle case instead (computed below).\\n    fi\\n\\n    # for bundles, pacemaker can run any bundle replica locally\\n    # (e.g. galera-bundle-docker-{0,1,2}), and a failure happens when\\n    # there are no more replica to try.\\n    # That is, when _at least_ one replica failed locally, and all the\\n    # others either failed or are currently running elsewhere.\\n    failures=$(bundle_failures_locally $HOST | grep -c -w INFINITY)\\n    running=$(bundle_running_globally)\\n    test $failures -gt 0 && \\\\\\n    test $(( $failures + $running )) -ge $BUNDLE_REPLICAS\\n}\\n\\ndid_resource_failed_globally() {\\n    local remotecount\\n    local failures\\n    if [ \\\"${NAME}\\\" != \\\"${BUNDLE_NAME}\\\" ]; then\\n\\t# we check the state of an ocf resource only if the\\n\\t# pcmkremotes are started\\n        remotecount=$(crm_mon --as-xml | xmllint --xpath \\\"count(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource[@resource_agent=\'${OCF}:pacemaker:remote\']/node)\\\" -)\\n\\tif [ \\\"${remotecount}\\\" = \\\"0\\\" ]; then\\n\\t    # no pcmkremote is running, so check the bundle state\\n\\t    # instead of checking the ocf resource\\n\\t    # bundle failed if all ${BUNDLE_REPLICAS} replicas failed\\n\\t    failures=$(bundle_failures_globally | grep -c -w INFINITY)\\n\\t    test $failures -eq $BUNDLE_REPLICAS\\n\\telse\\n\\t    # ocf resource failed if it failed to start on\\n\\t    # all $BUNDLE_REPLICAS bundle nodes\\n\\t    failures=$(ocf_failures_globally | grep -c -w INFINITY)\\n\\t    test $failures -eq $BUNDLE_REPLICAS\\n\\tfi\\n    else\\n\\t# bundle failed if all ${BUNDLE_REPLICAS} replicas failed\\n\\tfailures=$(bundle_failures_globally | grep -c -w INFINITY)\\n\\ttest $failures -eq $BUNDLE_REPLICAS\\n    fi\\n}\\n\\n\\n# Input validation\\n#\\n\\nNAME=$1\\nif [ -z \\\"${NAME}\\\" ]; then\\n    echo 2>&1 \\\"Error: argument NAME must not be empty\\\"\\n    exit 1\\nfi\\n\\nBUNDLE_NAME=$2\\nif [ -z \\\"${BUNDLE_NAME}\\\" ]; then\\n    echo 2>&1 \\\"Error: argument BUNDLE_NAME must not be empty\\\"\\n    exit 1\\nfi\\n\\nROLE_LOCAL=$3\\nif [ \\\"${ROLE_LOCAL}\\\" = \\\"_\\\" ]; then\\n    ROLE_LOCAL=\\\"\\\"\\nfi\\n\\nROLE_ANYWHERE=$4\\nif [ \\\"${ROLE_ANYWHERE}\\\" = \\\"_\\\" ]; then\\n    ROLE_ANYWHERE=\\\"\\\"\\nfi\\n\\nif [ -z \\\"${ROLE_LOCAL}\\\" ]; then\\n    if [ -z \\\"${ROLE_ANYWHERE}\\\" ]; then\\n        echo 2>&1 \\\"Error: either ROLE_LOCAL or ROLE_ANYWHERE must be non empty\\\"\\n        exit 1\\n    fi\\nelse\\n    if !(echo \\\"${ROLE_LOCAL}\\\" | grep -q -x -E \\\"(Started|Slave|Master|Unpromoted|Promoted)\\\"); then\\n        echo 2>&1 \\\"Error: argument ROLE_LOCAL must be either \'Started\' \'Slave\' \'Master\' \'Unpromoted\' or \'Promoted\'\\\"\\n        exit 1\\n    fi\\nfi\\n\\nif [ -n \\\"${ROLE_ANYWHERE}\\\" ] && !(echo \\\"${ROLE_ANYWHERE}\\\" | grep -q -x -E \\\"(Started|Slave|Master|Unpromoted|Promoted)\\\"); then\\n    echo 2>&1 \\\"Error: argument ROLE_ANYWHERE must be either \'Started\' \'Slave\' \'Master\' \'Unpromoted\' or \'Promoted\'\\\"\\n    exit 1\\nfi\\n\\n# Ensure compatibility with pacemaker 2.1\\nif pacemaker_supports_promoted; then\\n    ROLE_LOCAL=$(echo \\\"$ROLE_LOCAL\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\n    ROLE_ANYWHERE=$(echo \\\"$ROLE_ANYWHERE\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\n    OCF=\\\"ocf\\\"\\nelse\\n    OCF=\\\"ocf:\\\"\\nfi\\n\\nHOST=${5:-$(facter hostname)}\\nTIMEOUT=${6:-__PCMKTIMEOUT__}\\n\\n\\n# Configure the search\\n# ----\\n# Note: we can\'t use crm_resource in all searches because we can\'t\\n# easily extract the host the OCF resources run on (crm_resource\\n# returns the pcmk-remote nodes rather than the hosts)\\n# So instead, we implement various searches with XPath directly.\\n\\nif [ \\\"${BUNDLE_NAME}\\\" != \\\"${NAME}\\\" ]; then\\n# ocf resource\\nlocal_resource_xpath=\\\"//bundle/replica/resource[@resource_agent=\'${OCF}:pacemaker:remote\']/node[@name=\'${HOST}\']/../../resource[@id=\'${NAME}\']\\\"\\nany_resource_xpath=\\\"//bundle//resource[@id=\'${NAME}\']\\\"\\nreplicas_xpath=\\\"//bundle/primitive[@id=\'${BUNDLE_NAME}\']/../*[boolean(@image) and boolean(@replicas)]\\\"\\nelse\\n# bundle resource\\nlocal_resource_xpath=\\\"//bundle[@id=\'${NAME}\']/replica/resource/node[@name=\'${HOST}\']/../../resource\\\"\\nany_resource_xpath=\\\"//bundle[@id=\'${NAME}\']//resource\\\"\\nreplicas_xpath=\\\"//bundle[@id=\'${BUNDLE_NAME}\']/*[boolean(@image) and boolean(@replicas)]\\\"\\nfi\\n\\nbundle_def_xpath=\\\"//bundle[@id=\'${BUNDLE_NAME}\']/*[boolean(@image) and boolean(@replicas)]\\\"\\nBUNDLE_CONTAINER_ENGINE=$(cibadmin -Q | xmllint --xpath \\\"name(${bundle_def_xpath})\\\" -)\\nBUNDLE_REPLICAS=$(cibadmin -Q | xmllint --xpath \\\"string(${bundle_def_xpath}/@replicas)\\\" -)\\n\\n\\n# The wait algorithm follows a two-stage approach\\n#  1. Depending on how the script is called, we first check whether\\n#     the resource is restarted locally. An A/P resource may be\\n#     restarted elsewhere in the cluster.\\n#  2. If needed, check whether the A/P resource has restarted\\n#     elsewhere. For A/P M/S resources, in case the resource is\\n#     restarted as Slave locally, ensure a Master is available.\\n\\nsuccess=1\\nbailout=1\\ntimeout=$TIMEOUT\\nrole=\\\"\\\"\\n\\n# Stage 1: local check\\nif [ -n \\\"$ROLE_LOCAL\\\" ]; then\\n    log \\\"Waiting until ${NAME} has restarted on ${HOST} and is in state ${ROLE_LOCAL}\\\"\\n    log \\\"Will probe resource state with the following XPath pattern: ${local_resource_xpath}\\\"\\n\\n    while [ $timeout -gt 0 ] && [ $bailout -ne 0 ] && [ $success -ne 0 ]; do\\n        resource=$(crm_mon -r --as-xml | xmllint --xpath \\\"${local_resource_xpath}\\\" - 2>/dev/null)\\n        role=$(echo \\\"${resource}\\\" | sed -ne \'s/.*\\\\Wrole=\\\"\\\\([^\\\"]*\\\\)\\\".*/\\\\1/p\')\\n\\n\\tif [ \\\"$(crm_resource --meta -r ${NAME} -g is-managed 2>/dev/null)\\\" = \\\"false\\\" ]; then\\n            log \\\"${NAME} is unmanaged, will never reach target role. Bailing out\\\"\\n            bailout=0\\n            continue\\n\\telif [ \\\"$(crm_resource --meta -r ${NAME} -g target-role 2>/dev/null)\\\" = \\\"Stopped\\\" ]; then\\n            log \\\"${NAME} is disabled, will never reach target role. Bailing out\\\"\\n            bailout=0\\n            continue\\n        elif echo \\\"${resource}\\\" | grep -q -w \\\"\\\\Wblocked=\\\\\\\"true\\\\\\\"\\\"; then\\n            log \\\"${NAME} is blocked, will never reach target role. Bailing out\\\"\\n            bailout=0\\n            continue\\n\\telif did_resource_failed_locally; then\\n            log \\\"${NAME} is in failed state, will never reach target role. Bailing out\\\"\\n            bailout=0\\n            continue\\n        elif [ \\\"$role\\\" = \\\"$ROLE_LOCAL\\\" ]; then\\n            success=0\\n            continue\\n        elif [ -n \\\"$ROLE_ANYWHERE\\\" ] && [ \\\"$role\\\" = \\\"$ROLE_ANYWHERE\\\" ]; then\\n            # A/P: we are restarted in the expected state\\n            success=0\\n            continue\\n        else\\n            log \\\"Waiting for ${NAME} to transition to role ${ROLE_LOCAL} on ${HOST}\\\"\\n        fi\\n\\n        if [ $bailout -ne 0 ] && [ $success -ne 0 ]; then\\n            sleep 4\\n            timeout=$((timeout-4))\\n        fi\\n    done\\nfi\\n\\n# Stage 2: global check\\nif [ $timeout -gt 0 ] && [ -n \\\"$ROLE_ANYWHERE\\\" ] && [ \\\"$role\\\" != \\\"$ROLE_ANYWHERE\\\" ]; then\\n    log \\\"Wait until ${NAME} is restarted anywhere in the cluster in state ${ROLE_ANYWHERE}\\\"\\n    log \\\"Will probe resource state with the following XPath pattern: ${any_resource_xpath}\\\"\\n\\n    success=1\\n    bailout=1\\n    while [ $timeout -gt 0 ] && [ $bailout -ne 0 ] && [ $success -ne 0 ]; do\\n        resources=$(crm_mon -r --as-xml | xmllint --xpath \\\"${any_resource_xpath}\\\" - 2>/dev/null)\\n\\tif [ \\\"$(crm_resource --meta -r ${NAME} -g is-managed 2>/dev/null)\\\" = \\\"false\\\" ]; then\\n            log \\\"${NAME} is unmanaged, will never reach target role. Bailing out\\\"\\n            bailout=0\\n            continue\\n\\telif [ \\\"$(crm_resource --meta -r ${NAME} -g target-role 2>/dev/null)\\\" = \\\"Stopped\\\" ]; then\\n            log \\\"${NAME} is disabled, will never reach target role. Bailing out\\\"\\n            bailout=0\\n            continue\\n        elif ! (echo \\\"${resources}\\\" | grep -q -w \\\"\\\\Wblocked=\\\\\\\"false\\\\\\\"\\\"); then\\n            log \\\"${NAME} blocked, will never reach target role. Bailing out\\\"\\n            bailout=0\\n            continue\\n\\telif did_resource_failed_globally; then\\n            log \\\"${NAME} is in failed state, will never reach target role. Bailing out\\\"\\n            bailout=0\\n            continue\\n        elif echo \\\"${resources}\\\" | grep -q -w \\\"\\\\Wrole=\\\\\\\"${ROLE_ANYWHERE}\\\\\\\"\\\"; then\\n            success=0\\n            continue\\n        else\\n            log \\\"Waiting for ${NAME} to transition to role ${ROLE_ANYWHERE} anywhere in the cluster\\\"\\n        fi\\n\\n        if [ $bailout -ne 0 ] && [ $success -ne 0 ]; then\\n            sleep 4\\n            timeout=$((timeout-4))\\n        fi\\n    done\\nfi\\n\\nif [ $timeout -le 0 ]; then\\n    log \\\"Timeout reached after ${TIMEOUT}s while waiting for ${NAME} to be restarted\\\"\\nelif [ $bailout -le 0 ]; then\\n    log \\\"Restart monitoring for ${NAME} cancelled\\\"\\nfi\\n\\nif [ $success -eq 0 ]; then\\n    log \\\"${NAME} successfully restarted\\\"\\nelse\\n    log \\\"${NAME} was not restarted properly\\\"\\nfi\\n\\n# Don\'t block minor update or stack update if the wait was unsuccessful\\nexit 0\\n\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\": \"#!/usr/bin/bash\\nset -eu\\n\\nHOST=$1\\nPORT=$2\\n\\necho \\\"$(date -u): Checking whether we can bind to ${HOST}:${PORT}\\\"\\nwhile (ss -Htnl src \\\"${HOST}\\\" \\\"sport = :${PORT}\\\" | grep -wq \\\"${PORT}\\\"); do\\n    echo \\\"$(date -u): ${HOST}:${PORT} still in use, waiting...\\\";\\n    sleep 10;\\ndone\\n\\nshift 2\\nCOMMAND=\\\"$*\\\"\\nif [ -z \\\"${COMMAND}\\\" ]; then\\n    COMMAND=\\\"true\\\"\\nfi\\nexec $COMMAND\\n\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\": \"#!/usr/bin/bash\\n\\nMAX_RETRIES=10\\nCIB_ENOTFOUND=105\\n\\nusage() {\\n   echo \\\"Set a global property in the cluster with a validity timestamp.\\\"\\n   echo \\\"Usage:\\\"\\n   echo \\\"   $0 --acquire <lock_name> <lock_owner> <lock_ttl_in_seconds>\\\"\\n   echo \\\"   $0 --release <lock_name> <lock_owner>\\\"\\n   echo\\n}\\n\\nlog() {\\n    echo \\\"$(date -u): $1\\\" 1>&2\\n}\\n\\nerror() {\\n    echo \\\"$(date -u): $1\\\" 1>&2\\n    exit 1\\n}\\n\\nlock_create() {\\n    local name=$1\\n    local data=$2\\n    # cibadmin won\'t overwrite a key if someone else succeeded to create it concurrently\\n    cibadmin --sync-call --scope crm_config --create --xml-text \\\"<cluster_property_set id=\'${name}\'><nvpair id=\'${name}-pair\' name=\'${name}\' value=\'${data}\'/></cluster_property_set>\\\" &>/dev/null\\n    return $?\\n}\\n\\nlock_update() {\\n    local name=$1\\n    local expected_data=$2\\n    local new_data=$3\\n    # we only update the lock we expect to see, so we can\'t update someone else\'s lock\\n    cibadmin --sync-call --scope crm_config --modify --xpath \\\"//cluster_property_set/nvpair[@name=\'${name}\' and @value=\'${expected_data}\']/..\\\" --xml-text \\\"<nvpair id=\'${name}-pair\' name=\'${name}\' value=\'${new_data}\'/>\\\" &>/dev/null\\n    return $?\\n}\\n\\nlock_delete() {\\n    local name=$1\\n    local expected_data=$2\\n    # we only delete the lock we expect to see, so we can\'t delete someone else\'s lock\\n    cibadmin --sync-call --scope crm_config --delete --xpath \\\"//cluster_property_set/nvpair[@name=\'${name}\' and @value=\'${expected_data}\']/..\\\" &>/dev/null\\n    return $?\\n}\\n\\nlock_get() {\\n    local lockname=$1\\n    local res\\n    local rc\\n    res=$(cibadmin --query --scope crm_config --xpath \\\"//cluster_property_set/nvpair[@name=\'$lockname\']\\\" 2>/dev/null)\\n    rc=$?\\n    if [ $rc -eq 0 ]; then\\n        echo \\\"$res\\\" | sed -n \'s/.*value=\\\"\\\\([^\\\"]*\\\\)\\\".*/\\\\1/p\'\\n    fi\\n    return $rc\\n}\\n\\nlock_owner() {\\n    local lock=$1\\n    echo \\\"$lock\\\" | cut -d\':\' -f1\\n}\\n\\nlock_has_expired() {\\n    local lock=$1\\n    local expiry=$(echo \\\"$lock\\\" | cut -d\':\' -f2)\\n    local now=$(date +%s)\\n    test $now -ge $expiry\\n}\\n\\n\\n# Perform a lock action and restart if the CIB has been modified before\\n# committing the lock action\\ntry_action() {\\n    local fun=$1\\n    local lock=$2\\n    local requester=$3\\n    local args=${4:-}\\n    local tries=$MAX_RETRIES\\n    local rc=1\\n    if [ \\\"$fun\\\" = \\\"lock_acquire\\\" ] || [ \\\"$fun\\\" = \\\"lock_release\\\" ]; then\\n        log \\\"Try running $fun\\\"\\n    else\\n        return 2\\n    fi\\n    while [ $rc -ne 0 ]; do\\n        $fun $lock $requester $args\\n        rc=$?\\n        if [ $rc -eq 0 ]; then\\n            log \\\"Operation $1 succeeded\\\"\\n            return 0\\n        elif [ $rc -eq 3 ]; then\\n            # rc == 3 -> CIB changed before push\\n            if [ $tries -eq 0 ]; then\\n                log \\\"Failed to commit after $MAX_RETRIES retries. Bailing out.\\\"\\n                return 2\\n            else\\n                log \\\"Failed to commit. Retrying operation.\\\"\\n                tries=$(($tries - 1))\\n            fi\\n        elif [ $rc -eq 2 ]; then\\n            # rc == 2 -> unrecoverable cib error (e.g. pacemaker down)\\n            log \\\"Unexpected failure. Bailing out\\\"\\n            return $rc\\n        else\\n            # rc == 1 -> lock error (not owner, lock doesn\'t exists)\\n            return $rc\\n        fi\\n    done\\n}\\n\\n# The lock mechanism uses cibadmin\'s atomic creation so cluster-wide\\n# state coherency is guaranteed by pacemaker\\nlock_acquire() {\\n    local lockname=$1\\n    local requester=$2\\n    local ttl=$3\\n    local rc\\n    local lock\\n    local expiry\\n    local owner\\n\\n    log \\\"Check whether the lock is already held in the CIB\\\"\\n    lock=$(lock_get $lockname)\\n    rc=$?\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\n        log \\\"Could not retrieve info from the CIB\\\"\\n        return 2\\n    fi\\n\\n    if [ -n \\\"$lock\\\" ]; then\\n        lock_has_expired $lock\\n        rc=$?\\n        if [ $rc -eq 0 ]; then\\n            log \\\"Lock has expired, now available for being held\\\"\\n        else\\n            # lock is still held. check whether we\'re the owner\\n            owner=$(lock_owner $lock)\\n            if [ \\\"$owner\\\" = \\\"$requester\\\" ];then\\n                log \\\"Requester already owns the lock, acquiring attempt will just reconfigure the TTL\\\"\\n            else\\n                log \\\"Lock is held by someone else ($owner)\\\"\\n                return 1\\n            fi\\n        fi\\n    else\\n        log \\\"Lock is not held yet\\\"\\n    fi\\n\\n    # prepare the lock info\\n    expiry=$(($(date +%s) + $ttl))\\n\\n    if [ -n \\\"$lock\\\" ]; then\\n        log \\\"Attempting to update the lock\\\"\\n        lock_update $lockname \\\"$lock\\\" \\\"$requester:$expiry\\\"\\n        rc=$?\\n    else\\n        log \\\"Attempting to acquire the lock\\\"\\n        lock_create $lockname \\\"$requester:$expiry\\\"\\n        rc=$?\\n    fi\\n\\n    if [ $rc -eq 0 ]; then\\n        log \\\"Lock \'$lockname\' acquired by \'$requester\', valid until $(date -d @$expiry)\\\"\\n        return 0\\n    else\\n        log \\\"CIB changed, lock cannot be acquired\\\"\\n        return 3\\n    fi\\n}\\n\\n\\n# The lock mechanism uses the CIB\'s num_updates tag to implement\\n# a conditional store. Cluster-wide locking is guaranteed by pacemaker\\nlock_release() {\\n    local lockname=$1\\n    local requester=$2\\n    local rc\\n    local lock\\n    local owner\\n\\n    log \\\"Check whether the lock is already held in the CIB\\\"\\n    lock=$(lock_get $lockname)\\n    rc=$?\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\n        log \\\"Could not retrieve info from the CIB\\\"\\n        return 2\\n    fi\\n\\n    if [ -z \\\"$lock\\\" ]; then\\n        log \\\"Lock doesn\'t exist. Nothing to release\\\"\\n        return 0\\n    else\\n        log \\\"Lock exists, check whether we\'re the owner\\\"\\n        owner=$(lock_owner $lock)\\n        if [ \\\"$owner\\\" != \\\"$requester\\\" ];then\\n            log \\\"Lock is held by someone else ($owner), will not unlock\\\"\\n            return 1\\n        fi\\n    fi\\n\\n    lock_delete $lockname \\\"$lock\\\"\\n    rc=$?\\n\\n    if [ $rc -eq 0 ]; then\\n        log \\\"Lock \'$lockname\' released by \'$requester\'\\\"\\n        return 0\\n    else\\n        log \\\"CIB deletion error, lock cannot be released\\\"\\n        return 3\\n    fi\\n}\\n\\n\\n# Retrieve the owner of a lock from the CIB\\n# this is a read-only operation, so no need to log debug info\\nlock_get_owner() {\\n    local lockname=$1\\n    local rc\\n    local lock\\n    local owner\\n\\n    lock=$(lock_get $lockname)\\n    rc=$?\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\n        return 2\\n    fi\\n\\n    if [ -z \\\"$lock\\\" ]; then\\n        return 1\\n    else\\n        lock_owner $lock\\n        return 0\\n    fi\\n}\\n\\n\\nACTION=$1\\nLOCKNAME=$2\\nREQUESTER=$3\\nTTL=${4:-60}\\n\\nif [ -z \\\"$ACTION\\\" ]; then\\n    error \\\"Action must be specified\\\"\\nfi\\n\\nif [ $ACTION != \\\"--help\\\" ]; then\\n    if [ -z \\\"$LOCKNAME\\\" ]; then\\n        error \\\"You must specific a lock name\\\"\\n    fi\\n    if [ $ACTION != \\\"--owner\\\" ] && [ $ACTION != \\\"-o\\\" ]; then\\n        if [ -z \\\"$REQUESTER\\\" ]; then\\n            error \\\"You must specific a lock requester\\\"\\n        fi\\n    fi\\nfi\\n\\ncase $ACTION in\\n    --help) usage; exit 0;;\\n    --acquire|-a) try_action lock_acquire $LOCKNAME $REQUESTER $TTL;;\\n    --release|-r) try_action lock_release $LOCKNAME $REQUESTER;;\\n    --acquire-once|-A) lock_acquire $LOCKNAME $REQUESTER $TTL;;\\n    --owner|-o) lock_get_owner $LOCKNAME;;\\n    *) error \\\"Invalid action\\\";;\\nesac\\nexit $?\\n\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\": \"#!/usr/bin/bash\\n\\n# pacemaker_mutex_restart_bundle.sh --lock mysql galera galera-bundle Master _\\n# pacemaker_mutex_restart_bundle.sh --lock ovn_dbs ovndb_servers ovn-dbs-bundle Slave Master\\n\\nset -u\\n\\nusage() {\\n    echo \\\"Restart a clustered resource in a coordinated way across the cluster\\\"\\n    echo \\\"Usage:\\\"\\n    echo \\\"   $0 --lock <tripleo-service> <pcmk-resource> <pcmk-bundle> <target-state-local> <target-state-cluster>\\\"\\n    echo\\n}\\n\\nlog() {\\n    echo \\\"$(date -u): $1\\\"\\n}\\n\\nerror() {\\n    echo \\\"$(date -u): $1\\\" 1>&2\\n    exit 1\\n}\\n\\npacemaker_supports_promoted() {\\n    # The Promoted token is only matched in recent pacemaker versions\\n    grep -wq \\\"<value>Promoted</value>\\\" /usr/share/pacemaker/resources-*.rng\\n}\\n\\nACTION=$1\\ncase $ACTION in\\n    --help) usage; exit 0;;\\n    --lock) ;;\\n    *) error \\\"Unknown action \'$ACTION\'\\\";;\\nesac\\n\\nTRIPLEO_SERVICE=$2\\nLOCK_NAME=${TRIPLEO_SERVICE}-restart-lock\\nLOCK_OWNER=$(crm_node -n 2>/dev/null)\\nrc=$?\\nif [ $rc -ne 0 ]; then\\n    if [ $rc -eq 102 ]; then\\n        log \\\"Cluster is not running locally, no need to restart resource $TRIPLEO_SERVICE\\\"\\n        exit 0\\n    else\\n        error \\\"Unexpected error while connecting to the cluster (rc: $rc), bailing out\\\"\\n    fi\\nfi\\n\\nRESOURCE_NAME=$3\\nBUNDLE_NAME=$4\\nWAIT_TARGET_LOCAL=$5\\nWAIT_TARGET_ANYWHERE=${6:-_}\\n\\nif pacemaker_supports_promoted; then\\n    WAIT_TARGET_LOCAL=$(echo \\\"$5\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\n    WAIT_TARGET_ANYWHERE=$(echo \\\"${6:-_}\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\n    promoted_role=\\\"Promoted\\\"\\nelse\\n    promoted_role=\\\"Master\\\"\\nfi\\n\\n# The lock TTL should accomodate for the resource start/promote timeout\\nif [ \\\"$RESOURCE_NAME\\\" != \\\"$BUNDLE_NAME\\\" ]; then\\n    if [ \\\"$WAIT_TARGET_LOCAL\\\" = \\\"$promoted_role\\\" ] || [ \\\"$WAIT_TARGET_ANYWHERE\\\" = \\\"$promoted_role\\\" ]; then\\n        rsc_op=\\\"promote\\\"\\n    else\\n        rsc_op=\\\"start\\\"\\n    fi\\n    # <op id=\\\"galera-promote-interval-0s\\\" interval=\\\"0s\\\" name=\\\"promote\\\" on-fail=\\\"block\\\" timeout=\\\"300s\\\"/>\\n    PCMK_TTL=$(cibadmin -Q | xmllint -xpath \\\"string(//primitive[@id=\'${RESOURCE_NAME}\']/operations/op[@name=\'${rsc_op}\']/@timeout)\\\" - | sed \'s/s$//\')\\n    LOCK_TTL=$((PCMK_TTL + 30))\\nelse\\n    # The podman RA\'s default start timeout\\n    LOCK_TTL=90\\nfi\\n\\nlog \\\"Acquire a ${LOCK_TTL}s restart lock for service $TRIPLEO_SERVICE before restarting it\\\"\\n# Loop until we hold the lock. The lock has a TTL, so we\'re guaranteed to get it eventually\\nrc=1\\nwhile [ $rc -ne 0 ]; do\\n    /var/lib/container-config-scripts/pacemaker_resource_lock.sh --acquire $LOCK_NAME $LOCK_OWNER $LOCK_TTL\\n    rc=$?\\n    if [ $rc != 0 ]; then\\n        if [ $rc -gt 1 ]; then\\n            error \\\"Could not acquire lock due to unrecoverable error (rc: $rc), bailing out\\\"\\n        else\\n            log \\\"Could not acquire lock, retrying\\\"\\n            sleep 10\\n        fi\\n    fi\\ndone\\n\\nlog \\\"Restart the service $TRIPLEO_SERVICE locally\\\"\\n# Reuse the local restart script in t-h-t (driven by env var TRIPLEO_MINOR_UPDATE)\\nTRIPLEO_MINOR_UPDATE=true /var/lib/container-config-scripts/pacemaker_restart_bundle.sh $TRIPLEO_SERVICE $RESOURCE_NAME $BUNDLE_NAME $WAIT_TARGET_LOCAL $WAIT_TARGET_ANYWHERE\\n\\n# If we reached this point, always try to release the lock\\nlog \\\"Release the restart lock for service $TRIPLEO_SERVICE\\\"\\n/var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $LOCK_NAME $LOCK_OWNER\\nrc=$?\\nif [ $rc -ne 0 ] && [ $rc -ne 1 ]; then\\n    error \\\"Could not release held lock (rc: $rc)\\\"\\nfi\\n\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\": \"#!/usr/bin/bash\\n\\n# pacemaker_mutex_shutdown.sh --acquire\\n# pacemaker_mutex_shutdown.sh --release\\n\\nset -u\\n\\nusage() {\\n    echo \\\"Shutdown a cluster node in a coordinated way across the cluster\\\"\\n    echo \\\"Usage:\\\"\\n    echo \\\"   $0 --acquire # prevent other node from shutting down until we hold the lock\\\"\\n    echo \\\"   $0 --release # release the lock, other node can compete for the shutdown lock\\\"\\n    echo\\n}\\n\\nlog() {\\n    echo \\\"$(date -u): $1\\\"\\n}\\n\\nerror() {\\n    echo \\\"$(date -u): $1\\\" 1>&2\\n    exit 1\\n}\\n\\n# Loop until we hold the lock. The lock has a TTL, so we\'re guaranteed to get it eventually\\nshutdown_lock_acquire() {\\n    local lockname=$1\\n    local requester=$2\\n    local ttl=$3\\n    local rc=1\\n    local current_owner\\n    local owner_stopped\\n    local owner_rc\\n\\n    log \\\"Acquiring the shutdown lock\\\"\\n    while [ $rc -ne 0 ]; do\\n        /var/lib/container-config-scripts/pacemaker_resource_lock.sh --acquire-once $lockname $requester $ttl\\n        rc=$?\\n        if [ $rc -ne 0 ]; then\\n            if [ $rc -eq 2 ]; then\\n                error \\\"Could not acquire the shutdown lock due to unrecoverable error (rc: $rc), bailing out\\\"\\n            else\\n                # The lock is held by another node.\\n                current_owner=$(/var/lib/container-config-scripts/pacemaker_resource_lock.sh --owner $lockname)\\n                owner_rc=$?\\n                if [ $owner_rc -eq 2 ]; then\\n                    error \\\"Could not get the shutdown lock owner due to unrecoverable error (rc: $owner_rc), bailing out\\\"\\n                fi\\n                if [ $owner_rc -eq 0 ]; then\\n                    # If the owner is marked as offline, that means it has shutdown and\\n                    # we can clean the lock preemptively and try to acquire it.\\n                    owner_stopped=$(crm_mon -1X | xmllint --xpath \'count(//nodes/node[@name=\\\"\'${current_owner}\'\\\" and @online=\\\"false\\\" and @unclean=\\\"false\\\"])\' -)\\n                    if [ \\\"${owner_stopped}\\\" = \\\"1\\\" ]; then\\n                        log \\\"Shutdown lock held by stopped node \'${current_owner}\', lock can be released\\\"\\n                        /var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $lockname $current_owner\\n                        continue\\n                    fi\\n                fi\\n                log \\\"Shutdown lock held by another node (rc: $rc), retrying\\\"\\n                sleep 10\\n            fi\\n        fi\\n    done\\n    log \\\"Shutdown lock acquired\\\"\\n    return 0\\n}\\n\\n\\n# Release the lock if we still own it. Not owning it anymore is not fatal\\nshutdown_lock_release() {\\n    local lockname=$1\\n    local requester=$2\\n    local rc\\n\\n    log \\\"Releasing the shutdown lock\\\"\\n    /var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $lockname $requester\\n    rc=$?\\n    if [ $rc -ne 0 ]; then\\n        if [ $rc -gt 1 ]; then\\n            error \\\"Could not release the shutdown lock due to unrecoverable error (rc: $rc), bailing out\\\"\\n        else\\n            log \\\"Shutdown lock no longer held, nothing to do\\\"\\n        fi\\n    else\\n        log \\\"Shutdown lock released\\\"\\n    fi\\n    return 0\\n}\\n\\n\\nACTION=$1\\nif [ -z \\\"$ACTION\\\" ]; then\\n    error \\\"Action must be specified\\\"\\nfi\\n\\nLOCK_NAME=tripleo-shutdown-lock\\nLOCK_OWNER=$(crm_node -n 2>/dev/null)\\nrc=$?\\nif [ $rc -ne 0 ]; then\\n    if [ $rc -eq 102 ]; then\\n        log \\\"Cluster is not running locally, no need to aquire the shutdown lock\\\"\\n        exit 0\\n    else\\n        error \\\"Unexpected error while connecting to the cluster (rc: $rc), bailing out\\\"\\n    fi\\nfi\\n\\n# We start with a very high TTL, that long enough to accomodate a cluster stop.\\n# As soon as the node will get offline, the other competing node will be entitled\\n# to steal the lock, so they should never wait that long in practice.\\nLOCK_TTL=600\\n\\n\\ncase $ACTION in\\n    --help) usage; exit 0;;\\n    --acquire|-a) shutdown_lock_acquire ${LOCK_NAME} ${LOCK_OWNER} ${LOCK_TTL};;\\n    --release|-r) shutdown_lock_release ${LOCK_NAME} ${LOCK_OWNER};;\\n    *) error \\\"Invalid action\\\";;\\nesac\\nexit $?\\n\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Contains a static list of common things necessary for containers\\\\n\\\", \\\"parameters\\\": {\\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"InternalTLSCAFile\\\": {\\\"default\\\": \\\"/etc/ipa/ca.crt\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Specifies the default CA cert to use if TLS is used for services in the internal network.\\\"}, \\\"RpcPort\\\": {\\\"default\\\": 5672, \\\"description\\\": \\\"The network port for messaging backend\\\", \\\"type\\\": \\\"number\\\"}, \\\"PcmkConfigRestartTimeout\\\": {\\\"default\\\": 600, \\\"description\\\": \\\"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\\\", \\\"type\\\": \\\"number\\\"}, \\\"ContainerCli\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"podman\\\", \\\"description\\\": \\\"CLI tool used to manage containers.\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"docker\\\", \\\"podman\\\"]}]}}, \\\"conditions\\\": {\\\"internal_tls_enabled\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, true]}, \\\"docker_enabled\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"docker\\\"]}}, \\\"outputs\\\": {\\\"container_config_scripts\\\": {\\\"description\\\": \\\"Shared container config scripts\\\", \\\"value\\\": {\\\"container_puppet_apply.sh\\\": {\\\"mode\\\": \\\"0700\\\", \\\"content\\\": \\\"#!/bin/bash\\\\nset -eux\\\\nSTEP=$1\\\\nTAGS=$2\\\\nCONFIG=$3\\\\nEXTRA_ARGS=${4:-\'\'}\\\\nif [ -d /tmp/puppet-etc ]; then\\\\n  # ignore copy failures as these may be the same file depending on docker mounts\\\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\\\nfi\\\\necho \\\\\\\"{\\\\\\\\\\\\\\\"step\\\\\\\\\\\\\\\": ${STEP}}\\\\\\\" > /etc/puppet/hieradata/docker_puppet.json\\\\n# $::deployment_type in puppet-tripleo\\\\nexport FACTER_deployment_type=containers\\\\nset +e\\\\npuppet apply $EXTRA_ARGS \\\\\\\\\\\\n    --verbose \\\\\\\\\\\\n    --detailed-exitcodes \\\\\\\\\\\\n    --summarize \\\\\\\\\\\\n    --color=false \\\\\\\\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\\\\\\\n    --tags $TAGS \\\\\\\\\\\\n    -e \\\\\\\"noop_resource(\'package\'); ${CONFIG}\\\\\\\"\\\\nrc=$?\\\\nset -e\\\\nset +ux\\\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\\\n    exit 0\\\\nfi\\\\nexit $rc\\\\n\\\"}, \\\"pyshim.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": {\\\"get_file\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pyshim.sh\\\"}}, \\\"pacemaker_restart_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_file\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\\\"}, \\\"params\\\": {\\\"__PCMKTIMEOUT__\\\": {\\\"get_param\\\": \\\"PcmkConfigRestartTimeout\\\"}}}}}, \\\"pacemaker_wait_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_file\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\\\"}, \\\"params\\\": {\\\"__PCMKTIMEOUT__\\\": {\\\"get_param\\\": \\\"PcmkConfigRestartTimeout\\\"}}}}}, \\\"wait-port-and-run.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": {\\\"get_file\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\\\"}}, \\\"pacemaker_resource_lock.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": {\\\"get_file\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\\\"}}, \\\"pacemaker_mutex_restart_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": {\\\"get_file\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\\\"}}, \\\"pacemaker_mutex_shutdown.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": {\\\"get_file\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\\\"}}}}, \\\"volumes_base\\\": {\\\"description\\\": \\\"Base volume list\\\", \\\"value\\\": {\\\"list_concat\\\": [[\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\"], {\\\"if\\\": [\\\"internal_tls_enabled\\\", [{\\\"list_join\\\": [\\\":\\\", [{\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, \\\"ro\\\"]]}], null]}]}}, \\\"volumes\\\": {\\\"description\\\": \\\"Common volumes for the containers.\\\", \\\"value\\\": {\\\"list_concat\\\": [{\\\"list_concat\\\": [[\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\"], {\\\"if\\\": [\\\"internal_tls_enabled\\\", [{\\\"list_join\\\": [\\\":\\\", [{\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, \\\"ro\\\"]]}], null]}]}, [\\\"/etc/puppet:/etc/puppet:ro\\\"]]}}, \\\"pacemaker_restart_volumes\\\": {\\\"description\\\": \\\"Common volumes for the pacemaker restart containers.\\\", \\\"value\\\": {\\\"list_concat\\\": [{\\\"list_concat\\\": [[\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\"], {\\\"if\\\": [\\\"internal_tls_enabled\\\", [{\\\"list_join\\\": [\\\":\\\", [{\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, \\\"ro\\\"]]}], null]}]}, [\\\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\\\", \\\"/dev/shm:/dev/shm:rw\\\", \\\"/etc/puppet:/etc/puppet:ro\\\"], {\\\"if\\\": [\\\"docker_enabled\\\", [\\\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\\\"], null]}]}}, \\\"container_puppet_apply_volumes\\\": {\\\"description\\\": \\\"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\\\", \\\"value\\\": {\\\"list_concat\\\": [{\\\"list_concat\\\": [[\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\"], {\\\"if\\\": [\\\"internal_tls_enabled\\\", [{\\\"list_join\\\": [\\\":\\\", [{\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, \\\"ro\\\"]]}], null]}]}, [\\\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\\\", \\\"/etc/puppet:/tmp/puppet-etc:ro\\\", \\\"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\\\"]]}}, \\\"healthcheck_rpc_port\\\": {\\\"description\\\": \\\"healthcheck command that probes the RpcPort\\\", \\\"value\\\": {\\\"test\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"/openstack/healthcheck RPCPORT\\\", \\\"params\\\": {\\\"RPCPORT\\\": {\\\"get_param\\\": \\\"RpcPort\\\"}}}}}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Mysql client settings\\\\n\\\", \\\"parameters\\\": {\\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"InternalTLSCAFile\\\": {\\\"default\\\": \\\"/etc/ipa/ca.crt\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Specifies the default CA cert to use if TLS is used for services in the internal network.\\\"}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role for setting mysql client parameters\\\", \\\"value\\\": {\\\"service_name\\\": \\\"mysql_client\\\", \\\"config_settings\\\": {\\\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MysqlNetwork\\\"]}}}}, \\\"tripleo::profile::base::database::mysql::client::enable_ssl\\\": {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, \\\"tripleo::profile::base::database::mysql::client::ssl_ca\\\": {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}}, \\\"step_config\\\": \\\"include tripleo::profile::base::database::mysql::client\\\"}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-base.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack Cinder base service. Shared by all Cinder services.\\\\n\\\", \\\"parameters\\\": {\\\"CinderStorageAvailabilityZone\\\": {\\\"default\\\": \\\"nova\\\", \\\"description\\\": \\\"The Cinder service\'s storage availability zone.\\\", \\\"type\\\": \\\"string\\\"}, \\\"CinderPassword\\\": {\\\"description\\\": \\\"The password for the cinder service and db account.\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"Debug\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Set to True to enable debugging on all services.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"CinderDebug\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Set to True to enable debugging on Cinder services.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"EnableSQLAlchemyCollectd\\\": {\\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"Set to true to enable the SQLAlchemy-collectd server plugin\\\\n\\\", \\\"default\\\": false}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"KeystoneRegion\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"regionOne\\\", \\\"description\\\": \\\"Keystone region for endpoint\\\"}, \\\"CinderCronDbPurgeMinute\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge db entries marked as deleted and older than $age - Minute\\\\n\\\", \\\"default\\\": \\\"1\\\"}, \\\"CinderCronDbPurgeHour\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge db entries marked as deleted and older than $age - Hour\\\\n\\\", \\\"default\\\": \\\"0\\\"}, \\\"CinderCronDbPurgeMonthday\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge db entries marked as deleted and older than $age - Month Day\\\\n\\\", \\\"default\\\": \\\"*\\\"}, \\\"CinderCronDbPurgeMonth\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge db entries marked as deleted and older than $age - Month\\\\n\\\", \\\"default\\\": \\\"*\\\"}, \\\"CinderCronDbPurgeWeekday\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge db entries marked as deleted and older than $age - Week Day\\\\n\\\", \\\"default\\\": \\\"*\\\"}, \\\"CinderCronDbPurgeUser\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge db entries marked as deleted and older than $age - User\\\\n\\\", \\\"default\\\": \\\"cinder\\\"}, \\\"CinderCronDbPurgeAge\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge db entries marked as deleted and older than $age - Age\\\\n\\\", \\\"default\\\": \\\"30\\\"}, \\\"CinderCronDbPurgeDestination\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge db entries marked as deleted and older than $age - Log destination\\\\n\\\", \\\"default\\\": \\\"/var/log/cinder/cinder-rowsflush.log\\\"}, \\\"CinderCronDbPurgeMaxDelay\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge db entries marked as deleted and older than $age - Max Delay\\\\n\\\", \\\"default\\\": \\\"3600\\\"}, \\\"CinderRpcResponseTimeout\\\": {\\\"default\\\": 60, \\\"description\\\": \\\"Cinder\'s RPC response timeout, in seconds.\\\", \\\"type\\\": \\\"number\\\"}, \\\"NovaPassword\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"The password for the nova service and db account\\\", \\\"hidden\\\": true}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Cinder base service.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"cinder_base\\\", \\\"config_settings\\\": {\\\"cinder::database_connection\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"MysqlInternal\\\", \\\"protocol\\\"]}, \\\"username\\\": \\\"cinder\\\", \\\"password\\\": {\\\"get_param\\\": \\\"CinderPassword\\\"}, \\\"host\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"MysqlInternal\\\", \\\"host\\\"]}, \\\"path\\\": \\\"/cinder\\\", \\\"query\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableSQLAlchemyCollectd\\\"}, {\\\"read_default_file\\\": \\\"/etc/my.cnf.d/tripleo.cnf\\\", \\\"read_default_group\\\": \\\"tripleo\\\", \\\"plugin\\\": \\\"collectd\\\", \\\"collectd_program_name\\\": \\\"cinder\\\", \\\"collectd_host\\\": \\\"localhost\\\"}, {\\\"read_default_file\\\": \\\"/etc/my.cnf.d/tripleo.cnf\\\", \\\"read_default_group\\\": \\\"tripleo\\\"}]}}}, \\\"cinder::logging::debug\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"CinderDebug\\\"}, true, {\\\"get_param\\\": \\\"Debug\\\"}]}, \\\"cinder::storage_availability_zone\\\": {\\\"get_param\\\": \\\"CinderStorageAvailabilityZone\\\"}, \\\"cinder::rabbit_heartbeat_timeout_threshold\\\": 60, \\\"cinder::rpc_response_timeout\\\": {\\\"get_param\\\": \\\"CinderRpcResponseTimeout\\\"}, \\\"cinder::rabbit_heartbeat_in_pthread\\\": false, \\\"cinder::db::database_db_max_retries\\\": -1, \\\"cinder::db::database_max_retries\\\": -1, \\\"cinder::cron::db_purge::minute\\\": {\\\"get_param\\\": \\\"CinderCronDbPurgeMinute\\\"}, \\\"cinder::cron::db_purge::hour\\\": {\\\"get_param\\\": \\\"CinderCronDbPurgeHour\\\"}, \\\"cinder::cron::db_purge::monthday\\\": {\\\"get_param\\\": \\\"CinderCronDbPurgeMonthday\\\"}, \\\"cinder::cron::db_purge::month\\\": {\\\"get_param\\\": \\\"CinderCronDbPurgeMonth\\\"}, \\\"cinder::cron::db_purge::weekday\\\": {\\\"get_param\\\": \\\"CinderCronDbPurgeWeekday\\\"}, \\\"cinder::cron::db_purge::user\\\": {\\\"get_param\\\": \\\"CinderCronDbPurgeUser\\\"}, \\\"cinder::cron::db_purge::age\\\": {\\\"get_param\\\": \\\"CinderCronDbPurgeAge\\\"}, \\\"cinder::cron::db_purge::destination\\\": {\\\"get_param\\\": \\\"CinderCronDbPurgeDestination\\\"}, \\\"cinder::cron::db_purge::maxdelay\\\": {\\\"get_param\\\": \\\"CinderCronDbPurgeMaxDelay\\\"}, \\\"cinder::glance::glance_api_servers\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GlanceInternal\\\", \\\"uri\\\"]}, \\\"cinder::keystone::service_user::send_service_user_token\\\": true, \\\"cinder::keystone::service_user::project_name\\\": \\\"service\\\", \\\"cinder::keystone::service_user::auth_type\\\": \\\"password\\\", \\\"cinder::keystone::service_user::auth_url\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"uri\\\"]}, \\\"cinder::keystone::service_user::password\\\": {\\\"get_param\\\": \\\"CinderPassword\\\"}, \\\"cinder::keystone::service_user::region_name\\\": {\\\"get_param\\\": \\\"KeystoneRegion\\\"}, \\\"cinder::nova::interface\\\": \\\"admin\\\", \\\"cinder::nova::project_name\\\": \\\"service\\\", \\\"cinder::nova::auth_type\\\": \\\"password\\\", \\\"cinder::nova::auth_url\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"uri\\\"]}, \\\"cinder::nova::password\\\": {\\\"get_param\\\": \\\"NovaPassword\\\"}, \\\"cinder::nova::region_name\\\": {\\\"get_param\\\": \\\"KeystoneRegion\\\"}}}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Openstack Cinder NVMeOF backend\\\\n\\\", \\\"parameters\\\": {\\\"CinderEnableNVMeOFBackend\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to enable or not the NVMeOF backend for Cinder\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"CinderNVMeOFBackendName\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"tripleo_nvmeof\\\"}, \\\"CinderNVMeOFAvailabilityZone\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"CinderNVMeOFTargetPort\\\": {\\\"type\\\": \\\"number\\\", \\\"default\\\": 4420}, \\\"CinderNVMeOFTargetHelper\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"nvmet\\\"}, \\\"CinderNVMeOFTargetProtocol\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"nvmet_rdma\\\", \\\"description\\\": \\\"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\\\n\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"nvmet_rdma\\\", \\\"nvmet_tcp\\\"]}]}, \\\"CinderNVMeOFTargetPrefix\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"nvme-subsystem\\\"}, \\\"CinderNVMeOFTargetPortId\\\": {\\\"type\\\": \\\"number\\\", \\\"default\\\": 1}, \\\"CinderNVMeOFTargetNameSpaceId\\\": {\\\"type\\\": \\\"number\\\", \\\"default\\\": 10}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\"}}, \\\"outputs\\\": {\\\"cinder_nvmeof_host_prep_tasks\\\": {\\\"description\\\": \\\"Host prep tasks related to cinder\'s NVMeOF backend\\\", \\\"value\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"CinderEnableNVMeOFBackend\\\"}, [{\\\"name\\\": \\\"ensure /etc/nvme exists\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/nvme\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"container_file_t\\\"}}]]}}, \\\"cinder_nvmeof_volumes\\\": {\\\"description\\\": \\\"Volumes related to cinder\'s NVMeOF backend\\\", \\\"value\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"CinderEnableNVMeOFBackend\\\"}, [\\\"/etc/nvme:/etc/nvme:z\\\"]]}}, \\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Cinder NVMeOF backend.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"cinder_backend_nvmeof\\\", \\\"firewall_rules\\\": {\\\"120 LVM nvmet target\\\": {\\\"dport\\\": {\\\"get_param\\\": \\\"CinderNVMeOFTargetPort\\\"}}}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\\\": {\\\"get_param\\\": \\\"CinderEnableNVMeOFBackend\\\"}, \\\"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\\\": {\\\"get_param\\\": \\\"CinderNVMeOFBackendName\\\"}, \\\"tripleo::profile::base::cinder::volume::nvmeof::target_port\\\": {\\\"get_param\\\": \\\"CinderNVMeOFTargetPort\\\"}, \\\"tripleo::profile::base::cinder::volume::nvmeof::target_helper\\\": {\\\"get_param\\\": \\\"CinderNVMeOFTargetHelper\\\"}, \\\"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\\\": {\\\"get_param\\\": \\\"CinderNVMeOFTargetProtocol\\\"}, \\\"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\\\": {\\\"get_param\\\": \\\"CinderNVMeOFTargetPrefix\\\"}, \\\"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\\\": {\\\"get_param\\\": \\\"CinderNVMeOFTargetPortId\\\"}, \\\"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\\\": {\\\"get_param\\\": \\\"CinderNVMeOFTargetNameSpaceId\\\"}, \\\"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderIscsiNetwork\\\"]}}}}, \\\"cinder::backend::nvmeof::volume_backend_name\\\": {\\\"get_param\\\": \\\"CinderNVMeOFBackendName\\\"}}, {\\\"if\\\": [{\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"CinderNVMeOFAvailabilityZone\\\"}, \\\"\\\"]}}, {\\\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\\\": {\\\"get_param\\\": \\\"CinderNVMeOFAvailabilityZone\\\"}}]}]}}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Provides the list of common container volumes and environment used by various cinder services.\\\\n\\\", \\\"parameters\\\": {\\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"CinderVolumeOptVolumes\\\": {\\\"default\\\": [], \\\"description\\\": \\\"list of optional volumes to be mounted\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"CinderBackupOptVolumes\\\": {\\\"default\\\": [], \\\"description\\\": \\\"list of optional volumes to be mounted\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"CinderVolumeOptEnvVars\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"hash of optional environment variables\\\", \\\"type\\\": \\\"json\\\"}, \\\"CinderEnableIscsiBackend\\\": {\\\"default\\\": true, \\\"description\\\": \\\"Whether to enable or not the Iscsi backend for Cinder\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"CinderEnableNVMeOFBackend\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to enable or not the NVMeOF backend for Cinder\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"CinderLVMConfigureVG\\\": {\\\"default\\\": true, \\\"description\\\": \\\"Whether to configure the \'cinder-volumes\' VG used by the LVM driver. When disabled (set to False), the LVM driver will work as long as the \'cinder-volumes\' VG has been created through some other means.\\\\n\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"CinderLVMLoopDeviceSize\\\": {\\\"default\\\": 10280, \\\"description\\\": \\\"The size of the loopback file used by the cinder LVM driver.\\\", \\\"type\\\": \\\"number\\\"}, \\\"MultipathdEnable\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to enable the multipath daemon\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"CinderVolumeCluster\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"CinderImageConversionNfsShare\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"When set, the NFS share to be used for Cinder\'s image conversion directory.\\\", \\\"type\\\": \\\"string\\\"}, \\\"CinderImageConversionNfsOptions\\\": {\\\"default\\\": \\\"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\\\", \\\"description\\\": \\\"NFS mount options when using an NFS share for Cinder\'s image conversion directory.\\\", \\\"type\\\": \\\"string\\\"}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"EnableEtcdInternalTLS\\\": {\\\"description\\\": \\\"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\\\", \\\"type\\\": \\\"boolean\\\", \\\"default\\\": true}, \\\"CephConfigPath\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"/var/lib/tripleo-config/ceph\\\", \\\"description\\\": \\\"The path where the Ceph Cluster config files are stored on the host.\\\\n\\\"}, \\\"CephClientUserName\\\": {\\\"default\\\": \\\"openstack\\\", \\\"type\\\": \\\"string\\\"}, \\\"CephClusterName\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"ceph\\\", \\\"description\\\": \\\"The Ceph cluster name.\\\", \\\"constraints\\\": [{\\\"allowed_pattern\\\": \\\"[a-zA-Z0-9]+\\\", \\\"description\\\": \\\"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\\\n\\\"}]}, \\\"CephExternalMultiConfig\\\": {\\\"type\\\": \\\"json\\\", \\\"hidden\\\": true, \\\"description\\\": \\\"List of maps describing extra overrides which will be applied when configuring\\\\nextra external Ceph clusters. If this list is non-empty, ceph-ansible will run\\\\nan extra count(list) times using the same parameters as the first run except\\\\neach parameter within each map will override the defaults. If the following\\\\nwere used, the second run would configure the overcloud to also use the ceph2\\\\ncluster with all the previous parameters except /etc/ceph/ceph2.conf would have\\\\na mon_host entry containing the value of external_cluster_mon_ips below, and\\\\nnot the default CephExternalMonHost. Subsequent ceph-ansible runs are restricted\\\\nto just ceph clients. CephExternalMultiConfig may not be used to deploy additional\\\\ninternal Ceph clusters within one Heat stack. The map for each list should contain\\\\nnot tripleo-heat-template parameters but ceph-ansible parameters.\\\\n  - cluster: \'ceph2\'\\\\n    fsid: \'e2cba068-5f14-4b0f-b047-acf375c0004a\'\\\\n    external_cluster_mon_ips: \'172.18.0.5,172.18.0.6,172.18.0.7\'\\\\n    keys:\\\\n      - name: \\\\\\\"client.openstack\\\\\\\"\\\\n        caps:\\\\n          mgr: \\\\\\\"allow *\\\\\\\"\\\\n          mon: \\\\\\\"profile rbd\\\\\\\"\\\\n          osd: \\\\\\\"osd: profile rbd pool=volumes, profile rbd pool=backups, profile rbd pool=vms, profile rbd pool=images\\\\\\\"\\\\n        key: \\\\\\\"AQCwmeRcAAAAABAA6SQU/bGqFjlfLro5KxrB1Q==\\\\\\\"\\\\n        mode: \\\\\\\"0600\\\\\\\"\\\\n    dashboard_enabled: false\\\\n\\\", \\\"default\\\": []}}, \\\"conditions\\\": {\\\"cvol_active_active_tls_enabled\\\": {\\\"and\\\": [{\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"CinderVolumeCluster\\\"}, \\\"\\\"]}}, {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, {\\\"get_param\\\": \\\"EnableEtcdInternalTLS\\\"}]}, \\\"cinder_nfs_conversion_dir_enabled\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"CinderImageConversionNfsShare\\\"}, \\\"\\\"]}}, \\\"cinder_configure_lvm\\\": {\\\"and\\\": [{\\\"get_param\\\": \\\"CinderLVMConfigureVG\\\"}, {\\\"or\\\": [{\\\"get_param\\\": \\\"CinderEnableIscsiBackend\\\"}, {\\\"get_param\\\": \\\"CinderEnableNVMeOFBackend\\\"}]}]}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"CinderNVMeOF\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\\\"}}, \\\"outputs\\\": {\\\"cinder_image_conversion_nfs_dir\\\": {\\\"description\\\": \\\"The directory where cinder does its image conversion when the directory is backed by an NFS share.\\\", \\\"value\\\": \\\"/var/lib/cinder_image_conversion\\\"}, \\\"cinder_common_host_prep_tasks\\\": {\\\"description\\\": \\\"Common host prep tasks for cinder-volume and cinder-backup services\\\", \\\"value\\\": {\\\"list_concat\\\": [[{\\\"name\\\": \\\"create fcontext entry for cinder data\\\", \\\"community.general.sefcontext\\\": {\\\"target\\\": \\\"/var/lib/cinder(/.*)?\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"state\\\": \\\"present\\\"}}, {\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode|default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/cinder\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/lib/cinder\\\", \\\"setype\\\": \\\"container_file_t\\\"}]}, {\\\"name\\\": \\\"ensure ceph configurations exist\\\", \\\"file\\\": {\\\"path\\\": {\\\"get_param\\\": \\\"CephConfigPath\\\"}, \\\"state\\\": \\\"directory\\\"}}], {\\\"get_attr\\\": [\\\"CinderNVMeOF\\\", \\\"cinder_nvmeof_host_prep_tasks\\\"]}]}}, \\\"cinder_common_volumes\\\": {\\\"description\\\": \\\"Common volumes for all cinder services\\\", \\\"value\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/log/containers/cinder:/var/log/cinder:z\\\"], {\\\"if\\\": [\\\"cvol_active_active_tls_enabled\\\", [\\\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\\\", \\\"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\\\"]]}]}}, \\\"cinder_common_kolla_config_files\\\": {\\\"description\\\": \\\"Common kolla config_files for cinder-volume and cinder-backup services\\\", \\\"value\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-ceph/\\\", \\\"dest\\\": \\\"/etc/ceph/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-iscsid/*\\\", \\\"dest\\\": \\\"/etc/iscsi/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-tls/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true, \\\"optional\\\": true}]}, \\\"cinder_common_kolla_permissions\\\": {\\\"description\\\": \\\"Common kolla permissions for cinder-volume and cinder-backup services\\\", \\\"value\\\": {\\\"list_concat\\\": [[{\\\"path\\\": \\\"/var/log/cinder\\\", \\\"owner\\\": \\\"cinder:cinder\\\", \\\"recurse\\\": true}, {\\\"path\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"/etc/ceph/CLUSTER.client.USER.keyring\\\", \\\"params\\\": {\\\"CLUSTER\\\": {\\\"get_param\\\": \\\"CephClusterName\\\"}, \\\"USER\\\": {\\\"get_param\\\": \\\"CephClientUserName\\\"}}}}, \\\"owner\\\": \\\"cinder:cinder\\\", \\\"perm\\\": \\\"0600\\\"}, {\\\"path\\\": \\\"/etc/pki/tls/certs/etcd.crt\\\", \\\"owner\\\": \\\"cinder:cinder\\\"}, {\\\"path\\\": \\\"/etc/pki/tls/private/etcd.key\\\", \\\"owner\\\": \\\"cinder:cinder\\\"}], {\\\"repeat\\\": {\\\"template\\\": {\\\"path\\\": \\\"/etc/ceph/<%cluster%>.client.*.keyring\\\", \\\"owner\\\": \\\"cinder:cinder\\\", \\\"perm\\\": \\\"0600\\\"}, \\\"for_each\\\": {\\\"<%cluster%>\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"$.data.multiconfig.select($.cluster)\\\", \\\"data\\\": {\\\"multiconfig\\\": {\\\"get_param\\\": \\\"CephExternalMultiConfig\\\"}}}}}}}]}}, \\\"cinder_volume_host_prep_and_system_upgrade_post_tasks\\\": {\\\"description\\\": \\\"Common host_prep and system_upgrade post tasks for cinder-volume\\\", \\\"value\\\": [{\\\"name\\\": \\\"Support using an NFS share for cinder image conversion\\\", \\\"vars\\\": {\\\"image_conversion_nfs_enabled\\\": {\\\"if\\\": [\\\"cinder_nfs_conversion_dir_enabled\\\", true, false]}}, \\\"when\\\": [\\\"image_conversion_nfs_enabled|bool\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Create cinder image conversion directory\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/cinder_image_conversion\\\", \\\"state\\\": \\\"directory\\\"}}, {\\\"name\\\": \\\"Mount cinder\'s image conversion NFS share\\\", \\\"vars\\\": {\\\"image_conversion_nfs_share\\\": {\\\"get_param\\\": \\\"CinderImageConversionNfsShare\\\"}, \\\"image_conversion_nfs_options\\\": {\\\"get_param\\\": \\\"CinderImageConversionNfsOptions\\\"}}, \\\"mount\\\": {\\\"path\\\": \\\"/var/lib/cinder_image_conversion\\\", \\\"state\\\": \\\"mounted\\\", \\\"fstype\\\": \\\"nfs4\\\", \\\"src\\\": \\\"{{ image_conversion_nfs_share }}\\\", \\\"opts\\\": \\\"{{ image_conversion_nfs_options }}\\\"}}]}]}, \\\"cinder_volume_host_prep_tasks\\\": {\\\"description\\\": \\\"Host prep tasks for the cinder-volume service (HA or non-HA)\\\", \\\"value\\\": {\\\"list_concat\\\": [{\\\"list_concat\\\": [[{\\\"name\\\": \\\"create fcontext entry for cinder data\\\", \\\"community.general.sefcontext\\\": {\\\"target\\\": \\\"/var/lib/cinder(/.*)?\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"state\\\": \\\"present\\\"}}, {\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode|default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/cinder\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/lib/cinder\\\", \\\"setype\\\": \\\"container_file_t\\\"}]}, {\\\"name\\\": \\\"ensure ceph configurations exist\\\", \\\"file\\\": {\\\"path\\\": {\\\"get_param\\\": \\\"CephConfigPath\\\"}, \\\"state\\\": \\\"directory\\\"}}], {\\\"get_attr\\\": [\\\"CinderNVMeOF\\\", \\\"cinder_nvmeof_host_prep_tasks\\\"]}]}, [{\\\"name\\\": \\\"Support using an NFS share for cinder image conversion\\\", \\\"vars\\\": {\\\"image_conversion_nfs_enabled\\\": {\\\"if\\\": [\\\"cinder_nfs_conversion_dir_enabled\\\", true, false]}}, \\\"when\\\": [\\\"image_conversion_nfs_enabled|bool\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Create cinder image conversion directory\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/cinder_image_conversion\\\", \\\"state\\\": \\\"directory\\\"}}, {\\\"name\\\": \\\"Mount cinder\'s image conversion NFS share\\\", \\\"vars\\\": {\\\"image_conversion_nfs_share\\\": {\\\"get_param\\\": \\\"CinderImageConversionNfsShare\\\"}, \\\"image_conversion_nfs_options\\\": {\\\"get_param\\\": \\\"CinderImageConversionNfsOptions\\\"}}, \\\"mount\\\": {\\\"path\\\": \\\"/var/lib/cinder_image_conversion\\\", \\\"state\\\": \\\"mounted\\\", \\\"fstype\\\": \\\"nfs4\\\", \\\"src\\\": \\\"{{ image_conversion_nfs_share }}\\\", \\\"opts\\\": \\\"{{ image_conversion_nfs_options }}\\\"}}]}], [{\\\"name\\\": \\\"cinder_configure_lvm fact\\\", \\\"set_fact\\\": {\\\"cinder_configure_lvm\\\": {\\\"if\\\": [\\\"cinder_configure_lvm\\\", true, false]}}}, {\\\"when\\\": \\\"cinder_configure_lvm|bool\\\", \\\"block\\\": [{\\\"name\\\": \\\"ensure LVM rpm dependencies are installed\\\", \\\"package\\\": {\\\"name\\\": \\\"lvm2\\\", \\\"state\\\": \\\"latest\\\"}}, {\\\"name\\\": \\\"cinder create LVM volume group dd\\\", \\\"command\\\": {\\\"list_join\\\": [\\\"\\\", [\\\"dd if=/dev/zero of=/var/lib/cinder/cinder-volumes bs=1 count=0 seek=\\\", {\\\"str_replace\\\": {\\\"template\\\": \\\"VALUE\\\", \\\"params\\\": {\\\"VALUE\\\": {\\\"get_param\\\": \\\"CinderLVMLoopDeviceSize\\\"}}}}, \\\"M\\\"]]}, \\\"args\\\": {\\\"creates\\\": \\\"/var/lib/cinder/cinder-volumes\\\"}}, {\\\"name\\\": \\\"Get or create LVM loopback device\\\", \\\"shell\\\": \\\"exit_code=0\\\\nexisting_device=$(losetup -j /var/lib/cinder/cinder-volumes -l -n -O NAME)\\\\nif [[ -z \\\\\\\"${existing_device}\\\\\\\" ]]; then\\\\n    losetup -f /var/lib/cinder/cinder-volumes --show\\\\n    exit_code=2\\\\nelse\\\\n    echo ${existing_device%$\'\\\\\\\\n\'*}\\\\nfi\\\\nexit ${exit_code}\\\", \\\"args\\\": {\\\"executable\\\": \\\"/bin/bash\\\"}, \\\"register\\\": \\\"_loopback_device\\\", \\\"changed_when\\\": \\\"_loopback_device.rc == 2\\\", \\\"failed_when\\\": \\\"_loopback_device.rc not in [0,2]\\\"}, {\\\"name\\\": \\\"Create LVM volume group\\\", \\\"community.general.lvg\\\": {\\\"vg\\\": \\\"cinder-volumes\\\", \\\"pvs\\\": \\\"{{ _loopback_device.stdout }}\\\", \\\"state\\\": \\\"present\\\"}, \\\"when\\\": [\\\"not (ansible_check_mode | bool)\\\"]}, {\\\"name\\\": \\\"cinder create service to run losetup for LVM on startup\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/cinder-lvm-losetup.service\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Cinder LVM losetup\\\\nDefaultDependencies=no\\\\nConflicts=umount.target\\\\nRequires=lvm2-monitor.service systemd-udev-settle.service\\\\nBefore=local-fs.target umount.target\\\\nAfter=var.mount lvm2-monitor.service systemd-udev-settle.service\\\\n\\\\n[Service]\\\\nType=oneshot\\\\nExecStart=/sbin/losetup {{ _loopback_device.stdout }} /var/lib/cinder/cinder-volumes\\\\nExecStop=/sbin/losetup -d {{ _loopback_device.stdout }}\\\\nRemainAfterExit=yes\\\\n\\\\n[Install]\\\\nWantedBy=local-fs-pre.target\\\\n\\\"}, \\\"when\\\": [\\\"not (ansible_check_mode | bool)\\\"]}, {\\\"name\\\": \\\"cinder enable the LVM losetup service\\\", \\\"systemd\\\": {\\\"name\\\": \\\"cinder-lvm-losetup\\\", \\\"enabled\\\": true, \\\"daemon_reload\\\": true}}]}]]}}, \\\"cinder_volume_upgrade_tasks\\\": {\\\"description\\\": \\\"Upgrade tasks for the cinder-volume service (HA or non-HA)\\\", \\\"value\\\": [{\\\"name\\\": \\\"cinder-volume pre system_upgrade tasks\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_run\\\", \\\"system_upgrade_nfsmounts\\\"], \\\"when\\\": [\\\"step|int == 3\\\", \\\"upgrade_leapp_enabled\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Unmount cinder\'s image conversion NFS share\\\", \\\"vars\\\": {\\\"image_conversion_nfs_share\\\": {\\\"get_param\\\": \\\"CinderImageConversionNfsShare\\\"}, \\\"image_conversion_nfs_options\\\": {\\\"get_param\\\": \\\"CinderImageConversionNfsOptions\\\"}, \\\"image_conversion_nfs_enabled\\\": {\\\"if\\\": [\\\"cinder_nfs_conversion_dir_enabled\\\", true, false]}}, \\\"when\\\": \\\"image_conversion_nfs_enabled|bool\\\", \\\"mount\\\": {\\\"path\\\": \\\"/var/lib/cinder_image_conversion\\\", \\\"state\\\": \\\"absent\\\", \\\"fstype\\\": \\\"nfs4\\\"}}]}, {\\\"name\\\": \\\"cinder-volume post system_upgrade tasks\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_run\\\", \\\"system_upgrade_nfsmounts\\\"], \\\"when\\\": [\\\"step|int == 5\\\", \\\"upgrade_leapp_enabled\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Support using an NFS share for cinder image conversion\\\", \\\"vars\\\": {\\\"image_conversion_nfs_enabled\\\": {\\\"if\\\": [\\\"cinder_nfs_conversion_dir_enabled\\\", true, false]}}, \\\"when\\\": [\\\"image_conversion_nfs_enabled|bool\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Create cinder image conversion directory\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/cinder_image_conversion\\\", \\\"state\\\": \\\"directory\\\"}}, {\\\"name\\\": \\\"Mount cinder\'s image conversion NFS share\\\", \\\"vars\\\": {\\\"image_conversion_nfs_share\\\": {\\\"get_param\\\": \\\"CinderImageConversionNfsShare\\\"}, \\\"image_conversion_nfs_options\\\": {\\\"get_param\\\": \\\"CinderImageConversionNfsOptions\\\"}}, \\\"mount\\\": {\\\"path\\\": \\\"/var/lib/cinder_image_conversion\\\", \\\"state\\\": \\\"mounted\\\", \\\"fstype\\\": \\\"nfs4\\\", \\\"src\\\": \\\"{{ image_conversion_nfs_share }}\\\", \\\"opts\\\": \\\"{{ image_conversion_nfs_options }}\\\"}}]}]}]}, \\\"cinder_volume_config_settings\\\": {\\\"description\\\": \\\"Config settings for the cinder-volume container (HA or non-HA)\\\", \\\"value\\\": {\\\"if\\\": [\\\"cinder_nfs_conversion_dir_enabled\\\", {\\\"cinder::image_conversion_dir\\\": \\\"/var/lib/cinder_image_conversion\\\"}, {}]}}, \\\"cinder_volume_volumes\\\": {\\\"description\\\": \\\"Volumes for the cinder-volume container (HA or non-HA)\\\", \\\"value\\\": {\\\"list_concat\\\": [{\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/log/containers/cinder:/var/log/cinder:z\\\"], {\\\"if\\\": [\\\"cvol_active_active_tls_enabled\\\", [\\\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\\\", \\\"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\\\"]]}]}, {\\\"get_attr\\\": [\\\"CinderNVMeOF\\\", \\\"cinder_nvmeof_volumes\\\"]}, {\\\"get_param\\\": \\\"CinderVolumeOptVolumes\\\"}, [\\\"/var/lib/kolla/config_files/cinder_volume.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\\\", {\\\"list_join\\\": [\\\":\\\", [{\\\"get_param\\\": \\\"CephConfigPath\\\"}], [\\\"/var/lib/kolla/config_files/src-ceph\\\"], [\\\"z\\\"]]}, \\\"/lib/modules:/lib/modules:ro\\\", \\\"/dev:/dev\\\", \\\"/run:/run\\\", \\\"/sys:/sys\\\", \\\"/var/lib/cinder:/var/lib/cinder:z\\\", \\\"/var/lib/iscsi:/var/lib/iscsi:z\\\"], {\\\"if\\\": [{\\\"get_param\\\": \\\"CinderEnableIscsiBackend\\\"}, [\\\"/etc/target:/etc/target:z\\\"]]}, {\\\"if\\\": [{\\\"get_param\\\": \\\"MultipathdEnable\\\"}, [\\\"/etc/multipath:/etc/multipath:z\\\", \\\"/etc/multipath.conf:/etc/multipath.conf:ro\\\"]]}, {\\\"if\\\": [\\\"cinder_nfs_conversion_dir_enabled\\\", [{\\\"str_replace\\\": {\\\"template\\\": \\\"DIR:DIR:slave\\\", \\\"params\\\": {\\\"DIR\\\": \\\"/var/lib/cinder_image_conversion\\\"}}}]]}]}}, \\\"cinder_volume_environment\\\": {\\\"description\\\": \\\"Docker environment for the cinder-volume container (HA or non-HA)\\\", \\\"value\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"CinderVolumeOptEnvVars\\\"}, {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}]}}, \\\"cinder_backup_host_prep_tasks\\\": {\\\"description\\\": \\\"Host prep tasks for the cinder-backup service (HA or non-HA)\\\", \\\"value\\\": {\\\"list_concat\\\": [[{\\\"name\\\": \\\"create fcontext entry for cinder data\\\", \\\"community.general.sefcontext\\\": {\\\"target\\\": \\\"/var/lib/cinder(/.*)?\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"state\\\": \\\"present\\\"}}, {\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode|default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/cinder\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/lib/cinder\\\", \\\"setype\\\": \\\"container_file_t\\\"}]}, {\\\"name\\\": \\\"ensure ceph configurations exist\\\", \\\"file\\\": {\\\"path\\\": {\\\"get_param\\\": \\\"CephConfigPath\\\"}, \\\"state\\\": \\\"directory\\\"}}], {\\\"get_attr\\\": [\\\"CinderNVMeOF\\\", \\\"cinder_nvmeof_host_prep_tasks\\\"]}]}}, \\\"cinder_backup_volumes\\\": {\\\"description\\\": \\\"Volumes for the cinder-backup container (HA or non-HA)\\\", \\\"value\\\": {\\\"list_concat\\\": [{\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/log/containers/cinder:/var/log/cinder:z\\\"], {\\\"if\\\": [\\\"cvol_active_active_tls_enabled\\\", [\\\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\\\", \\\"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\\\"]]}]}, {\\\"get_attr\\\": [\\\"CinderNVMeOF\\\", \\\"cinder_nvmeof_volumes\\\"]}, {\\\"get_param\\\": \\\"CinderBackupOptVolumes\\\"}, [\\\"/var/lib/kolla/config_files/cinder_backup.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\\\", {\\\"list_join\\\": [\\\":\\\", [{\\\"get_param\\\": \\\"CephConfigPath\\\"}], [\\\"/var/lib/kolla/config_files/src-ceph\\\"], [\\\"z\\\"]]}, \\\"/dev:/dev\\\", \\\"/run:/run\\\", \\\"/sys:/sys\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/var/lib/cinder:/var/lib/cinder:z\\\", \\\"/var/lib/iscsi:/var/lib/iscsi:z\\\"], {\\\"if\\\": [{\\\"get_param\\\": \\\"MultipathdEnable\\\"}, [\\\"/etc/multipath:/etc/multipath:z\\\", \\\"/etc/multipath.conf:/etc/multipath.conf:ro\\\"]]}]}}, \\\"cinder_backup_environment\\\": {\\\"description\\\": \\\"Docker environment for the cinder-backup container (HA or non-HA)\\\", \\\"value\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Cinder API service\\\\n\\\", \\\"parameters\\\": {\\\"ContainerCinderApiImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerCinderConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the cinder config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"CinderApiLoggingSource\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {\\\"tag\\\": \\\"openstack.cinder.api\\\", \\\"file\\\": \\\"/var/log/containers/cinder/cinder-api.log\\\"}}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"DeployIdentifier\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\\\n\\\"}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"CinderDefaultVolumeType\\\": {\\\"default\\\": \\\"tripleo\\\", \\\"description\\\": \\\"The name of Cinder\'s default volume type.\\\", \\\"type\\\": \\\"string\\\", \\\"constraints\\\": [{\\\"allowed_pattern\\\": \\\".*\\\\\\\\S.*\\\", \\\"description\\\": \\\"The default volume type name cannot be empty.\\\\n\\\"}]}, \\\"CinderEnableDBPurge\\\": {\\\"default\\\": true, \\\"description\\\": \\\"Whether to create cron job for purging soft deleted rows in Cinder database.\\\\n\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"CinderPassword\\\": {\\\"description\\\": \\\"The password for the cinder service and db account.\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"KeystoneRegion\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"regionOne\\\", \\\"description\\\": \\\"Keystone region for endpoint\\\"}, \\\"MonitoringSubscriptionCinderApi\\\": {\\\"default\\\": \\\"overcloud-cinder-api\\\", \\\"type\\\": \\\"string\\\"}, \\\"CinderWorkers\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Set the number of workers for cinder::wsgi::apache\\\", \\\"default\\\": \\\"%{::os_workers}\\\"}, \\\"CinderApiPolicies\\\": {\\\"description\\\": \\\"A hash of policies to configure for Cinder API.\\\\ne.g. { cinder-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\\\n\\\", \\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}, \\\"CinderApiWsgiTimeout\\\": {\\\"default\\\": 60, \\\"description\\\": \\\"The number of seconds until a Cinder API WSGI connection times out.\\\", \\\"type\\\": \\\"number\\\"}, \\\"NotificationDriver\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": \\\"noop\\\", \\\"description\\\": \\\"Driver or drivers to handle sending notifications.\\\"}, \\\"RootStackName\\\": {\\\"description\\\": \\\"The name of the stack/plan.\\\", \\\"type\\\": \\\"string\\\"}, \\\"MemcacheUseAdvancedPool\\\": {\\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"Use the advanced (eventlet safe) memcached client pool.\\\\n\\\", \\\"default\\\": true}, \\\"AuthCloudName\\\": {\\\"description\\\": \\\"Entry in clouds.yaml to use for authentication\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\"}}, \\\"conditions\\\": {\\\"auth_cloud_name_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"AuthCloudName\\\"}, \\\"\\\"]}}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"MySQLClient\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\\\"}, \\\"CinderBase\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-base.yaml\\\", \\\"properties\\\": {\\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"CinderCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\\\"}, \\\"ApacheServiceBase\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}, \\\"EnableInternalTLS\\\": {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}}}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerCinderApiImage\\\": \\\"ContainerCinderApiImage\\\", \\\"ContainerCinderConfigImage\\\": \\\"ContainerCinderConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerCinderApiImage\\\": {\\\"get_param\\\": \\\"ContainerCinderApiImage\\\"}, \\\"ContainerCinderConfigImage\\\": {\\\"get_param\\\": \\\"ContainerCinderConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Cinder API role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"cinder_api\\\", \\\"firewall_rules\\\": {\\\"119 cinder\\\": {\\\"dport\\\": [8776]}}, \\\"firewall_frontend_rules\\\": {\\\"100 cinder_haproxy_frontend\\\": {\\\"dport\\\": [8776]}}, \\\"firewall_ssl_frontend_rules\\\": {\\\"100 cinder_haproxy_frontend_ssl\\\": {\\\"dport\\\": [13776]}}, \\\"keystone_resources\\\": {\\\"cinder\\\": {\\\"users\\\": {\\\"cinder\\\": {\\\"password\\\": {\\\"get_param\\\": \\\"CinderPassword\\\"}, \\\"roles\\\": [\\\"admin\\\", \\\"service\\\"]}}}, \\\"cinderv3\\\": {\\\"endpoints\\\": {\\\"public\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderV3Public\\\", \\\"uri\\\"]}, \\\"internal\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderV3Internal\\\", \\\"uri\\\"]}, \\\"admin\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"CinderV3Admin\\\", \\\"uri\\\"]}}, \\\"users\\\": {\\\"cinderv3\\\": {\\\"password\\\": {\\\"get_param\\\": \\\"CinderPassword\\\"}, \\\"roles\\\": [\\\"admin\\\", \\\"service\\\"]}}, \\\"region\\\": {\\\"get_param\\\": \\\"KeystoneRegion\\\"}, \\\"service\\\": \\\"volumev3\\\"}}, \\\"monitoring_subscription\\\": {\\\"get_param\\\": \\\"MonitoringSubscriptionCinderApi\\\"}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"CinderBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"get_attr\\\": [\\\"ApacheServiceBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"keystone_resources_managed\\\": false}, {\\\"cinder::keystone::authtoken::www_authenticate_uri\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystonePublic\\\", \\\"uri_no_suffix\\\"]}, \\\"cinder::keystone::authtoken::auth_url\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"uri_no_suffix\\\"]}, \\\"cinder::keystone::authtoken::password\\\": {\\\"get_param\\\": \\\"CinderPassword\\\"}, \\\"cinder::keystone::authtoken::project_name\\\": \\\"service\\\", \\\"cinder::keystone::authtoken::user_domain_name\\\": \\\"Default\\\", \\\"cinder::keystone::authtoken::project_domain_name\\\": \\\"Default\\\", \\\"cinder::keystone::authtoken::region_name\\\": {\\\"get_param\\\": \\\"KeystoneRegion\\\"}, \\\"cinder::keystone::authtoken::interface\\\": \\\"internal\\\", \\\"cinder::keystone::authtoken::memcache_use_advanced_pool\\\": {\\\"get_param\\\": \\\"MemcacheUseAdvancedPool\\\"}, \\\"cinder::policy::policies\\\": {\\\"get_param\\\": \\\"CinderApiPolicies\\\"}, \\\"cinder::notification_driver\\\": {\\\"get_param\\\": \\\"NotificationDriver\\\"}, \\\"cinder::api::default_volume_type\\\": {\\\"get_param\\\": \\\"CinderDefaultVolumeType\\\"}, \\\"cinder::api::enable_proxy_headers_parsing\\\": true, \\\"tripleo::profile::base::cinder::cinder_enable_db_purge\\\": {\\\"get_param\\\": \\\"CinderEnableDBPurge\\\"}, \\\"cinder::api::bind_host\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'fqdn_$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}}}}, \\\"cinder::wsgi::apache::ssl\\\": {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, \\\"cinder::api::service_name\\\": \\\"httpd\\\", \\\"cinder::wsgi::apache::bind_host\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}}}}, \\\"cinder::wsgi::apache::servername\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'fqdn_$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderApiNetwork\\\"]}}}}, \\\"cinder::wsgi::apache::vhost_custom_fragment\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"Timeout TIMEOUT\\\", \\\"params\\\": {\\\"TIMEOUT\\\": {\\\"get_param\\\": \\\"CinderApiWsgiTimeout\\\"}}}}, \\\"cinder::wsgi::apache::workers\\\": {\\\"get_param\\\": \\\"CinderWorkers\\\"}}]}, \\\"service_config_settings\\\": {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_cinder_api\\\": [{\\\"get_param\\\": \\\"CinderApiLoggingSource\\\"}]}, \\\"mysql\\\": {\\\"cinder::db::mysql::password\\\": {\\\"get_param\\\": \\\"CinderPassword\\\"}, \\\"cinder::db::mysql::user\\\": \\\"cinder\\\", \\\"cinder::db::mysql::host\\\": \\\"%\\\", \\\"cinder::db::mysql::dbname\\\": \\\"cinder\\\"}}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"cinder\\\", \\\"puppet_tags\\\": \\\"cinder_config,file,concat,file_line,cinder_api_paste_ini\\\", \\\"step_config\\\": {\\\"list_join\\\": [\\\"\\\\n\\\", [\\\"include tripleo::profile::base::cinder::api\\\", {\\\"get_attr\\\": [\\\"MySQLClient\\\", \\\"role_data\\\", \\\"step_config\\\"]}]]}, \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/cinder_api.json\\\": {\\\"command\\\": \\\"/usr/sbin/httpd -DFOREGROUND\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/etc/httpd/conf.d\\\", \\\"dest\\\": \\\"/etc/httpd/conf.d\\\", \\\"merge\\\": false, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\\\", \\\"dest\\\": \\\"/etc/httpd/conf.modules.d\\\", \\\"merge\\\": false, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-tls/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true, \\\"optional\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/cinder\\\", \\\"owner\\\": \\\"cinder:cinder\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/certs/etcd.crt\\\", \\\"owner\\\": \\\"cinder:cinder\\\"}, {\\\"path\\\": \\\"/etc/pki/tls/private/etcd.key\\\", \\\"owner\\\": \\\"cinder:cinder\\\"}]}, \\\"/var/lib/kolla/config_files/cinder_api_db_sync.json\\\": {\\\"command\\\": \\\"/usr/bin/bootstrap_host_exec cinder_api su cinder -s /bin/bash -c \'cinder-manage db sync --bump-versions\'\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/etc/httpd/conf.d\\\", \\\"dest\\\": \\\"/etc/httpd/conf.d\\\", \\\"merge\\\": false, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\\\", \\\"dest\\\": \\\"/etc/httpd/conf.modules.d\\\", \\\"merge\\\": false, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-tls/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true, \\\"optional\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/cinder\\\", \\\"owner\\\": \\\"cinder:cinder\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/certs/etcd.crt\\\", \\\"owner\\\": \\\"cinder:cinder\\\"}, {\\\"path\\\": \\\"/etc/pki/tls/private/etcd.key\\\", \\\"owner\\\": \\\"cinder:cinder\\\"}]}, \\\"/var/lib/kolla/config_files/cinder_api_cron.json\\\": {\\\"command\\\": \\\"/usr/sbin/crond -n\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/cinder\\\", \\\"owner\\\": \\\"cinder:cinder\\\", \\\"recurse\\\": true}]}}, \\\"docker_config\\\": {\\\"step_2\\\": {\\\"cinder_api_init_logs\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderApiImage\\\"]}, \\\"net\\\": \\\"none\\\", \\\"privileged\\\": false, \\\"user\\\": \\\"root\\\", \\\"volumes\\\": [\\\"/var/log/containers/cinder:/var/log/cinder:z\\\", \\\"/var/log/containers/httpd/cinder-api:/var/log/httpd:z\\\"], \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R cinder:cinder /var/log/cinder\\\"]}}, \\\"step_3\\\": {\\\"cinder_api_db_sync\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderApiImage\\\"]}, \\\"cap_add\\\": [\\\"AUDIT_WRITE\\\"], \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"detach\\\": false, \\\"user\\\": \\\"root\\\", \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/cinder_api_db_sync.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/log/containers/cinder:/var/log/cinder:z\\\"], {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, [\\\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\\\", \\\"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\\\"]]}]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\", \\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}}}}, \\\"step_4\\\": {\\\"cinder_api\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderApiImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"restart\\\": \\\"always\\\", \\\"user\\\": \\\"root\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/cinder_api.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/log/containers/cinder:/var/log/cinder:z\\\", \\\"/var/log/containers/httpd/cinder-api:/var/log/httpd:z\\\"], {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, [\\\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\\\", \\\"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\\\"]]}]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}, \\\"cinder_api_cron\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderApiImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"user\\\": \\\"root\\\", \\\"privileged\\\": false, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/usr/share/openstack-tripleo-common/healthcheck/cron cinder\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/cinder_api_cron.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/log/containers/cinder:/var/log/cinder:z\\\", \\\"/var/log/containers/httpd/cinder-api:/var/log/httpd:z\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"metadata_settings\\\": {\\\"get_attr\\\": [\\\"ApacheServiceBase\\\", \\\"role_data\\\", \\\"metadata_settings\\\"]}, \\\"deploy_steps_tasks\\\": {\\\"get_attr\\\": [\\\"ApacheServiceBase\\\", \\\"role_data\\\", \\\"deploy_steps_tasks\\\"]}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode|default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/cinder\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/log/containers/httpd/cinder-api\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}], \\\"external_upgrade_tasks\\\": [{\\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Online data migration for Cinder\\\", \\\"command\\\": \\\"{{ container_cli }} exec cinder_api cinder-manage db online_data_migrations\\\", \\\"delegate_to\\\": \\\"{{ (groups[\'cinder_api\'] | difference(groups[\'excluded_overcloud\']))[0] }}\\\", \\\"become\\\": true, \\\"tags\\\": [\\\"online_upgrade\\\", \\\"online_upgrade_cinder\\\"]}]}, {\\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade_transfer_data\\\", \\\"system_upgrade_stop_services\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Stop cinder api container\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_stop\\\"}, \\\"vars\\\": {\\\"tripleo_containers_to_stop\\\": [\\\"cinder_api\\\", \\\"cinder_api_cron\\\"], \\\"tripleo_delegate_to\\\": \\\"{{ groups[\'cinder_api\'] | difference(groups[\'excluded_overcloud\']) }}\\\"}}]}], \\\"external_update_tasks\\\": [{\\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Online data migration for Cinder\\\", \\\"command\\\": \\\"{{ container_cli }} exec cinder_api cinder-manage db online_data_migrations\\\", \\\"delegate_to\\\": \\\"{{ (groups[\'cinder_api\'] | difference(groups[\'excluded_overcloud\']))[0] }}\\\", \\\"become\\\": true, \\\"tags\\\": [\\\"online_upgrade\\\", \\\"online_upgrade_cinder\\\"]}]}], \\\"external_deploy_tasks\\\": [{\\\"name\\\": \\\"Clean up legacy Cinder keystone catalog entries\\\", \\\"become\\\": true, \\\"openstack.cloud.catalog_service\\\": {\\\"cloud\\\": {\\\"if\\\": [\\\"auth_cloud_name_set\\\", {\\\"get_param\\\": \\\"AuthCloudName\\\"}, {\\\"get_param\\\": \\\"RootStackName\\\"}]}, \\\"name\\\": \\\"{{ item.service_name }}\\\", \\\"service_type\\\": \\\"{{ item.service_type }}\\\", \\\"state\\\": \\\"absent\\\"}, \\\"loop\\\": [{\\\"service_name\\\": \\\"cinderv2\\\", \\\"service_type\\\": \\\"volumev2\\\"}, {\\\"service_name\\\": \\\"cinderv3\\\", \\\"service_type\\\": \\\"volume\\\"}], \\\"loop_control\\\": {\\\"index_var\\\": \\\"cinder_api_service\\\"}, \\\"when\\\": [\\\"step|int == 4\\\", \\\"not ansible_check_mode|bool\\\"]}, {\\\"name\\\": \\\"Manage Cinder\'s default volume type\\\", \\\"become\\\": true, \\\"vars\\\": {\\\"default_volume_type\\\": {\\\"get_param\\\": \\\"CinderDefaultVolumeType\\\"}}, \\\"environment\\\": {\\\"OS_CLOUD\\\": {\\\"if\\\": [\\\"auth_cloud_name_set\\\", {\\\"get_param\\\": \\\"AuthCloudName\\\"}, {\\\"get_param\\\": \\\"RootStackName\\\"}]}}, \\\"when\\\": [\\\"step|int == 5\\\", \\\"not ansible_check_mode|bool\\\"], \\\"shell\\\": \\\"if ! openstack volume type show \\\\\\\"{{ default_volume_type }}\\\\\\\"; then\\\\n    openstack volume type create --public \\\\\\\"{{ default_volume_type }}\\\\\\\"\\\\nfi\\\\neval $(openstack volume type show __DEFAULT__ -f shell -c id -c description)\\\\nif [ -n \\\\\\\"$id\\\\\\\" ]; then\\\\n    if ! openstack volume type delete $id ; then\\\\n        tripleo_descr=\\\\\\\"For internal use, \'{{ default_volume_type }}\' is the default volume type\\\\\\\"\\\\n        if [ \\\\\\\"$description\\\\\\\" != \\\\\\\"$tripleo_descr\\\\\\\" ]; then\\\\n            openstack volume type set $id --description \\\\\\\"$tripleo_descr\\\\\\\"\\\\n        fi\\\\n    fi\\\\nfi\\\\n\\\", \\\"args\\\": {\\\"executable\\\": \\\"/bin/bash\\\"}, \\\"changed_when\\\": false}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Cinder Scheduler service\\\\n\\\", \\\"parameters\\\": {\\\"ContainerCinderSchedulerImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerCinderConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the cinder config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"CinderSchedulerLoggingSource\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {\\\"tag\\\": \\\"openstack.cinder.scheduler\\\", \\\"file\\\": \\\"/var/log/containers/cinder/cinder-scheduler.log\\\"}}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"MonitoringSubscriptionCinderScheduler\\\": {\\\"default\\\": \\\"overcloud-cinder-scheduler\\\", \\\"type\\\": \\\"string\\\"}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"MySQLClient\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\\\"}, \\\"CinderBase\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-base.yaml\\\", \\\"properties\\\": {\\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"CinderCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\\\"}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerCinderSchedulerImage\\\": \\\"ContainerCinderSchedulerImage\\\", \\\"ContainerCinderConfigImage\\\": \\\"ContainerCinderConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerCinderSchedulerImage\\\": {\\\"get_param\\\": \\\"ContainerCinderSchedulerImage\\\"}, \\\"ContainerCinderConfigImage\\\": {\\\"get_param\\\": \\\"ContainerCinderConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Cinder Scheduler role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"cinder_scheduler\\\", \\\"monitoring_subscription\\\": {\\\"get_param\\\": \\\"MonitoringSubscriptionCinderScheduler\\\"}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"CinderBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"cinder::scheduler::scheduler_driver\\\": \\\"cinder.scheduler.filter_scheduler.FilterScheduler\\\"}]}, \\\"service_config_settings\\\": {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_cinder_scheduler\\\": [{\\\"get_param\\\": \\\"CinderSchedulerLoggingSource\\\"}]}}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"cinder\\\", \\\"puppet_tags\\\": \\\"cinder_config,file,concat,file_line\\\", \\\"step_config\\\": {\\\"list_join\\\": [\\\"\\\\n\\\", [\\\"include tripleo::profile::base::cinder::scheduler\\\"], [{\\\"get_attr\\\": [\\\"CinderBase\\\", \\\"role_data\\\", \\\"step_config\\\"]}, {\\\"get_attr\\\": [\\\"MySQLClient\\\", \\\"role_data\\\", \\\"step_config\\\"]}]]}, \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/cinder_scheduler.json\\\": {\\\"command\\\": \\\"/usr/bin/cinder-scheduler --config-file /usr/share/cinder/cinder-dist.conf --config-file /etc/cinder/cinder.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-tls/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true, \\\"optional\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/cinder\\\", \\\"owner\\\": \\\"cinder:cinder\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/certs/etcd.crt\\\", \\\"owner\\\": \\\"cinder:cinder\\\"}, {\\\"path\\\": \\\"/etc/pki/tls/private/etcd.key\\\", \\\"owner\\\": \\\"cinder:cinder\\\"}]}}, \\\"docker_config\\\": {\\\"step_2\\\": {\\\"cinder_scheduler_init_logs\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderSchedulerImage\\\"]}, \\\"net\\\": \\\"none\\\", \\\"privileged\\\": false, \\\"user\\\": \\\"root\\\", \\\"volumes\\\": [\\\"/var/log/containers/cinder:/var/log/cinder:z\\\"], \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R cinder:cinder /var/log/cinder\\\"]}}, \\\"step_4\\\": {\\\"cinder_scheduler\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderSchedulerImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"healthcheck_rpc_port\\\"]}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"CinderCommon\\\", \\\"cinder_common_volumes\\\"]}, [\\\"/var/lib/kolla/config_files/cinder_scheduler.json:/var/lib/kolla/config_files/config.json:ro\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/cinder\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}, {\\\"name\\\": \\\"enable virt_sandbox_use_netlink for healthcheck\\\", \\\"seboolean\\\": {\\\"name\\\": \\\"virt_sandbox_use_netlink\\\", \\\"persistent\\\": true, \\\"state\\\": true}, \\\"when\\\": [\\\"ansible_facts.selinux is defined\\\", \\\"ansible_facts.selinux.status == \\\\\\\"enabled\\\\\\\"\\\"]}], \\\"external_upgrade_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade_transfer_data\\\", \\\"system_upgrade_stop_services\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Stop cinder scheduler container\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_stop\\\"}, \\\"vars\\\": {\\\"tripleo_containers_to_stop\\\": [\\\"cinder_scheduler\\\"], \\\"tripleo_delegate_to\\\": \\\"{{ groups[\'cinder_scheduler\'] | difference(groups[\'excluded_overcloud\']) }}\\\"}}]}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Cinder Volume service\\\\n\\\", \\\"parameters\\\": {\\\"ContainerCinderVolumeImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerCinderConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the cinder config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"DockerCinderVolumeUlimit\\\": {\\\"default\\\": [\\\"nofile=131072\\\"], \\\"description\\\": \\\"ulimit for Cinder Volume Container\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"CinderVolumeLoggingSource\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {\\\"tag\\\": \\\"openstack.cinder.volume\\\", \\\"file\\\": \\\"/var/log/containers/cinder/cinder-volume.log\\\"}}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"CephClientUserName\\\": {\\\"default\\\": \\\"openstack\\\", \\\"type\\\": \\\"string\\\"}, \\\"CephClusterName\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"ceph\\\", \\\"description\\\": \\\"The Ceph cluster name.\\\", \\\"constraints\\\": [{\\\"allowed_pattern\\\": \\\"[a-zA-Z0-9]+\\\", \\\"description\\\": \\\"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\\\n\\\"}]}, \\\"CinderVolumeCluster\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"CinderEnableNfsBackend\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to enable or not the NFS backend for Cinder\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"CinderEnableIscsiBackend\\\": {\\\"default\\\": true, \\\"description\\\": \\\"Whether to enable or not the Iscsi backend for Cinder\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"CinderEnableRbdBackend\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to enable or not the Rbd backend for Cinder\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"CinderISCSIAvailabilityZone\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The availability zone of the Iscsi Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"CinderISCSIHelper\\\": {\\\"default\\\": \\\"lioadm\\\", \\\"description\\\": \\\"The iSCSI helper to use with cinder.\\\", \\\"type\\\": \\\"string\\\"}, \\\"CinderISCSIProtocol\\\": {\\\"default\\\": \\\"iscsi\\\", \\\"description\\\": \\\"Whether to use TCP (\'iscsi\') or iSER RDMA (\'iser\') for iSCSI\\\", \\\"type\\\": \\\"string\\\"}, \\\"CinderNfsAvailabilityZone\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The availability zone of the NFS Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"CinderNfsMountOptions\\\": {\\\"default\\\": \\\"context=system_u:object_r:container_file_t:s0\\\", \\\"description\\\": \\\"Mount options for NFS mounts used by Cinder NFS backend. Effective when CinderEnableNfsBackend is true.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"CinderNfsServers\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"NFS servers used by Cinder NFS backend. Effective when CinderEnableNfsBackend is true.\\\\n\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"CinderNfsSnapshotSupport\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to enable support for snapshots in the NFS driver. Effective when CinderEnableNfsBackend is true.\\\\n\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"CinderNasSecureFileOperations\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Controls whether security enhanced NFS file operations are enabled. Valid values are \'auto\', \'true\' or \'false\'. Effective when CinderEnableNfsBackend is true.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"CinderNasSecureFilePermissions\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Controls whether security enhanced NFS file permissions are enabled. Valid values are \'auto\', \'true\' or \'false\'. Effective when CinderEnableNfsBackend is true.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"CinderRbdBackendName\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": \\\"tripleo_ceph\\\", \\\"description\\\": \\\"A list of Cinder RBD backend names.\\\"}, \\\"CinderRbdAvailabilityZone\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The availability zone of the RBD Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"CinderRbdPoolName\\\": {\\\"default\\\": \\\"volumes\\\", \\\"type\\\": \\\"string\\\"}, \\\"CinderRbdExtraPools\\\": {\\\"default\\\": [], \\\"description\\\": \\\"List of extra Ceph pools for use with RBD backends for Cinder. An extra Cinder RBD backend driver is created for each pool in the list. This is in addition to the standard RBD backend driver associated with the CinderRbdPoolName.\\\\n\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"CinderRbdFlattenVolumeFromSnapshot\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether RBD volumes created from a snapshot should be flattened in order to remove a dependency on the snapshot.\\\\n\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"CinderRbdMultiConfig\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {}, \\\"description\\\": \\\"Dictionary of settings when configuring multiple RBD backends. The\\\\nhash key is the backend name, and the value is a dictionary of parameter\\\\nvalues unique to that backend. The following parameters are required,\\\\nand must match the corresponding value defined in CephExternalMultiConfig.\\\\n  CephClusterName (must match the CephExternalMultiConfig entry\'s \'cluster\')\\\\n  CephClusterFSID (must match the CephExternalMultiConfig entry\'s \'fsid\')\\\\nThe following parameters are optional, and override the corresponding\\\\nparameter\'s default value.\\\\n  CephClientUserName\\\\n  CinderRbdPoolName\\\\n  CinderRbdExtraPools\\\\n  CinderRbdAvailabilityZone\\\\n  CinderRbdFlattenVolumeFromSnapshot\\\\n\\\"}, \\\"CephClusterFSID\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"The Ceph cluster FSID. Must be a UUID.\\\"}, \\\"MonitoringSubscriptionCinderVolume\\\": {\\\"default\\\": \\\"overcloud-cinder-volume\\\", \\\"type\\\": \\\"string\\\"}, \\\"CinderEtcdLocalConnect\\\": {\\\"default\\\": false, \\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"When running Cinder A/A, whether to connect to Etcd via the local IP for the Etcd network. If set to true, the ip on the local node will be used. If set to false, the VIP on the Etcd network will be used instead. Defaults to false.\\\"}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"EnableEtcdInternalTLS\\\": {\\\"description\\\": \\\"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\\\", \\\"type\\\": \\\"boolean\\\", \\\"default\\\": true}, \\\"CephConfigPath\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"/var/lib/tripleo-config/ceph\\\", \\\"description\\\": \\\"The path where the Ceph Cluster config files are stored on the host.\\\\n\\\"}}, \\\"conditions\\\": {\\\"cvol_active_active_tls_enabled\\\": {\\\"and\\\": [{\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"CinderVolumeCluster\\\"}, \\\"\\\"]}}, {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, {\\\"get_param\\\": \\\"EnableEtcdInternalTLS\\\"}]}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"MySQLClient\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\\\"}, \\\"CinderBase\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-base.yaml\\\", \\\"properties\\\": {\\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"CinderCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\\\"}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerCinderVolumeImage\\\": \\\"ContainerCinderVolumeImage\\\", \\\"ContainerCinderConfigImage\\\": \\\"ContainerCinderConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerCinderVolumeImage\\\": {\\\"get_param\\\": \\\"ContainerCinderVolumeImage\\\"}, \\\"ContainerCinderConfigImage\\\": {\\\"get_param\\\": \\\"ContainerCinderConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Cinder Volume role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"cinder_volume\\\", \\\"firewall_rules\\\": {\\\"120 iscsi initiator\\\": {\\\"dport\\\": 3260}}, \\\"monitoring_subscription\\\": {\\\"get_param\\\": \\\"MonitoringSubscriptionCinderVolume\\\"}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"CinderBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"get_attr\\\": [\\\"CinderCommon\\\", \\\"cinder_volume_config_settings\\\"]}, {\\\"tripleo::profile::base::lvm::enable_udev\\\": false, \\\"tripleo::profile::base::cinder::volume::cinder_enable_iscsi_backend\\\": {\\\"get_param\\\": \\\"CinderEnableIscsiBackend\\\"}, \\\"tripleo::profile::base::cinder::volume::cinder_enable_nfs_backend\\\": {\\\"get_param\\\": \\\"CinderEnableNfsBackend\\\"}, \\\"tripleo::profile::base::cinder::volume::cinder_enable_rbd_backend\\\": {\\\"get_param\\\": \\\"CinderEnableRbdBackend\\\"}, \\\"tripleo::profile::base::cinder::volume::cinder_volume_cluster\\\": {\\\"get_param\\\": \\\"CinderVolumeCluster\\\"}, \\\"tripleo::profile::base::cinder::volume::nfs::cinder_nfs_mount_options\\\": {\\\"get_param\\\": \\\"CinderNfsMountOptions\\\"}, \\\"tripleo::profile::base::cinder::volume::nfs::cinder_nfs_servers\\\": {\\\"get_param\\\": \\\"CinderNfsServers\\\"}, \\\"tripleo::profile::base::cinder::volume::nfs::cinder_nfs_snapshot_support\\\": {\\\"get_param\\\": \\\"CinderNfsSnapshotSupport\\\"}, \\\"tripleo::profile::base::cinder::volume::nfs::cinder_nas_secure_file_operations\\\": {\\\"get_param\\\": \\\"CinderNasSecureFileOperations\\\"}, \\\"tripleo::profile::base::cinder::volume::nfs::cinder_nas_secure_file_permissions\\\": {\\\"get_param\\\": \\\"CinderNasSecureFilePermissions\\\"}, \\\"tripleo::profile::base::cinder::volume::iscsi::cinder_iscsi_helper\\\": {\\\"get_param\\\": \\\"CinderISCSIHelper\\\"}, \\\"tripleo::profile::base::cinder::volume::iscsi::cinder_iscsi_protocol\\\": {\\\"get_param\\\": \\\"CinderISCSIProtocol\\\"}, \\\"tripleo::profile::base::cinder::volume::rbd::backend_name\\\": {\\\"get_param\\\": \\\"CinderRbdBackendName\\\"}, \\\"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_ceph_conf\\\": {\\\"list_join\\\": [\\\"\\\", [\\\"/etc/ceph/\\\", {\\\"get_param\\\": \\\"CephClusterName\\\"}, \\\".conf\\\"]]}, \\\"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_pool_name\\\": {\\\"get_param\\\": \\\"CinderRbdPoolName\\\"}, \\\"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_extra_pools\\\": {\\\"get_param\\\": \\\"CinderRbdExtraPools\\\"}, \\\"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_secret_uuid\\\": {\\\"get_param\\\": \\\"CephClusterFSID\\\"}, \\\"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_user_name\\\": {\\\"get_param\\\": \\\"CephClientUserName\\\"}, \\\"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_flatten_volume_from_snapshot\\\": {\\\"get_param\\\": \\\"CinderRbdFlattenVolumeFromSnapshot\\\"}, \\\"tripleo::profile::base::cinder::volume::rbd::multi_config\\\": {\\\"get_param\\\": \\\"CinderRbdMultiConfig\\\"}, \\\"tripleo::profile::base::cinder::volume::iscsi::cinder_iscsi_address\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderIscsiNetwork\\\"]}}}}}, {\\\"if\\\": [{\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"CinderISCSIAvailabilityZone\\\"}, \\\"\\\"]}}, {\\\"tripleo::profile::base::cinder::volume::iscsi::backend_availability_zone\\\": {\\\"get_param\\\": \\\"CinderISCSIAvailabilityZone\\\"}}]}, {\\\"if\\\": [{\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"CinderNfsAvailabilityZone\\\"}, \\\"\\\"]}}, {\\\"tripleo::profile::base::cinder::volume::nfs::backend_availability_zone\\\": {\\\"get_param\\\": \\\"CinderNfsAvailabilityZone\\\"}}]}, {\\\"if\\\": [{\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"CinderRbdAvailabilityZone\\\"}, \\\"\\\"]}}, {\\\"tripleo::profile::base::cinder::volume::rbd::backend_availability_zone\\\": {\\\"get_param\\\": \\\"CinderRbdAvailabilityZone\\\"}}]}, {\\\"if\\\": [{\\\"get_param\\\": \\\"CinderEtcdLocalConnect\\\"}, {\\\"tripleo::profile::base::cinder::volume::etcd_host\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"EtcdNetwork\\\"]}}}}}]}]}, \\\"service_config_settings\\\": {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_cinder_volume\\\": [{\\\"get_param\\\": \\\"CinderVolumeLoggingSource\\\"}]}}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"cinder\\\", \\\"puppet_tags\\\": \\\"cinder_config,file,concat,file_line\\\", \\\"step_config\\\": {\\\"list_join\\\": [\\\"\\\\n\\\", [\\\"include tripleo::profile::base::lvm\\\", \\\"include tripleo::profile::base::cinder::volume\\\", {\\\"get_attr\\\": [\\\"MySQLClient\\\", \\\"role_data\\\", \\\"step_config\\\"]}]]}, \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/cinder_volume.json\\\": {\\\"command\\\": \\\"/usr/bin/cinder-volume --config-file /usr/share/cinder/cinder-dist.conf --config-file /etc/cinder/cinder.conf\\\", \\\"config_files\\\": {\\\"get_attr\\\": [\\\"CinderCommon\\\", \\\"cinder_common_kolla_config_files\\\"]}, \\\"permissions\\\": {\\\"get_attr\\\": [\\\"CinderCommon\\\", \\\"cinder_common_kolla_permissions\\\"]}}}, \\\"docker_config\\\": {\\\"step_3\\\": {\\\"cinder_volume_init_logs\\\": {\\\"start_order\\\": 0, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderVolumeImage\\\"]}, \\\"net\\\": \\\"none\\\", \\\"privileged\\\": false, \\\"user\\\": \\\"root\\\", \\\"volumes\\\": [\\\"/var/log/containers/cinder:/var/log/cinder:z\\\"], \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R cinder:cinder /var/log/cinder\\\"]}}, \\\"step_4\\\": {\\\"cinder_volume\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderVolumeImage\\\"]}, \\\"ulimit\\\": {\\\"get_param\\\": \\\"DockerCinderVolumeUlimit\\\"}, \\\"ipc\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"healthcheck_rpc_port\\\"]}, \\\"volumes\\\": {\\\"get_attr\\\": [\\\"CinderCommon\\\", \\\"cinder_volume_volumes\\\"]}, \\\"environment\\\": {\\\"get_attr\\\": [\\\"CinderCommon\\\", \\\"cinder_volume_environment\\\"]}}}}, \\\"host_prep_tasks\\\": {\\\"get_attr\\\": [\\\"CinderCommon\\\", \\\"cinder_volume_host_prep_tasks\\\"]}, \\\"upgrade_tasks\\\": {\\\"get_attr\\\": [\\\"CinderCommon\\\", \\\"cinder_volume_upgrade_tasks\\\"]}, \\\"external_upgrade_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade_transfer_data\\\", \\\"system_upgrade_stop_services\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Stop cinder volume container\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_stop\\\"}, \\\"vars\\\": {\\\"tripleo_containers_to_stop\\\": [\\\"cinder_volume\\\"], \\\"tripleo_delegate_to\\\": \\\"{{ groups[\'cinder_volume\'] | difference(groups[\'excluded_overcloud\']) }}\\\"}}]}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Cinder Volume service\\\\n\\\", \\\"parameters\\\": {\\\"ContainerCinderVolumeImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerCinderConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the cinder config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ClusterCommonTag\\\": {\\\"default\\\": false, \\\"description\\\": \\\"When set to false, a pacemaker service is configured to use a floating tag for its container image name, e.g. \'REGISTRY/NAMESPACE/IMAGENAME:pcmklatest\'. When set to true, the service uses a floating prefix as well, e.g. \'cluster.common.tag/IMAGENAME:pcmklatest\'.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"ClusterFullTag\\\": {\\\"default\\\": true, \\\"description\\\": \\\"When set to true, the pacemaker service uses a fully constant tag for its container image name, e.g. \'cluster.common.tag/SERVICENAME:pcmklatest\'.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"ConfigDebug\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to run config management (e.g. Puppet) in debug mode.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"ContainerCli\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"podman\\\", \\\"description\\\": \\\"CLI tool used to manage containers.\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"docker\\\", \\\"podman\\\"]}]}, \\\"DeployIdentifier\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\\\n\\\"}, \\\"CinderVolumeLoggingSource\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {\\\"tag\\\": \\\"openstack.cinder.volume\\\", \\\"file\\\": \\\"/var/log/containers/cinder/cinder-volume.log\\\"}}, \\\"CephConfigPath\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"/var/lib/tripleo-config/ceph\\\", \\\"description\\\": \\\"The path where the Ceph Cluster config files are stored on the host.\\\\n\\\"}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"MySQLClient\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\\\"}, \\\"CinderBase\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\\\", \\\"properties\\\": {\\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"CinderCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\\\"}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerCinderVolumeImage\\\": \\\"ContainerCinderVolumeImage\\\", \\\"ContainerCinderConfigImage\\\": \\\"ContainerCinderConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerCinderVolumeImage\\\": {\\\"get_param\\\": \\\"ContainerCinderVolumeImage\\\"}, \\\"ContainerCinderConfigImage\\\": {\\\"get_param\\\": \\\"ContainerCinderConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Cinder Volume role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"cinder_volume\\\", \\\"firewall_rules\\\": {\\\"get_attr\\\": [\\\"CinderBase\\\", \\\"role_data\\\", \\\"firewall_rules\\\"]}, \\\"monitoring_subscription\\\": {\\\"get_attr\\\": [\\\"CinderBase\\\", \\\"role_data\\\", \\\"monitoring_subscription\\\"]}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"CinderBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"tripleo::profile::base::lvm::enable_udev\\\": false, \\\"tripleo::profile::pacemaker::cinder::volume_bundle::cinder_volume_docker_image\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/cinder-volume:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderVolumeImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderVolumeImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"tripleo::profile::pacemaker::cinder::volume_bundle::docker_volumes\\\": {\\\"get_attr\\\": [\\\"CinderCommon\\\", \\\"cinder_volume_volumes\\\"]}, \\\"tripleo::profile::pacemaker::cinder::volume_bundle::docker_environment\\\": {\\\"get_attr\\\": [\\\"CinderCommon\\\", \\\"cinder_volume_environment\\\"]}, \\\"tripleo::profile::pacemaker::cinder::volume_bundle::container_backend\\\": {\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"tripleo::profile::pacemaker::cinder::volume_bundle::ceph_conf_path\\\": {\\\"get_param\\\": \\\"CephConfigPath\\\"}, \\\"cinder::volume::manage_service\\\": false, \\\"cinder::volume::enabled\\\": false, \\\"cinder::backend_host\\\": \\\"hostgroup\\\"}]}, \\\"service_config_settings\\\": {\\\"get_attr\\\": [\\\"CinderBase\\\", \\\"role_data\\\", \\\"service_config_settings\\\"]}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"cinder\\\", \\\"puppet_tags\\\": \\\"cinder_config,file,concat,file_line\\\", \\\"step_config\\\": {\\\"list_join\\\": [\\\"\\\\n\\\", [\\\"include tripleo::profile::base::lvm\\\"], [\\\"include tripleo::profile::pacemaker::cinder::volume_bundle\\\", {\\\"get_attr\\\": [\\\"MySQLClient\\\", \\\"role_data\\\", \\\"step_config\\\"]}]]}, \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/cinder_volume.json\\\": {\\\"command\\\": \\\"/usr/bin/cinder-volume --config-file /usr/share/cinder/cinder-dist.conf --config-file /etc/cinder/cinder.conf\\\", \\\"config_files\\\": {\\\"get_attr\\\": [\\\"CinderCommon\\\", \\\"cinder_common_kolla_config_files\\\"]}, \\\"permissions\\\": {\\\"get_attr\\\": [\\\"CinderCommon\\\", \\\"cinder_common_kolla_permissions\\\"]}}}, \\\"container_config_scripts\\\": {\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"container_config_scripts\\\"]}, \\\"docker_config\\\": {\\\"step_3\\\": {\\\"cinder_volume_init_logs\\\": {\\\"start_order\\\": 0, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderVolumeImage\\\"]}, \\\"net\\\": \\\"none\\\", \\\"privileged\\\": false, \\\"user\\\": \\\"root\\\", \\\"volumes\\\": [\\\"/var/log/containers/cinder:/var/log/cinder\\\"], \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R cinder:cinder /var/log/cinder\\\"]}}}, \\\"host_prep_tasks\\\": {\\\"get_attr\\\": [\\\"CinderCommon\\\", \\\"cinder_volume_host_prep_tasks\\\"]}, \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Cinder Volume tag container image for pacemaker\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_tag\\\"}, \\\"vars\\\": {\\\"container_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderVolumeImage\\\"]}, \\\"container_image_latest\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/cinder-volume:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderVolumeImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderVolumeImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}}}, {\\\"name\\\": \\\"Cinder Volume HA Wrappers Step\\\", \\\"when\\\": \\\"step|int == 5\\\", \\\"block\\\": [{\\\"name\\\": \\\"Cinder volume puppet bundle\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_ha_wrapper\\\"}, \\\"vars\\\": {\\\"tripleo_ha_wrapper_service_name\\\": \\\"cinder_volume\\\", \\\"tripleo_ha_wrapper_resource_name\\\": \\\"openstack-cinder-volume\\\", \\\"tripleo_ha_wrapper_bundle_name\\\": \\\"openstack-cinder-volume\\\", \\\"tripleo_ha_wrapper_resource_state\\\": \\\"_ Started\\\", \\\"tripleo_ha_wrapper_puppet_config_volume\\\": \\\"cinder\\\", \\\"tripleo_ha_wrapper_puppet_execute\\\": \\\"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::cinder::volume_bundle\\\", \\\"tripleo_ha_wrapper_puppet_tags\\\": \\\"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\\\", \\\"tripleo_ha_wrapper_puppet_debug\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"tripleo_ha_wrapper_config_suffix\\\": \\\".cinder_volume_previous_run\\\"}}]}], \\\"external_update_tasks\\\": [{\\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": \\\"ha_image_update\\\", \\\"block\\\": [{\\\"block\\\": [{\\\"name\\\": \\\"Get cinder_volume image from pacemaker\\\", \\\"become\\\": true, \\\"register\\\": \\\"xmllint_pcmk_cinder_volume_image\\\", \\\"shell\\\": \\\"xmllint --xpath \\\\\\\"string(//bundle[@id=\'openstack-cinder-volume\']/podman/@image)\\\\\\\" /var/lib/pacemaker/cib/cib.xml\\\"}, {\\\"name\\\": \\\"Get container cinder_volume image\\\", \\\"set_fact\\\": {\\\"cinder_volume_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderVolumeImage\\\"]}, \\\"cinder_volume_image_latest\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/cinder-volume:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderVolumeImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderVolumeImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"pcmk_cinder_volume_image\\\": \\\"{{xmllint_pcmk_cinder_volume_image.stdout}}\\\"}}], \\\"delegate_to\\\": \\\"{{ (groups[\\\\\\\"cinder_volume\\\\\\\"] | difference(groups[\\\\\\\"excluded_overcloud\\\\\\\"]))[0] }}\\\"}, {\\\"name\\\": \\\"cinder-volume temporary pacemaker container tag in case of image switch\\\", \\\"become\\\": true, \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_ha_image_update\\\"}, \\\"vars\\\": {\\\"tripleo_ha_image_update_node_names\\\": \\\"{{ groups[\\\\\\\"cinder_volume\\\\\\\"] | difference(groups[\\\\\\\"excluded_overcloud\\\\\\\"]) }}\\\", \\\"tripleo_ha_image_update_bundle\\\": \\\"openstack-cinder-volume\\\", \\\"tripleo_ha_image_update_new_image\\\": \\\"{{cinder_volume_image_latest}}\\\", \\\"tripleo_ha_image_update_old_image\\\": \\\"{{pcmk_cinder_volume_image}}\\\"}, \\\"when\\\": [\\\"(pcmk_cinder_volume_image != \\\\\\\"\\\\\\\")\\\", \\\"(pcmk_cinder_volume_image != cinder_volume_image_latest)\\\"]}]}], \\\"update_tasks\\\": [{\\\"block\\\": [{\\\"name\\\": \\\"Get cinder_volume image from pacemaker\\\", \\\"become\\\": true, \\\"register\\\": \\\"xmllint_pcmk_cinder_volume_image\\\", \\\"shell\\\": \\\"xmllint --xpath \\\\\\\"string(//bundle[@id=\'openstack-cinder-volume\']/podman/@image)\\\\\\\" /var/lib/pacemaker/cib/cib.xml\\\"}, {\\\"name\\\": \\\"Get container cinder_volume image\\\", \\\"set_fact\\\": {\\\"cinder_volume_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderVolumeImage\\\"]}, \\\"cinder_volume_image_latest\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/cinder-volume:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderVolumeImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderVolumeImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"pcmk_cinder_volume_image\\\": \\\"{{xmllint_pcmk_cinder_volume_image.stdout}}\\\"}}], \\\"when\\\": \\\"(step|int == 0 or step|int == 2)\\\"}, {\\\"name\\\": \\\"Check for update of cinder-volume container image name\\\", \\\"when\\\": \\\"step|int == 0\\\", \\\"assert\\\": {\\\"that\\\": \\\"pcmk_cinder_volume_image == cinder_volume_image_latest\\\", \\\"fail_msg\\\": \\\"cinder-volume image change detected, run overcloud external-update --tags ha_image_update first\\\"}}, {\\\"name\\\": \\\"Tear-down non-HA cinder_volume container\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Remove non-HA cinder_volume container\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_rm\\\"}, \\\"vars\\\": {\\\"tripleo_container_cli\\\": \\\"{{ container_cli }}\\\", \\\"tripleo_containers_to_rm\\\": [\\\"cinder_volume\\\"]}}]}, {\\\"name\\\": \\\"cinder_volume fetch and retag container image for pacemaker\\\", \\\"when\\\": \\\"step|int == 2\\\", \\\"block\\\": [{\\\"name\\\": \\\"Retag pcmklatest to latest cinder_volume image\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_tag\\\"}, \\\"vars\\\": {\\\"container_image\\\": \\\"{{cinder_volume_image}}\\\", \\\"container_image_latest\\\": \\\"{{cinder_volume_image_latest}}\\\"}}]}], \\\"post_update_tasks\\\": [{\\\"name\\\": \\\"Cinder volume bundle post update\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Cinder volume puppet bundle\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_ha_wrapper\\\"}, \\\"vars\\\": {\\\"tripleo_ha_wrapper_service_name\\\": \\\"cinder_volume\\\", \\\"tripleo_ha_wrapper_resource_name\\\": \\\"openstack-cinder-volume\\\", \\\"tripleo_ha_wrapper_bundle_name\\\": \\\"openstack-cinder-volume\\\", \\\"tripleo_ha_wrapper_resource_state\\\": \\\"_ Started\\\", \\\"tripleo_ha_wrapper_puppet_config_volume\\\": \\\"cinder\\\", \\\"tripleo_ha_wrapper_puppet_execute\\\": \\\"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::cinder::volume_bundle\\\", \\\"tripleo_ha_wrapper_puppet_tags\\\": \\\"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\\\", \\\"tripleo_ha_wrapper_puppet_debug\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"tripleo_ha_wrapper_config_suffix\\\": \\\".cinder_volume_previous_run\\\"}}], \\\"vars\\\": {\\\"tripleo_ha_wrapper_minor_update\\\": true}}], \\\"upgrade_tasks\\\": {\\\"list_concat\\\": [[{\\\"name\\\": \\\"Tear-down non-HA cinder_volume container\\\", \\\"when\\\": [\\\"step|int == 0\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Remove non-HA cinder_volume container\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_rm\\\"}, \\\"vars\\\": {\\\"tripleo_container_cli\\\": \\\"{{ container_cli }}\\\", \\\"tripleo_containers_to_rm\\\": [\\\"cinder_volume\\\"]}}]}, {\\\"name\\\": \\\"Prepare switch of cinder_volume image name\\\", \\\"when\\\": [\\\"step|int == 0\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Get cinder_volume image id currently used by pacemaker\\\", \\\"shell\\\": \\\"pcs resource config openstack-cinder-volume | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\\\", \\\"register\\\": \\\"cinder_volume_image_current_res\\\", \\\"failed_when\\\": false}, {\\\"name\\\": \\\"cinder_volume image facts\\\", \\\"set_fact\\\": {\\\"cinder_volume_image_latest\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/cinder-volume:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderVolumeImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderVolumeImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"cinder_volume_image_current\\\": \\\"{{cinder_volume_image_current_res.stdout}}\\\"}}, {\\\"name\\\": \\\"Temporarily tag the current cinder_volume image id with the upgraded image name\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_tag\\\"}, \\\"vars\\\": {\\\"container_image\\\": \\\"{{cinder_volume_image_current}}\\\", \\\"container_image_latest\\\": \\\"{{cinder_volume_image_latest}}\\\", \\\"pull_image\\\": false}, \\\"when\\\": [\\\"cinder_volume_image_current != \'\'\\\", \\\"cinder_volume_image_current != cinder_volume_image_latest\\\"]}, {\\\"name\\\": \\\"Create cinder_volume retag statefile\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/tripleo/cinder_volume_needs_retag\\\", \\\"state\\\": \\\"touch\\\"}, \\\"when\\\": [\\\"cinder_volume_image_current != \'\'\\\", \\\"cinder_volume_image_current != cinder_volume_image_latest\\\"]}]}, {\\\"name\\\": \\\"Update cinder_volume pcs resource bundle for new container image\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"set is_cinder_volume_bootstrap_node fact\\\", \\\"tags\\\": \\\"common\\\", \\\"set_fact\\\": \\\"is_cinder_volume_bootstrap_node={{cinder_volume_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\\\"}, {\\\"name\\\": \\\"Check for cinder_volume retag statefile\\\", \\\"stat\\\": {\\\"path\\\": \\\"/var/lib/tripleo/cinder_volume_needs_retag\\\"}, \\\"register\\\": \\\"cinder_volume_retag_state_file\\\"}]}, {\\\"name\\\": \\\"Update cinder_volume pcs resource bundle for new container image\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"is_cinder_volume_bootstrap_node\\\", \\\"cinder_volume_retag_state_file.stat.exists|bool\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Disable the cinder_volume cluster resource before container upgrade\\\", \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"openstack-cinder-volume\\\", \\\"state\\\": \\\"disable\\\", \\\"wait_for_resource\\\": true}, \\\"register\\\": \\\"output\\\", \\\"retries\\\": 5, \\\"until\\\": \\\"output.rc == 0\\\"}, {\\\"name\\\": \\\"pcs resource bundle update cinder_volume for new container image name\\\", \\\"command\\\": \\\"pcs resource bundle update openstack-cinder-volume container image={{cinder_volume_image_latest}}\\\"}, {\\\"name\\\": \\\"Enable the cinder_volume cluster resource\\\", \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"openstack-cinder-volume\\\", \\\"state\\\": \\\"enable\\\", \\\"wait_for_resource\\\": true}, \\\"register\\\": \\\"output\\\", \\\"retries\\\": 5, \\\"until\\\": \\\"output.rc == 0\\\"}]}, {\\\"name\\\": \\\"Check for cinder_volume retag statefile\\\", \\\"when\\\": [\\\"step|int == 3\\\"], \\\"stat\\\": {\\\"path\\\": \\\"/var/lib/tripleo/cinder_volume_needs_retag\\\"}, \\\"register\\\": \\\"cinder_volume_retag_state_file\\\"}, {\\\"name\\\": \\\"Retag pacemaker cinder_volume\\\", \\\"when\\\": [\\\"step|int == 3\\\", \\\"cinder_volume_retag_state_file.stat.exists|bool\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Disable the cinder_volume cluster resource before container upgrade\\\", \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"openstack-cinder-volume\\\", \\\"state\\\": \\\"disable\\\", \\\"wait_for_resource\\\": true}, \\\"register\\\": \\\"output\\\", \\\"retries\\\": 5, \\\"until\\\": \\\"output.rc == 0\\\"}, {\\\"name\\\": \\\"Retag the pacemaker image if containerized\\\", \\\"block\\\": [{\\\"block\\\": [{\\\"name\\\": \\\"Get cinder_volume image from pacemaker\\\", \\\"become\\\": true, \\\"register\\\": \\\"xmllint_pcmk_cinder_volume_image\\\", \\\"shell\\\": \\\"xmllint --xpath \\\\\\\"string(//bundle[@id=\'openstack-cinder-volume\']/podman/@image)\\\\\\\" /var/lib/pacemaker/cib/cib.xml\\\"}, {\\\"name\\\": \\\"Get container cinder_volume image\\\", \\\"set_fact\\\": {\\\"cinder_volume_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderVolumeImage\\\"]}, \\\"cinder_volume_image_latest\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/cinder-volume:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderVolumeImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderVolumeImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"pcmk_cinder_volume_image\\\": \\\"{{xmllint_pcmk_cinder_volume_image.stdout}}\\\"}}]}, {\\\"block\\\": [{\\\"name\\\": \\\"Retag pcmklatest to latest cinder_volume image\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_tag\\\"}, \\\"vars\\\": {\\\"container_image\\\": \\\"{{cinder_volume_image}}\\\", \\\"container_image_latest\\\": \\\"{{cinder_volume_image_latest}}\\\"}}]}]}, {\\\"name\\\": \\\"Enable the cinder_volume cluster resource\\\", \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"openstack-cinder-volume\\\", \\\"state\\\": \\\"enable\\\", \\\"wait_for_resource\\\": true}, \\\"register\\\": \\\"output\\\", \\\"retries\\\": 5, \\\"until\\\": \\\"output.rc == 0\\\"}, {\\\"name\\\": \\\"Remove cinder_volume retag statefile\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/tripleo/cinder_volume_needs_retag\\\", \\\"state\\\": \\\"absent\\\"}}]}], {\\\"get_attr\\\": [\\\"CinderCommon\\\", \\\"cinder_volume_upgrade_tasks\\\"]}]}, \\\"post_upgrade_tasks\\\": [{\\\"name\\\": \\\"Start cinder_volume service (pacemaker)\\\", \\\"become\\\": true, \\\"when\\\": \\\"step|int == 1\\\", \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"openstack-cinder-volume\\\", \\\"state\\\": \\\"enable\\\"}}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Keystone service\\\\n\\\", \\\"parameters\\\": {\\\"ContainerKeystoneImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerKeystoneConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the keystone config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"DeployIdentifier\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\\\n\\\"}, \\\"AdminPassword\\\": {\\\"description\\\": \\\"The password for the keystone admin account, used for monitoring, querying neutron etc.\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"KeystoneTokenProvider\\\": {\\\"description\\\": \\\"The keystone token format\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"fernet\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"fernet\\\"]}]}, \\\"SSLCertificate\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The content of the SSL certificate (without Key) in PEM format.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"PublicSSLCertificateAutogenerated\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether the public SSL certificate was autogenerated or not.\\\\n\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"EnablePublicTLS\\\": {\\\"default\\\": true, \\\"description\\\": \\\"Whether to enable TLS on the public interface or not.\\\\n\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"PublicTLSCAFile\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Specifies the default CA cert to use if TLS is used for services in the public network.\\\"}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"MemcachedTLS\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"KeystoneSSLCertificate\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Keystone certificate for verifying token validity.\\\", \\\"type\\\": \\\"string\\\"}, \\\"KeystoneSSLCertificateKey\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Keystone key for signing tokens.\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"KeystoneNotificationFormat\\\": {\\\"description\\\": \\\"The Keystone notification format\\\", \\\"default\\\": \\\"basic\\\", \\\"type\\\": \\\"string\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"basic\\\", \\\"cadf\\\"]}]}, \\\"KeystoneNotificationTopics\\\": {\\\"description\\\": \\\"Keystone notification topics to enable\\\", \\\"default\\\": [], \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"KeystoneRegion\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"regionOne\\\", \\\"description\\\": \\\"Keystone region for endpoint\\\"}, \\\"Debug\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false, \\\"description\\\": \\\"Set to True to enable debugging on all services.\\\"}, \\\"KeystoneDebug\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Set to True to enable debugging Keystone service.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"EnableCache\\\": {\\\"description\\\": \\\"Enable caching with memcached\\\", \\\"type\\\": \\\"boolean\\\", \\\"default\\\": true}, \\\"EnableSQLAlchemyCollectd\\\": {\\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"Set to true to enable the SQLAlchemy-collectd server plugin\\\\n\\\", \\\"default\\\": false}, \\\"AdminToken\\\": {\\\"description\\\": \\\"The keystone auth secret and db password.\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"TokenExpiration\\\": {\\\"default\\\": 3600, \\\"description\\\": \\\"Set a token expiration time in seconds.\\\", \\\"type\\\": \\\"number\\\"}, \\\"KeystoneWorkers\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Set the number of workers for keystone::wsgi::apache\\\", \\\"default\\\": \\\"%{::os_workers_keystone}\\\"}, \\\"MonitoringSubscriptionKeystone\\\": {\\\"default\\\": \\\"overcloud-keystone\\\", \\\"type\\\": \\\"string\\\"}, \\\"KeystoneCredential0\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"The first Keystone credential key. Must be a valid key.\\\"}, \\\"KeystoneCredential1\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"The second Keystone credential key. Must be a valid key.\\\"}, \\\"KeystoneFernetKeys\\\": {\\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"Mapping containing keystone\'s fernet keys and their paths.\\\"}, \\\"KeystoneFernetMaxActiveKeys\\\": {\\\"type\\\": \\\"number\\\", \\\"description\\\": \\\"The maximum active keys in the keystone fernet key repository.\\\", \\\"default\\\": 5}, \\\"ManageKeystoneFernetKeys\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": true, \\\"description\\\": \\\"Whether TripleO should manage the keystone fernet keys or not. If set to true, the fernet keys will get the values from the saved keys repository in mistral (the KeystoneFernetKeys variable). If set to false, only the stack creation initializes the keys, but subsequent updates won\'t touch them.\\\"}, \\\"KeystoneLoggingSource\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {\\\"tag\\\": \\\"openstack.keystone\\\", \\\"file\\\": \\\"/var/log/containers/keystone/keystone.log\\\"}}, \\\"KeystonePolicies\\\": {\\\"description\\\": \\\"A hash of policies to configure for Keystone.\\\\ne.g. { keystone-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\\\n\\\", \\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}, \\\"KeystoneLDAPDomainEnable\\\": {\\\"description\\\": \\\"Trigger to call ldap_backend puppet keystone define.\\\", \\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"KeystoneLDAPBackendConfigs\\\": {\\\"description\\\": \\\"Hash containing the configurations for the LDAP backends configured in keystone.\\\", \\\"type\\\": \\\"json\\\", \\\"default\\\": {}, \\\"hidden\\\": true}, \\\"NotificationDriver\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": \\\"noop\\\", \\\"description\\\": \\\"Driver or drivers to handle sending notifications.\\\"}, \\\"KeystoneNotificationDriver\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": [], \\\"description\\\": \\\"Driver or drivers to handle sending notifications. This parameter is\\\\nspecific to Keystone.\\\\n\\\"}, \\\"KeystoneEnableDBPurge\\\": {\\\"default\\\": true, \\\"description\\\": \\\"Whether to create cron job for purging soft deleted rows in Keystone database.\\\\n\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"KeystoneCronTrustFlushEnsure\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge expired or soft-deleted trusts - Ensure\\\\n\\\", \\\"default\\\": \\\"present\\\"}, \\\"KeystoneCronTrustFlushMinute\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge expired or soft-deleted trusts - Minute\\\\n\\\", \\\"default\\\": \\\"1\\\"}, \\\"KeystoneCronTrustFlushHour\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge expired or soft-deleted trusts - Hour\\\\n\\\", \\\"default\\\": \\\"*\\\"}, \\\"KeystoneCronTrustFlushMonthday\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge expired or soft-deleted trusts - Month Day\\\\n\\\", \\\"default\\\": \\\"*\\\"}, \\\"KeystoneCronTrustFlushMonth\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge expired or soft-deleted trusts - Month\\\\n\\\", \\\"default\\\": \\\"*\\\"}, \\\"KeystoneCronTrustFlushWeekday\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge expired or soft-deleted trusts - Week Day\\\\n\\\", \\\"default\\\": \\\"*\\\"}, \\\"KeystoneCronTrustFlushMaxDelay\\\": {\\\"type\\\": \\\"number\\\", \\\"description\\\": \\\"Cron to purge expired or soft-deleted trusts - Max Delay\\\\n\\\", \\\"default\\\": 0}, \\\"KeystoneCronTrustFlushDestination\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge expired or soft-deleted trusts - Log destination\\\\n\\\", \\\"default\\\": \\\"/var/log/keystone/keystone-trustflush.log\\\"}, \\\"KeystoneCronTrustFlushUser\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge expired or soft-deleted trusts - User\\\\n\\\", \\\"default\\\": \\\"keystone\\\"}, \\\"KeystoneChangePasswordUponFirstUse\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Enabling this option requires users to change their password when the user is created, or upon administrative reset.\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"\\\", \\\"true\\\", \\\"True\\\", \\\"TRUE\\\", \\\"false\\\", \\\"False\\\", \\\"FALSE\\\"]}]}, \\\"KeystoneDisableUserAccountDaysInactive\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The maximum number of days a user can go without authenticating before being considered \\\\\\\"inactive\\\\\\\" and automatically disabled (locked).\\\"}, \\\"KeystoneLockoutDuration\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The number of seconds a user account will be locked when the maximum number of failed authentication attempts (as specified by KeystoneLockoutFailureAttempts) is exceeded.\\\"}, \\\"KeystoneLockoutFailureAttempts\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The maximum number of times that a user can fail to authenticate before the user account is locked for the number of seconds specified by KeystoneLockoutDuration.\\\"}, \\\"KeystoneMinimumPasswordAge\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The number of days that a password must be used before the user can change it. This prevents users from changing their passwords immediately in order to wipe out their password history and reuse an old password.\\\"}, \\\"KeystonePasswordExpiresDays\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The number of days for which a password will be considered valid before requiring it to be changed.\\\"}, \\\"KeystonePasswordRegex\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The regular expression used to validate password strength requirements.\\\"}, \\\"KeystonePasswordRegexDescription\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Describe your password regular expression here in language for humans.\\\"}, \\\"KeystoneUniqueLastPasswordCount\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"This controls the number of previous user password iterations to keep in history, in order to enforce that newly created passwords are unique.\\\"}, \\\"KeystoneCorsAllowedOrigin\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Indicate whether this resource may be shared with the domain received in the request \\\\\\\"origin\\\\\\\" header.\\\"}, \\\"KeystoneEnableMember\\\": {\\\"description\\\": \\\"Create the _member_ role, useful for undercloud deployment.\\\", \\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"KeystoneFederationEnable\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false, \\\"description\\\": \\\"Enable support for federated authentication.\\\"}, \\\"KeystoneTrustedDashboards\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": [], \\\"description\\\": \\\"A list of dashboard URLs trusted for single sign-on.\\\"}, \\\"KeystoneAuthMethods\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": [], \\\"description\\\": \\\"A list of methods used for authentication.\\\"}, \\\"KeystoneOpenIdcEnable\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false, \\\"description\\\": \\\"Enable support for OpenIDC federation.\\\"}, \\\"KeystoneOpenIdcIdpName\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The name associated with the IdP in Keystone.\\\"}, \\\"KeystoneOpenIdcProviderMetadataUrl\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The url that points to your OpenID Connect provider metadata\\\"}, \\\"KeystoneOpenIdcClientId\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The client ID to use when handshaking with your OpenID Connect provider\\\"}, \\\"KeystoneOpenIdcClientSecret\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The client secret to use when handshaking with your OpenID Connect provider\\\"}, \\\"KeystoneOpenIdcCryptoPassphrase\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"openstack\\\", \\\"description\\\": \\\"Passphrase to use when encrypting data for OpenID Connect handshake.\\\"}, \\\"KeystoneOpenIdcOutgoingProxy\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The outgoing proxy to use for OpenID connections.\\\"}, \\\"KeystoneOpenIdcResponseType\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"id_token\\\", \\\"description\\\": \\\"Response type to be expected from the OpenID Connect provider.\\\"}, \\\"KeystoneOpenIdcRemoteIdAttribute\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"OIDC-iss\\\", \\\"description\\\": \\\"Attribute to be used to obtain the entity ID of the Identity Provider from the environment.\\\"}, \\\"KeystoneOpenIdcEnableOAuth\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false, \\\"description\\\": \\\"Enable OAuth 2.0 integration.\\\"}, \\\"KeystoneOpenIdcIntrospectionEndpoint\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"OAuth 2.0 introspection endpoint for mod_auth_openidc\\\"}, \\\"KeystoneOpenIdcClaimDelimiter\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\";\\\", \\\"description\\\": \\\"The delimiter to use when setting multi-valued claims.\\\"}, \\\"KeystoneOpenIdcPassUserInfoAs\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"claims\\\", \\\"description\\\": \\\"Define the way(s) in which the claims resolved from the userinfo endpoint are passed to the application according to OIDCPassClaimsAs.\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"claims\\\", \\\"json\\\", \\\"jwt\\\"]}]}, \\\"KeystoneOpenIdcPassClaimsAs\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"both\\\", \\\"description\\\": \\\"Define the way in which the claims and tokens are passed to the application environment: \\\\\\\"none\\\\\\\": no claims/tokens are passed \\\\\\\"environment\\\\\\\": claims/tokens are passed as environment variables \\\\\\\"headers\\\\\\\": claims/tokens are passed in headers (also useful in reverse proxy scenario\'s) \\\\\\\"both\\\\\\\": claims/tokens are passed as both headers as well as environment variables (default)\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"none\\\", \\\"environment\\\", \\\"headers\\\", \\\"both\\\"]}]}, \\\"RootStackName\\\": {\\\"description\\\": \\\"The name of the stack/plan.\\\", \\\"type\\\": \\\"string\\\"}, \\\"EnforceSecureRbac\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false, \\\"description\\\": \\\"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\\\"}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"MySQLClient\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\\\"}, \\\"ApacheServiceBase\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}, \\\"EnableInternalTLS\\\": {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}}}, \\\"KeystoneLogging\\\": {\\\"type\\\": \\\"OS::TripleO::Services::Logging::Keystone\\\"}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerKeystoneImage\\\": \\\"ContainerKeystoneImage\\\", \\\"ContainerKeystoneConfigImage\\\": \\\"ContainerKeystoneConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerKeystoneImage\\\": {\\\"get_param\\\": \\\"ContainerKeystoneImage\\\"}, \\\"ContainerKeystoneConfigImage\\\": {\\\"get_param\\\": \\\"ContainerKeystoneConfigImage\\\"}}}]}}}}, \\\"conditions\\\": {\\\"public_tls_enabled\\\": {\\\"and\\\": [{\\\"get_param\\\": \\\"EnablePublicTLS\\\"}, {\\\"or\\\": [{\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"SSLCertificate\\\"}, \\\"\\\"]}}, {\\\"get_param\\\": \\\"PublicSSLCertificateAutogenerated\\\"}]}]}, \\\"keystone_fernet_tokens\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"KeystoneTokenProvider\\\"}, \\\"fernet\\\"]}, \\\"nontls_cache_enabled\\\": {\\\"and\\\": [{\\\"get_param\\\": \\\"EnableCache\\\"}, {\\\"not\\\": {\\\"get_param\\\": \\\"MemcachedTLS\\\"}}]}, \\\"tls_cache_enabled\\\": {\\\"and\\\": [{\\\"get_param\\\": \\\"EnableCache\\\"}, {\\\"get_param\\\": \\\"MemcachedTLS\\\"}]}, \\\"keystone_outgoing_proxy\\\": {\\\"and\\\": [{\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"KeystoneOpenIdcOutgoingProxy\\\"}, \\\"\\\"]}}, {\\\"get_param\\\": \\\"KeystoneOpenIdcEnable\\\"}]}, \\\"change_password_upon_first_use_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"KeystoneChangePasswordUponFirstUse\\\"}, \\\"\\\"]}}, \\\"disable_user_account_days_inactive_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"KeystoneDisableUserAccountDaysInactive\\\"}, \\\"\\\"]}}, \\\"lockout_duration_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"KeystoneLockoutDuration\\\"}, \\\"\\\"]}}, \\\"lockout_failure_attempts_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"KeystoneLockoutFailureAttempts\\\"}, \\\"\\\"]}}, \\\"minimum_password_age_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"KeystoneMinimumPasswordAge\\\"}, \\\"\\\"]}}, \\\"password_expires_days_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"KeystonePasswordExpiresDays\\\"}, \\\"\\\"]}}, \\\"password_regex_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"KeystonePasswordRegex\\\"}, \\\"\\\"]}}, \\\"password_regex_description_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"KeystonePasswordRegexDescription\\\"}, \\\"\\\"]}}, \\\"unique_last_password_count_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"KeystoneUniqueLastPasswordCount\\\"}, \\\"\\\"]}}, \\\"cors_allowed_origin_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"KeystoneCorsAllowedOrigin\\\"}, \\\"\\\"]}}, \\\"keystone_notification_driver_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"KeystoneNotificationDriver\\\"}, []]}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Keystone API role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"keystone\\\", \\\"firewall_rules\\\": {\\\"111 keystone\\\": {\\\"dport\\\": [5000, {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneAdmin\\\", \\\"port\\\"]}]}}, \\\"firewall_frontend_rules\\\": {\\\"100 keystone_public_haproxy_frontend\\\": {\\\"dport\\\": [5000]}, \\\"100 keystone_admin_haproxy_frontend\\\": {\\\"dport\\\": [{\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneAdmin\\\", \\\"port\\\"]}]}}, \\\"firewall_ssl_frontend_rules\\\": {\\\"100 keystone_public_haproxy_frontend_ssl\\\": {\\\"dport\\\": [13000]}}, \\\"monitoring_subscription\\\": {\\\"get_param\\\": \\\"MonitoringSubscriptionKeystone\\\"}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"ApacheServiceBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"if\\\": [\\\"cors_allowed_origin_set\\\", {\\\"keystone::cors::allowed_origin\\\": {\\\"get_param\\\": \\\"KeystoneCorsAllowedOrigin\\\"}}]}, {\\\"keystone::database_connection\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"MysqlInternal\\\", \\\"protocol\\\"]}, \\\"username\\\": \\\"keystone\\\", \\\"password\\\": {\\\"get_param\\\": \\\"AdminToken\\\"}, \\\"host\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"MysqlInternal\\\", \\\"host\\\"]}, \\\"path\\\": \\\"/keystone\\\", \\\"query\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableSQLAlchemyCollectd\\\"}, {\\\"read_default_file\\\": \\\"/etc/my.cnf.d/tripleo.cnf\\\", \\\"read_default_group\\\": \\\"tripleo\\\", \\\"plugin\\\": \\\"collectd\\\", \\\"collectd_program_name\\\": \\\"keystone\\\", \\\"collectd_host\\\": \\\"localhost\\\"}, {\\\"read_default_file\\\": \\\"/etc/my.cnf.d/tripleo.cnf\\\", \\\"read_default_group\\\": \\\"tripleo\\\"}]}}}, \\\"keystone::token_expiration\\\": {\\\"get_param\\\": \\\"TokenExpiration\\\"}, \\\"keystone::policy::policies\\\": {\\\"get_param\\\": \\\"KeystonePolicies\\\"}, \\\"keystone_ssl_certificate\\\": {\\\"get_param\\\": \\\"KeystoneSSLCertificate\\\"}, \\\"keystone_ssl_certificate_key\\\": {\\\"get_param\\\": \\\"KeystoneSSLCertificateKey\\\"}, \\\"keystone::token_provider\\\": {\\\"get_param\\\": \\\"KeystoneTokenProvider\\\"}, \\\"keystone::enable_fernet_setup\\\": {\\\"if\\\": [\\\"keystone_fernet_tokens\\\", true, false]}, \\\"keystone::fernet_max_active_keys\\\": {\\\"get_param\\\": \\\"KeystoneFernetMaxActiveKeys\\\"}, \\\"keystone::enable_proxy_headers_parsing\\\": true, \\\"keystone::enable_credential_setup\\\": true, \\\"keystone::credential_keys\\\": {\\\"/etc/keystone/credential-keys/0\\\": {\\\"content\\\": {\\\"get_param\\\": \\\"KeystoneCredential0\\\"}}, \\\"/etc/keystone/credential-keys/1\\\": {\\\"content\\\": {\\\"get_param\\\": \\\"KeystoneCredential1\\\"}}}, \\\"keystone::fernet_keys\\\": {\\\"get_param\\\": \\\"KeystoneFernetKeys\\\"}, \\\"keystone::fernet_replace_keys\\\": {\\\"get_param\\\": \\\"ManageKeystoneFernetKeys\\\"}, \\\"keystone::logging::debug\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"KeystoneDebug\\\"}, true, {\\\"get_param\\\": \\\"Debug\\\"}]}, \\\"keystone::notification_driver\\\": {\\\"if\\\": [\\\"keystone_notification_driver_set\\\", {\\\"get_param\\\": \\\"KeystoneNotificationDriver\\\"}, {\\\"get_param\\\": \\\"NotificationDriver\\\"}]}, \\\"keystone::notification_format\\\": {\\\"get_param\\\": \\\"KeystoneNotificationFormat\\\"}, \\\"tripleo::profile::base::keystone::extra_notification_topics\\\": {\\\"get_param\\\": \\\"KeystoneNotificationTopics\\\"}, \\\"keystone_enable_db_purge\\\": {\\\"get_param\\\": \\\"KeystoneEnableDBPurge\\\"}, \\\"keystone::cron::trust_flush::ensure\\\": {\\\"get_param\\\": \\\"KeystoneCronTrustFlushEnsure\\\"}, \\\"keystone::cron::trust_flush::minute\\\": {\\\"get_param\\\": \\\"KeystoneCronTrustFlushMinute\\\"}, \\\"keystone::cron::trust_flush::hour\\\": {\\\"get_param\\\": \\\"KeystoneCronTrustFlushHour\\\"}, \\\"keystone::cron::trust_flush::monthday\\\": {\\\"get_param\\\": \\\"KeystoneCronTrustFlushMonthday\\\"}, \\\"keystone::cron::trust_flush::month\\\": {\\\"get_param\\\": \\\"KeystoneCronTrustFlushMonth\\\"}, \\\"keystone::cron::trust_flush::weekday\\\": {\\\"get_param\\\": \\\"KeystoneCronTrustFlushWeekday\\\"}, \\\"keystone::cron::trust_flush::maxdelay\\\": {\\\"get_param\\\": \\\"KeystoneCronTrustFlushMaxDelay\\\"}, \\\"keystone::cron::trust_flush::destination\\\": {\\\"get_param\\\": \\\"KeystoneCronTrustFlushDestination\\\"}, \\\"keystone::cron::trust_flush::user\\\": {\\\"get_param\\\": \\\"KeystoneCronTrustFlushUser\\\"}, \\\"keystone::rabbit_heartbeat_timeout_threshold\\\": 60, \\\"keystone::rabbit_heartbeat_in_pthread\\\": false, \\\"keystone::service_name\\\": \\\"httpd\\\", \\\"keystone::enable_ssl\\\": {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, \\\"keystone::wsgi::apache::api_port\\\": [5000, {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneAdmin\\\", \\\"port\\\"]}], \\\"keystone::wsgi::apache::ssl\\\": {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, \\\"keystone::wsgi::apache::servername\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'fqdn_$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"KeystonePublicApiNetwork\\\"]}}}}, \\\"keystone::wsgi::apache::workers\\\": {\\\"get_param\\\": \\\"KeystoneWorkers\\\"}, \\\"keystone::wsgi::apache::threads\\\": 1, \\\"keystone::db::database_db_max_retries\\\": -1, \\\"keystone::db::database_max_retries\\\": -1, \\\"keystone::wsgi::apache::bind_host\\\": [{\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"KeystonePublicApiNetwork\\\"]}}}}, {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"KeystoneAdminApiNetwork\\\"]}}}}]}, {\\\"keystone::cache::enabled\\\": {\\\"get_param\\\": \\\"EnableCache\\\"}, \\\"keystone::cache::backend_argument\\\": [{\\\"str_replace\\\": {\\\"template\\\": \\\"memcached_expire_time: $EXPIRATION\\\", \\\"params\\\": {\\\"$EXPIRATION\\\": {\\\"get_param\\\": \\\"TokenExpiration\\\"}}}}], \\\"keystone::cache::tls_enabled\\\": {\\\"get_param\\\": \\\"MemcachedTLS\\\"}}, {\\\"if\\\": [\\\"tls_cache_enabled\\\", {\\\"keystone::cache::backend\\\": \\\"dogpile.cache.pymemcache\\\", \\\"keystone::token_caching\\\": true}, {\\\"keystone::cache::backend\\\": \\\"dogpile.cache.memcached\\\"}]}, {\\\"if\\\": [{\\\"get_param\\\": \\\"KeystoneFederationEnable\\\"}, {\\\"keystone_federation_enabled\\\": true, \\\"keystone::federation::trusted_dashboards\\\": {\\\"get_param\\\": \\\"KeystoneTrustedDashboards\\\"}}]}, {\\\"if\\\": [{\\\"get_param\\\": \\\"KeystoneOpenIdcEnable\\\"}, {\\\"keystone_openidc_enabled\\\": true, \\\"keystone::federation::openidc::methods\\\": {\\\"get_param\\\": \\\"KeystoneAuthMethods\\\"}, \\\"keystone::federation::openidc::keystone_url\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystonePublic\\\", \\\"uri_no_suffix\\\"]}, \\\"keystone::federation::openidc::idp_name\\\": {\\\"get_param\\\": \\\"KeystoneOpenIdcIdpName\\\"}, \\\"keystone::federation::openidc::openidc_provider_metadata_url\\\": {\\\"get_param\\\": \\\"KeystoneOpenIdcProviderMetadataUrl\\\"}, \\\"keystone::federation::openidc::openidc_client_id\\\": {\\\"get_param\\\": \\\"KeystoneOpenIdcClientId\\\"}, \\\"keystone::federation::openidc::openidc_client_secret\\\": {\\\"get_param\\\": \\\"KeystoneOpenIdcClientSecret\\\"}, \\\"keystone::federation::openidc::openidc_crypto_passphrase\\\": {\\\"get_param\\\": \\\"KeystoneOpenIdcCryptoPassphrase\\\"}, \\\"keystone::federation::openidc::openidc_response_type\\\": {\\\"get_param\\\": \\\"KeystoneOpenIdcResponseType\\\"}, \\\"keystone::federation::openidc::remote_id_attribute\\\": {\\\"get_param\\\": \\\"KeystoneOpenIdcRemoteIdAttribute\\\"}, \\\"keystone::federation::openidc::openidc_enable_oauth\\\": {\\\"get_param\\\": \\\"KeystoneOpenIdcEnableOAuth\\\"}, \\\"keystone::federation::openidc::openidc_introspection_endpoint\\\": {\\\"get_param\\\": \\\"KeystoneOpenIdcIntrospectionEndpoint\\\"}, \\\"keystone::federation::openidc::openidc_pass_userinfo_as\\\": {\\\"get_param\\\": \\\"KeystoneOpenIdcPassUserInfoAs\\\"}, \\\"keystone::federation::openidc::openidc_pass_claim_as\\\": {\\\"get_param\\\": \\\"KeystoneOpenIdcPassClaimsAs\\\"}, \\\"keystone::federation::openidc::openidc_claim_delimiter\\\": {\\\"get_param\\\": \\\"KeystoneOpenIdcClaimDelimiter\\\"}, \\\"keystone::federation::openidc::openidc_cache_type\\\": {\\\"if\\\": [\\\"nontls_cache_enabled\\\", \\\"memcache\\\"]}}]}, {\\\"if\\\": [\\\"keystone_outgoing_proxy\\\", {\\\"keystone::federation::openidc::openidc_outgoing_proxy\\\": {\\\"get_param\\\": \\\"KeystoneOpenIdcOutgoingProxy\\\"}}]}, {\\\"if\\\": [{\\\"get_param\\\": \\\"KeystoneLDAPDomainEnable\\\"}, {\\\"tripleo::profile::base::keystone::ldap_backend_enable\\\": true, \\\"keystone::using_domain_config\\\": true, \\\"tripleo::profile::base::keystone::ldap_backends_config\\\": {\\\"get_param\\\": \\\"KeystoneLDAPBackendConfigs\\\"}}]}, {\\\"if\\\": [\\\"change_password_upon_first_use_set\\\", {\\\"keystone::security_compliance::change_password_upon_first_use\\\": {\\\"get_param\\\": \\\"KeystoneChangePasswordUponFirstUse\\\"}}]}, {\\\"if\\\": [\\\"disable_user_account_days_inactive_set\\\", {\\\"keystone::security_compliance::disable_user_account_days_inactive\\\": {\\\"get_param\\\": \\\"KeystoneDisableUserAccountDaysInactive\\\"}}]}, {\\\"if\\\": [\\\"lockout_duration_set\\\", {\\\"keystone::security_compliance::lockout_duration\\\": {\\\"get_param\\\": \\\"KeystoneLockoutDuration\\\"}}]}, {\\\"if\\\": [\\\"lockout_failure_attempts_set\\\", {\\\"keystone::security_compliance::lockout_failure_attempts\\\": {\\\"get_param\\\": \\\"KeystoneLockoutFailureAttempts\\\"}}]}, {\\\"if\\\": [\\\"minimum_password_age_set\\\", {\\\"keystone::security_compliance::minimum_password_age\\\": {\\\"get_param\\\": \\\"KeystoneMinimumPasswordAge\\\"}}]}, {\\\"if\\\": [\\\"password_expires_days_set\\\", {\\\"keystone::security_compliance::password_expires_days\\\": {\\\"get_param\\\": \\\"KeystonePasswordExpiresDays\\\"}}]}, {\\\"if\\\": [\\\"password_regex_set\\\", {\\\"keystone::security_compliance::password_regex\\\": {\\\"get_param\\\": \\\"KeystonePasswordRegex\\\"}}]}, {\\\"if\\\": [\\\"password_regex_description_set\\\", {\\\"keystone::security_compliance::password_regex_description\\\": {\\\"get_param\\\": \\\"KeystonePasswordRegexDescription\\\"}}]}, {\\\"if\\\": [\\\"unique_last_password_count_set\\\", {\\\"keystone::security_compliance::unique_last_password_count\\\": {\\\"get_param\\\": \\\"KeystoneUniqueLastPasswordCount\\\"}}]}, {\\\"apache::default_vhost\\\": false}, {\\\"get_attr\\\": [\\\"KeystoneLogging\\\", \\\"config_settings\\\"]}]}, \\\"service_config_settings\\\": {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_keystone\\\": {\\\"get_param\\\": \\\"KeystoneLoggingSource\\\"}}, \\\"mysql\\\": {\\\"keystone::db::mysql::password\\\": {\\\"get_param\\\": \\\"AdminToken\\\"}, \\\"keystone::db::mysql::user\\\": \\\"keystone\\\", \\\"keystone::db::mysql::host\\\": \\\"%\\\", \\\"keystone::db::mysql::dbname\\\": \\\"keystone\\\"}, \\\"pacemaker\\\": {\\\"keystone::endpoint::public_url\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystonePublic\\\", \\\"uri_no_suffix\\\"]}, \\\"keystone::endpoint::internal_url\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"uri_no_suffix\\\"]}, \\\"keystone::endpoint::admin_url\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneAdmin\\\", \\\"uri_no_suffix\\\"]}, \\\"keystone::endpoint::region\\\": {\\\"get_param\\\": \\\"KeystoneRegion\\\"}, \\\"keystone::admin_password\\\": {\\\"get_param\\\": \\\"AdminPassword\\\"}}, \\\"horizon\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"KeystoneLDAPDomainEnable\\\"}, {\\\"horizon::keystone_multidomain_support\\\": true, \\\"horizon::keystone_default_domain\\\": \\\"Default\\\"}]}}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"keystone\\\", \\\"puppet_tags\\\": \\\"keystone_config,keystone_domain_config\\\", \\\"step_config\\\": {\\\"list_join\\\": [\\\"\\\\n\\\", [\\\"[\'Keystone_user\', \'Keystone_endpoint\', \'Keystone_domain\', \'Keystone_tenant\', \'Keystone_user_role\', \'Keystone_role\', \'Keystone_service\'].each |String $val| { noop_resource($val) }\\\", \\\"include tripleo::profile::base::keystone\\\\n\\\", {\\\"get_attr\\\": [\\\"MySQLClient\\\", \\\"role_data\\\", \\\"step_config\\\"]}]]}, \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerKeystoneConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/keystone.json\\\": {\\\"command\\\": \\\"/usr/sbin/httpd\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/etc/keystone/fernet-keys\\\", \\\"dest\\\": \\\"/etc/keystone/fernet-keys\\\", \\\"merge\\\": false, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/etc/httpd/conf.d\\\", \\\"dest\\\": \\\"/etc/httpd/conf.d\\\", \\\"merge\\\": false, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\\\", \\\"dest\\\": \\\"/etc/httpd/conf.modules.d\\\", \\\"merge\\\": false, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}, \\\"/var/lib/kolla/config_files/keystone_cron.json\\\": {\\\"command\\\": \\\"/usr/sbin/crond -n\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}}, \\\"docker_config\\\": {\\\"step_2\\\": {\\\"get_attr\\\": [\\\"KeystoneLogging\\\", \\\"docker_config\\\", \\\"step_2\\\"]}, \\\"step_3\\\": {\\\"keystone_db_sync\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerKeystoneImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"user\\\": \\\"root\\\", \\\"privileged\\\": false, \\\"detach\\\": false, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"KeystoneLogging\\\", \\\"volumes\\\"]}, [\\\"/etc/openldap:/etc/openldap:ro\\\", \\\"/var/lib/kolla/config_files/keystone.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/keystone:/var/lib/kolla/config_files/src:ro\\\"], {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, [\\\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\\\", \\\"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\\\"]]}]}, \\\"environment\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"KeystoneLogging\\\", \\\"environment\\\"]}, {\\\"KOLLA_BOOTSTRAP\\\": true, \\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\", \\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}}]}, \\\"command\\\": [\\\"/usr/bin/bootstrap_host_exec\\\", \\\"keystone\\\", \\\"/usr/local/bin/kolla_start\\\"]}, \\\"keystone\\\": {\\\"start_order\\\": 2, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerKeystoneImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"KeystoneLogging\\\", \\\"volumes\\\"]}, [\\\"/etc/openldap:/etc/openldap:ro\\\", \\\"/var/lib/kolla/config_files/keystone.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/keystone:/var/lib/kolla/config_files/src:ro\\\"], {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, [\\\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\\\", \\\"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\\\"]]}]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}, \\\"keystone_bootstrap\\\": {\\\"start_order\\\": 3, \\\"action\\\": \\\"exec\\\", \\\"user\\\": \\\"root\\\", \\\"command\\\": [\\\"keystone\\\", \\\"/usr/bin/bootstrap_host_exec\\\", \\\"keystone\\\", \\\"keystone-manage\\\", \\\"bootstrap\\\"], \\\"environment\\\": {\\\"KOLLA_BOOTSTRAP\\\": true, \\\"OS_BOOTSTRAP_PASSWORD\\\": {\\\"get_param\\\": \\\"AdminPassword\\\"}, \\\"OS_BOOTSTRAP_USERNAME\\\": \\\"admin\\\", \\\"OS_BOOTSTRAP_PROJECT_NAME\\\": \\\"admin\\\", \\\"OS_BOOTSTRAP_ROLE_NAME\\\": \\\"admin\\\", \\\"OS_BOOTSTRAP_SERVICE_NAME\\\": \\\"keystone\\\", \\\"OS_BOOTSTRAP_ADMIN_URL\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneAdmin\\\", \\\"uri_no_suffix\\\"]}, \\\"OS_BOOTSTRAP_PUBLIC_URL\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystonePublic\\\", \\\"uri_no_suffix\\\"]}, \\\"OS_BOOTSTRAP_INTERNAL_URL\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"uri_no_suffix\\\"]}, \\\"OS_BOOTSTRAP_REGION_ID\\\": {\\\"get_param\\\": \\\"KeystoneRegion\\\"}}}, \\\"keystone_cron\\\": {\\\"start_order\\\": 4, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerKeystoneImage\\\"]}, \\\"user\\\": \\\"root\\\", \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/usr/share/openstack-tripleo-common/healthcheck/cron keystone\\\"}, \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"/usr/local/bin/kolla_set_configs && /usr/sbin/crond -n\\\"], \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"KeystoneLogging\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/keystone_cron.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/keystone:/var/lib/kolla/config_files/src:ro\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}, \\\"step_4\\\": {\\\"keystone_refresh\\\": {\\\"start_order\\\": 1, \\\"action\\\": \\\"exec\\\", \\\"user\\\": \\\"root\\\", \\\"command\\\": [\\\"keystone\\\", \\\"pkill\\\", \\\"--signal\\\", \\\"USR1\\\", \\\"httpd\\\"]}}}, \\\"external_deploy_tasks\\\": [{\\\"name\\\": \\\"Manage clouds.yaml files\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"not ansible_check_mode|bool\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Create /etc/openstack directory if it does not exist\\\", \\\"become\\\": true, \\\"file\\\": {\\\"mode\\\": \\\"0755\\\", \\\"owner\\\": \\\"root\\\", \\\"path\\\": \\\"/etc/openstack\\\", \\\"state\\\": \\\"directory\\\"}}, {\\\"name\\\": \\\"Configure /etc/openstack/clouds.yaml\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_keystone_resources\\\", \\\"tasks_from\\\": \\\"clouds\\\"}, \\\"vars\\\": {\\\"tripleo_keystone_resources_cloud_name\\\": {\\\"get_param\\\": \\\"RootStackName\\\"}, \\\"tripleo_keystone_resources_cloud_config\\\": {\\\"auth\\\": {\\\"auth_url\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystonePublic\\\", \\\"uri_no_suffix\\\"]}, \\\"password\\\": {\\\"get_param\\\": \\\"AdminPassword\\\"}, \\\"project_domain_name\\\": \\\"Default\\\", \\\"project_name\\\": \\\"admin\\\", \\\"user_domain_name\\\": \\\"Default\\\", \\\"username\\\": \\\"admin\\\"}, \\\"cacert\\\": {\\\"if\\\": [\\\"public_tls_enabled\\\", {\\\"get_param\\\": \\\"PublicTLSCAFile\\\"}, \\\"\\\"]}, \\\"identity_api_version\\\": \\\"3\\\", \\\"volume_api_version\\\": \\\"3\\\", \\\"region_name\\\": {\\\"get_param\\\": \\\"KeystoneRegion\\\"}}}}]}, {\\\"name\\\": \\\"Manage Keystone resources\\\", \\\"become\\\": true, \\\"when\\\": [\\\"step|int == 4\\\", \\\"not ansible_check_mode|bool\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Manage Keystone resources for OpenStack services\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_keystone_resources\\\"}, \\\"vars\\\": {\\\"tripleo_keystone_resources_catalog_config\\\": \\\"{{ keystone_resources }}\\\", \\\"tripleo_keystone_resources_service_project\\\": \\\"service\\\", \\\"tripleo_keystone_resources_cloud_name\\\": {\\\"get_param\\\": \\\"RootStackName\\\"}, \\\"tripleo_keystone_resources_region\\\": {\\\"get_param\\\": \\\"KeystoneRegion\\\"}, \\\"tripleo_keystone_resources_admin_endpoint\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneAdmin\\\", \\\"uri_no_suffix\\\"]}, \\\"tripleo_keystone_resources_public_endpoint\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystonePublic\\\", \\\"uri_no_suffix\\\"]}, \\\"tripleo_keystone_resources_internal_endpoint\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"uri_no_suffix\\\"]}, \\\"tripleo_keystone_resources_admin_password\\\": {\\\"get_param\\\": \\\"AdminPassword\\\"}, \\\"tripleo_keystone_resources_member_role_enabled\\\": {\\\"get_param\\\": \\\"KeystoneEnableMember\\\"}}}, {\\\"name\\\": \\\"is Keystone LDAP enabled\\\", \\\"set_fact\\\": {\\\"keystone_ldap_domain_enabled\\\": {\\\"get_param\\\": \\\"KeystoneLDAPDomainEnable\\\"}}}, {\\\"name\\\": \\\"Set fact for tripleo_keystone_ldap_domains\\\", \\\"set_fact\\\": {\\\"tripleo_keystone_ldap_domains\\\": {\\\"get_param\\\": \\\"KeystoneLDAPBackendConfigs\\\"}}, \\\"when\\\": \\\"keystone_ldap_domain_enabled|bool\\\"}, {\\\"name\\\": \\\"Manage Keystone domains from LDAP config\\\", \\\"when\\\": \\\"keystone_ldap_domain_enabled|bool\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_keystone_resources\\\", \\\"tasks_from\\\": \\\"domains\\\"}, \\\"vars\\\": {\\\"tripleo_keystone_resources_catalog_config\\\": \\\"{{ keystone_resources }}\\\", \\\"tripleo_keystone_resources_cloud_name\\\": {\\\"get_param\\\": \\\"RootStackName\\\"}, \\\"batched_tripleo_keystone_resources_domains\\\": \\\"{{ tripleo_keystone_ldap_domains | list }}\\\"}}]}], \\\"deploy_steps_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ApacheServiceBase\\\", \\\"role_data\\\", \\\"deploy_steps_tasks\\\"]}, [{\\\"name\\\": \\\"validate keystone container state\\\", \\\"containers.podman.podman_container_info\\\": {\\\"name\\\": \\\"keystone\\\"}, \\\"register\\\": \\\"keystone_infos\\\", \\\"failed_when\\\": [\\\"keystone_infos.containers.0.Healthcheck.Status is defined\\\", \\\"\'healthy\' not in keystone_infos.containers.0.Healthcheck.Status\\\"], \\\"retries\\\": 10, \\\"delay\\\": 30, \\\"tags\\\": [\\\"opendev-validation\\\", \\\"opendev-validation-keystone\\\"], \\\"when\\\": [\\\"container_cli == \'podman\'\\\", \\\"not container_healthcheck_disabled\\\", \\\"step|int == 4\\\"]}]]}, \\\"host_prep_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"KeystoneLogging\\\", \\\"host_prep_tasks\\\"]}, [{\\\"name\\\": \\\"Check if file certs_valid exist\\\", \\\"stat\\\": {\\\"path\\\": \\\"/etc/openldap/certs/certs_valid\\\"}, \\\"register\\\": \\\"certs_valid_stat\\\"}, {\\\"name\\\": \\\"Check if file cert9.db exist\\\", \\\"stat\\\": {\\\"path\\\": \\\"/etc/openldap/certs/cert9.db\\\"}, \\\"register\\\": \\\"cert9_stat\\\", \\\"when\\\": \\\"not certs_valid_stat.stat.exists\\\"}, {\\\"name\\\": \\\"Check if file key4.db exist\\\", \\\"stat\\\": {\\\"path\\\": \\\"/etc/openldap/certs/key4.db\\\"}, \\\"register\\\": \\\"key4_stat\\\", \\\"when\\\": \\\"not certs_valid_stat.stat.exists\\\"}, {\\\"fail\\\": {\\\"msg\\\": \\\"Keys and/or certificates were found in /etc/openldap/certs but these conflicts with keystone python LDAP calls.  If you know those certificates are valid and not causing any conflicts, you can touch /etc/openldap/certs/certs_valid in order to skip this failure and retry or you can delete the files located in /etc/openldap/certs and retry.\\\\n\\\"}, \\\"when\\\": \\\"( cert9_stat.stat.exists or key4_stat.stat.exists ) and not certs_valid_stat.stat.exists\\\"}]]}, \\\"metadata_settings\\\": {\\\"get_attr\\\": [\\\"ApacheServiceBase\\\", \\\"role_data\\\", \\\"metadata_settings\\\"]}, \\\"external_upgrade_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade_transfer_data\\\", \\\"system_upgrade_stop_services\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Stop keystone container\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_stop\\\"}, \\\"vars\\\": {\\\"tripleo_containers_to_stop\\\": [\\\"keystone\\\", \\\"keystone_cron\\\"], \\\"tripleo_delegate_to\\\": \\\"{{ groups[\'keystone\'] | difference(groups[\'excluded_overcloud\']) }}\\\"}}]}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack Glance service configured with Puppet\\\\n\\\", \\\"parameters\\\": {\\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"DeployIdentifier\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\\\n\\\"}, \\\"Debug\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Set to True to enable debugging on all services.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"GlanceDebug\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Set to True to enable debugging Glance service.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"EnableSQLAlchemyCollectd\\\": {\\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"Set to true to enable the SQLAlchemy-collectd server plugin\\\\n\\\", \\\"default\\\": false}, \\\"GlancePassword\\\": {\\\"description\\\": \\\"The password for the glance service and db account, used by the glance services.\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"GlanceWorkers\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Number of API worker processes for Glance. If left unset (empty string), the\\\\ndefault value will result in the configuration being left unset and a\\\\nsystem-dependent default value will be chosen (e.g.: number of\\\\nprocessors). Please note that this will create a large number of\\\\nprocesses on systems with a large number of CPUs resulting in excess\\\\nmemory consumption. It is recommended that a suitable non-default value\\\\nbe selected on such systems.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"MonitoringSubscriptionGlanceApi\\\": {\\\"default\\\": \\\"overcloud-glance-api\\\", \\\"type\\\": \\\"string\\\"}, \\\"GlanceApiLoggingSource\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {\\\"tag\\\": \\\"openstack.glance.api\\\", \\\"file\\\": \\\"/var/log/containers/glance/api.log\\\"}}, \\\"GlanceImageMemberQuota\\\": {\\\"default\\\": 128, \\\"description\\\": \\\"Maximum number of image members per image.\\\\nNegative values evaluate to unlimited.\\\\n\\\", \\\"type\\\": \\\"number\\\"}, \\\"GlanceNfsEnabled\\\": {\\\"default\\\": false, \\\"description\\\": \\\"When using GlanceBackend \'file\', mount NFS share for image storage.\\\\n\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"GlanceCacheEnabled\\\": {\\\"description\\\": \\\"Enable Glance Image Cache\\\", \\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"GlanceImageCacheDir\\\": {\\\"description\\\": \\\"Base directory that the Image Cache uses\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"/var/lib/glance/image-cache\\\"}, \\\"GlanceImageCacheMaxSize\\\": {\\\"description\\\": \\\"The upper limit on cache size, in bytes, after which the cache-pruner cleans up the image cache.\\\\n\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 10737418240}, \\\"GlanceImageCacheStallTime\\\": {\\\"description\\\": \\\"The amount of time, in seconds, to let an image remain in the cache without being accessed.\\\\n\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 86400}, \\\"GlanceImagePrefetcherInterval\\\": {\\\"description\\\": \\\"The interval in seconds to run periodic job cache_images.\\\\n\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 300}, \\\"GlanceNfsShare\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"NFS share to mount for image storage (when GlanceNfsEnabled is true)\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"GlanceNetappNfsEnabled\\\": {\\\"default\\\": false, \\\"description\\\": \\\"When using GlanceBackend \'file\', Netapp mount NFS share for image storage.\\\\n\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"NetappShareLocation\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Netapp share to mount for image storage (when GlanceNetappNfsEnabled is true)\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"GlanceNfsOptions\\\": {\\\"default\\\": \\\"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\\\", \\\"description\\\": \\\"NFS mount options for image storage (when GlanceNfsEnabled is true)\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"GlanceRbdPoolName\\\": {\\\"default\\\": \\\"images\\\", \\\"type\\\": \\\"string\\\"}, \\\"NovaEnableRbdBackend\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to enable the Rbd backend for Nova ephemeral storage.\\\", \\\"type\\\": \\\"boolean\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"GlanceImageImportPlugins\\\": {\\\"default\\\": [\\\"no_op\\\"], \\\"description\\\": \\\"List of enabled Image Import Plugins. Valid values in the list are \'image_conversion\', \'inject_metadata\', \'no_op\'.\\\\n\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"GlanceDiskFormats\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"List of allowed disk formats in Glance; all formats are allowed when left unset.\\\\n\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"GlanceImageConversionOutputFormat\\\": {\\\"default\\\": \\\"raw\\\", \\\"description\\\": \\\"Desired output format for image conversion plugin.\\\", \\\"type\\\": \\\"string\\\"}, \\\"GlanceInjectMetadataProperties\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Metadata properties to be injected in image.\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"GlanceIgnoreUserRoles\\\": {\\\"default\\\": \\\"admin\\\", \\\"description\\\": \\\"List of user roles to be ignored for injecting image metadata properties.\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"GlanceEnabledImportMethods\\\": {\\\"default\\\": \\\"web-download\\\", \\\"description\\\": \\\"List of enabled Image Import Methods. Valid values in the list are \'glance-direct\', \'web-download\', or \'copy-image\'\\\\n\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"GlanceStagingNfsShare\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"NFS share to mount for image import staging\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"GlanceNodeStagingUri\\\": {\\\"default\\\": \\\"file:///var/lib/glance/staging\\\", \\\"description\\\": \\\"URI that specifies the staging location to use when importing images\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"GlanceStagingNfsOptions\\\": {\\\"default\\\": \\\"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\\\", \\\"description\\\": \\\"NFS mount options for NFS image import staging\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"GlanceSparseUploadEnabled\\\": {\\\"default\\\": false, \\\"description\\\": \\\"When using GlanceBackend \'file\' and \'rbd\' to enable or not sparse upload.\\\\n\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"EnforceSecureRbac\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false, \\\"description\\\": \\\"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\\\"}, \\\"KeystoneRegion\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"regionOne\\\", \\\"description\\\": \\\"Keystone region for endpoint\\\"}, \\\"GlanceApiPolicies\\\": {\\\"description\\\": \\\"A hash of policies to configure for Glance API.\\\\ne.g. { glance-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\\\n\\\", \\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}, \\\"NotificationDriver\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": \\\"noop\\\", \\\"description\\\": \\\"Driver or drivers to handle sending notifications.\\\"}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"GlanceNotifierStrategy\\\": {\\\"description\\\": \\\"Strategy to use for Glance notification queue\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"noop\\\"}, \\\"GlanceLogFile\\\": {\\\"description\\\": \\\"The filepath of the file to use for logging messages from Glance.\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\"}, \\\"GlanceBackend\\\": {\\\"default\\\": \\\"swift\\\", \\\"description\\\": \\\"The short name of the Glance backend to use. Should be one of swift, rbd, cinder, or file\\\", \\\"type\\\": \\\"string\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"swift\\\", \\\"file\\\", \\\"rbd\\\", \\\"cinder\\\"]}]}, \\\"GlanceBackendID\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"default_backend\\\", \\\"description\\\": \\\"The default backend\'s identifier.\\\", \\\"constraints\\\": [{\\\"allowed_pattern\\\": \\\"[a-zA-Z0-9_-]+\\\"}]}, \\\"GlanceStoreDescription\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"Default glance store backend.\\\", \\\"description\\\": \\\"User facing description for the Glance backend.\\\"}, \\\"GlanceMultistoreConfig\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {}, \\\"description\\\": \\\"Dictionary of settings when configuring additional glance backends. The\\\\nhash key is the backend ID, and the value is a dictionary of parameter\\\\nvalues unique to that backend. Multiple rbd and cinder backends are allowed, but\\\\nfile and swift backends are limited to one each. Example:\\\\n  # Default glance store is rbd.\\\\n  GlanceBackend: rbd\\\\n  GlanceStoreDescription: \'Default rbd store\'\\\\n  # GlanceMultistoreConfig specifies a second rbd backend, plus a cinder\\\\n  # backend.\\\\n  GlanceMultistoreConfig:\\\\n    rbd2_store:\\\\n      GlanceBackend: rbd\\\\n      GlanceStoreDescription: \'Second rbd store\'\\\\n      CephClusterName: ceph2\\\\n      # Override CephClientUserName if this cluster uses a different\\\\n      # client name.\\\\n      CephClientUserName: client2\\\\n    cinder1_store:\\\\n      GlanceBackend: cinder\\\\n      GlanceCinderVolumeType: \'volume-type-1\'\\\\n      GlanceStoreDescription: \'First cinder store\'\\\\n    cinder2_store:\\\\n      GlanceBackend: cinder\\\\n      GlanceCinderVolumeType: \'volume-type-2\'\\\\n      GlanceStoreDescription: \'Seconde cinder store\'\\\\n\\\"}, \\\"GlanceCinderMountPointBase\\\": {\\\"default\\\": \\\"/var/lib/glance/mnt\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"The mount point base when glance is using cinder as store and cinder backend\\\\nis NFS. This mount point is where the NFS volume is mounted on the glance node.\\\\n\\\"}, \\\"GlanceCinderVolumeType\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"A unique volume type required for each cinder store while configuring multiple cinder\\\\nstores as glance backends. The same volume types must be configured in Cinder as well.\\\\nThe volume type must exist in cinder prior to any attempt to add an image in the associated\\\\ncinder store. If no volume type is specified then cinder\'s default volume type will be used.\\\\n\\\"}, \\\"GlanceCinderLockPath\\\": {\\\"default\\\": \\\"/var/lib/cinder/tmp\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"The oslo.coordination lock_path to use when glance is using cinder as a store. Using\\\\ncinder\'s lock_path ensures os-brick operations are synchronized across both services.\\\\n\\\"}, \\\"CephClientUserName\\\": {\\\"default\\\": \\\"openstack\\\", \\\"type\\\": \\\"string\\\"}, \\\"CephClusterName\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"ceph\\\", \\\"description\\\": \\\"The Ceph cluster name.\\\", \\\"constraints\\\": [{\\\"allowed_pattern\\\": \\\"[a-zA-Z0-9]+\\\", \\\"description\\\": \\\"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\\\n\\\"}]}, \\\"CephConfigPath\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"/var/lib/tripleo-config/ceph\\\", \\\"description\\\": \\\"The path where the Ceph Cluster config files are stored on the host.\\\\n\\\"}, \\\"MultipathdEnable\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to enable the multipath daemon\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"GlanceApiOptVolumes\\\": {\\\"default\\\": [], \\\"description\\\": \\\"list of optional volumes to be mounted\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"ContainerGlanceApiImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerGlanceApiConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the glance_api config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"GlanceCronDbPurgeMinute\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge db entries marked as deleted and older than $age - Minute\\\\n\\\", \\\"default\\\": \\\"1\\\"}, \\\"GlanceCronDbPurgeHour\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge db entries marked as deleted and older than $age - Hour\\\\n\\\", \\\"default\\\": \\\"0\\\"}, \\\"GlanceCronDbPurgeMonthday\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge db entries marked as deleted and older than $age - Month Day\\\\n\\\", \\\"default\\\": \\\"*\\\"}, \\\"GlanceCronDbPurgeMonth\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge db entries marked as deleted and older than $age - Month\\\\n\\\", \\\"default\\\": \\\"*\\\"}, \\\"GlanceCronDbPurgeWeekday\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge db entries marked as deleted and older than $age - Week Day\\\\n\\\", \\\"default\\\": \\\"*\\\"}, \\\"GlanceCronDbPurgeUser\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge db entries marked as deleted and older than $age - User\\\\n\\\", \\\"default\\\": \\\"glance\\\"}, \\\"GlanceCronDbPurgeAge\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge db entries marked as deleted and older than $age - Age\\\\n\\\", \\\"default\\\": \\\"30\\\"}, \\\"GlanceCronDbPurgeMaxRows\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge db entries marked as deleted and older than $age - Max Rows\\\\n\\\", \\\"default\\\": \\\"100\\\"}, \\\"GlanceCronDbPurgeDestination\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge db entries marked as deleted and older than $age - Log destination\\\\n\\\", \\\"default\\\": \\\"/var/log/glance/glance-rowsflush.log\\\"}, \\\"GlanceCronDbPurgeMaxDelay\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge db entries marked as deleted and older than $age - Max Delay\\\\n\\\", \\\"default\\\": \\\"3600\\\"}, \\\"MemcacheUseAdvancedPool\\\": {\\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"Use the advanced (eventlet safe) memcached client pool.\\\\n\\\", \\\"default\\\": true}, \\\"GlanceShowMultipleLocations\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to show multiple image locations e.g for copy-on-write support on\\\\nRBD or Netapp backends. Potential security risk, see glance.conf for more information.\\\\n\\\", \\\"type\\\": \\\"boolean\\\"}}, \\\"parameter_groups\\\": [{\\\"label\\\": \\\"deprecated\\\", \\\"description\\\": \\\"The following parameters are deprecated and will be removed. They should not\\\\nbe relied on for new deployments.\\\\n\\\", \\\"parameters\\\": [\\\"GlanceShowMultipleLocations\\\"]}], \\\"conditions\\\": {\\\"cinder_backend_enabled\\\": {\\\"or\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"GlanceBackend\\\"}, \\\"cinder\\\"]}, {\\\"yaql\\\": {\\\"expression\\\": \\\"$.data.values().any($.get(\\\\\\\"GlanceBackend\\\\\\\", \\\\\\\"\\\\\\\") = \\\\\\\"cinder\\\\\\\")\\\", \\\"data\\\": {\\\"get_param\\\": \\\"GlanceMultistoreConfig\\\"}}}]}, \\\"cinder_multipathd_enabled\\\": {\\\"and\\\": [\\\"cinder_backend_enabled\\\", {\\\"get_param\\\": \\\"MultipathdEnable\\\"}]}, \\\"rbd_backend_enabled\\\": {\\\"or\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"GlanceBackend\\\"}, \\\"rbd\\\"]}, {\\\"yaql\\\": {\\\"expression\\\": \\\"$.data.values().any($.get(\\\\\\\"GlanceBackend\\\\\\\", \\\\\\\"\\\\\\\") = \\\\\\\"rbd\\\\\\\")\\\", \\\"data\\\": {\\\"get_param\\\": \\\"GlanceMultistoreConfig\\\"}}}]}, \\\"force_image_conversion_plugin\\\": {\\\"or\\\": [{\\\"and\\\": [\\\"rbd_backend_enabled\\\", {\\\"equals\\\": [{\\\"get_param\\\": \\\"GlanceImageImportPlugins\\\"}, [\\\"no_op\\\"]]}, {\\\"get_param\\\": \\\"NovaEnableRbdBackend\\\"}]}, {\\\"get_param\\\": \\\"GlanceSparseUploadEnabled\\\"}]}, \\\"glance_workers_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"GlanceWorkers\\\"}, \\\"\\\"]}}, \\\"glance_multiple_locations\\\": {\\\"or\\\": [{\\\"get_param\\\": \\\"GlanceShowMultipleLocations\\\"}, {\\\"get_param\\\": \\\"GlanceNetappNfsEnabled\\\"}, {\\\"and\\\": [\\\"rbd_backend_enabled\\\", {\\\"get_param\\\": \\\"NovaEnableRbdBackend\\\"}]}]}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"MySQLClient\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\\\"}, \\\"GlanceLogging\\\": {\\\"type\\\": \\\"OS::TripleO::Services::Logging::GlanceApi\\\"}, \\\"CinderNVMeOF\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\\\"}, \\\"TLSProxyBase\\\": {\\\"type\\\": \\\"OS::TripleO::Services::TLSProxyBase\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}, \\\"EnableInternalTLS\\\": {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}}}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerGlanceApiImage\\\": \\\"ContainerGlanceApiImage\\\", \\\"ContainerGlanceApiConfigImage\\\": \\\"ContainerGlanceApiConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerGlanceApiImage\\\": {\\\"get_param\\\": \\\"ContainerGlanceApiImage\\\"}, \\\"ContainerGlanceApiConfigImage\\\": {\\\"get_param\\\": \\\"ContainerGlanceApiConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"glance_api_host_prep_and_system_upgrade_post_tasks\\\": {\\\"description\\\": \\\"Common host_prep and system_upgrade post tasks for glance_api\\\", \\\"value\\\": [{\\\"name\\\": \\\"Mount NFS on host\\\", \\\"vars\\\": {\\\"nfs_backend_enabled\\\": {\\\"get_param\\\": \\\"GlanceNfsEnabled\\\"}, \\\"glance_netapp_nfs_enabled\\\": {\\\"get_param\\\": \\\"GlanceNetappNfsEnabled\\\"}, \\\"glance_nfs_share\\\": {\\\"get_param\\\": \\\"GlanceNfsShare\\\"}, \\\"netapp_share_location\\\": {\\\"get_param\\\": \\\"NetappShareLocation\\\"}, \\\"nfs_share\\\": \\\"{{ glance_nfs_share if (glance_nfs_share) else netapp_share_location }}\\\", \\\"nfs_options\\\": {\\\"get_param\\\": \\\"GlanceNfsOptions\\\"}}, \\\"mount\\\": {\\\"name\\\": \\\"/var/lib/glance/images\\\", \\\"state\\\": \\\"mounted\\\", \\\"fstype\\\": \\\"nfs\\\", \\\"src\\\": \\\"{{nfs_share}}\\\", \\\"opts\\\": \\\"{{nfs_options}}\\\"}, \\\"when\\\": \\\"nfs_backend_enabled or glance_netapp_nfs_enabled\\\"}, {\\\"name\\\": \\\"Mount Node Staging Location\\\", \\\"vars\\\": {\\\"glance_node_staging_uri\\\": {\\\"get_param\\\": \\\"GlanceNodeStagingUri\\\"}, \\\"glance_staging_nfs_share\\\": {\\\"get_param\\\": \\\"GlanceStagingNfsShare\\\"}, \\\"glance_nfs_options\\\": {\\\"get_param\\\": \\\"GlanceStagingNfsOptions\\\"}}, \\\"mount\\\": {\\\"name\\\": \\\"{{glance_node_staging_uri[7:]}}\\\", \\\"state\\\": \\\"mounted\\\", \\\"fstype\\\": \\\"nfs\\\", \\\"src\\\": \\\"{{glance_staging_nfs_share}}\\\", \\\"opts\\\": \\\"{{glance_nfs_options}}\\\"}, \\\"when\\\": \\\"glance_staging_nfs_share != \'\'\\\"}]}, \\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Glance API role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"glance_api\\\", \\\"firewall_rules\\\": {\\\"112 glance_api\\\": {\\\"dport\\\": [9292]}}, \\\"firewall_frontend_rules\\\": {\\\"100 glance_api_haproxy_frontend\\\": {\\\"dport\\\": [9292]}}, \\\"firewall_ssl_frontend_rules\\\": {\\\"100 glance_api_haproxy_frontend_ssl\\\": {\\\"dport\\\": [13292]}}, \\\"keystone_resources\\\": {\\\"glance\\\": {\\\"endpoints\\\": {\\\"public\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GlancePublic\\\", \\\"uri\\\"]}, \\\"internal\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GlanceInternal\\\", \\\"uri\\\"]}, \\\"admin\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GlanceAdmin\\\", \\\"uri\\\"]}}, \\\"users\\\": {\\\"glance\\\": {\\\"password\\\": {\\\"get_param\\\": \\\"GlancePassword\\\"}}}, \\\"region\\\": {\\\"get_param\\\": \\\"KeystoneRegion\\\"}, \\\"service\\\": \\\"image\\\"}}, \\\"monitoring_subscription\\\": {\\\"get_param\\\": \\\"MonitoringSubscriptionGlanceApi\\\"}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"TLSProxyBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"glance::api::db::database_connection\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"MysqlInternal\\\", \\\"protocol\\\"]}, \\\"username\\\": \\\"glance\\\", \\\"password\\\": {\\\"get_param\\\": \\\"GlancePassword\\\"}, \\\"host\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"MysqlInternal\\\", \\\"host\\\"]}, \\\"path\\\": \\\"/glance\\\", \\\"query\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableSQLAlchemyCollectd\\\"}, {\\\"read_default_file\\\": \\\"/etc/my.cnf.d/tripleo.cnf\\\", \\\"read_default_group\\\": \\\"tripleo\\\", \\\"plugin\\\": \\\"collectd\\\", \\\"collectd_program_name\\\": \\\"glance\\\", \\\"collectd_host\\\": \\\"localhost\\\"}, {\\\"read_default_file\\\": \\\"/etc/my.cnf.d/tripleo.cnf\\\", \\\"read_default_group\\\": \\\"tripleo\\\"}]}}}, \\\"glance::api::authtoken::www_authenticate_uri\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystonePublic\\\", \\\"uri_no_suffix\\\"]}, \\\"glance::api::authtoken::auth_url\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"uri_no_suffix\\\"]}, \\\"glance::api::enable_v1_api\\\": false, \\\"glance::api::enable_v2_api\\\": true, \\\"glance::api::authtoken::password\\\": {\\\"get_param\\\": \\\"GlancePassword\\\"}, \\\"glance::api::enable_proxy_headers_parsing\\\": true, \\\"glance::api::logging::debug\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"GlanceDebug\\\"}, true, {\\\"get_param\\\": \\\"Debug\\\"}]}, \\\"glance::policy::policies\\\": {\\\"get_param\\\": \\\"GlanceApiPolicies\\\"}, \\\"glance::api::authtoken::project_name\\\": \\\"service\\\", \\\"glance::api::authtoken::region_name\\\": {\\\"get_param\\\": \\\"KeystoneRegion\\\"}, \\\"glance::api::authtoken::user_domain_name\\\": \\\"Default\\\", \\\"glance::api::authtoken::project_domain_name\\\": \\\"Default\\\", \\\"glance::api::authtoken::interface\\\": \\\"internal\\\", \\\"glance::api::authtoken::memcache_use_advanced_pool\\\": {\\\"get_param\\\": \\\"MemcacheUseAdvancedPool\\\"}, \\\"glance::api::pipeline\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"GlanceCacheEnabled\\\"}, \\\"keystone+cachemanagement\\\", \\\"keystone\\\"]}, \\\"glance::api::os_region_name\\\": {\\\"get_param\\\": \\\"KeystoneRegion\\\"}, \\\"glance::api::image_member_quota\\\": {\\\"get_param\\\": \\\"GlanceImageMemberQuota\\\"}, \\\"glance::api::enabled_import_methods\\\": {\\\"get_param\\\": \\\"GlanceEnabledImportMethods\\\"}, \\\"glance::api::node_staging_uri\\\": {\\\"get_param\\\": \\\"GlanceNodeStagingUri\\\"}, \\\"glance::api::image_import_plugins\\\": {\\\"if\\\": [\\\"force_image_conversion_plugin\\\", {\\\"list_concat_unique\\\": [{\\\"get_param\\\": \\\"GlanceImageImportPlugins\\\"}, [\\\"image_conversion\\\"]]}, {\\\"get_param\\\": \\\"GlanceImageImportPlugins\\\"}]}, \\\"glance::api::image_conversion_output_format\\\": {\\\"get_param\\\": \\\"GlanceImageConversionOutputFormat\\\"}, \\\"glance::api::inject_metadata_properties\\\": {\\\"get_param\\\": \\\"GlanceInjectMetadataProperties\\\"}, \\\"glance::api::ignore_user_roles\\\": {\\\"get_param\\\": \\\"GlanceIgnoreUserRoles\\\"}, \\\"tripleo::profile::base::glance::api::tls_proxy_bind_ip\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GlanceApiNetwork\\\"]}}}}, \\\"tripleo::profile::base::glance::api::tls_proxy_fqdn\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'fqdn_$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GlanceApiNetwork\\\"]}}}}, \\\"tripleo::profile::base::glance::api::tls_proxy_port\\\": 9292, \\\"glance::api::bind_host\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, \\\"%{hiera(\'localhost_address\')}\\\", {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GlanceApiNetwork\\\"]}}}}]}, \\\"glance_notifier_strategy\\\": {\\\"get_param\\\": \\\"GlanceNotifierStrategy\\\"}, \\\"glance_log_file\\\": {\\\"get_param\\\": \\\"GlanceLogFile\\\"}, \\\"glance::backend::rbd::rbd_thin_provisioning\\\": {\\\"get_param\\\": \\\"GlanceSparseUploadEnabled\\\"}, \\\"glance::backend::file::filesystem_thin_provisioning\\\": {\\\"get_param\\\": \\\"GlanceSparseUploadEnabled\\\"}, \\\"glance::backend::swift::swift_store_auth_address\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneV3Internal\\\", \\\"uri\\\"]}, \\\"glance::backend::swift::swift_store_user\\\": \\\"service:glance\\\", \\\"glance::backend::swift::swift_store_key\\\": {\\\"get_param\\\": \\\"GlancePassword\\\"}, \\\"glance::backend::swift::swift_store_create_container_on_put\\\": true, \\\"glance::backend::swift::swift_store_auth_version\\\": 3, \\\"glance::backend::rbd::rbd_store_ceph_conf\\\": {\\\"list_join\\\": [\\\"\\\", [\\\"/etc/ceph/\\\", {\\\"get_param\\\": \\\"CephClusterName\\\"}, \\\".conf\\\"]]}, \\\"glance::backend::rbd::rbd_store_pool\\\": {\\\"get_param\\\": \\\"GlanceRbdPoolName\\\"}, \\\"glance::backend::rbd::rbd_store_user\\\": {\\\"get_param\\\": \\\"CephClientUserName\\\"}, \\\"glance_backend\\\": {\\\"get_param\\\": \\\"GlanceBackend\\\"}, \\\"tripleo::profile::base::glance::api::glance_backend_id\\\": {\\\"get_param\\\": \\\"GlanceBackendID\\\"}, \\\"tripleo::profile::base::glance::api::glance_store_description\\\": {\\\"get_param\\\": \\\"GlanceStoreDescription\\\"}, \\\"tripleo::profile::base::glance::api::multistore_config\\\": {\\\"get_param\\\": \\\"GlanceMultistoreConfig\\\"}, \\\"tripleo::profile::base::glance::backend::rbd::glance_rbd_ceph_conf_path\\\": {\\\"get_param\\\": \\\"CephConfigPath\\\"}, \\\"glance::notify::rabbitmq::notification_driver\\\": {\\\"get_param\\\": \\\"NotificationDriver\\\"}, \\\"glance::notify::rabbitmq::rabbit_heartbeat_in_pthread\\\": false, \\\"glance::cron::db_purge::minute\\\": {\\\"get_param\\\": \\\"GlanceCronDbPurgeMinute\\\"}, \\\"glance::cron::db_purge::hour\\\": {\\\"get_param\\\": \\\"GlanceCronDbPurgeHour\\\"}, \\\"glance::cron::db_purge::monthday\\\": {\\\"get_param\\\": \\\"GlanceCronDbPurgeMonthday\\\"}, \\\"glance::cron::db_purge::month\\\": {\\\"get_param\\\": \\\"GlanceCronDbPurgeMonth\\\"}, \\\"glance::cron::db_purge::weekday\\\": {\\\"get_param\\\": \\\"GlanceCronDbPurgeWeekday\\\"}, \\\"glance::cron::db_purge::user\\\": {\\\"get_param\\\": \\\"GlanceCronDbPurgeUser\\\"}, \\\"glance::cron::db_purge::age\\\": {\\\"get_param\\\": \\\"GlanceCronDbPurgeAge\\\"}, \\\"glance::cron::db_purge::max_rows\\\": {\\\"get_param\\\": \\\"GlanceCronDbPurgeMaxRows\\\"}, \\\"glance::cron::db_purge::destination\\\": {\\\"get_param\\\": \\\"GlanceCronDbPurgeDestination\\\"}, \\\"glance::cron::db_purge::maxdelay\\\": {\\\"get_param\\\": \\\"GlanceCronDbPurgeMaxDelay\\\"}}, {\\\"if\\\": [\\\"glance_workers_set\\\", {\\\"glance::api::workers\\\": {\\\"get_param\\\": \\\"GlanceWorkers\\\"}}]}, {\\\"if\\\": [{\\\"get_param\\\": \\\"EnforceSecureRbac\\\"}, {\\\"glance::api::enforce_secure_rbac\\\": true, \\\"glance::policy::enforce_new_defaults\\\": true}]}, {\\\"if\\\": [\\\"cinder_backend_enabled\\\", {\\\"glance::backend::cinder::cinder_store_auth_address\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneV3Internal\\\", \\\"uri\\\"]}, \\\"glance::backend::cinder::cinder_store_project_name\\\": \\\"service\\\", \\\"glance::backend::cinder::cinder_store_user_name\\\": \\\"glance\\\", \\\"glance::backend::cinder::cinder_store_password\\\": {\\\"get_param\\\": \\\"GlancePassword\\\"}, \\\"glance::api::lock_path\\\": {\\\"get_param\\\": \\\"GlanceCinderLockPath\\\"}, \\\"tripleo::profile::base::glance::backend::cinder::cinder_mount_point_base\\\": {\\\"get_param\\\": \\\"GlanceCinderMountPointBase\\\"}, \\\"tripleo::profile::base::glance::backend::cinder::cinder_volume_type\\\": {\\\"get_param\\\": \\\"GlanceCinderVolumeType\\\"}}]}, {\\\"if\\\": [\\\"cinder_multipathd_enabled\\\", {\\\"glance::backend::cinder::cinder_use_multipath\\\": true}]}, {\\\"if\\\": [{\\\"get_param\\\": \\\"GlanceCacheEnabled\\\"}, {\\\"tripleo::profile::base::glance::api::glance_enable_cache\\\": true, \\\"glance::api::image_cache_dir\\\": {\\\"get_param\\\": \\\"GlanceImageCacheDir\\\"}, \\\"glance::api::image_cache_max_size\\\": {\\\"get_param\\\": \\\"GlanceImageCacheMaxSize\\\"}, \\\"glance::api::image_cache_stall_time\\\": {\\\"get_param\\\": \\\"GlanceImageCacheStallTime\\\"}, \\\"glance::api::cache_prefetcher_interval\\\": {\\\"get_param\\\": \\\"GlanceImagePrefetcherInterval\\\"}}]}, {\\\"if\\\": [{\\\"get_param\\\": \\\"GlanceNetappNfsEnabled\\\"}, {\\\"tripleo::profile::base::glance::netapp::netapp_share\\\": {\\\"get_param\\\": \\\"NetappShareLocation\\\"}, \\\"glance::api::filesystem_store_metadata_file\\\": \\\"/etc/glance/glance-metadata-file.json\\\", \\\"glance::api::filesystem_store_file_perm\\\": \\\"0644\\\"}]}, {\\\"if\\\": [{\\\"contains\\\": [\\\"glance-direct\\\", {\\\"get_param\\\": \\\"GlanceEnabledImportMethods\\\"}]}, {\\\"glance::api::worker_self_reference_url\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, {\\\"str_replace\\\": {\\\"template\\\": \\\"https://%{hiera(\'fqdn_NETWORK\')}:PORT\\\", \\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GlanceApiNetwork\\\"]}, \\\"PORT\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GlanceInternal\\\", \\\"port\\\"]}}}}, {\\\"str_replace\\\": {\\\"template\\\": \\\"http://%{hiera(\'NETWORK_uri\')}:PORT\\\", \\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"GlanceApiNetwork\\\"]}, \\\"PORT\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GlanceInternal\\\", \\\"port\\\"]}}}}]}}]}, {\\\"if\\\": [{\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"GlanceDiskFormats\\\"}, []]}}, {\\\"glance::api::disk_formats\\\": {\\\"get_param\\\": \\\"GlanceDiskFormats\\\"}}]}]}, \\\"service_config_settings\\\": {\\\"mysql\\\": {\\\"glance::db::mysql::password\\\": {\\\"get_param\\\": \\\"GlancePassword\\\"}, \\\"glance::db::mysql::user\\\": \\\"glance\\\", \\\"glance::db::mysql::host\\\": \\\"%\\\", \\\"glance::db::mysql::dbname\\\": \\\"glance\\\"}, \\\"rsyslog\\\": {\\\"tripleo_logging_sources_glance_api\\\": [{\\\"get_param\\\": \\\"GlanceApiLoggingSource\\\"}]}}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"glance_api\\\", \\\"puppet_tags\\\": \\\"glance_api_config,glance_api_paste_ini,glance_swift_config,glance_cache_config,glance_image_import_config\\\", \\\"step_config\\\": {\\\"list_join\\\": [\\\"\\\\n\\\", [\\\"include tripleo::profile::base::glance::api\\\", {\\\"if\\\": [{\\\"get_param\\\": \\\"GlanceNetappNfsEnabled\\\"}, \\\"include tripleo::profile::base::glance::netapp\\\"]}, {\\\"get_attr\\\": [\\\"MySQLClient\\\", \\\"role_data\\\", \\\"step_config\\\"]}]]}, \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerGlanceApiConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/glance_api.json\\\": {\\\"command\\\": \\\"/usr/bin/glance-api --config-file /usr/share/glance/glance-api-dist.conf --config-file /etc/glance/glance-api.conf --config-file /etc/glance/glance-image-import.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-ceph/\\\", \\\"dest\\\": \\\"/etc/ceph/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-iscsid/*\\\", \\\"dest\\\": \\\"/etc/iscsi/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": {\\\"list_concat\\\": [[{\\\"path\\\": \\\"/var/lib/glance\\\", \\\"owner\\\": \\\"glance:glance\\\", \\\"recurse\\\": true}, {\\\"path\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"/etc/ceph/CLUSTER.client.USER.keyring\\\", \\\"params\\\": {\\\"CLUSTER\\\": {\\\"get_param\\\": \\\"CephClusterName\\\"}, \\\"USER\\\": {\\\"get_param\\\": \\\"CephClientUserName\\\"}}}}, \\\"owner\\\": \\\"glance:glance\\\", \\\"perm\\\": \\\"0600\\\"}], {\\\"repeat\\\": {\\\"template\\\": {\\\"path\\\": \\\"/etc/ceph/<%keyring%>\\\", \\\"owner\\\": \\\"glance:glance\\\", \\\"perm\\\": \\\"0600\\\"}, \\\"for_each\\\": {\\\"<%keyring%>\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"let(u => $.data.user) -> $.data.multistore.values().where($.get(\\\\\\\"CephClusterName\\\\\\\")).select($.CephClusterName + \\\\\\\".client.\\\\\\\" + $.get(\\\\\\\"CephClientUserName\\\\\\\", $u) +\\\\\\\".keyring\\\\\\\")\\\", \\\"data\\\": {\\\"user\\\": {\\\"get_param\\\": \\\"CephClientUserName\\\"}, \\\"multistore\\\": {\\\"get_param\\\": \\\"GlanceMultistoreConfig\\\"}}}}}}}]}}, \\\"/var/lib/kolla/config_files/glance_api_tls_proxy.json\\\": {\\\"command\\\": \\\"/usr/sbin/httpd -DFOREGROUND\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/etc/httpd/conf.d\\\", \\\"dest\\\": \\\"/etc/httpd/conf.d\\\", \\\"merge\\\": false, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\\\", \\\"dest\\\": \\\"/etc/httpd/conf.modules.d\\\", \\\"merge\\\": false, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}, \\\"/var/lib/kolla/config_files/glance_api_cron.json\\\": {\\\"command\\\": \\\"/usr/sbin/crond -n\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/glance\\\", \\\"owner\\\": \\\"glance:glance\\\", \\\"recurse\\\": true}]}}, \\\"docker_config\\\": {\\\"step_2\\\": {\\\"get_attr\\\": [\\\"GlanceLogging\\\", \\\"docker_config\\\", \\\"step_2\\\"]}, \\\"step_3\\\": {\\\"glance_api_db_sync\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerGlanceApiImage\\\"]}, \\\"cap_add\\\": [\\\"AUDIT_WRITE\\\"], \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"detach\\\": false, \\\"user\\\": \\\"root\\\", \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"GlanceLogging\\\", \\\"volumes\\\"]}, {\\\"get_param\\\": \\\"GlanceApiOptVolumes\\\"}, [\\\"/var/lib/kolla/config_files/glance_api.json:/var/lib/kolla/config_files/config.json\\\", \\\"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\\\", {\\\"list_join\\\": [\\\":\\\", [{\\\"get_param\\\": \\\"CephConfigPath\\\"}], [\\\"/var/lib/kolla/config_files/src-ceph\\\"], [\\\"z\\\"]]}, \\\"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\\\", \\\"/var/lib/glance:/var/lib/glance:shared\\\"], {\\\"if\\\": [\\\"cinder_backend_enabled\\\", {\\\"list_concat\\\": [[\\\"/dev:/dev\\\", \\\"/var/lib/iscsi:/var/lib/iscsi:z\\\", {\\\"list_join\\\": [\\\":\\\", [{\\\"get_param\\\": \\\"GlanceCinderLockPath\\\"}, {\\\"get_param\\\": \\\"GlanceCinderLockPath\\\"}, \\\"z\\\"]]}], {\\\"get_attr\\\": [\\\"CinderNVMeOF\\\", \\\"cinder_nvmeof_volumes\\\"]}]}]}, {\\\"if\\\": [\\\"cinder_multipathd_enabled\\\", [\\\"/etc/multipath:/etc/multipath:z\\\", \\\"/etc/multipath.conf:/etc/multipath.conf:ro\\\"]]}]}, \\\"environment\\\": {\\\"KOLLA_BOOTSTRAP\\\": true, \\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\", \\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}}, \\\"command\\\": \\\"/usr/bin/bootstrap_host_exec glance_api su glance -s /bin/bash -c \'/usr/local/bin/kolla_start\'\\\"}}, \\\"step_4\\\": {\\\"glance_api\\\": {\\\"start_order\\\": 2, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerGlanceApiImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": {\\\"if\\\": [\\\"cinder_backend_enabled\\\", true, false]}, \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": {\\\"if\\\": [{\\\"or\\\": [{\\\"get_param\\\": \\\"GlanceNfsEnabled\\\"}, {\\\"get_param\\\": \\\"GlanceNetappNfsEnabled\\\"}]}, \\\"var-lib-glance-images.mount\\\"]}, \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"GlanceLogging\\\", \\\"volumes\\\"]}, {\\\"get_param\\\": \\\"GlanceApiOptVolumes\\\"}, [\\\"/var/lib/kolla/config_files/glance_api.json:/var/lib/kolla/config_files/config.json\\\", \\\"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\\\", {\\\"list_join\\\": [\\\":\\\", [{\\\"get_param\\\": \\\"CephConfigPath\\\"}], [\\\"/var/lib/kolla/config_files/src-ceph\\\"], [\\\"z\\\"]]}, \\\"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\\\", \\\"/var/lib/glance:/var/lib/glance:shared\\\"], {\\\"if\\\": [\\\"cinder_backend_enabled\\\", {\\\"list_concat\\\": [[\\\"/dev:/dev\\\", \\\"/var/lib/iscsi:/var/lib/iscsi:z\\\", {\\\"list_join\\\": [\\\":\\\", [{\\\"get_param\\\": \\\"GlanceCinderLockPath\\\"}, {\\\"get_param\\\": \\\"GlanceCinderLockPath\\\"}, \\\"z\\\"]]}], {\\\"get_attr\\\": [\\\"CinderNVMeOF\\\", \\\"cinder_nvmeof_volumes\\\"]}]}]}, {\\\"if\\\": [\\\"cinder_multipathd_enabled\\\", [\\\"/etc/multipath:/etc/multipath:z\\\", \\\"/etc/multipath.conf:/etc/multipath.conf:ro\\\"]]}]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}, \\\"glance_api_tls_proxy\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, {\\\"start_order\\\": 3, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerGlanceApiImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"user\\\": \\\"root\\\", \\\"restart\\\": \\\"always\\\", \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"GlanceLogging\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/glance_api_tls_proxy.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\\\", \\\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\\\", \\\"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}]}, \\\"glance_api_cron\\\": {\\\"start_order\\\": 2, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerGlanceApiImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"user\\\": \\\"root\\\", \\\"privileged\\\": false, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/usr/share/openstack-tripleo-common/healthcheck/cron glance\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"GlanceLogging\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/glance_api_cron.json:/var/lib/kolla/config_files/config.json\\\", \\\"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/glance:/var/lib/glance:shared\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"host_prep_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"GlanceLogging\\\", \\\"host_prep_tasks\\\"]}, [{\\\"name\\\": \\\"Mount NFS on host\\\", \\\"vars\\\": {\\\"nfs_backend_enabled\\\": {\\\"get_param\\\": \\\"GlanceNfsEnabled\\\"}, \\\"glance_netapp_nfs_enabled\\\": {\\\"get_param\\\": \\\"GlanceNetappNfsEnabled\\\"}, \\\"glance_nfs_share\\\": {\\\"get_param\\\": \\\"GlanceNfsShare\\\"}, \\\"netapp_share_location\\\": {\\\"get_param\\\": \\\"NetappShareLocation\\\"}, \\\"nfs_share\\\": \\\"{{ glance_nfs_share if (glance_nfs_share) else netapp_share_location }}\\\", \\\"nfs_options\\\": {\\\"get_param\\\": \\\"GlanceNfsOptions\\\"}}, \\\"mount\\\": {\\\"name\\\": \\\"/var/lib/glance/images\\\", \\\"state\\\": \\\"mounted\\\", \\\"fstype\\\": \\\"nfs\\\", \\\"src\\\": \\\"{{nfs_share}}\\\", \\\"opts\\\": \\\"{{nfs_options}}\\\"}, \\\"when\\\": \\\"nfs_backend_enabled or glance_netapp_nfs_enabled\\\"}, {\\\"name\\\": \\\"Mount Node Staging Location\\\", \\\"vars\\\": {\\\"glance_node_staging_uri\\\": {\\\"get_param\\\": \\\"GlanceNodeStagingUri\\\"}, \\\"glance_staging_nfs_share\\\": {\\\"get_param\\\": \\\"GlanceStagingNfsShare\\\"}, \\\"glance_nfs_options\\\": {\\\"get_param\\\": \\\"GlanceStagingNfsOptions\\\"}}, \\\"mount\\\": {\\\"name\\\": \\\"{{glance_node_staging_uri[7:]}}\\\", \\\"state\\\": \\\"mounted\\\", \\\"fstype\\\": \\\"nfs\\\", \\\"src\\\": \\\"{{glance_staging_nfs_share}}\\\", \\\"opts\\\": \\\"{{glance_nfs_options}}\\\"}, \\\"when\\\": \\\"glance_staging_nfs_share != \'\'\\\"}], [{\\\"name\\\": \\\"ensure ceph configurations exist\\\", \\\"file\\\": {\\\"path\\\": {\\\"get_param\\\": \\\"CephConfigPath\\\"}, \\\"state\\\": \\\"directory\\\"}}, {\\\"name\\\": \\\"ensure /var/lib/glance exists\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/glance\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"container_file_t\\\"}}], {\\\"if\\\": [\\\"cinder_backend_enabled\\\", [{\\\"name\\\": \\\"Allow glance to use cinder\'s lock_path\\\", \\\"file\\\": {\\\"path\\\": {\\\"get_param\\\": \\\"GlanceCinderLockPath\\\"}, \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": 504, \\\"group\\\": 42400}}, {\\\"name\\\": \\\"Identify dynamic os-brick lock files used by glance\\\", \\\"vars\\\": {\\\"lock_path\\\": {\\\"get_param\\\": \\\"GlanceCinderLockPath\\\"}}, \\\"ansible.builtin.find\\\": {\\\"paths\\\": \\\"{{ lock_path }}\\\", \\\"patterns\\\": \\\"os-brick-connect_to_iscsi_portal-*\\\"}, \\\"register\\\": \\\"find_dynamic_locks\\\"}, {\\\"name\\\": \\\"Prepare the os-brick lock files used by glance\\\", \\\"vars\\\": {\\\"lock_path\\\": {\\\"get_param\\\": \\\"GlanceCinderLockPath\\\"}, \\\"static_brick_locks\\\": [\\\"{{ lock_path }}/os-brick-connect_volume\\\", \\\"{{ lock_path }}/os-brick-extend_volume\\\", \\\"{{ lock_path }}/scaleio-scaleio\\\"], \\\"dynamic_brick_locks\\\": \\\"{{ find_dynamic_locks.files | map(attribute=\'path\') }}\\\"}, \\\"file\\\": {\\\"path\\\": \\\"{{ item }}\\\", \\\"state\\\": \\\"touch\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": 432, \\\"group\\\": 42400}, \\\"loop\\\": \\\"{{ (static_brick_locks + dynamic_brick_locks) | flatten}}\\\"}]]}, {\\\"get_attr\\\": [\\\"CinderNVMeOF\\\", \\\"cinder_nvmeof_host_prep_tasks\\\"]}]}, \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"glance-api pre system_upgrade tasks\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_run\\\", \\\"system_upgrade_nfsmounts\\\"], \\\"when\\\": [\\\"step|int == 3\\\", \\\"upgrade_leapp_enabled\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Unmount and remove NFS glance entry\\\", \\\"vars\\\": {\\\"nfs_backend_enabled\\\": {\\\"get_param\\\": \\\"GlanceNfsEnabled\\\"}, \\\"glance_netapp_nfs_enabled\\\": {\\\"get_param\\\": \\\"GlanceNetappNfsEnabled\\\"}}, \\\"mount\\\": {\\\"name\\\": \\\"/var/lib/glance/images\\\", \\\"fstype\\\": \\\"nfs\\\", \\\"state\\\": \\\"absent\\\"}, \\\"when\\\": \\\"nfs_backend_enabled or glance_netapp_nfs_enabled\\\"}, {\\\"name\\\": \\\"Unmount and remove NFS glance-staging entry\\\", \\\"vars\\\": {\\\"glance_node_staging_uri\\\": {\\\"get_param\\\": \\\"GlanceNodeStagingUri\\\"}, \\\"glance_staging_nfs_share\\\": {\\\"get_param\\\": \\\"GlanceStagingNfsShare\\\"}}, \\\"mount\\\": {\\\"name\\\": \\\"{{glance_node_staging_uri[7:]}}\\\", \\\"fstype\\\": \\\"nfs\\\", \\\"state\\\": \\\"absent\\\"}, \\\"when\\\": \\\"glance_staging_nfs_share != \'\'\\\"}]}, {\\\"name\\\": \\\"glance-api post system_upgrade tasks\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_run\\\", \\\"system_upgrade_nfsmounts\\\"], \\\"when\\\": [\\\"step|int == 5\\\", \\\"upgrade_leapp_enabled\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Mount NFS on host\\\", \\\"vars\\\": {\\\"nfs_backend_enabled\\\": {\\\"get_param\\\": \\\"GlanceNfsEnabled\\\"}, \\\"glance_netapp_nfs_enabled\\\": {\\\"get_param\\\": \\\"GlanceNetappNfsEnabled\\\"}, \\\"glance_nfs_share\\\": {\\\"get_param\\\": \\\"GlanceNfsShare\\\"}, \\\"netapp_share_location\\\": {\\\"get_param\\\": \\\"NetappShareLocation\\\"}, \\\"nfs_share\\\": \\\"{{ glance_nfs_share if (glance_nfs_share) else netapp_share_location }}\\\", \\\"nfs_options\\\": {\\\"get_param\\\": \\\"GlanceNfsOptions\\\"}}, \\\"mount\\\": {\\\"name\\\": \\\"/var/lib/glance/images\\\", \\\"state\\\": \\\"mounted\\\", \\\"fstype\\\": \\\"nfs\\\", \\\"src\\\": \\\"{{nfs_share}}\\\", \\\"opts\\\": \\\"{{nfs_options}}\\\"}, \\\"when\\\": \\\"nfs_backend_enabled or glance_netapp_nfs_enabled\\\"}, {\\\"name\\\": \\\"Mount Node Staging Location\\\", \\\"vars\\\": {\\\"glance_node_staging_uri\\\": {\\\"get_param\\\": \\\"GlanceNodeStagingUri\\\"}, \\\"glance_staging_nfs_share\\\": {\\\"get_param\\\": \\\"GlanceStagingNfsShare\\\"}, \\\"glance_nfs_options\\\": {\\\"get_param\\\": \\\"GlanceStagingNfsOptions\\\"}}, \\\"mount\\\": {\\\"name\\\": \\\"{{glance_node_staging_uri[7:]}}\\\", \\\"state\\\": \\\"mounted\\\", \\\"fstype\\\": \\\"nfs\\\", \\\"src\\\": \\\"{{glance_staging_nfs_share}}\\\", \\\"opts\\\": \\\"{{glance_nfs_options}}\\\"}, \\\"when\\\": \\\"glance_staging_nfs_share != \'\'\\\"}]}], \\\"metadata_settings\\\": {\\\"get_attr\\\": [\\\"TLSProxyBase\\\", \\\"role_data\\\", \\\"metadata_settings\\\"]}, \\\"external_upgrade_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade_transfer_data\\\", \\\"system_upgrade_stop_services\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Stop glance api container\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_stop\\\"}, \\\"vars\\\": {\\\"tripleo_containers_to_stop\\\": [\\\"glance_api\\\", \\\"glance_api_cron\\\"], \\\"tripleo_delegate_to\\\": \\\"{{ groups[\'glance_api\'] | difference(groups[\'excluded_overcloud\']) }}\\\"}}]}], \\\"deploy_steps_tasks\\\": {\\\"get_attr\\\": [\\\"TLSProxyBase\\\", \\\"role_data\\\", \\\"deploy_steps_tasks\\\"]}}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack Glance internal service configured with Puppet\\\\n\\\", \\\"parameters\\\": {\\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"GlanceApiInternalLoggingSource\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {\\\"tag\\\": \\\"openstack.glance.api\\\", \\\"file\\\": \\\"/var/log/containers/glance/api_internal.log\\\"}}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"GlanceNetappNfsEnabled\\\": {\\\"default\\\": false, \\\"description\\\": \\\"When using GlanceBackend \'file\', Netapp mount NFS share for image storage.\\\\n\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"ContainerGlanceApiImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerGlanceApiInternalConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the glance_api_internal config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}}, \\\"resources\\\": {\\\"GlanceApi\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}, \\\"EnableInternalTLS\\\": {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}}}, \\\"MySQLClient\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\\\"}, \\\"GlanceLogging\\\": {\\\"type\\\": \\\"OS::TripleO::Services::Logging::GlanceApi\\\"}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerGlanceApiImage\\\": \\\"ContainerGlanceApiImage\\\", \\\"ContainerGlanceApiInternalConfigImage\\\": \\\"ContainerGlanceApiInternalConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerGlanceApiImage\\\": {\\\"get_param\\\": \\\"ContainerGlanceApiImage\\\"}, \\\"ContainerGlanceApiInternalConfigImage\\\": {\\\"get_param\\\": \\\"ContainerGlanceApiInternalConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the internal Glance API.\\\", \\\"value\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"GlanceApi\\\", \\\"role_data\\\"]}, {\\\"service_name\\\": \\\"glance_api_internal\\\", \\\"firewall_rules\\\": {\\\"112 glance_api_internal\\\": {\\\"dport\\\": [{\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GlanceInternal\\\", \\\"port\\\"]}]}}, \\\"firewall_frontend_rules\\\": {\\\"100 glance_api_internal_haproxy_frontend\\\": {\\\"dport\\\": [{\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GlanceInternal\\\", \\\"port\\\"]}]}}, \\\"keystone_resources\\\": {}, \\\"config_settings\\\": {\\\"get_attr\\\": [\\\"GlanceApi\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, \\\"service_config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"GlanceApi\\\", \\\"role_data\\\", \\\"service_config_settings\\\"]}, {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_glance_api_internal\\\": [{\\\"get_param\\\": \\\"GlanceApiInternalLoggingSource\\\"}]}}]}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"glance_api_internal\\\", \\\"puppet_tags\\\": \\\"glance_api_config,glance_api_paste_ini,glance_swift_config,glance_cache_config,glance_image_import_config\\\", \\\"step_config\\\": {\\\"list_join\\\": [\\\"\\\\n\\\", [{\\\"str_replace\\\": {\\\"template\\\": \\\"class { \'tripleo::profile::base::glance::api\':\\\\n  bind_port => PORT,\\\\n  tls_proxy_port => PORT,\\\\n  log_file => \'/var/log/glance/api_internal.log\',\\\\n  show_image_direct_url => true,\\\\n  show_multiple_locations => true,\\\\n}\\\\n\\\", \\\"params\\\": {\\\"PORT\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GlanceInternal\\\", \\\"port\\\"]}}}}, {\\\"if\\\": [{\\\"get_param\\\": \\\"GlanceNetappNfsEnabled\\\"}, \\\"include tripleo::profile::base::glance::netapp\\\"]}, {\\\"get_attr\\\": [\\\"MySQLClient\\\", \\\"role_data\\\", \\\"step_config\\\"]}]]}, \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerGlanceApiInternalConfigImage\\\"]}}, \\\"docker_config\\\": {\\\"step_2\\\": {\\\"get_attr\\\": [\\\"GlanceLogging\\\", \\\"docker_config\\\", \\\"step_2\\\"]}, \\\"step_4\\\": {\\\"glance_api_internal\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"GlanceApi\\\", \\\"role_data\\\", \\\"docker_config\\\", \\\"step_4\\\", \\\"glance_api\\\"]}, {\\\"volumes\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"$.data.vols.select($.replace(\'puppet-generated/glance_api\', \'puppet-generated/glance_api_internal\'))\\\", \\\"data\\\": {\\\"vols\\\": {\\\"get_attr\\\": [\\\"GlanceApi\\\", \\\"role_data\\\", \\\"docker_config\\\", \\\"step_4\\\", \\\"glance_api\\\", \\\"volumes\\\"]}}}}}]}, \\\"glance_api_internal_tls_proxy\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"GlanceApi\\\", \\\"role_data\\\", \\\"docker_config\\\", \\\"step_4\\\", \\\"glance_api_tls_proxy\\\"]}, {\\\"volumes\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"$.data.vols.select($.replace(\'puppet-generated/glance_api\', \'puppet-generated/glance_api_internal\'))\\\", \\\"data\\\": {\\\"vols\\\": {\\\"get_attr\\\": [\\\"GlanceApi\\\", \\\"role_data\\\", \\\"docker_config\\\", \\\"step_4\\\", \\\"glance_api_tls_proxy\\\", \\\"volumes\\\"]}}}}}]}]}}}, \\\"external_upgrade_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade_transfer_data\\\", \\\"system_upgrade_stop_services\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Stop glance api internal container\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_stop\\\"}, \\\"vars\\\": {\\\"tripleo_containers_to_stop\\\": [\\\"glance_api_internal\\\"], \\\"tripleo_delegate_to\\\": \\\"{{ groups[\'glance_api_internal\'] | default([]) }}\\\"}}]}]}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Openstack Heat base service. Shared for all Heat services.\\\\n\\\", \\\"parameters\\\": {\\\"Debug\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Set to True to enable debugging on all services.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"HeatDebug\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Set to True to enable debugging Heat services.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"HeatPassword\\\": {\\\"description\\\": \\\"The password for the Heat service and db account, used by the Heat services.\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"KeystoneRegion\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"regionOne\\\", \\\"description\\\": \\\"Keystone region for endpoint\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"EnableCache\\\": {\\\"description\\\": \\\"Enable caching with memcached\\\", \\\"type\\\": \\\"boolean\\\", \\\"default\\\": true}, \\\"HeatCronPurgeDeletedEnsure\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge db entries marked as deleted and older than $age - Ensure\\\\n\\\", \\\"default\\\": \\\"present\\\"}, \\\"HeatCronPurgeDeletedMinute\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge db entries marked as deleted and older than $age - Minute\\\\n\\\", \\\"default\\\": \\\"1\\\"}, \\\"HeatCronPurgeDeletedHour\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge db entries marked as deleted and older than $age - Hour\\\\n\\\", \\\"default\\\": \\\"0\\\"}, \\\"HeatCronPurgeDeletedMonthday\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge db entries marked as deleted and older than $age - Month Day\\\\n\\\", \\\"default\\\": \\\"*\\\"}, \\\"HeatCronPurgeDeletedMonth\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge db entries marked as deleted and older than $age - Month\\\\n\\\", \\\"default\\\": \\\"*\\\"}, \\\"HeatCronPurgeDeletedWeekday\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge db entries marked as deleted and older than $age - Week Day\\\\n\\\", \\\"default\\\": \\\"*\\\"}, \\\"HeatCronPurgeDeletedMaxDelay\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge db entries marked as deleted and older than $age - Max Delay\\\\n\\\", \\\"default\\\": \\\"3600\\\"}, \\\"HeatCronPurgeDeletedUser\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge db entries marked as deleted and older than $age - User\\\\n\\\", \\\"default\\\": \\\"heat\\\"}, \\\"HeatCronPurgeDeletedAge\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge db entries marked as deleted and older than $age - Age\\\\n\\\", \\\"default\\\": \\\"30\\\"}, \\\"HeatCronPurgeDeletedAgeType\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge db entries marked as deleted and older than $age - Age type\\\\n\\\", \\\"default\\\": \\\"days\\\"}, \\\"HeatCronPurgeDeletedDestination\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge db entries marked as deleted and older than $age - Log destination\\\\n\\\", \\\"default\\\": \\\"/dev/null\\\"}, \\\"HeatYaqlLimitIterators\\\": {\\\"type\\\": \\\"number\\\", \\\"description\\\": \\\"The maximum number of elements in collection yaql expressions can take for its evaluation.\\\\n\\\", \\\"default\\\": 1000}, \\\"HeatYaqlMemoryQuota\\\": {\\\"type\\\": \\\"number\\\", \\\"description\\\": \\\"The maximum size of memory in bytes that yaql exrpessions can take for its evaluation.\\\\n\\\", \\\"default\\\": 100000}, \\\"HeatMaxJsonBodySize\\\": {\\\"default\\\": 4194304, \\\"description\\\": \\\"Maximum raw byte size of the Heat API JSON request body.\\\", \\\"type\\\": \\\"number\\\"}, \\\"NotificationDriver\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": \\\"noop\\\", \\\"description\\\": \\\"Driver or drivers to handle sending notifications.\\\"}, \\\"HeatCorsAllowedOrigin\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Indicate whether this resource may be shared with the domain received in the request \\\\\\\"origin\\\\\\\" header.\\\"}, \\\"MemcachedTLS\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"MemcacheUseAdvancedPool\\\": {\\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"Use the advanced (eventlet safe) memcached client pool.\\\\n\\\", \\\"default\\\": true}, \\\"HeatApiPolicies\\\": {\\\"description\\\": \\\"A hash of policies to configure for Heat API.\\\\ne.g. { heat-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\\\n\\\", \\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}, \\\"EnforceSecureRbac\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false, \\\"description\\\": \\\"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\\\"}}, \\\"conditions\\\": {\\\"tls_cache_enabled\\\": {\\\"and\\\": [{\\\"get_param\\\": \\\"EnableCache\\\"}, {\\\"get_param\\\": \\\"MemcachedTLS\\\"}]}, \\\"cors_allowed_origin_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"HeatCorsAllowedOrigin\\\"}, \\\"\\\"]}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Shared role data for the Heat services.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"heat_base\\\", \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"if\\\": [{\\\"get_param\\\": \\\"EnforceSecureRbac\\\"}, {\\\"heat::policy::enforce_scope\\\": true, \\\"heat::policy::enforce_new_defaults\\\": true}]}, {\\\"if\\\": [\\\"cors_allowed_origin_set\\\", {\\\"heat::cors::allowed_origin\\\": {\\\"get_param\\\": \\\"HeatCorsAllowedOrigin\\\"}}]}, {\\\"heat::notification_driver\\\": {\\\"get_param\\\": \\\"NotificationDriver\\\"}, \\\"heat::logging::debug\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"HeatDebug\\\"}, true, {\\\"get_param\\\": \\\"Debug\\\"}]}, \\\"heat::policy::policies\\\": {\\\"get_param\\\": \\\"HeatApiPolicies\\\"}, \\\"heat::enable_proxy_headers_parsing\\\": true, \\\"heat::rpc_response_timeout\\\": 600, \\\"heat::rabbit_heartbeat_timeout_threshold\\\": 60, \\\"heat::rabbit_heartbeat_in_pthread\\\": false, \\\"heat::region_name\\\": {\\\"get_param\\\": \\\"KeystoneRegion\\\"}, \\\"heat::keystone::authtoken::project_name\\\": \\\"service\\\", \\\"heat::keystone::authtoken::user_domain_name\\\": \\\"Default\\\", \\\"heat::keystone::authtoken::project_domain_name\\\": \\\"Default\\\", \\\"heat::keystone::authtoken::www_authenticate_uri\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystonePublic\\\", \\\"uri_no_suffix\\\"]}, \\\"heat::keystone::authtoken::auth_url\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"uri_no_suffix\\\"]}, \\\"heat::keystone::authtoken::password\\\": {\\\"get_param\\\": \\\"HeatPassword\\\"}, \\\"heat::keystone::authtoken::region_name\\\": {\\\"get_param\\\": \\\"KeystoneRegion\\\"}, \\\"heat::keystone::authtoken::interface\\\": \\\"internal\\\", \\\"heat::keystone::authtoken::memcache_use_advanced_pool\\\": {\\\"get_param\\\": \\\"MemcacheUseAdvancedPool\\\"}, \\\"heat::keystone::domain::domain_name\\\": \\\"heat_stack\\\", \\\"heat::keystone::domain::domain_admin\\\": \\\"heat_stack_domain_admin\\\", \\\"heat::keystone::domain::domain_admin_email\\\": \\\"heat_stack_domain_admin@localhost\\\", \\\"heat::db::database_db_max_retries\\\": -1, \\\"heat::db::database_max_retries\\\": -1, \\\"heat::yaql_memory_quota\\\": {\\\"get_param\\\": \\\"HeatYaqlMemoryQuota\\\"}, \\\"heat::yaql_limit_iterators\\\": {\\\"get_param\\\": \\\"HeatYaqlLimitIterators\\\"}, \\\"heat::cors::max_age\\\": 3600, \\\"heat::cors::allow_headers\\\": \\\"Content-Type,Cache-Control,Content-Language,Expires,Last-Modified,Pragma,X-Auth-Token\\\", \\\"heat::cors::expose_headers\\\": \\\"Content-Type,Cache-Control,Content-Language,Expires,Last-Modified,Pragma\\\", \\\"heat::cron::purge_deleted::ensure\\\": {\\\"get_param\\\": \\\"HeatCronPurgeDeletedEnsure\\\"}, \\\"heat::cron::purge_deleted::minute\\\": {\\\"get_param\\\": \\\"HeatCronPurgeDeletedMinute\\\"}, \\\"heat::cron::purge_deleted::hour\\\": {\\\"get_param\\\": \\\"HeatCronPurgeDeletedHour\\\"}, \\\"heat::cron::purge_deleted::monthday\\\": {\\\"get_param\\\": \\\"HeatCronPurgeDeletedMonthday\\\"}, \\\"heat::cron::purge_deleted::month\\\": {\\\"get_param\\\": \\\"HeatCronPurgeDeletedMonth\\\"}, \\\"heat::cron::purge_deleted::weekday\\\": {\\\"get_param\\\": \\\"HeatCronPurgeDeletedWeekday\\\"}, \\\"heat::cron::purge_deleted::maxdelay\\\": {\\\"get_param\\\": \\\"HeatCronPurgeDeletedMaxDelay\\\"}, \\\"heat::cron::purge_deleted::user\\\": {\\\"get_param\\\": \\\"HeatCronPurgeDeletedUser\\\"}, \\\"heat::cron::purge_deleted::age\\\": {\\\"get_param\\\": \\\"HeatCronPurgeDeletedAge\\\"}, \\\"heat::cron::purge_deleted::age_type\\\": {\\\"get_param\\\": \\\"HeatCronPurgeDeletedAgeType\\\"}, \\\"heat::cron::purge_deleted::destination\\\": {\\\"get_param\\\": \\\"HeatCronPurgeDeletedDestination\\\"}, \\\"heat::max_json_body_size\\\": {\\\"get_param\\\": \\\"HeatMaxJsonBodySize\\\"}}, {\\\"heat::cache::enabled\\\": {\\\"get_param\\\": \\\"EnableCache\\\"}, \\\"heat::cache::tls_enabled\\\": {\\\"get_param\\\": \\\"MemcachedTLS\\\"}, \\\"heat::cache::resource_finder_caching\\\": false}, {\\\"if\\\": [\\\"tls_cache_enabled\\\", {\\\"heat::cache::backend\\\": \\\"dogpile.cache.pymemcache\\\"}, {\\\"heat::cache::backend\\\": \\\"dogpile.cache.memcached\\\"}]}]}}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Heat API service\\\\n\\\", \\\"parameters\\\": {\\\"ContainerHeatApiImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerHeatApiConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the heat_api config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"HeatApiLoggingSource\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {\\\"tag\\\": \\\"openstack.heat.api\\\", \\\"file\\\": \\\"/var/log/containers/heat/heat_api.log\\\"}}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"HeatApiOptVolumes\\\": {\\\"default\\\": [], \\\"description\\\": \\\"list of optional volumes to be mounted\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"HeatApiOptEnvVars\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"hash of optional environment variables\\\", \\\"type\\\": \\\"json\\\"}, \\\"HeatWorkers\\\": {\\\"default\\\": 0, \\\"description\\\": \\\"Number of workers for Heat service.\\\", \\\"type\\\": \\\"number\\\"}, \\\"HeatPassword\\\": {\\\"description\\\": \\\"The password for the Heat service and db account, used by the Heat services.\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"KeystoneRegion\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"regionOne\\\", \\\"description\\\": \\\"Keystone region for endpoint\\\"}, \\\"MonitoringSubscriptionHeatApi\\\": {\\\"default\\\": \\\"overcloud-heat-api\\\", \\\"type\\\": \\\"string\\\"}, \\\"HeatStackDomainAdminPassword\\\": {\\\"description\\\": \\\"Password for heat_stack_domain_admin user.\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}}, \\\"conditions\\\": {\\\"heat_workers_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"HeatWorkers\\\"}, 0]}}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"ApacheServiceBase\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}, \\\"EnableInternalTLS\\\": {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}}}, \\\"HeatBase\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml\\\", \\\"properties\\\": {\\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"HeatApiLogging\\\": {\\\"type\\\": \\\"OS::TripleO::Services::Logging::HeatApi\\\"}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerHeatApiImage\\\": \\\"ContainerHeatApiImage\\\", \\\"ContainerHeatApiConfigImage\\\": \\\"ContainerHeatApiConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerHeatApiImage\\\": {\\\"get_param\\\": \\\"ContainerHeatApiImage\\\"}, \\\"ContainerHeatApiConfigImage\\\": {\\\"get_param\\\": \\\"ContainerHeatApiConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Heat API role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"heat_api\\\", \\\"firewall_rules\\\": {\\\"125 heat_api\\\": {\\\"dport\\\": [8004]}}, \\\"firewall_frontend_rules\\\": {\\\"100 heat_api_haproxy_frontend\\\": {\\\"dport\\\": [8004]}}, \\\"firewall_ssl_frontend_rules\\\": {\\\"100 heat_api_haproxy_frontend_ssl\\\": {\\\"dport\\\": [13004]}}, \\\"keystone_resources\\\": {\\\"heat\\\": {\\\"endpoints\\\": {\\\"public\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatPublic\\\", \\\"uri\\\"]}, \\\"internal\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatInternal\\\", \\\"uri\\\"]}, \\\"admin\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatAdmin\\\", \\\"uri\\\"]}}, \\\"users\\\": {\\\"heat\\\": {\\\"password\\\": {\\\"get_param\\\": \\\"HeatPassword\\\"}}, \\\"heat_stack_domain_admin\\\": {\\\"password\\\": {\\\"get_param\\\": \\\"HeatStackDomainAdminPassword\\\"}, \\\"roles\\\": [\\\"admin\\\"], \\\"domain\\\": \\\"heat_stack\\\"}}, \\\"region\\\": {\\\"get_param\\\": \\\"KeystoneRegion\\\"}, \\\"service\\\": \\\"orchestration\\\", \\\"roles\\\": [\\\"heat_stack_user\\\"], \\\"domains\\\": [\\\"heat_stack\\\"]}}, \\\"monitoring_subscription\\\": {\\\"get_param\\\": \\\"MonitoringSubscriptionHeatApi\\\"}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"HeatBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"get_attr\\\": [\\\"HeatApiLogging\\\", \\\"config_settings\\\"]}, {\\\"get_attr\\\": [\\\"ApacheServiceBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"apache::default_vhost\\\": false, \\\"heat::api::bind_host\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HeatApiNetwork\\\"]}}}}, \\\"heat::wsgi::apache_api::ssl\\\": {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, \\\"heat::wsgi::apache_api::vhost_custom_fragment\\\": \\\"Timeout 600\\\", \\\"heat::api::service_name\\\": \\\"httpd\\\", \\\"heat::wsgi::apache_api::bind_host\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HeatApiNetwork\\\"]}}}}, \\\"heat::wsgi::apache_api::servername\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'fqdn_$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HeatApiNetwork\\\"]}}}}}, {\\\"if\\\": [\\\"heat_workers_set\\\", {\\\"heat::wsgi::apache_api::workers\\\": {\\\"get_param\\\": \\\"HeatWorkers\\\"}}]}]}, \\\"service_config_settings\\\": {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_heat_api\\\": [{\\\"get_param\\\": \\\"HeatApiLoggingSource\\\"}]}}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"heat_api\\\", \\\"puppet_tags\\\": \\\"heat_config,file,concat,file_line,heat_api_paste_ini\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::heat::api\\\\n\\\", \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHeatApiConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/heat_api.json\\\": {\\\"command\\\": \\\"/usr/sbin/httpd -DFOREGROUND\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/etc/httpd/conf.d\\\", \\\"dest\\\": \\\"/etc/httpd/conf.d\\\", \\\"merge\\\": false, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\\\", \\\"dest\\\": \\\"/etc/httpd/conf.modules.d\\\", \\\"merge\\\": false, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/heat\\\", \\\"owner\\\": \\\"heat:heat\\\", \\\"recurse\\\": true}]}, \\\"/var/lib/kolla/config_files/heat_api_cron.json\\\": {\\\"command\\\": \\\"/usr/sbin/crond -n\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/heat\\\", \\\"owner\\\": \\\"heat:heat\\\", \\\"recurse\\\": true}]}}, \\\"docker_config\\\": {\\\"step_2\\\": {\\\"get_attr\\\": [\\\"HeatApiLogging\\\", \\\"docker_config\\\", \\\"step_2\\\"]}, \\\"step_4\\\": {\\\"heat_api\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHeatApiImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"restart\\\": \\\"always\\\", \\\"user\\\": \\\"root\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"HeatApiLogging\\\", \\\"volumes\\\"]}, {\\\"get_param\\\": \\\"HeatApiOptVolumes\\\"}, [\\\"/var/lib/kolla/config_files/heat_api.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/heat_api:/var/lib/kolla/config_files/src:ro\\\"], {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, [\\\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\\\", \\\"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\\\"]]}]}, \\\"environment\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"HeatApiOptEnvVars\\\"}, {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}]}}, \\\"heat_api_cron\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHeatApiImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"user\\\": \\\"root\\\", \\\"privileged\\\": false, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/usr/share/openstack-tripleo-common/healthcheck/cron heat\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"HeatApiLogging\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/heat_api_cron.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/heat_api:/var/lib/kolla/config_files/src:ro\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"host_prep_tasks\\\": {\\\"get_attr\\\": [\\\"HeatApiLogging\\\", \\\"host_prep_tasks\\\"]}, \\\"upgrade_tasks\\\": [], \\\"metadata_settings\\\": {\\\"get_attr\\\": [\\\"ApacheServiceBase\\\", \\\"role_data\\\", \\\"metadata_settings\\\"]}, \\\"deploy_steps_tasks\\\": {\\\"get_attr\\\": [\\\"ApacheServiceBase\\\", \\\"role_data\\\", \\\"deploy_steps_tasks\\\"]}, \\\"external_upgrade_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade_transfer_data\\\", \\\"system_upgrade_stop_services\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Stop heat api container\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_stop\\\"}, \\\"vars\\\": {\\\"tripleo_containers_to_stop\\\": [\\\"heat_api\\\", \\\"heat_api_cron\\\"], \\\"tripleo_delegate_to\\\": \\\"{{ groups[\'heat_api\'] | difference(groups[\'excluded_overcloud\']) }}\\\"}}]}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Heat API CFN service\\\\n\\\", \\\"parameters\\\": {\\\"ContainerHeatApiCfnImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerHeatApiCfnConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the heat_api_cfn config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"HeatApiCfnLoggingSource\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {\\\"tag\\\": \\\"openstack.heat.api.cfn\\\", \\\"file\\\": \\\"/var/log/containers/heat/heat_api_cfn.log\\\"}}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"HeatWorkers\\\": {\\\"default\\\": 0, \\\"description\\\": \\\"Number of workers for Heat service.\\\", \\\"type\\\": \\\"number\\\"}, \\\"HeatPassword\\\": {\\\"description\\\": \\\"The password for the Heat service and db account, used by the Heat services.\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"KeystoneRegion\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"regionOne\\\", \\\"description\\\": \\\"Keystone region for endpoint\\\"}, \\\"MonitoringSubscriptionHeatApiCnf\\\": {\\\"default\\\": \\\"overcloud-heat-api-cfn\\\", \\\"type\\\": \\\"string\\\"}}, \\\"conditions\\\": {\\\"heat_workers_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"HeatWorkers\\\"}, 0]}}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"ApacheServiceBase\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}, \\\"EnableInternalTLS\\\": {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}}}, \\\"HeatBase\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml\\\", \\\"properties\\\": {\\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"HeatApiCfnLogging\\\": {\\\"type\\\": \\\"OS::TripleO::Services::Logging::HeatApiCfn\\\"}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerHeatApiCfnImage\\\": \\\"ContainerHeatApiCfnImage\\\", \\\"ContainerHeatApiCfnConfigImage\\\": \\\"ContainerHeatApiCfnConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerHeatApiCfnImage\\\": {\\\"get_param\\\": \\\"ContainerHeatApiCfnImage\\\"}, \\\"ContainerHeatApiCfnConfigImage\\\": {\\\"get_param\\\": \\\"ContainerHeatApiCfnConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Heat API CFN role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"heat_api_cfn\\\", \\\"firewall_rules\\\": {\\\"125 heat_cfn\\\": {\\\"dport\\\": [8000]}}, \\\"firewall_frontend_rules\\\": {\\\"100 heat_api_cfn_haproxy_frontend\\\": {\\\"dport\\\": [8000]}}, \\\"firewall_ssl_frontend_rules\\\": {\\\"100 heat_api_cfn_haproxy_frontend_ssl\\\": {\\\"dport\\\": [13005]}}, \\\"keystone_resources\\\": {\\\"heat-cfn\\\": {\\\"endpoints\\\": {\\\"public\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatCfnPublic\\\", \\\"uri\\\"]}, \\\"internal\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatCfnInternal\\\", \\\"uri\\\"]}, \\\"admin\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatCfnAdmin\\\", \\\"uri\\\"]}}, \\\"users\\\": {\\\"heat-cfn\\\": {\\\"password\\\": {\\\"get_param\\\": \\\"HeatPassword\\\"}}}, \\\"region\\\": {\\\"get_param\\\": \\\"KeystoneRegion\\\"}, \\\"service\\\": \\\"cloudformation\\\"}}, \\\"monitoring_subscription\\\": {\\\"get_param\\\": \\\"MonitoringSubscriptionHeatApiCnf\\\"}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"HeatBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"get_attr\\\": [\\\"HeatApiCfnLogging\\\", \\\"config_settings\\\"]}, {\\\"apache::default_vhost\\\": false, \\\"heat::api_cfn::bind_host\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HeatApiCfnNetwork\\\"]}}}}, \\\"heat::wsgi::apache_api_cfn::ssl\\\": {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, \\\"heat::api_cfn::service_name\\\": \\\"httpd\\\", \\\"heat::wsgi::apache_api_cfn::bind_host\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HeatApiCfnNetwork\\\"]}}}}, \\\"heat::wsgi::apache_api_cfn::servername\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'fqdn_$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HeatApiCfnNetwork\\\"]}}}}}, {\\\"if\\\": [\\\"heat_workers_set\\\", {\\\"heat::wsgi::apache_api_cfn::workers\\\": {\\\"get_param\\\": \\\"HeatWorkers\\\"}}]}]}, \\\"service_config_settings\\\": {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_heat_api_cfn\\\": [{\\\"get_param\\\": \\\"HeatApiCfnLoggingSource\\\"}]}}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"heat_api_cfn\\\", \\\"puppet_tags\\\": \\\"heat_config,file,concat,file_line\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::heat::api_cfn\\\\n\\\", \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHeatApiCfnConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/heat_api_cfn.json\\\": {\\\"command\\\": \\\"/usr/sbin/httpd -DFOREGROUND\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/etc/httpd/conf.d\\\", \\\"dest\\\": \\\"/etc/httpd/conf.d\\\", \\\"merge\\\": false, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\\\", \\\"dest\\\": \\\"/etc/httpd/conf.modules.d\\\", \\\"merge\\\": false, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/heat\\\", \\\"owner\\\": \\\"heat:heat\\\", \\\"recurse\\\": true}]}}, \\\"docker_config\\\": {\\\"step_2\\\": {\\\"get_attr\\\": [\\\"HeatApiCfnLogging\\\", \\\"docker_config\\\", \\\"step_2\\\"]}, \\\"step_4\\\": {\\\"heat_api_cfn\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHeatApiCfnImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"restart\\\": \\\"always\\\", \\\"user\\\": \\\"root\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"HeatApiCfnLogging\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/heat_api_cfn.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/heat_api_cfn:/var/lib/kolla/config_files/src:ro\\\"], {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, [\\\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\\\", \\\"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\\\"]]}]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"host_prep_tasks\\\": {\\\"get_attr\\\": [\\\"HeatApiCfnLogging\\\", \\\"host_prep_tasks\\\"]}, \\\"upgrade_tasks\\\": [], \\\"metadata_settings\\\": {\\\"get_attr\\\": [\\\"ApacheServiceBase\\\", \\\"role_data\\\", \\\"metadata_settings\\\"]}, \\\"deploy_steps_tasks\\\": {\\\"get_attr\\\": [\\\"ApacheServiceBase\\\", \\\"role_data\\\", \\\"deploy_steps_tasks\\\"]}, \\\"external_upgrade_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade_transfer_data\\\", \\\"system_upgrade_stop_services\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Stop heat cfn container\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_stop\\\"}, \\\"vars\\\": {\\\"tripleo_containers_to_stop\\\": [\\\"heat_api_cfn\\\"], \\\"tripleo_delegate_to\\\": \\\"{{ groups[\'heat_api_cfn\'] | difference(groups[\'excluded_overcloud\']) }}\\\"}}]}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Openstack Heat CloudWatch API service, disabled by default since Pike\\\\n\\\", \\\"parameters\\\": {\\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the disabled Heat CloudWatch API\\\", \\\"value\\\": {\\\"service_name\\\": \\\"heat_api_cloudwatch_disabled\\\", \\\"upgrade_tasks\\\": []}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Heat Engine service\\\\n\\\", \\\"parameters\\\": {\\\"ContainerHeatEngineImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerHeatConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the heat config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"HeatEngineLoggingSource\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {\\\"tag\\\": \\\"openstack.heat.engine\\\", \\\"file\\\": \\\"/var/log/containers/heat/heat-engine.log\\\"}}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"DeployIdentifier\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\\\n\\\"}, \\\"HeatEngineOptVolumes\\\": {\\\"default\\\": [], \\\"description\\\": \\\"list of optional volumes to be mounted\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"HeatEngineOptEnvVars\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"hash of optional environment variables\\\", \\\"type\\\": \\\"json\\\"}, \\\"HeatEnableDBPurge\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": true, \\\"description\\\": \\\"Whether to create cron job for purging soft deleted rows in the Heat database.\\\\n\\\"}, \\\"EnableSQLAlchemyCollectd\\\": {\\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"Set to true to enable the SQLAlchemy-collectd server plugin\\\\n\\\", \\\"default\\\": false}, \\\"HeatWorkers\\\": {\\\"default\\\": 0, \\\"description\\\": \\\"Number of workers for Heat service.\\\", \\\"type\\\": \\\"number\\\"}, \\\"HeatMaxNestedStackDepth\\\": {\\\"default\\\": 6, \\\"description\\\": \\\"Maximum number of nested stack depth.\\\", \\\"type\\\": \\\"number\\\"}, \\\"HeatReauthenticationAuthMethod\\\": {\\\"description\\\": \\\"Allow reauthentication on token expiry, such that long-running tasks may complete. Note this defeats the expiry of any provided user tokens.\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"\\\", \\\"trusts\\\"]}]}, \\\"HeatPassword\\\": {\\\"description\\\": \\\"The password for the Heat service and db account, used by the Heat services.\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"HeatStackDomainAdminPassword\\\": {\\\"description\\\": \\\"Password for heat_stack_domain_admin user.\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"HeatAuthEncryptionKey\\\": {\\\"description\\\": \\\"Auth encryption key for heat-engine\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true, \\\"default\\\": \\\"\\\"}, \\\"MonitoringSubscriptionHeatEngine\\\": {\\\"default\\\": \\\"overcloud-heat-engine\\\", \\\"type\\\": \\\"string\\\"}, \\\"HeatConvergenceEngine\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": true, \\\"description\\\": \\\"Enables the heat engine with the convergence architecture.\\\"}, \\\"HeatMaxResourcesPerStack\\\": {\\\"type\\\": \\\"number\\\", \\\"default\\\": 1000, \\\"description\\\": \\\"Maximum resources allowed per top-level stack. -1 stands for unlimited.\\\"}, \\\"HeatEnginePluginDirs\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": [], \\\"description\\\": \\\"An array of directories to search for plug-ins.\\\"}, \\\"HeatConfigureDelegatedRoles\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false, \\\"description\\\": \\\"Create delegated roles\\\"}, \\\"ClientRetryLimit\\\": {\\\"type\\\": \\\"number\\\", \\\"default\\\": 2, \\\"description\\\": \\\"Client retries for transient errors.\\\"}}, \\\"conditions\\\": {\\\"heat_workers_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"HeatWorkers\\\"}, 0]}}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"MySQLClient\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\\\"}, \\\"HeatBase\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml\\\", \\\"properties\\\": {\\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"HeatEngineLogging\\\": {\\\"type\\\": \\\"OS::TripleO::Services::Logging::HeatEngine\\\"}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerHeatEngineImage\\\": \\\"ContainerHeatEngineImage\\\", \\\"ContainerHeatConfigImage\\\": \\\"ContainerHeatConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerHeatEngineImage\\\": {\\\"get_param\\\": \\\"ContainerHeatEngineImage\\\"}, \\\"ContainerHeatConfigImage\\\": {\\\"get_param\\\": \\\"ContainerHeatConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Heat Engine role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"heat_engine\\\", \\\"monitoring_subscription\\\": {\\\"get_param\\\": \\\"MonitoringSubscriptionHeatEngine\\\"}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"HeatBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"apache::default_vhost\\\": false, \\\"heat::engine::configure_delegated_roles\\\": {\\\"get_param\\\": \\\"HeatConfigureDelegatedRoles\\\"}, \\\"heat::engine::trusts_delegated_roles\\\": [], \\\"heat::engine::max_nested_stack_depth\\\": {\\\"get_param\\\": \\\"HeatMaxNestedStackDepth\\\"}, \\\"heat::engine::max_resources_per_stack\\\": {\\\"get_param\\\": \\\"HeatMaxResourcesPerStack\\\"}, \\\"heat::engine::reauthentication_auth_method\\\": {\\\"get_param\\\": \\\"HeatReauthenticationAuthMethod\\\"}, \\\"heat::engine::heat_metadata_server_url\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatCfnPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatCfnPublic\\\", \\\"host\\\"]}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatCfnPublic\\\", \\\"port\\\"]}}}, \\\"heat::engine::heat_waitcondition_server_url\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatCfnPublic\\\", \\\"protocol\\\"]}, \\\"host\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatCfnPublic\\\", \\\"host\\\"]}, \\\"port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"HeatCfnPublic\\\", \\\"port\\\"]}, \\\"path\\\": \\\"/v1/waitcondition\\\"}}, \\\"heat::engine::convergence_engine\\\": {\\\"get_param\\\": \\\"HeatConvergenceEngine\\\"}, \\\"heat::engine::client_retry_limit\\\": {\\\"get_param\\\": \\\"ClientRetryLimit\\\"}, \\\"tripleo::profile::base::heat::manage_db_purge\\\": {\\\"get_param\\\": \\\"HeatEnableDBPurge\\\"}, \\\"heat::database_connection\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"MysqlInternal\\\", \\\"protocol\\\"]}, \\\"username\\\": \\\"heat\\\", \\\"password\\\": {\\\"get_param\\\": \\\"HeatPassword\\\"}, \\\"host\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"MysqlInternal\\\", \\\"host\\\"]}, \\\"path\\\": \\\"/heat\\\", \\\"query\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableSQLAlchemyCollectd\\\"}, {\\\"read_default_file\\\": \\\"/etc/my.cnf.d/tripleo.cnf\\\", \\\"read_default_group\\\": \\\"tripleo\\\", \\\"plugin\\\": \\\"collectd\\\", \\\"collectd_program_name\\\": \\\"heat\\\", \\\"collectd_host\\\": \\\"localhost\\\"}, {\\\"read_default_file\\\": \\\"/etc/my.cnf.d/tripleo.cnf\\\", \\\"read_default_group\\\": \\\"tripleo\\\"}]}}}, \\\"heat::keystone_ec2_uri\\\": {\\\"list_join\\\": [\\\"\\\", [{\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneV3Internal\\\", \\\"uri\\\"]}, \\\"/ec2tokens\\\"]]}, \\\"heat::keystone::domain::domain_password\\\": {\\\"get_param\\\": \\\"HeatStackDomainAdminPassword\\\"}, \\\"heat::engine::auth_encryption_key\\\": {\\\"get_param\\\": \\\"HeatAuthEncryptionKey\\\"}, \\\"heat::engine::plugin_dirs\\\": {\\\"get_param\\\": \\\"HeatEnginePluginDirs\\\"}}, {\\\"if\\\": [\\\"heat_workers_set\\\", {\\\"heat::engine::num_engine_workers\\\": {\\\"get_param\\\": \\\"HeatWorkers\\\"}}]}]}, \\\"service_config_settings\\\": {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_heat_engine\\\": [{\\\"get_param\\\": \\\"HeatEngineLoggingSource\\\"}]}, \\\"mysql\\\": {\\\"heat::db::mysql::password\\\": {\\\"get_param\\\": \\\"HeatPassword\\\"}, \\\"heat::db::mysql::user\\\": \\\"heat\\\", \\\"heat::db::mysql::host\\\": \\\"%\\\", \\\"heat::db::mysql::dbname\\\": \\\"heat\\\"}}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"heat\\\", \\\"puppet_tags\\\": \\\"heat_config,file,concat,file_line\\\", \\\"step_config\\\": {\\\"list_join\\\": [\\\"\\\\n\\\", [\\\"include tripleo::profile::base::heat::engine\\\", {\\\"get_attr\\\": [\\\"MySQLClient\\\", \\\"role_data\\\", \\\"step_config\\\"]}]]}, \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHeatConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/heat_engine.json\\\": {\\\"command\\\": {\\\"list_join\\\": [\\\" \\\", [\\\"/usr/bin/heat-engine --config-file /usr/share/heat/heat-dist.conf --config-file /etc/heat/heat.conf\\\", {\\\"get_attr\\\": [\\\"HeatEngineLogging\\\", \\\"cmd_extra_args\\\"]}]]}, \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/heat\\\", \\\"owner\\\": \\\"heat:heat\\\", \\\"recurse\\\": true}]}, \\\"/var/lib/kolla/config_files/heat_engine_db_sync.json\\\": {\\\"command\\\": \\\"/usr/bin/bootstrap_host_exec heat_engine su heat -s /bin/bash -c \'heat-manage db_sync\'\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/heat\\\", \\\"owner\\\": \\\"heat:heat\\\", \\\"recurse\\\": true}]}}, \\\"docker_config\\\": {\\\"step_2\\\": {\\\"get_attr\\\": [\\\"HeatEngineLogging\\\", \\\"docker_config\\\", \\\"step_2\\\"]}, \\\"step_3\\\": {\\\"heat_engine_db_sync\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHeatEngineImage\\\"]}, \\\"cap_add\\\": [\\\"AUDIT_WRITE\\\"], \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"detach\\\": false, \\\"user\\\": \\\"root\\\", \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"HeatEngineLogging\\\", \\\"volumes\\\"]}, {\\\"get_param\\\": \\\"HeatEngineOptVolumes\\\"}, [\\\"/var/lib/kolla/config_files/heat_engine_db_sync.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/heat:/var/lib/kolla/config_files/src:ro\\\"]]}, \\\"environment\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"HeatEngineOptEnvVars\\\"}, {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\", \\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}}]}}}, \\\"step_4\\\": {\\\"heat_engine\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHeatEngineImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"stop_grace_period\\\": 60, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"healthcheck_rpc_port\\\"]}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"HeatEngineLogging\\\", \\\"volumes\\\"]}, {\\\"get_param\\\": \\\"HeatEngineOptVolumes\\\"}, [\\\"/var/lib/kolla/config_files/heat_engine.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/heat:/var/lib/kolla/config_files/src:ro\\\"]]}, \\\"environment\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"HeatEngineOptEnvVars\\\"}, {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}]}}}}, \\\"host_prep_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"HeatEngineLogging\\\", \\\"host_prep_tasks\\\"]}, [{\\\"name\\\": \\\"enable virt_sandbox_use_netlink for healthcheck\\\", \\\"seboolean\\\": {\\\"name\\\": \\\"virt_sandbox_use_netlink\\\", \\\"persistent\\\": true, \\\"state\\\": true}, \\\"when\\\": [\\\"ansible_facts.selinux is defined\\\", \\\"ansible_facts.selinux.status == \\\\\\\"enabled\\\\\\\"\\\"]}]]}, \\\"upgrade_tasks\\\": [], \\\"external_upgrade_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade_transfer_data\\\", \\\"system_upgrade_stop_services\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Stop heat engine container\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_stop\\\"}, \\\"vars\\\": {\\\"tripleo_containers_to_stop\\\": [\\\"heat_engine\\\"], \\\"tripleo_delegate_to\\\": \\\"{{ groups[\'heat_engine\'] | difference(groups[\'excluded_overcloud\']) }}\\\"}}]}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Load kernel modules with kmod and configure kernel options with sysctl.\\\\n\\\", \\\"parameters\\\": {\\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"KernelPidMax\\\": {\\\"default\\\": 1048576, \\\"description\\\": \\\"Configures sysctl kernel.pid_max key\\\", \\\"type\\\": \\\"number\\\"}, \\\"KernelDisableIPv6\\\": {\\\"default\\\": 0, \\\"description\\\": \\\"Configures sysctl net.ipv6.{default/all}.disable_ipv6 keys\\\", \\\"type\\\": \\\"number\\\"}, \\\"KernelIpForward\\\": {\\\"default\\\": 1, \\\"description\\\": \\\"Configures net.ipv4.ip_forward key\\\", \\\"type\\\": \\\"number\\\"}, \\\"KernelIpv6ConfAllForwarding\\\": {\\\"default\\\": 0, \\\"description\\\": \\\"Configures the net.ipv6.conf.all.forwarding key\\\", \\\"type\\\": \\\"number\\\"}, \\\"KernelIpv4ConfAllRpFilter\\\": {\\\"default\\\": 1, \\\"description\\\": \\\"Configures the net.ipv4.conf.all.rp_filter key\\\", \\\"type\\\": \\\"number\\\"}, \\\"KernelIpNonLocalBind\\\": {\\\"default\\\": 1, \\\"description\\\": \\\"Configures net.ipv{4,6}.ip_nonlocal_bind key\\\", \\\"type\\\": \\\"number\\\"}, \\\"NeighbourGcThreshold1\\\": {\\\"default\\\": 1024, \\\"description\\\": \\\"Configures sysctl net.ipv4.neigh.default.gc_thresh1 value. This is the minimum number of entries to keep in the ARP cache. The garbage collector will not run if there are fewer than this number of entries in the cache.\\\", \\\"type\\\": \\\"number\\\"}, \\\"NeighbourGcThreshold2\\\": {\\\"default\\\": 2048, \\\"description\\\": \\\"Configures sysctl net.ipv4.neigh.default.gc_thresh2 value. This is the soft maximum number of entries to keep in the ARP cache. The garbage collector will  allow the number of entries to exceed this for 5 seconds before collection will be performed.\\\", \\\"type\\\": \\\"number\\\"}, \\\"NeighbourGcThreshold3\\\": {\\\"default\\\": 4096, \\\"description\\\": \\\"Configures sysctl net.ipv4.neigh.default.gc_thresh3 value. This is the hard maximum number of entries to keep in the ARP cache. The garbage collector will always run if there are more than this number of entries in the cache.\\\", \\\"type\\\": \\\"number\\\"}, \\\"InotifyInstancesMax\\\": {\\\"default\\\": 1024, \\\"description\\\": \\\"Configures sysctl fs.inotify.max_user_instances key\\\", \\\"type\\\": \\\"number\\\"}, \\\"BridgeNfCallArpTables\\\": {\\\"default\\\": 1, \\\"description\\\": \\\"Configures sysctl net.bridge.bridge-nf-call-arptables key\\\", \\\"type\\\": \\\"number\\\"}, \\\"BridgeNfCallIpTables\\\": {\\\"default\\\": 1, \\\"description\\\": \\\"Configures sysctl net.bridge.bridge-nf-call-iptables key\\\", \\\"type\\\": \\\"number\\\"}, \\\"BridgeNfCallIp6Tables\\\": {\\\"default\\\": 1, \\\"description\\\": \\\"Configures sysctl net.bridge.bridge-nf-call-ip6tables key\\\", \\\"type\\\": \\\"number\\\"}, \\\"ExtraKernelModules\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Hash of extra Kernel modules to load.\\\", \\\"type\\\": \\\"json\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ExtraKernelPackages\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"List of extra kernel related packages to install.\\\", \\\"type\\\": \\\"json\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ExtraSysctlSettings\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Hash of extra sysctl settings to apply.\\\", \\\"type\\\": \\\"json\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"FsAioMaxNumber\\\": {\\\"default\\\": 0, \\\"description\\\": \\\"The kernel allocates aio memory on demand, and this number limits the number of parallel aio requests; the only drawback of a larger limit is that a malicious guest could issue parallel requests to cause the kernel to set aside memory.  Set this number at least as large as\\\\n  128 * (number of virtual disks on the host)\\\\nLibvirt uses a default of 1M requests to allow 8k disks, with at most 64M of kernel memory if all disks hit an aio request at the same time.\\\\n\\\", \\\"type\\\": \\\"number\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"InotifyIntancesMax\\\": {\\\"default\\\": 1024, \\\"description\\\": \\\"Configures sysctl fs.inotify.max_user_instances key\\\", \\\"type\\\": \\\"number\\\"}}, \\\"parameter_groups\\\": [{\\\"label\\\": \\\"deprecated\\\", \\\"description\\\": \\\"Do not use deprecated params, they will be removed.\\\", \\\"parameters\\\": [\\\"InotifyIntancesMax\\\"]}], \\\"conditions\\\": {\\\"ipv6_disabled\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"KernelDisableIPv6\\\"}, 1]}, \\\"is_inotify_intances_max_default\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"InotifyIntancesMax\\\"}, 1024]}, \\\"fs_aio_max_number_set\\\": {\\\"and\\\": [{\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"FsAioMaxNumber\\\"]}, 0]}}, {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"FsAioMaxNumber\\\"]}, \\\"\\\"]}}]}}, \\\"resources\\\": {\\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"extra_kernel_modules\\\": \\\"ExtraKernelModules\\\", \\\"extra_kernel_packages\\\": \\\"ExtraKernelPackages\\\", \\\"extra_sysctl_settings\\\": \\\"ExtraSysctlSettings\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ExtraKernelModules\\\": {\\\"get_param\\\": \\\"ExtraKernelModules\\\"}, \\\"ExtraKernelPackages\\\": {\\\"get_param\\\": \\\"ExtraKernelPackages\\\"}, \\\"ExtraSysctlSettings\\\": {\\\"get_param\\\": \\\"ExtraSysctlSettings\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Kernel modules\\\", \\\"value\\\": {\\\"service_name\\\": \\\"kernel\\\", \\\"host_prep_tasks\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"tripleo_kernel\\\"}}], \\\"ansible_group_vars\\\": {\\\"hieradata_localhost_address\\\": {\\\"if\\\": [\\\"ipv6_disabled\\\", \\\"127.0.0.1\\\", \\\"localhost\\\"]}, \\\"tripleo_kernel_extra_modules\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"extra_kernel_modules\\\"]}, \\\"tripleo_kernel_extra_packages\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"extra_kernel_packages\\\"]}, \\\"tripleo_kernel_sysctl_extra_settings\\\": {\\\"map_merge\\\": [{\\\"net.ipv6.conf.default.disable_ipv6\\\": {\\\"value\\\": {\\\"get_param\\\": \\\"KernelDisableIPv6\\\"}}, \\\"net.ipv4.ip_local_reserved_ports\\\": {\\\"value\\\": \\\"35357,49000-49001\\\"}, \\\"net.ipv6.conf.all.disable_ipv6\\\": {\\\"value\\\": {\\\"get_param\\\": \\\"KernelDisableIPv6\\\"}}, \\\"net.ipv6.conf.lo.disable_ipv6\\\": {\\\"value\\\": 0}, \\\"net.ipv4.ip_forward\\\": {\\\"value\\\": {\\\"get_param\\\": \\\"KernelIpForward\\\"}}, \\\"net.ipv4.conf.all.rp_filter\\\": {\\\"value\\\": {\\\"get_param\\\": \\\"KernelIpv4ConfAllRpFilter\\\"}}, \\\"net.ipv6.conf.all.forwarding\\\": {\\\"value\\\": {\\\"get_param\\\": \\\"KernelIpv6ConfAllForwarding\\\"}}, \\\"net.ipv4.ip_nonlocal_bind\\\": {\\\"value\\\": {\\\"get_param\\\": \\\"KernelIpNonLocalBind\\\"}}, \\\"net.ipv6.ip_nonlocal_bind\\\": {\\\"value\\\": {\\\"get_param\\\": \\\"KernelIpNonLocalBind\\\"}}, \\\"kernel.pid_max\\\": {\\\"value\\\": {\\\"get_param\\\": \\\"KernelPidMax\\\"}}, \\\"net.ipv4.neigh.default.gc_thresh1\\\": {\\\"value\\\": {\\\"get_param\\\": \\\"NeighbourGcThreshold1\\\"}}, \\\"net.ipv4.neigh.default.gc_thresh2\\\": {\\\"value\\\": {\\\"get_param\\\": \\\"NeighbourGcThreshold2\\\"}}, \\\"net.ipv4.neigh.default.gc_thresh3\\\": {\\\"value\\\": {\\\"get_param\\\": \\\"NeighbourGcThreshold3\\\"}}, \\\"net.bridge.bridge-nf-call-arptables\\\": {\\\"value\\\": {\\\"get_param\\\": \\\"BridgeNfCallArpTables\\\"}}, \\\"net.bridge.bridge-nf-call-iptables\\\": {\\\"value\\\": {\\\"get_param\\\": \\\"BridgeNfCallIpTables\\\"}}, \\\"net.bridge.bridge-nf-call-ip6tables\\\": {\\\"value\\\": {\\\"get_param\\\": \\\"BridgeNfCallIp6Tables\\\"}}, \\\"fs.inotify.max_user_instances\\\": {\\\"value\\\": {\\\"if\\\": [\\\"is_inotify_intances_max_default\\\", {\\\"get_param\\\": \\\"InotifyInstancesMax\\\"}, {\\\"get_param\\\": \\\"InotifyIntancesMax\\\"}]}}}, {\\\"if\\\": [\\\"fs_aio_max_number_set\\\", {\\\"fs.aio-max-nr\\\": {\\\"value\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"FsAioMaxNumber\\\"]}}}]}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"extra_sysctl_settings\\\"]}]}}}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/mysql_upgrade_db.sh\": \"#!/usr/bin/bash\\n\\nset -e\\n\\n# Wait until we know the mysql server is up and responding\\ntimeout ${DB_MAX_TIMEOUT:-60} /bin/bash -c \'until mysqladmin -uroot ping 2>/dev/null; do sleep 1; done\'\\n\\n# After an upgrade, make sure that the running mysql had a chance to\\n# update its data table on disk.\\nmysql_upgrade\\n\\n# Upgrade to 10.3: the default table row format changed from COMPACT\\n# to DYNAMIC, so upgrade the existing tables.\\ncompact_tables=$(mysql -se \'SELECT CONCAT(\\\"`\\\",TABLE_SCHEMA,\\\"`.`\\\",TABLE_NAME,\\\"`\\\") FROM information_schema.tables WHERE ENGINE = \\\"InnoDB\\\" and ROW_FORMAT = \\\"Compact\\\";\');\\nfor i in $compact_tables; do echo converting row format of table $i; mysql -e \\\"ALTER TABLE $i ROW_FORMAT=DYNAMIC;\\\"; done;\\n\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-base.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"MySQL service deployment using puppet\\\\n\\\", \\\"parameters\\\": {\\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"MysqlMaxConnections\\\": {\\\"description\\\": \\\"Configures MySQL max_connections config setting\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 4096}, \\\"MysqlIncreaseFileLimit\\\": {\\\"description\\\": \\\"Flag to increase MySQL open-files-limit to 16384\\\", \\\"type\\\": \\\"boolean\\\", \\\"default\\\": true}, \\\"MysqlRootPassword\\\": {\\\"type\\\": \\\"string\\\", \\\"hidden\\\": true, \\\"default\\\": \\\"\\\"}, \\\"MysqlClustercheckPassword\\\": {\\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"EnableGalera\\\": {\\\"default\\\": true, \\\"description\\\": \\\"Whether to use Galera instead of regular MariaDB.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"EnableMysqlAuthEd25519\\\": {\\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"Whether to configure MySQL users to connect to the server using the Ed25519-based client authentication.\\\", \\\"default\\\": false}, \\\"MysqlIPv6\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Enable IPv6 in MySQL\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"MysqlInnodbBufferPoolSize\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Buffer pool size for MySQL database; this needs to be larger for at-scale deployments\\\", \\\"default\\\": \\\"1G\\\"}, \\\"CertificateKeySize\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"2048\\\", \\\"description\\\": \\\"Specifies the private key size used when creating the certificate.\\\"}, \\\"MysqlCertificateKeySize\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Override the private key size used when creating the certificate for this service\\\"}}, \\\"parameter_groups\\\": [{\\\"label\\\": \\\"deprecated\\\", \\\"description\\\": \\\"The following parameters are deprecated and will be removed. They should not\\\\nbe relied on for new deployments. If you have concerns regarding deprecated\\\\nparameters, please contact the TripleO development team on IRC or the\\\\nOpenStack mailing list.\\\\n\\\", \\\"parameters\\\": [\\\"MysqlIPv6\\\"]}], \\\"conditions\\\": {\\\"is_ipv6\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"ServiceData\\\", \\\"net_ip_version_map\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MysqlNetwork\\\"]}]}, 6]}, \\\"innodb_buffer_pool_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"MysqlInnodbBufferPoolSize\\\"}, \\\"\\\"]}}, \\\"key_size_override_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"MysqlCertificateKeySize\\\"}, \\\"\\\"]}}}, \\\"outputs\\\": {\\\"container_config_scripts\\\": {\\\"description\\\": \\\"Shared docker config scripts\\\", \\\"value\\\": {\\\"mysql_upgrade_db.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": {\\\"get_file\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/mysql_upgrade_db.sh\\\"}}}}, \\\"mysql_drop_unused_users\\\": {\\\"description\\\": \\\"Ansible block to clean up unusued Openstack DB users\\\", \\\"value\\\": [{\\\"name\\\": \\\"Drop unused OpenStack DB users\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"mysql_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower\\\"], \\\"block\\\": [{\\\"name\\\": \\\"mysql container id\\\", \\\"command\\\": \\\"podman ps -q --filter name={{ mysql_container_name }} --filter status=running\\\", \\\"register\\\": \\\"mysql_container_id\\\"}, {\\\"name\\\": \\\"set mysql container id fact\\\", \\\"set_fact\\\": {\\\"mysql_container\\\": \\\"{{ mysql_container_id.stdout }}\\\"}}, {\\\"name\\\": \\\"Mysql script to drop unused DB users\\\", \\\"when\\\": \\\"( mysql_container | length ) > 0\\\", \\\"block\\\": [{\\\"name\\\": \\\"Get the list of all OpenStack DB users\\\", \\\"shell\\\": \\\"jq -r \'to_entries[] | select(.key|endswith(\\\\\\\"::db::mysql::user\\\\\\\")) | .value\' /etc/puppet/hieradata/service_configs.json\\\", \\\"register\\\": \\\"openstack_db_users\\\"}, {\\\"name\\\": \\\"List all DB users that match the DB users to be dropped\\\", \\\"shell\\\": \\\"for u in {{ openstack_db_users.stdout_lines | join(\' \') }}; do podman exec -u root -it \\\\\\\"{{ mysql_container }}\\\\\\\" mysql -sNe \\\\\\\"select concat(\'\\\\\\\\`\',user,\'\\\\\\\\`@\\\\\\\\`\',host,\'\\\\\\\\`\') from mysql.user where user = \'$u\' and host != \'%\';\\\\\\\"; done\\\", \\\"register\\\": \\\"mysql_db_users\\\"}, {\\\"name\\\": \\\"resulting DB users to be dropped\\\", \\\"debug\\\": {\\\"msg\\\": \\\"{{ mysql_db_users.stdout_lines }}\\\"}}, {\\\"name\\\": \\\"Drop all unneeded Openstack DB users\\\", \\\"shell\\\": \\\"podman exec -u root -it \\\\\\\"{{ mysql_container }}\\\\\\\" mysql -sNe \'drop user {{ item }};\'\\\", \\\"loop\\\": \\\"{{ mysql_db_users.stdout_lines }}\\\"}]}]}]}, \\\"role_data\\\": {\\\"description\\\": \\\"Service MySQL using composable services.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"mysql\\\", \\\"config_settings\\\": {\\\"mysql::server::package_name\\\": \\\"mariadb-galera-server\\\", \\\"mysql::server::manage_config_file\\\": true, \\\"mysql_ipv6\\\": {\\\"if\\\": [\\\"is_ipv6\\\", true, false]}, \\\"mysql_max_connections\\\": {\\\"get_param\\\": \\\"MysqlMaxConnections\\\"}, \\\"mysql::server::root_password\\\": {\\\"get_param\\\": \\\"MysqlRootPassword\\\"}, \\\"mysql_clustercheck_password\\\": {\\\"get_param\\\": \\\"MysqlClustercheckPassword\\\"}, \\\"enable_galera\\\": {\\\"get_param\\\": \\\"EnableGalera\\\"}, \\\"mysql_auth_ed25519\\\": {\\\"get_param\\\": \\\"EnableMysqlAuthEd25519\\\"}, \\\"mysql_bind_host\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MysqlNetwork\\\"]}}}}, \\\"tripleo::profile::base::database::mysql::bind_address\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'fqdn_$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MysqlNetwork\\\"]}}}}, \\\"tripleo::profile::base::database::mysql::client_bind_address\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MysqlNetwork\\\"]}}}}, \\\"tripleo::profile::base::database::mysql::generate_dropin_file_limit\\\": {\\\"get_param\\\": \\\"MysqlIncreaseFileLimit\\\"}, \\\"tripleo::profile::base::database::mysql::certificate_specs\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, {\\\"service_certificate\\\": \\\"/etc/pki/tls/certs/mysql.crt\\\", \\\"service_key\\\": \\\"/etc/pki/tls/private/mysql.key\\\"}]}, \\\"innodb_buffer_pool_size\\\": {\\\"if\\\": [\\\"innodb_buffer_pool_set\\\", {\\\"get_param\\\": \\\"MysqlInnodbBufferPoolSize\\\"}]}}, \\\"step_config\\\": \\\"include tripleo::profile::base::database::mysql\\\\n\\\", \\\"metadata_settings\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, [{\\\"service\\\": \\\"mysql\\\", \\\"network\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MysqlNetwork\\\"]}, \\\"type\\\": \\\"vip\\\"}, {\\\"service\\\": \\\"mysql\\\", \\\"network\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MysqlNetwork\\\"]}, \\\"type\\\": \\\"node\\\"}]]}, \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Certificate generation\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"enable_internal_tls\\\"], \\\"block\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"linux-system-roles.certificate\\\"}, \\\"vars\\\": {\\\"certificate_requests\\\": [{\\\"name\\\": \\\"mysql\\\", \\\"dns\\\": [{\\\"str_replace\\\": {\\\"template\\\": \\\"{{fqdn_$NETWORK}}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MysqlNetwork\\\"]}}}}, {\\\"str_replace\\\": {\\\"template\\\": \\\"{{cloud_names.cloud_name_NETWORK}}\\\", \\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MysqlNetwork\\\"]}}}}], \\\"principal\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"mysql/{{fqdn_$NETWORK}}@{{idm_realm}}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MysqlNetwork\\\"]}}}}, \\\"key_size\\\": {\\\"if\\\": [\\\"key_size_override_set\\\", {\\\"get_param\\\": \\\"MysqlCertificateKeySize\\\"}, {\\\"get_param\\\": \\\"CertificateKeySize\\\"}]}, \\\"ca\\\": \\\"ipa\\\"}]}}]}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"MySQL service deployment with pacemaker bundle\\\\n\\\", \\\"parameters\\\": {\\\"ContainerMysqlImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerMysqlConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the mysql config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ClusterCommonTag\\\": {\\\"default\\\": false, \\\"description\\\": \\\"When set to false, a pacemaker service is configured to use a floating tag for its container image name, e.g. \'REGISTRY/NAMESPACE/IMAGENAME:pcmklatest\'. When set to true, the service uses a floating prefix as well, e.g. \'cluster.common.tag/IMAGENAME:pcmklatest\'.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"ClusterFullTag\\\": {\\\"default\\\": true, \\\"description\\\": \\\"When set to true, the pacemaker service uses a fully constant tag for its container image name, e.g. \'cluster.common.tag/SERVICENAME:pcmklatest\'.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"MysqlRootPassword\\\": {\\\"type\\\": \\\"string\\\", \\\"hidden\\\": true, \\\"default\\\": \\\"\\\"}, \\\"MysqlClustercheckPassword\\\": {\\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"MysqlUpgradePersist\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"MysqlUpgradeTransfer\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": true}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"InternalTLSCAFile\\\": {\\\"default\\\": \\\"/etc/ipa/ca.crt\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Specifies the default CA cert to use if TLS is used for services in the internal network.\\\"}, \\\"ConfigDebug\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to run config management (e.g. Puppet) in debug mode.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"DeployIdentifier\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\\\n\\\"}, \\\"ContainerCli\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"podman\\\", \\\"description\\\": \\\"CLI tool used to manage containers.\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"docker\\\", \\\"podman\\\"]}]}, \\\"MysqlGaleraSSTMethod\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"rsync\\\", \\\"description\\\": \\\"Method used by galera to perform State Snapshot Transfers\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"rsync\\\", \\\"mariabackup\\\"]}]}, \\\"MysqlMariabackupUser\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"mariabackup\\\", \\\"description\\\": \\\"When MysqlGaleraSSTMethod is set to mariabackup, the name of the database user that executes the SST.\\\"}, \\\"MysqlMariabackupPassword\\\": {\\\"type\\\": \\\"string\\\", \\\"hidden\\\": true, \\\"description\\\": \\\"When MysqlGaleraSSTMethod is set to mariabackup, the password of the database user that executes the SST.\\\"}, \\\"MysqlGaleraSSLCipher\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"AES128-SHA256\\\", \\\"description\\\": \\\"Symmetric cipher to use.\\\"}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"MysqlBase\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-base.yaml\\\", \\\"properties\\\": {\\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerMysqlImage\\\": \\\"ContainerMysqlImage\\\", \\\"ContainerMysqlConfigImage\\\": \\\"ContainerMysqlConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerMysqlImage\\\": {\\\"get_param\\\": \\\"ContainerMysqlImage\\\"}, \\\"ContainerMysqlConfigImage\\\": {\\\"get_param\\\": \\\"ContainerMysqlConfigImage\\\"}}}]}}}}, \\\"conditions\\\": {\\\"docker_enabled\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"docker\\\"]}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Containerized service MySQL using composable services.\\\", \\\"value\\\": {\\\"service_name\\\": {\\\"get_attr\\\": [\\\"MysqlBase\\\", \\\"role_data\\\", \\\"service_name\\\"]}, \\\"firewall_rules\\\": {\\\"104 mysql galera-bundle\\\": {\\\"dport\\\": [873, 3123, 3306, 4444, 4567, 4568, 9200]}}, \\\"firewall_frontend_rules\\\": {\\\"100 mysql_haproxy\\\": {\\\"dport\\\": [3306]}}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"MysqlBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"tripleo::profile::pacemaker::database::mysql::bind_address\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'fqdn_$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MysqlNetwork\\\"]}}}}, \\\"tripleo::profile::pacemaker::database::mysql::gmcast_listen_addr\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MysqlNetwork\\\"]}}}}, \\\"tripleo::profile::pacemaker::database::mysql::ca_file\\\": {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, \\\"tripleo::profile::pacemaker::database::mysql_bundle::mysql_docker_image\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/mariadb:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"tripleo::profile::pacemaker::database::mysql_bundle::control_port\\\": 3123, \\\"tripleo::profile::pacemaker::database::mysql_bundle::container_backend\\\": {\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"tripleo::profile::pacemaker::database::mysql_bundle::bind_address\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'fqdn_$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MysqlNetwork\\\"]}}}}, \\\"tripleo::profile::pacemaker::database::mysql_bundle::ca_file\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}]}, \\\"tripleo::profile::pacemaker::database::mysql_bundle::sst_method\\\": {\\\"get_param\\\": \\\"MysqlGaleraSSTMethod\\\"}, \\\"tripleo::profile::pacemaker::database::mysql_bundle::mariabackup_user\\\": {\\\"get_param\\\": \\\"MysqlMariabackupUser\\\"}, \\\"tripleo::profile::pacemaker::database::mysql_bundle::mariabackup_password\\\": {\\\"get_param\\\": \\\"MysqlMariabackupPassword\\\"}, \\\"tripleo::profile::pacemaker::database::mysql_bundle::force_ocf\\\": true, \\\"tripleo::profile::pacemaker::database::mysql_bundle::gcomm_cipher\\\": {\\\"get_param\\\": \\\"MysqlGaleraSSLCipher\\\"}}]}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"mysql\\\", \\\"puppet_tags\\\": \\\"file\\\", \\\"step_config\\\": {\\\"list_join\\\": [\\\"\\\\n\\\", [\\\"[\'Mysql_datadir\', \'Mysql_user\', \'Mysql_database\', \'Mysql_grant\', \'Mysql_plugin\'].each |String $val| { noop_resource($val) }\\\", \\\"exec {\'wait-for-settle\': command => \'/bin/true\' }\\\", \\\"include tripleo::profile::pacemaker::database::mysql_bundle\\\"]]}, \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/mysql.json\\\": {\\\"command\\\": \\\"/usr/sbin/pacemaker_remoted\\\", \\\"config_files\\\": [{\\\"dest\\\": \\\"/etc/libqb/force-filesystem-sockets\\\", \\\"source\\\": \\\"/dev/null\\\", \\\"owner\\\": \\\"root\\\", \\\"perm\\\": \\\"0644\\\"}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-tls/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"optional\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/mysql\\\", \\\"owner\\\": \\\"mysql:mysql\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/certs/mysql.crt\\\", \\\"owner\\\": \\\"mysql:mysql\\\", \\\"perm\\\": \\\"0600\\\", \\\"optional\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/private/mysql.key\\\", \\\"owner\\\": \\\"mysql:mysql\\\", \\\"perm\\\": \\\"0600\\\", \\\"optional\\\": true}]}}, \\\"container_config_scripts\\\": {\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"container_config_scripts\\\"]}, \\\"docker_config\\\": {\\\"step_1\\\": {\\\"mysql_data_ownership\\\": {\\\"start_order\\\": 0, \\\"detach\\\": false, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"user\\\": \\\"root\\\", \\\"command\\\": [\\\"chown\\\", \\\"-R\\\", \\\"mysql:\\\", \\\"/var/lib/mysql\\\"], \\\"volumes\\\": [\\\"/var/lib/mysql:/var/lib/mysql:z\\\"]}, \\\"mysql_bootstrap\\\": {\\\"start_order\\\": 1, \\\"detach\\\": false, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"user\\\": \\\"root\\\", \\\"command\\\": [\\\"bash\\\", \\\"-ec\\\", {\\\"list_join\\\": [\\\"\\\\n\\\", [\\\"if [ -e /var/lib/mysql/mysql ]; then exit 0; fi\\\", \\\"echo -e \\\\\\\"\\\\\\\\n[mysqld]\\\\\\\\nwsrep_provider=none\\\\\\\" >> /etc/my.cnf\\\", \\\"export DB_ROOT_PASSWORD=$(hiera \'mysql::server::root_password\')\\\", \\\"kolla_set_configs\\\", \\\"sudo -u mysql -E kolla_extend_start\\\", \\\"timeout ${DB_MAX_TIMEOUT} /bin/bash -c \'while pgrep -af /usr/bin/mysqld_safe | grep -q -v grep; do sleep 1; done\'\\\", \\\"mysqld_safe --skip-networking --wsrep-on=OFF &\\\", \\\"timeout ${DB_MAX_TIMEOUT} /bin/bash -c \'until mysqladmin -uroot -p\\\\\\\"$(hiera \'mysql::server::root_password\')\\\\\\\" ping 2>/dev/null; do sleep 1; done\'\\\"], {\\\"if\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"MysqlGaleraSSTMethod\\\"}, \\\"mariabackup\\\"]}, [\\\"mysql -uroot -p\\\\\\\"$(hiera \'mysql::server::root_password\')\\\\\\\" -e \\\\\\\"CREATE USER \'${DB_MARIABACKUP_USER}\'@\'localhost\' IDENTIFIED BY \'${DB_MARIABACKUP_PASSWORD}\';\\\\\\\"\\\", \\\"mysql -uroot -p\\\\\\\"$(hiera \'mysql::server::root_password\')\\\\\\\" -e \\\\\\\"GRANT RELOAD, PROCESS, LOCK TABLES, REPLICATION CLIENT ON *.* TO \'${DB_MARIABACKUP_USER}\'@\'localhost\';\\\\\\\"\\\"]]}, [\\\"mysql -uroot -p\\\\\\\"$(hiera \'mysql::server::root_password\')\\\\\\\" -e \\\\\\\"CREATE USER \'clustercheck\'@\'localhost\' IDENTIFIED BY \'$(hiera mysql_clustercheck_password)\';\\\\\\\"\\\", \\\"mysql -uroot -p\\\\\\\"$(hiera \'mysql::server::root_password\')\\\\\\\" -e \\\\\\\"GRANT PROCESS ON *.* TO \'clustercheck\'@\'localhost\' WITH GRANT OPTION;\\\\\\\"\\\", \\\"mysql -uroot -p\\\\\\\"$(hiera \'mysql::server::root_password\')\\\\\\\" -e \\\\\\\"DELETE FROM mysql.user WHERE user = \'root\' AND host NOT IN (\'%\',\'localhost\');\\\\\\\"\\\", \\\"timeout ${DB_MAX_TIMEOUT} mysqladmin -uroot -p\\\\\\\"$(hiera \'mysql::server::root_password\')\\\\\\\" shutdown\\\"]]}], \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/mysql.json:/var/lib/kolla/config_files/config.json:rw,z\\\", \\\"/var/lib/config-data/puppet-generated/mysql:/var/lib/kolla/config_files/src:ro,z\\\", \\\"/var/lib/mysql:/var/lib/mysql:rw,z\\\"], {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, [\\\"/etc/pki/tls/certs/mysql.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/mysql.crt:ro\\\", \\\"/etc/pki/tls/private/mysql.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/mysql.key:ro\\\"]]}]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\", \\\"KOLLA_BOOTSTRAP\\\": true, \\\"DB_MAX_TIMEOUT\\\": 60, \\\"DB_MARIABACKUP_USER\\\": {\\\"get_param\\\": \\\"MysqlMariabackupUser\\\"}, \\\"DB_MARIABACKUP_PASSWORD\\\": {\\\"get_param\\\": \\\"MysqlMariabackupPassword\\\"}}}}, \\\"step_2\\\": {\\\"mysql_wait_bundle\\\": {\\\"start_order\\\": 0, \\\"detach\\\": false, \\\"net\\\": \\\"host\\\", \\\"ipc\\\": \\\"host\\\", \\\"user\\\": \\\"root\\\", \\\"command\\\": {\\\"list_concat\\\": [[\\\"/container_puppet_apply.sh\\\", \\\"2\\\", \\\"file,file_line,concat,augeas,galera_ready,mysql_database,mysql_grant,mysql_user\\\", \\\"include tripleo::profile::pacemaker::database::mysql_bundle\\\"], {\\\"if\\\": [{\\\"get_param\\\": \\\"ConfigDebug\\\"}, [\\\"--debug\\\"]]}]}, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"container_puppet_apply_volumes\\\"]}, [\\\"/var/lib/mysql:/var/lib/mysql:rw,z\\\", \\\"/var/lib/config-data/puppet-generated/mysql/root:/root:rw\\\"], {\\\"if\\\": [\\\"docker_enabled\\\", [\\\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\\\"]]}]}, \\\"environment\\\": {\\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}}}}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode|default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/mysql\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/lib/mysql\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/log/mariadb\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}], \\\"metadata_settings\\\": {\\\"get_attr\\\": [\\\"MysqlBase\\\", \\\"role_data\\\", \\\"metadata_settings\\\"]}, \\\"deploy_steps_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"MysqlBase\\\", \\\"role_data\\\", \\\"deploy_steps_tasks\\\"]}, [{\\\"name\\\": \\\"MySQL tag container image for pacemaker\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_tag\\\"}, \\\"vars\\\": {\\\"container_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}, \\\"container_image_latest\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/mariadb:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}}}, {\\\"name\\\": \\\"MySQL HA Wrappers Step\\\", \\\"when\\\": \\\"step|int == 2\\\", \\\"block\\\": [{\\\"name\\\": \\\"Mysql puppet bundle\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_ha_wrapper\\\"}, \\\"vars\\\": {\\\"tripleo_ha_wrapper_service_name\\\": \\\"mysql\\\", \\\"tripleo_ha_wrapper_resource_name\\\": \\\"galera\\\", \\\"tripleo_ha_wrapper_bundle_name\\\": \\\"galera-bundle\\\", \\\"tripleo_ha_wrapper_resource_state\\\": \\\"Master\\\", \\\"tripleo_ha_wrapper_puppet_config_volume\\\": \\\"mysql\\\", \\\"tripleo_ha_wrapper_puppet_execute\\\": \\\"[\\\\\\\"Mysql_datadir\\\\\\\", \\\\\\\"Mysql_user\\\\\\\", \\\\\\\"Mysql_database\\\\\\\", \\\\\\\"Mysql_grant\\\\\\\", \\\\\\\"Mysql_plugin\\\\\\\"].each |String $val| { noop_resource($val) }; include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::database::mysql_bundle\\\", \\\"tripleo_ha_wrapper_puppet_tags\\\": \\\"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\\\", \\\"tripleo_ha_wrapper_puppet_debug\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"tripleo_ha_wrapper_config_suffix\\\": \\\".previous_run\\\"}}]}]]}, \\\"external_update_tasks\\\": [{\\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": \\\"ha_image_update\\\", \\\"block\\\": [{\\\"block\\\": [{\\\"name\\\": \\\"Get galera image from pacemaker\\\", \\\"become\\\": true, \\\"register\\\": \\\"xmllint_pcmk_galera_image\\\", \\\"shell\\\": \\\"xmllint --xpath \\\\\\\"string(//bundle[@id=\'galera-bundle\']/podman/@image)\\\\\\\" /var/lib/pacemaker/cib/cib.xml\\\"}, {\\\"name\\\": \\\"Get container galera image\\\", \\\"set_fact\\\": {\\\"galera_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}, \\\"galera_image_latest\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/mariadb:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"pcmk_galera_image\\\": \\\"{{xmllint_pcmk_galera_image.stdout}}\\\"}}], \\\"delegate_to\\\": \\\"{{ (groups[\\\\\\\"mysql\\\\\\\"] | difference(groups[\\\\\\\"excluded_overcloud\\\\\\\"]))[0] }}\\\"}, {\\\"name\\\": \\\"MySQL temporary pacemaker container tag in case of image switch\\\", \\\"become\\\": true, \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_ha_image_update\\\"}, \\\"vars\\\": {\\\"tripleo_ha_image_update_node_names\\\": \\\"{{ groups[\\\\\\\"mysql\\\\\\\"] | difference(groups[\\\\\\\"excluded_overcloud\\\\\\\"]) }}\\\", \\\"tripleo_ha_image_update_bundle\\\": \\\"galera-bundle\\\", \\\"tripleo_ha_image_update_new_image\\\": \\\"{{galera_image_latest}}\\\", \\\"tripleo_ha_image_update_old_image\\\": \\\"{{pcmk_galera_image}}\\\"}, \\\"when\\\": [\\\"(pcmk_galera_image != \\\\\\\"\\\\\\\")\\\", \\\"(pcmk_galera_image != galera_image_latest)\\\"]}]}], \\\"update_tasks\\\": [{\\\"block\\\": [{\\\"name\\\": \\\"Get galera image from pacemaker\\\", \\\"become\\\": true, \\\"register\\\": \\\"xmllint_pcmk_galera_image\\\", \\\"shell\\\": \\\"xmllint --xpath \\\\\\\"string(//bundle[@id=\'galera-bundle\']/podman/@image)\\\\\\\" /var/lib/pacemaker/cib/cib.xml\\\"}, {\\\"name\\\": \\\"Get container galera image\\\", \\\"set_fact\\\": {\\\"galera_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}, \\\"galera_image_latest\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/mariadb:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"pcmk_galera_image\\\": \\\"{{xmllint_pcmk_galera_image.stdout}}\\\"}}], \\\"when\\\": \\\"(step|int == 0 or step|int == 2)\\\"}, {\\\"name\\\": \\\"Check for update of galera container image name\\\", \\\"when\\\": \\\"step|int == 0\\\", \\\"assert\\\": {\\\"that\\\": \\\"pcmk_galera_image == galera_image_latest\\\", \\\"fail_msg\\\": \\\"galera image change detected, run overcloud external-update --tags ha_image_update first\\\"}}, {\\\"name\\\": \\\"Tear-down non-HA mysql container\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"stat mysql container\\\", \\\"command\\\": \\\"podman container exists mysql\\\", \\\"failed_when\\\": false, \\\"changed_when\\\": false, \\\"register\\\": \\\"stat_mysql_container\\\"}, {\\\"name\\\": \\\"Create clustercheck user and permissions\\\", \\\"command\\\": {\\\"argv\\\": \\\"{{ mysql_exec_data | container_exec_cmd }}\\\"}, \\\"changed_when\\\": true, \\\"when\\\": [\\\"stat_mysql_container.rc == 0\\\"], \\\"vars\\\": {\\\"mysql_exec_data\\\": {\\\"environment\\\": {\\\"CLUSTERCHECK_PASSWORD\\\": {\\\"get_param\\\": \\\"MysqlClustercheckPassword\\\"}}, \\\"command\\\": [\\\"mysql\\\", \\\"/bin/sh\\\", \\\"-c\\\", \\\"mysql -e \\\\\\\"CREATE USER IF NOT EXISTS \'clustercheck\'@\'localhost\' IDENTIFIED BY \'${CLUSTERCHECK_PASSWORD}\'; GRANT PROCESS ON *.* TO \'clustercheck\'@\'localhost\' WITH GRANT OPTION;\\\\\\\"\\\"]}}}, {\\\"name\\\": \\\"Remove non-HA mysql container\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_rm\\\"}, \\\"vars\\\": {\\\"tripleo_container_cli\\\": \\\"{{ container_cli }}\\\", \\\"tripleo_containers_to_rm\\\": [\\\"mysql\\\"]}}]}, {\\\"name\\\": \\\"Mariadb fetch and retag container image for pacemaker\\\", \\\"when\\\": \\\"step|int == 2\\\", \\\"block\\\": [{\\\"name\\\": \\\"Retag pcmklatest to latest galera image\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_tag\\\"}, \\\"vars\\\": {\\\"container_image\\\": \\\"{{galera_image}}\\\", \\\"container_image_latest\\\": \\\"{{galera_image_latest}}\\\"}}]}, {\\\"name\\\": \\\"Ensure mariadb-server is not installed on the host\\\", \\\"when\\\": \\\"step|int == 2\\\", \\\"yum\\\": {\\\"name\\\": \\\"mariadb-server*\\\", \\\"state\\\": \\\"absent\\\"}}], \\\"post_update_tasks\\\": [{\\\"name\\\": \\\"Mysql bundle post update\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Mysql puppet bundle\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_ha_wrapper\\\"}, \\\"vars\\\": {\\\"tripleo_ha_wrapper_service_name\\\": \\\"mysql\\\", \\\"tripleo_ha_wrapper_resource_name\\\": \\\"galera\\\", \\\"tripleo_ha_wrapper_bundle_name\\\": \\\"galera-bundle\\\", \\\"tripleo_ha_wrapper_resource_state\\\": \\\"Master\\\", \\\"tripleo_ha_wrapper_puppet_config_volume\\\": \\\"mysql\\\", \\\"tripleo_ha_wrapper_puppet_execute\\\": \\\"[\\\\\\\"Mysql_datadir\\\\\\\", \\\\\\\"Mysql_user\\\\\\\", \\\\\\\"Mysql_database\\\\\\\", \\\\\\\"Mysql_grant\\\\\\\", \\\\\\\"Mysql_plugin\\\\\\\"].each |String $val| { noop_resource($val) }; include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::database::mysql_bundle\\\", \\\"tripleo_ha_wrapper_puppet_tags\\\": \\\"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\\\", \\\"tripleo_ha_wrapper_puppet_debug\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"tripleo_ha_wrapper_config_suffix\\\": \\\".previous_run\\\"}}], \\\"vars\\\": {\\\"tripleo_ha_wrapper_minor_update\\\": true}}], \\\"upgrade_tasks\\\": {\\\"list_concat\\\": [[{\\\"name\\\": \\\"Tear-down non-HA mysql container\\\", \\\"when\\\": [\\\"step|int == 0\\\"], \\\"block\\\": [{\\\"name\\\": \\\"stat mysql container\\\", \\\"command\\\": \\\"podman container exists mysql\\\", \\\"failed_when\\\": false, \\\"changed_when\\\": false, \\\"register\\\": \\\"stat_mysql_container\\\"}, {\\\"name\\\": \\\"Create clustercheck user and permissions\\\", \\\"command\\\": {\\\"argv\\\": \\\"{{ mysql_exec_data | container_exec_cmd }}\\\"}, \\\"changed_when\\\": true, \\\"when\\\": [\\\"stat_mysql_container.rc == 0\\\"], \\\"vars\\\": {\\\"mysql_exec_data\\\": {\\\"environment\\\": {\\\"CLUSTERCHECK_PASSWORD\\\": {\\\"get_param\\\": \\\"MysqlClustercheckPassword\\\"}}, \\\"command\\\": [\\\"mysql\\\", \\\"/bin/sh\\\", \\\"-c\\\", \\\"mysql -e \\\\\\\"CREATE USER IF NOT EXISTS \'clustercheck\'@\'localhost\' IDENTIFIED BY \'${CLUSTERCHECK_PASSWORD}\'; GRANT PROCESS ON *.* TO \'clustercheck\'@\'localhost\' WITH GRANT OPTION;\\\\\\\"\\\"]}}}, {\\\"name\\\": \\\"Remove non-HA mysql container\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_rm\\\"}, \\\"vars\\\": {\\\"tripleo_container_cli\\\": \\\"{{ container_cli }}\\\", \\\"tripleo_containers_to_rm\\\": [\\\"mysql\\\"]}}]}], [{\\\"name\\\": \\\"set mysql container name fact\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"set_fact\\\": {\\\"mysql_container_name\\\": \\\"galera-bundle\\\"}}], {\\\"get_attr\\\": [\\\"MysqlBase\\\", \\\"mysql_drop_unused_users\\\"]}, [{\\\"vars\\\": {\\\"mysql_upgrade_persist\\\": {\\\"get_param\\\": \\\"MysqlUpgradePersist\\\"}}, \\\"when\\\": [\\\"step|int == 3\\\", \\\"mysql_upgrade_persist\\\"], \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_prepare\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Persist mysql data\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_persist\\\", \\\"tasks_from\\\": \\\"persist.yml\\\"}, \\\"vars\\\": {\\\"tripleo_persist_dir\\\": \\\"/var/lib/mysql\\\"}}]}, {\\\"vars\\\": {\\\"mysql_upgrade_persist\\\": {\\\"get_param\\\": \\\"MysqlUpgradePersist\\\"}}, \\\"when\\\": [\\\"step|int == 5\\\", \\\"mysql_upgrade_persist\\\"], \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_run\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Restore mysql data\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_persist\\\", \\\"tasks_from\\\": \\\"restore.yml\\\"}, \\\"vars\\\": {\\\"tripleo_persist_dir\\\": \\\"/var/lib/mysql\\\"}}]}, {\\\"name\\\": \\\"Prepare switch of galera image name\\\", \\\"when\\\": [\\\"step|int == 0\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Get galera image id currently used by pacemaker\\\", \\\"shell\\\": \\\"pcs resource config galera-bundle | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\\\", \\\"register\\\": \\\"galera_image_current_res\\\", \\\"failed_when\\\": false}, {\\\"name\\\": \\\"Image facts for galera\\\", \\\"set_fact\\\": {\\\"galera_image_latest\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/mariadb:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"galera_image_current\\\": \\\"{{galera_image_current_res.stdout}}\\\"}}, {\\\"name\\\": \\\"Temporarily tag the current galera image id with the upgraded image name\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_tag\\\"}, \\\"vars\\\": {\\\"container_image\\\": \\\"{{galera_image_current}}\\\", \\\"container_image_latest\\\": \\\"{{galera_image_latest}}\\\", \\\"pull_image\\\": false}, \\\"when\\\": [\\\"galera_image_current != \'\'\\\", \\\"galera_image_current != galera_image_latest\\\"]}, {\\\"name\\\": \\\"Create galera retag statefile\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/tripleo/galera_needs_retag\\\", \\\"state\\\": \\\"touch\\\"}, \\\"when\\\": [\\\"galera_image_current != \'\'\\\", \\\"galera_image_current != galera_image_latest\\\"]}]}, {\\\"name\\\": \\\"Update galera pcs resource bundle for new container image - check\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"set is_mysql_bootstrap_node fact\\\", \\\"tags\\\": \\\"common\\\", \\\"set_fact\\\": \\\"is_mysql_bootstrap_node={{mysql_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\\\"}, {\\\"name\\\": \\\"Check for galera retag statefile\\\", \\\"stat\\\": {\\\"path\\\": \\\"/var/lib/tripleo/galera_needs_retag\\\"}, \\\"register\\\": \\\"galera_retag_state_file\\\"}]}, {\\\"name\\\": \\\"Update galera pcs resource bundle for new container image\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"is_mysql_bootstrap_node|bool\\\", \\\"galera_retag_state_file.stat.exists|bool\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Disable the galera cluster resource before container upgrade\\\", \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"galera-bundle\\\", \\\"state\\\": \\\"disable\\\", \\\"wait_for_resource\\\": true}, \\\"register\\\": \\\"output\\\", \\\"retries\\\": 5, \\\"until\\\": \\\"output.rc == 0\\\"}, {\\\"name\\\": \\\"Move Mysql logging to /var/log/containers\\\", \\\"block\\\": [{\\\"name\\\": \\\"Check Mysql logging configuration in pacemaker\\\", \\\"command\\\": \\\"cibadmin --query --xpath \\\\\\\"//storage-mapping[@id=\'mysql-log\']\\\\\\\"\\\", \\\"failed_when\\\": false, \\\"register\\\": \\\"mysql_logs_moved\\\"}, {\\\"name\\\": \\\"Change Mysql logging configuration in pacemaker\\\", \\\"when\\\": \\\"mysql_logs_moved.rc == 6\\\", \\\"block\\\": [{\\\"name\\\": \\\"Add a bind mount for logging in the galera bundle\\\", \\\"command\\\": \\\"pcs resource bundle update galera-bundle storage-map add id=mysql-log source-dir=/var/log/containers/mysql target-dir=/var/log/mysql options=rw\\\"}, {\\\"name\\\": \\\"Reconfigure Mysql log file in the galera resource agent\\\", \\\"command\\\": \\\"pcs resource update galera log=/var/log/mysql/mysqld.log\\\"}]}]}, {\\\"name\\\": \\\"Update the galera bundle to use the new container image name\\\", \\\"command\\\": \\\"pcs resource bundle update galera-bundle container image={{galera_image_latest}}\\\"}, {\\\"name\\\": \\\"Enable the galera cluster resource\\\", \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"galera-bundle\\\", \\\"state\\\": \\\"enable\\\", \\\"wait_for_resource\\\": true}, \\\"register\\\": \\\"output\\\", \\\"retries\\\": 5, \\\"until\\\": \\\"output.rc == 0\\\"}]}, {\\\"name\\\": \\\"Upgrade galera in step3\\\", \\\"when\\\": [\\\"step|int == 3\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Bind mounts for temporary container\\\", \\\"set_fact\\\": {\\\"mysql_upgrade_db_bind_mounts\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/mysql.json:/var/lib/kolla/config_files/config.json:rw,z\\\", \\\"/var/lib/config-data/puppet-generated/mysql:/var/lib/kolla/config_files/src:ro,z\\\", \\\"/var/lib/mysql:/var/lib/mysql:rw,z\\\"], [\\\"/var/log/containers/mysql:/var/log/mysql:rw,z\\\"], {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, [\\\"/etc/pki/tls/certs/mysql.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/mysql.crt:ro\\\", \\\"/etc/pki/tls/private/mysql.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/mysql.key:ro\\\"]]}]}}}, {\\\"name\\\": \\\"Check if Galera needs upgrade\\\", \\\"shell\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"CONTAINER_CLI run --rm --log-driver=k8s-file --log-opt path=LOG_DIR/db-upgrade.log \\\\\\\\ -u root --net=host UPGRADE_ENV UPGRADE_VOLUMES \\\\\\\"UPGRADE_IMAGE\\\\\\\" /bin/bash -ecx \\\\\\\"$UPGRADE_SCRIPT\\\\\\\"\\\", \\\"params\\\": {\\\"UPGRADE_ENV\\\": \\\"-e \\\\\\\"KOLLA_CONFIG_STRATEGY=COPY_ALWAYS\\\\\\\"\\\", \\\"UPGRADE_IMAGE\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/mariadb:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"UPGRADE_VOLUMES\\\": \\\"-v {{ mysql_upgrade_db_bind_mounts | join(\' -v \')}}\\\", \\\"CONTAINER_CLI\\\": \\\"{{ container_cli }}\\\", \\\"LOG_DIR\\\": \\\"/var/log/containers/mysql\\\"}}}, \\\"environment\\\": {\\\"UPGRADE_SCRIPT\\\": \\\"kolla_set_configs\\\\nupgraded_ver=$(cat /var/lib/mysql/mysql_upgrade_info 2>/dev/null || true)\\\\nmysql_ver=$(mysql --version | awk -F\'[ ,]*\' \'{print $5}\')\\\\nif [ \\\\\\\"${upgraded_ver}\\\\\\\" = \\\\\\\"${mysql_ver}\\\\\\\" ]; then\\\\n    echo \\\\\\\"mysql already upgraded\\\\\\\"\\\\nelse\\\\n    echo \\\\\\\"${upgraded_ver} VS ${mysql_ver}\\\\\\\"\\\\nfi\\\\n\\\"}, \\\"register\\\": \\\"mysql_upgrade_needed\\\"}, {\\\"name\\\": \\\"Set fact upgrade_mysql\\\", \\\"set_fact\\\": {\\\"upgrade_mysql\\\": \\\"{{ (mysql_upgrade_needed.stdout != \\\\\\\"mysql already upgraded\\\\\\\") | bool }}\\\"}}, {\\\"debug\\\": {\\\"msg\\\": \\\"MYSQL check - {{ mysql_upgrade_needed.stdout }} - Upgrade needed: {{ upgrade_mysql }}\\\"}}, {\\\"name\\\": \\\"Disable the galera cluster resource before container upgrade\\\", \\\"when\\\": [\\\"upgrade_mysql|bool\\\"], \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"galera-bundle\\\", \\\"state\\\": \\\"disable\\\", \\\"wait_for_resource\\\": true}, \\\"register\\\": \\\"output\\\", \\\"retries\\\": 5, \\\"until\\\": \\\"output.rc == 0\\\"}, {\\\"block\\\": [{\\\"name\\\": \\\"Get galera image from pacemaker\\\", \\\"become\\\": true, \\\"register\\\": \\\"xmllint_pcmk_galera_image\\\", \\\"shell\\\": \\\"xmllint --xpath \\\\\\\"string(//bundle[@id=\'galera-bundle\']/podman/@image)\\\\\\\" /var/lib/pacemaker/cib/cib.xml\\\"}, {\\\"name\\\": \\\"Get container galera image\\\", \\\"set_fact\\\": {\\\"galera_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}, \\\"galera_image_latest\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/mariadb:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"pcmk_galera_image\\\": \\\"{{xmllint_pcmk_galera_image.stdout}}\\\"}}]}, {\\\"name\\\": \\\"Check for galera retag statefile\\\", \\\"stat\\\": {\\\"path\\\": \\\"/var/lib/tripleo/galera_needs_retag\\\"}, \\\"register\\\": \\\"galera_retag_state_file\\\"}, {\\\"name\\\": \\\"Retag the pacemaker image if containerized\\\", \\\"when\\\": [\\\"galera_retag_state_file.stat.exists|bool\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Retag pcmklatest to latest galera image\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_tag\\\"}, \\\"vars\\\": {\\\"container_image\\\": \\\"{{galera_image}}\\\", \\\"container_image_latest\\\": \\\"{{galera_image_latest}}\\\"}}]}, {\\\"name\\\": \\\"Remove galera retag statefile\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/tripleo/galera_needs_retag\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"Mysql upgrade script\\\", \\\"when\\\": [\\\"upgrade_mysql|bool\\\"], \\\"set_fact\\\": {\\\"mysql_upgrade_script\\\": {\\\"list_join\\\": [\\\"\\\\n\\\", [\\\"kolla_set_configs\\\\nif mysqladmin ping --silent; then exit 0; fi\\\\nupgraded_ver=$(cat /var/lib/mysql/mysql_upgrade_info 2>/dev/null || true)\\\\nmysql_ver=$(mysql --version | awk -F\'[ ,]*\' \'{print $5}\')\\\\nif [ \\\\\\\"${upgraded_ver}\\\\\\\" = \\\\\\\"${mysql_ver}\\\\\\\" ]; then\\\\n    echo \\\\\\\"mysql already upgraded\\\\\\\"\\\\n    exit 0\\\\nfi\\\\nchown -R mysql:mysql /var/lib/mysql\\\\nchown -R mysql:mysql /var/log/mysql\\\\nmysqld_safe --user=mysql --wsrep-provider=none --skip-networking --wsrep-on=off --log-error=/var/log/mysql/mysqld-upgrade.log &\\\\n\\\", {\\\"get_file\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/mysql_upgrade_db.sh\\\"}, \\\"mysqladmin shutdown\\\"]]}}}, {\\\"name\\\": \\\"Upgrade Mysql database from a temporary container\\\", \\\"when\\\": [\\\"upgrade_mysql|bool\\\"], \\\"shell\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"CONTAINER_CLI run --rm --log-driver=k8s-file --log-opt path=LOG_DIR/db-upgrade.log \\\\\\\\ -u root --net=host UPGRADE_ENV UPGRADE_VOLUMES \\\\\\\"UPGRADE_IMAGE\\\\\\\" /bin/bash -ecx \\\\\\\"$UPGRADE_SCRIPT\\\\\\\"\\\", \\\"params\\\": {\\\"UPGRADE_ENV\\\": \\\"-e \\\\\\\"KOLLA_CONFIG_STRATEGY=COPY_ALWAYS\\\\\\\"\\\", \\\"UPGRADE_IMAGE\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/mariadb:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"UPGRADE_VOLUMES\\\": \\\"-v {{ mysql_upgrade_db_bind_mounts | join(\' -v \')}}\\\", \\\"CONTAINER_CLI\\\": \\\"{{ container_cli }}\\\", \\\"LOG_DIR\\\": \\\"/var/log/containers/mysql\\\"}}}, \\\"environment\\\": {\\\"UPGRADE_SCRIPT\\\": \\\"{{ mysql_upgrade_script }}\\\"}}, {\\\"name\\\": \\\"Enable the galera cluster resource\\\", \\\"when\\\": [\\\"upgrade_mysql|bool\\\"], \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"galera-bundle\\\", \\\"state\\\": \\\"enable\\\", \\\"wait_for_resource\\\": true}, \\\"register\\\": \\\"output\\\", \\\"retries\\\": 5, \\\"until\\\": \\\"output.rc == 0\\\"}]}]]}, \\\"external_upgrade_tasks\\\": [{\\\"vars\\\": {\\\"mysql_upgrade_transfer\\\": {\\\"get_param\\\": \\\"MysqlUpgradeTransfer\\\"}}, \\\"when\\\": [\\\"step|int == 2\\\", \\\"mysql_upgrade_transfer\\\"], \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade_transfer_data\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Transfer mysql data\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_transfer\\\"}, \\\"vars\\\": {\\\"tripleo_transfer_src_dir\\\": \\\"/var/lib/mysql\\\", \\\"tripleo_transfer_src_host\\\": \\\"{{hostvars[groups[\'overcloud\'][0]][\'mysql_short_node_names\'][1]}}\\\", \\\"tripleo_transfer_dest_dir\\\": \\\"/var/lib/mysql\\\", \\\"tripleo_transfer_dest_host\\\": \\\"{{hostvars[groups[\'overcloud\'][0]][\'mysql_short_bootstrap_node_name\']}}\\\", \\\"tripleo_transfer_flag_file\\\": \\\"/var/lib/tripleo/transfer-flags/var-lib-mysql\\\", \\\"tripleo_transfer_sync_options\\\": \\\"--whole-file --ignore-times --inplace --archive --delete\\\", \\\"tripleo_transfer_include\\\": [\\\"/ibdata*\\\", \\\"/ib_lru_dump\\\", \\\"/ib_logfile[0-9]*\\\", \\\"/undo*\\\", \\\"/*/\\\"], \\\"tripleo_transfer_exclude\\\": \\\"/*\\\"}}]}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-base.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack Neutron base service. Shared for all Neutron agents.\\\\n\\\", \\\"parameters\\\": {\\\"DatabaseSyncTimeout\\\": {\\\"default\\\": 300, \\\"description\\\": \\\"DB Sync Timeout default\\\", \\\"type\\\": \\\"number\\\"}, \\\"NeutronDhcpAgentsPerNetwork\\\": {\\\"type\\\": \\\"number\\\", \\\"default\\\": 0, \\\"description\\\": \\\"The number of neutron dhcp agents to schedule per network\\\"}, \\\"DhcpAgentNotification\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether or not to enable DHCP agent notifications.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"NeutronDnsDomain\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"openstacklocal\\\", \\\"description\\\": \\\"Domain to use for building the hostnames.\\\"}, \\\"NeutronCorePlugin\\\": {\\\"default\\\": \\\"ml2\\\", \\\"description\\\": \\\"The core plugin for Neutron. The value should be the entrypoint to be loaded\\\\nfrom neutron.core_plugins namespace.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"NeutronServicePlugins\\\": {\\\"default\\\": \\\"qos,ovn-router,trunk,segments,port_forwarding,log\\\", \\\"description\\\": \\\"Comma-separated list of service plugin entrypoints to be loaded from the\\\\nneutron.service_plugins namespace.\\\\n\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"Debug\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false, \\\"description\\\": \\\"Set to True to enable debugging on all services.\\\"}, \\\"NeutronDebug\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Set to True to enable debugging Neutron services.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"EnableConfigPurge\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false, \\\"description\\\": \\\"Remove configuration that is not generated by TripleO. Used to avoid configuration remnants after upgrades.\\\\n\\\"}, \\\"NeutronGlobalPhysnetMtu\\\": {\\\"type\\\": \\\"number\\\", \\\"default\\\": 0, \\\"description\\\": \\\"MTU of the underlying physical network. Neutron uses this value to\\\\ncalculate MTU for all virtual network components. For flat and VLAN\\\\nnetworks, neutron uses this value without modification. For overlay\\\\nnetworks such as VXLAN, neutron automatically subtracts the overlay\\\\nprotocol overhead from this value.\\\\n(If this is not changed TenantNetPhysnetMtu will be used.)\\\\n\\\"}, \\\"TenantNetPhysnetMtu\\\": {\\\"type\\\": \\\"number\\\", \\\"default\\\": 1500, \\\"description\\\": \\\"MTU of the underlying physical network. Neutron uses this value to\\\\ncalculate MTU for all virtual network components. For flat and VLAN\\\\nnetworks, neutron uses this value without modification. For overlay\\\\nnetworks such as VXLAN, neutron automatically subtracts the overlay\\\\nprotocol overhead from this value.\\\\n(The mtu setting of the Tenant network in network_data.yaml\\\\ncontrol\'s this parameter.)\\\\n\\\"}, \\\"NeutronDBSyncExtraParams\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"String of extra command line parameters to append to the neutron-db-manage\\\\nupgrade head command.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"NotificationDriver\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": \\\"noop\\\", \\\"description\\\": \\\"Driver or drivers to handle sending notifications.\\\"}, \\\"EnableVLANTransparency\\\": {\\\"default\\\": false, \\\"description\\\": \\\"If True, then allow plugins that support it to create VLAN transparent networks.\\\\n\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"NeutronGlobalReportInterval\\\": {\\\"default\\\": 300, \\\"description\\\": \\\"Seconds between nodes reporting state to server; should be less than NeutronAgentDownTime, best if it is half or less than NeutronAgentDownTime.\\\\n\\\", \\\"type\\\": \\\"number\\\"}}, \\\"conditions\\\": {\\\"dhcp_agents_zero\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"NeutronDhcpAgentsPerNetwork\\\"}, 0]}, \\\"global_physnet_mtu_unset\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"NeutronGlobalPhysnetMtu\\\"}, 0]}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Neutron base service.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"neutron_base\\\", \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"neutron::notification_driver\\\": {\\\"get_param\\\": \\\"NotificationDriver\\\"}, \\\"neutron::core_plugin\\\": {\\\"get_param\\\": \\\"NeutronCorePlugin\\\"}, \\\"neutron::service_plugins\\\": {\\\"get_param\\\": \\\"NeutronServicePlugins\\\"}, \\\"neutron::report_interval\\\": {\\\"get_param\\\": \\\"NeutronGlobalReportInterval\\\"}, \\\"neutron::logging::debug\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"NeutronDebug\\\"}, true, {\\\"get_param\\\": \\\"Debug\\\"}]}, \\\"neutron::purge_config\\\": {\\\"get_param\\\": \\\"EnableConfigPurge\\\"}, \\\"neutron::allow_overlapping_ips\\\": true, \\\"neutron::dhcp_agent_notification\\\": {\\\"get_param\\\": \\\"DhcpAgentNotification\\\"}, \\\"neutron::dns_domain\\\": {\\\"get_param\\\": \\\"NeutronDnsDomain\\\"}, \\\"neutron::rabbit_heartbeat_timeout_threshold\\\": 60, \\\"neutron::host\\\": \\\"%{hiera(\'fqdn_canonical\')}\\\", \\\"neutron::db::database_db_max_retries\\\": -1, \\\"neutron::db::database_max_retries\\\": -1, \\\"neutron::db::sync::db_sync_timeout\\\": {\\\"get_param\\\": \\\"DatabaseSyncTimeout\\\"}, \\\"neutron::global_physnet_mtu\\\": {\\\"if\\\": [\\\"global_physnet_mtu_unset\\\", {\\\"get_param\\\": \\\"TenantNetPhysnetMtu\\\"}, {\\\"get_param\\\": \\\"NeutronGlobalPhysnetMtu\\\"}]}, \\\"neutron::db::sync::extra_params\\\": {\\\"get_param\\\": \\\"NeutronDBSyncExtraParams\\\"}, \\\"neutron::vlan_transparent\\\": {\\\"get_param\\\": \\\"EnableVLANTransparency\\\"}, \\\"neutron::rabbit_heartbeat_in_pthread\\\": false}, {\\\"if\\\": [\\\"dhcp_agents_zero\\\", {}, {\\\"tripleo::profile::base::neutron::dhcp_agents_per_network\\\": {\\\"get_param\\\": \\\"NeutronDhcpAgentsPerNetwork\\\"}}]}]}}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/kill-script\": \"#!/bin/bash\\n{% if debug_enabled|bool -%}\\nset -x\\n{% endif -%}\\nadd_date() {\\n  echo \\\"$(date) $@\\\"\\n}\\n\\n# Set up script logging for debugging purpose.\\n# It will be taken care of by logrotate since there is the .log\\n# suffix.\\nexec 3>&1 4>&2\\ntrap \'exec 2>&4 1>&3\' 0 1 2 3\\nexec 1>>/var/log/neutron/kill-script.log 2>&1\\n\\nSIG=$1\\nPID=$2\\nNETNS=$(ip netns identify ${PID})\\n\\nif [ \\\"x${NETNS}\\\" == \\\"x\\\" ]; then\\n  CLI=\\\"nsenter --all --preserve-credentials -t 1 podman\\\"\\n  SIG=9\\nelse\\n  CLI=\\\"nsenter --net=/run/netns/${NETNS} --preserve-credentials -m -t 1 podman\\\"\\nfi\\n\\nkill_container() {\\n  add_date \\\"Killing container $1 ($2)\\\"\\n  signal_container $1 $2 9\\n}\\n\\nstop_container() {\\n  add_date \\\"Stopping container $1 ($2)\\\"\\n  $CLI stop $2\\n}\\n\\nsignal_container() {\\n  SIGNAL=$3\\n  if [ -z \\\"$SIGNAL\\\" ]; then\\n      SIGNAL=\\\"HUP\\\"\\n  fi\\n  add_date \\\"Sending signal \'$SIGNAL\' to $1 ($2)\\\"\\n  $CLI kill --signal $SIGNAL $2\\n}\\n\\ndelete_container() {\\n  add_date \\\"Deleting container $1 ($2)\\\"\\n  $CLI rm $2 || echo \\\"Deleting container $1 ($2) failed\\\"\\n}\\n\\n\\n{% raw -%}\\nif [ -f /proc/$PID/cgroup ]; then\\n  # Get container ID based on process cgroups\\n  CT_ID=$(awk \'BEGIN {FS=\\\".scope|-\\\"} /\\\\/libpod-/ {if ($(NF-1)) print $(NF-1);exit}\' /proc/$PID/cgroup)\\n  CT_NAME=$($CLI inspect -f \'{{.Name}}\' $CT_ID)\\n\\n  case $SIG in\\n    HUP)\\n      signal_container $CT_NAME $CT_ID\\n      ;;\\n    9)\\n      kill_container $CT_NAME $CT_ID\\n      delete_container $CT_NAME $CT_ID\\n      ;;\\n    15)\\n      stop_container $CT_NAME $CT_ID\\n      delete_container $CT_NAME $CT_ID\\n      ;;\\n    *)\\n      add_date \\\"Unknown action ${SIG} for ${CT_NAME} ${CT_ID}\\\"\\n      exit 1\\n      ;;\\n  esac\\n\\nelse\\n  add_date \\\"No such PID: ${PID}\\\"\\n  exit 1\\nfi\\n{% endraw %}\\n\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized OVN Metadata agent\\\\n\\\", \\\"parameters\\\": {\\\"ContainerOvnMetadataImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerNeutronConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the neutron config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"OvnMetadataAgentLoggingSource\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {\\\"tag\\\": \\\"openstack.neutron.agent.ovn-metadata\\\", \\\"file\\\": \\\"/var/log/containers/neutron/networking-ovn-metadata-agent.log\\\"}}, \\\"OVNEnableHaproxyDockerWrapper\\\": {\\\"description\\\": \\\"Generate a wrapper script so that haproxy is launched in a separate container.\\\", \\\"type\\\": \\\"boolean\\\", \\\"default\\\": true}, \\\"Debug\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false, \\\"description\\\": \\\"Set to True to enable debugging on all services.\\\"}, \\\"OVNWrapperDebug\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false, \\\"description\\\": \\\"Controls debugging for the wrapper scripts.\\\"}, \\\"ContainerCli\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"podman\\\", \\\"description\\\": \\\"CLI tool used to manage containers.\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"docker\\\", \\\"podman\\\"]}]}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"DeployIdentifier\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\\\n\\\"}, \\\"NeutronMetadataProxySharedSecret\\\": {\\\"description\\\": \\\"Shared secret to prevent spoofing\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"NeutronMetadataWorkers\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Sets the number of worker processes for the neutron OVN metadata agent.\\\\nThe default value results in the configuration being left unset and a\\\\nsystem-dependent default will be chosen (usually the number of\\\\nprocessors). Please note that this can result in a large number of\\\\nprocesses and memory consumption on systems with a large core count. On\\\\nsuch systems it is recommended that a non-default value be selected that\\\\nmatches the load requirements.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"NeutronPassword\\\": {\\\"description\\\": \\\"The password for the neutron service and db account, used by neutron agents.\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"OVNNorthboundServerPort\\\": {\\\"description\\\": \\\"Port of the OVN Northbound DB server\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 6641}, \\\"OVNSouthboundServerPort\\\": {\\\"description\\\": \\\"Port of the OVN Southbound DB server\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 6642}, \\\"OVNDbConnectionTimeout\\\": {\\\"description\\\": \\\"Timeout in seconds for the OVSDB connection transaction\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 180}, \\\"OVNOvsdbProbeInterval\\\": {\\\"description\\\": \\\"Probe interval in ms for the OVSDB session\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 60000}, \\\"MonitoringSubscriptionOvnMetadata\\\": {\\\"default\\\": \\\"overcloud-ovn-metadata\\\", \\\"type\\\": \\\"string\\\"}, \\\"OvnMetadataAgentDebug\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Set to True to enable debugging for OVN Metadata agent.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"InternalTLSCAFile\\\": {\\\"default\\\": \\\"/etc/ipa/ca.crt\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Specifies the default CA cert to use if TLS is used for services in the internal network.\\\"}, \\\"DockerAdditionalSockets\\\": {\\\"default\\\": [\\\"/var/lib/openstack/docker.sock\\\"], \\\"description\\\": \\\"Additional domain sockets for the docker daemon to bind to (useful for mounting into containers that launch other containers)\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"CertificateKeySize\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"2048\\\", \\\"description\\\": \\\"Specifies the private key size used when creating the certificate.\\\"}, \\\"OvnMetadataCertificateKeySize\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Override the private key size used when creating the certificate for this service\\\"}, \\\"OvnHardwareOffloadedQos\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false, \\\"description\\\": \\\"Enable the QoS support for hardware offloaded ports\\\"}, \\\"OVNMetadataImageUpdateTimeout\\\": {\\\"description\\\": \\\"During update, how long we wait for the container image to be updated, in seconds.\\\\n\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 600}, \\\"OVNMetadataUpdateTimeout\\\": {\\\"description\\\": \\\"During update, how long we wait for the container to be updated, in seconds.\\\\n\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 600}}, \\\"conditions\\\": {\\\"haproxy_wrapper_enabled\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"OVNEnableHaproxyDockerWrapper\\\"}, true]}, \\\"docker_enabled\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"docker\\\"]}, \\\"internal_tls_enabled\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, true]}, \\\"neutron_metadata_workers_unset\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"NeutronMetadataWorkers\\\"}, \\\"\\\"]}, \\\"key_size_override_unset\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"OvnMetadataCertificateKeySize\\\"}, \\\"\\\"]}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"NeutronBase\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-base.yaml\\\", \\\"properties\\\": {\\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"NeutronLogging\\\": {\\\"type\\\": \\\"OS::TripleO::Services::Logging::NeutronCommon\\\", \\\"properties\\\": {\\\"NeutronServiceName\\\": \\\"ovn-metadata-agent\\\"}}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerOvnMetadataImage\\\": \\\"ContainerOvnMetadataImage\\\", \\\"ContainerNeutronConfigImage\\\": \\\"ContainerNeutronConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerOvnMetadataImage\\\": {\\\"get_param\\\": \\\"ContainerOvnMetadataImage\\\"}, \\\"ContainerNeutronConfigImage\\\": {\\\"get_param\\\": \\\"ContainerNeutronConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for OVNMetadata agent\\\", \\\"value\\\": {\\\"service_name\\\": \\\"ovn_metadata\\\", \\\"monitoring_subscription\\\": {\\\"get_param\\\": \\\"MonitoringSubscriptionOvnMetadata\\\"}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"NeutronBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"get_attr\\\": [\\\"NeutronLogging\\\", \\\"config_settings\\\"]}, {\\\"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::enable_haproxy_wrapper\\\": {\\\"get_param\\\": \\\"OVNEnableHaproxyDockerWrapper\\\"}, \\\"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::haproxy_process_wrapper\\\": \\\"/var/lib/neutron/ovn_metadata_haproxy_wrapper\\\", \\\"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::haproxy_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerOvnMetadataImage\\\"]}, \\\"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::debug\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"OVNWrapperDebug\\\"}, true, {\\\"get_param\\\": \\\"Debug\\\"}]}, \\\"tripleo::profile::base::neutron::container_cli\\\": {\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"neutron::agents::ovn_metadata::shared_secret\\\": {\\\"get_param\\\": \\\"NeutronMetadataProxySharedSecret\\\"}, \\\"neutron::agents::ovn_metadata::auth_password\\\": {\\\"get_param\\\": \\\"NeutronPassword\\\"}, \\\"neutron::agents::ovn_metadata::auth_url\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"uri_no_suffix\\\"]}, \\\"neutron::agents::ovn_metadata::auth_tenant\\\": \\\"service\\\", \\\"neutron::agents::ovn_metadata::metadata_host\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaMetadataCellInternal\\\", \\\"host_nobrackets\\\"]}, \\\"neutron::agents::ovn_metadata::ovsdb_connection_timeout\\\": {\\\"get_param\\\": \\\"OVNDbConnectionTimeout\\\"}, \\\"neutron::agents::ovn_metadata::ovsdb_probe_interval\\\": {\\\"get_param\\\": \\\"OVNOvsdbProbeInterval\\\"}, \\\"neutron::agents::ovn_metadata::hwol_qos_enabled\\\": {\\\"get_param\\\": \\\"OvnHardwareOffloadedQos\\\"}, \\\"ovn::northbound::port\\\": {\\\"get_param\\\": \\\"OVNNorthboundServerPort\\\"}, \\\"ovn::southbound::port\\\": {\\\"get_param\\\": \\\"OVNSouthboundServerPort\\\"}, \\\"neutron::agents::ovn_metadata::debug\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"OvnMetadataAgentDebug\\\"}, true, {\\\"get_param\\\": \\\"Debug\\\"}]}, \\\"neutron::agents::ovn_metadata::metadata_protocol\\\": {\\\"if\\\": [\\\"internal_tls_enabled\\\", \\\"https\\\", \\\"http\\\"]}}, {\\\"if\\\": [\\\"neutron_metadata_workers_unset\\\", {}, {\\\"neutron::agents::ovn_metadata::metadata_workers\\\": {\\\"get_param\\\": \\\"NeutronMetadataWorkers\\\"}}]}, {\\\"if\\\": [\\\"internal_tls_enabled\\\", {\\\"tripleo::profile::base::neutron::ovn_metadata::ovn_nb_ca_cert\\\": {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, \\\"tripleo::profile::base::neutron::ovn_metadata::ovn_sb_ca_cert\\\": {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, \\\"tripleo::profile::base::neutron::ovn_metadata::protocol\\\": \\\"ssl\\\", \\\"tripleo::profile::base::neutron::ovn_metadata::ovn_nb_certificate\\\": \\\"/etc/pki/tls/certs/ovn_metadata.crt\\\", \\\"tripleo::profile::base::neutron::ovn_metadata::ovn_nb_private_key\\\": \\\"/etc/pki/tls/private/ovn_metadata.key\\\", \\\"tripleo::profile::base::neutron::ovn_metadata::ovn_sb_certificate\\\": \\\"/etc/pki/tls/certs/ovn_metadata.crt\\\", \\\"tripleo::profile::base::neutron::ovn_metadata::ovn_sb_private_key\\\": \\\"/etc/pki/tls/private/ovn_metadata.key\\\"}, {}]}]}, \\\"puppet_config\\\": {\\\"puppet_tags\\\": \\\"neutron_config,ovn_metadata_agent_config\\\", \\\"config_volume\\\": \\\"neutron\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::neutron::ovn_metadata\\\\n\\\", \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNeutronConfigImage\\\"]}, \\\"volumes\\\": [\\\"/lib/modules:/lib/modules:ro\\\", \\\"/run/openvswitch:/run/openvswitch:shared,z\\\"]}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/ovn_metadata_agent.json\\\": {\\\"command\\\": {\\\"list_join\\\": [\\\" \\\", [\\\"/usr/bin/networking-ovn-metadata-agent --config-file /etc/neutron/neutron.conf --config-file /etc/neutron/plugins/networking-ovn/networking-ovn-metadata-agent.ini\\\", {\\\"get_attr\\\": [\\\"NeutronLogging\\\", \\\"cmd_extra_args\\\"]}]]}, \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/neutron\\\", \\\"owner\\\": \\\"neutron:neutron\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/var/lib/neutron\\\", \\\"owner\\\": \\\"neutron:neutron\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/certs/ovn_metadata.crt\\\", \\\"owner\\\": \\\"neutron:neutron\\\", \\\"optional\\\": true, \\\"perm\\\": \\\"0644\\\"}, {\\\"path\\\": \\\"/etc/pki/tls/private/ovn_metadata.key\\\", \\\"owner\\\": \\\"neutron:neutron\\\", \\\"optional\\\": true, \\\"perm\\\": \\\"0644\\\"}]}}, \\\"container_config_scripts\\\": {\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"container_config_scripts\\\"]}, \\\"docker_config\\\": {\\\"step_2\\\": {\\\"create_haproxy_wrapper\\\": {\\\"start_order\\\": 1, \\\"detach\\\": false, \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"user\\\": \\\"root\\\", \\\"command\\\": {\\\"list_concat\\\": [[\\\"/container_puppet_apply.sh\\\", \\\"4\\\", \\\"file\\\", \\\"include ::tripleo::profile::base::neutron::ovn_metadata_agent_wrappers\\\"]]}, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerOvnMetadataImage\\\"]}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"container_puppet_apply_volumes\\\"]}, [\\\"/run/openvswitch:/run/openvswitch:shared,z\\\", \\\"/var/lib/neutron:/var/lib/neutron:shared,z\\\"]]}}}, \\\"step_4\\\": {\\\"setup_ovs_manager\\\": {\\\"start_order\\\": 0, \\\"detach\\\": false, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"user\\\": \\\"root\\\", \\\"command\\\": {\\\"list_concat\\\": [[\\\"/container_puppet_apply.sh\\\", \\\"4\\\", \\\"exec\\\", \\\"include tripleo::profile::base::neutron::ovn_metadata\\\"]]}, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerOvnMetadataImage\\\"]}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"container_puppet_apply_volumes\\\"]}, [\\\"/lib/modules:/lib/modules:ro\\\", \\\"/run/openvswitch:/run/openvswitch:shared,z\\\"]]}, \\\"environment\\\": {\\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}}}, \\\"ovn_metadata_agent\\\": {\\\"start_order\\\": 1, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerOvnMetadataImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"cgroupns\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"NeutronLogging\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/ovn_metadata_agent.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/neutron:/var/lib/kolla/config_files/src:ro\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/run/openvswitch:/run/openvswitch:shared,z\\\", \\\"/var/lib/neutron:/var/lib/neutron:shared,z\\\", \\\"/run/netns:/run/netns:shared\\\", \\\"/var/lib/neutron/kill_scripts:/etc/neutron/kill_scripts:shared,z\\\"], {\\\"if\\\": [\\\"docker_enabled\\\", [\\\"/var/lib/openstack:/var/lib/openstack\\\"], null]}, {\\\"if\\\": [\\\"haproxy_wrapper_enabled\\\", [\\\"/var/lib/neutron/ovn_metadata_haproxy_wrapper:/usr/local/bin/haproxy:ro\\\"], null]}, {\\\"if\\\": [\\\"internal_tls_enabled\\\", [\\\"/etc/pki/tls/certs/ovn_metadata.crt:/etc/pki/tls/certs/ovn_metadata.crt\\\", \\\"/etc/pki/tls/private/ovn_metadata.key:/etc/pki/tls/private/ovn_metadata.key\\\"], null]}]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"metadata_settings\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"NeutronBase\\\", \\\"role_data\\\", \\\"metadata_settings\\\"]}, {\\\"if\\\": [\\\"internal_tls_enabled\\\", [{\\\"service\\\": \\\"ovn_metadata\\\", \\\"network\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OvnDbsNetwork\\\"]}, \\\"type\\\": \\\"node\\\"}], null]}]}, \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Certificate generation\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"enable_internal_tls\\\"], \\\"block\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"linux-system-roles.certificate\\\"}, \\\"vars\\\": {\\\"certificate_requests\\\": [{\\\"name\\\": \\\"ovn_metadata\\\", \\\"dns\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"{{fqdn_$NETWORK}}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OvnDbsNetwork\\\"]}}}}, \\\"principal\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"ovn_metadata/{{fqdn_$NETWORK}}@{{idm_realm}}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OvnDbsNetwork\\\"]}}}}, \\\"run_after\\\": \\\"systemctl restart tripleo_ovn_metadata_agent\\\\n\\\", \\\"key_size\\\": {\\\"if\\\": [\\\"key_size_override_unset\\\", {\\\"get_param\\\": \\\"CertificateKeySize\\\"}, {\\\"get_param\\\": \\\"OvnMetadataCertificateKeySize\\\"}]}, \\\"ca\\\": \\\"ipa\\\"}]}}]}], \\\"host_prep_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"NeutronLogging\\\", \\\"host_prep_tasks\\\"]}, [{\\\"name\\\": \\\"create /run/netns with temp namespace\\\", \\\"command\\\": \\\"ip netns add ns_temp\\\", \\\"register\\\": \\\"ipnetns_add_result\\\", \\\"failed_when\\\": false}, {\\\"name\\\": \\\"remove temp namespace\\\", \\\"command\\\": \\\"ip netns delete ns_temp\\\", \\\"failed_when\\\": false, \\\"when\\\": [\\\"ipnetns_add_result.rc is defined\\\", \\\"ipnetns_add_result.rc == 0\\\"]}, {\\\"name\\\": \\\"create /var/lib/neutron\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/neutron\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"container_file_t\\\"}}, {\\\"name\\\": \\\"set conditions\\\", \\\"set_fact\\\": {\\\"haproxy_wrapper_enabled\\\": {\\\"get_param\\\": \\\"OVNEnableHaproxyDockerWrapper\\\"}, \\\"debug_enabled\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"OVNWrapperDebug\\\"}, true, {\\\"get_param\\\": \\\"Debug\\\"}]}, \\\"docker_additional_sockets\\\": {\\\"get_param\\\": \\\"DockerAdditionalSockets\\\"}}}, {\\\"name\\\": \\\"create kill_scripts directory within /var/lib/neutron\\\", \\\"file\\\": {\\\"state\\\": \\\"directory\\\", \\\"path\\\": \\\"/var/lib/neutron/kill_scripts\\\"}}, {\\\"name\\\": \\\"create haproxy kill script\\\", \\\"when\\\": \\\"haproxy_wrapper_enabled|bool\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/var/lib/neutron/kill_scripts/haproxy-kill\\\", \\\"mode\\\": 493, \\\"content\\\": {\\\"get_file\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/kill-script\\\"}}}]]}, \\\"upgrade_tasks\\\": [], \\\"external_update_tasks\\\": [{\\\"name\\\": \\\"Check if python3-openvswitch3.1 workaround is needed\\\", \\\"delegate_to\\\": \\\"{{ item }}\\\", \\\"become\\\": true, \\\"tags\\\": [\\\"ovn\\\", \\\"ovn_image\\\"], \\\"when\\\": \\\"step|int == 1\\\", \\\"shell\\\": \\\"if podman exec ovn_metadata_agent rpm -q python3-openvswitch3.1 > /dev/null ; then echo REQUIRED; else echo OK ; fi\\\\n\\\", \\\"register\\\": \\\"metadata_python_ovs_3_1\\\", \\\"failed_when\\\": false, \\\"loop\\\": \\\"{{ groups[\'ovn_metadata\'] | difference(groups[\'excluded_overcloud\']) }}\\\"}, {\\\"name\\\": \\\"Update ovn_metadata_agents\\\", \\\"vars\\\": {\\\"hosts_to_update_metadata\\\": \\\"{{ metadata_python_ovs_3_1.results | selectattr(\'stdout\', \'eq\', \'REQUIRED\') | map(attribute=\'item\') | list }}\\\"}, \\\"tags\\\": [\\\"ovn\\\", \\\"ovn_image\\\"], \\\"when\\\": [\\\"step|int == 1\\\", \\\"hosts_to_update_metadata | length > 0\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Force pull image in case image name doesn\'t change.\\\", \\\"become\\\": true, \\\"loop\\\": \\\"{{ hosts_to_update_metadata }}\\\", \\\"delegate_to\\\": \\\"{{ item }}\\\", \\\"async\\\": {\\\"get_param\\\": \\\"OVNMetadataImageUpdateTimeout\\\"}, \\\"poll\\\": 0, \\\"register\\\": \\\"ovn_metadata_image_update\\\", \\\"containers.podman.podman_image\\\": {\\\"name\\\": {\\\"get_param\\\": \\\"ContainerOvnMetadataImage\\\"}, \\\"validate_certs\\\": false, \\\"force\\\": true}}, {\\\"name\\\": \\\"Was the ovn_metadata_agent image pull successful.\\\", \\\"when\\\": [\\\"\'results\' in ovn_metadata_image_update\\\"], \\\"become\\\": true, \\\"delegate_to\\\": \\\"{{ async_result_item.item }}\\\", \\\"async_status\\\": {\\\"jid\\\": \\\"{{ async_result_item.ansible_job_id }}\\\"}, \\\"loop\\\": \\\"{{ovn_metadata_image_update.results }}\\\", \\\"loop_control\\\": {\\\"loop_var\\\": \\\"async_result_item\\\"}, \\\"register\\\": \\\"async_poll_results\\\", \\\"until\\\": \\\"async_poll_results.finished\\\", \\\"retries\\\": {\\\"get_param\\\": \\\"OVNMetadataImageUpdateTimeout\\\"}, \\\"delay\\\": 1}, {\\\"name\\\": \\\"Now rotate all ovn_metadata_agents\\\", \\\"tags\\\": [\\\"ovn_metadata_parallel\\\"], \\\"delegate_to\\\": \\\"{{ item }}\\\", \\\"become\\\": true, \\\"tripleo_container_manage\\\": {\\\"config_dir\\\": \\\"/var/lib/tripleo-config/container-startup-config/step_4\\\", \\\"config_id\\\": [\\\"ovn_metadata_agent\\\"], \\\"config_patterns\\\": \\\"*ovn_metadata_agent.json\\\", \\\"config_overrides\\\": {\\\".*ovn_metadata_agent\\\": {\\\"image\\\": {\\\"get_param\\\": \\\"ContainerOvnMetadataImage\\\"}, \\\"name\\\": \\\"ovn_metadata_agent\\\"}}}, \\\"loop\\\": \\\"{{ hosts_to_update_metadata }}\\\", \\\"async\\\": {\\\"get_param\\\": \\\"OVNMetadataImageUpdateTimeout\\\"}, \\\"poll\\\": 0}]}, {\\\"name\\\": \\\"Now rotate all ovn_metadata_agents\\\", \\\"vars\\\": {\\\"hosts_to_update_metadata\\\": \\\"{{ metadata_python_ovs_3_1.results | selectattr(\'stdout\', \'eq\', \'REQUIRED\') | map(attribute=\'item\') | list }}\\\"}, \\\"tags\\\": [\\\"never\\\", \\\"ovn_metadata_serial\\\"], \\\"when\\\": [\\\"step|int == 1\\\", \\\"hosts_to_update_metadata | length > 0\\\"], \\\"delegate_to\\\": \\\"{{ item }}\\\", \\\"become\\\": true, \\\"tripleo_container_manage\\\": {\\\"config_dir\\\": \\\"/var/lib/tripleo-config/container-startup-config/step_4\\\", \\\"config_id\\\": [\\\"ovn_metadata_agent\\\"], \\\"config_patterns\\\": \\\"*ovn_metadata_agent.json\\\", \\\"config_overrides\\\": {\\\".*ovn_metadata_agent\\\": {\\\"image\\\": {\\\"get_param\\\": \\\"ContainerOvnMetadataImage\\\"}, \\\"name\\\": \\\"ovn_metadata_agent\\\"}}}, \\\"loop\\\": \\\"{{ hosts_to_update_metadata }}\\\", \\\"loop_control\\\": {\\\"pause\\\": 1}}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Neutron API service\\\\n\\\", \\\"parameters\\\": {\\\"ContainerNeutronApiImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerNeutronConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the neutron config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NeutronApiLoggingSource\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {\\\"tag\\\": \\\"openstack.neutron.api\\\", \\\"file\\\": \\\"/var/log/containers/neutron/server.log\\\"}}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"DeployIdentifier\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\\\n\\\"}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"NeutronApiOptVolumes\\\": {\\\"default\\\": [], \\\"description\\\": \\\"list of optional volumes to be mounted\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"NeutronApiOptEnvVars\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"hash of optional environment variables\\\", \\\"type\\\": \\\"json\\\"}, \\\"NeutronWorkers\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Sets the number of API workers for the Neutron service.\\\\nThe default value results in the configuration being left unset\\\\nand a system-dependent default will be chosen (usually the number\\\\nof processors). Please note that this can result in a large number\\\\nof processes and memory consumption on systems with a large core\\\\ncount. On such systems it is recommended that a non-default value\\\\nbe selected that matches the load requirements.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"NeutronRpcWorkers\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Sets the number of RPC workers for the Neutron service.\\\\nIf not specified, it\'ll take the value of NeutronWorkers and if this is\\\\nnot specified either, the default value results in the configuration\\\\nbeing left unset and a system-dependent default will be chosen\\\\n(usually 1).\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"NeutronPassword\\\": {\\\"description\\\": \\\"The password for the neutron service and db account, used by neutron agents.\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"NeutronAllowL3AgentFailover\\\": {\\\"default\\\": \\\"True\\\", \\\"description\\\": \\\"Allow automatic l3-agent failover\\\", \\\"type\\\": \\\"string\\\"}, \\\"NovaPassword\\\": {\\\"description\\\": \\\"The password for the nova service and db account\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"NeutronEnableDVR\\\": {\\\"description\\\": \\\"Enable Neutron DVR.\\\", \\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"NeutronEnableIgmpSnooping\\\": {\\\"description\\\": \\\"Enable IGMP Snooping.\\\", \\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"KeystoneRegion\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"regionOne\\\", \\\"description\\\": \\\"Keystone region for endpoint\\\"}, \\\"MonitoringSubscriptionNeutronServer\\\": {\\\"default\\\": \\\"overcloud-neutron-server\\\", \\\"type\\\": \\\"string\\\"}, \\\"EnableSQLAlchemyCollectd\\\": {\\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"Set to true to enable the SQLAlchemy-collectd server plugin\\\\n\\\", \\\"default\\\": false}, \\\"NeutronApiPolicies\\\": {\\\"description\\\": \\\"A hash of policies to configure for Neutron API.\\\\ne.g. { neutron-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\\\n\\\", \\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}, \\\"NeutronOvsIntegrationBridge\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Name of Open vSwitch bridge to use\\\"}, \\\"NeutronPortQuota\\\": {\\\"default\\\": \\\"500\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Number of ports allowed per tenant, and minus means unlimited.\\\"}, \\\"NeutronSecurityGroupQuota\\\": {\\\"default\\\": \\\"10\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Number of security groups allowed per tenant, and minus means unlimited\\\"}, \\\"NeutronMechanismDrivers\\\": {\\\"default\\\": \\\"ovn\\\", \\\"description\\\": \\\"The mechanism drivers for the Neutron tenant network.\\\\n\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"NeutronDefaultAvailabilityZones\\\": {\\\"description\\\": \\\"Comma-separated list of default network availability zones to be used by Neutron if its resource is created without availability zone hints. If not set, no AZs will be configured for Neutron network services.\\\", \\\"default\\\": [], \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"NeutronNetworkSchedulerDriver\\\": {\\\"description\\\": \\\"The network schedule driver to use for avialability zones.\\\", \\\"default\\\": \\\"neutron.scheduler.dhcp_agent_scheduler.AZAwareWeightScheduler\\\", \\\"type\\\": \\\"string\\\"}, \\\"NeutronRouterSchedulerDriver\\\": {\\\"description\\\": \\\"The router schedule driver to use for avialability zones.\\\", \\\"default\\\": \\\"neutron.scheduler.l3_agent_scheduler.AZLeastRoutersScheduler\\\", \\\"type\\\": \\\"string\\\"}, \\\"NeutronDhcpLoadType\\\": {\\\"description\\\": \\\"Additional to the availability zones aware network scheduler.\\\", \\\"default\\\": \\\"networks\\\", \\\"type\\\": \\\"string\\\"}, \\\"InternalTLSCAFile\\\": {\\\"default\\\": \\\"/etc/ipa/ca.crt\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Specifies the default CA cert to use if TLS is used for services in the internal network.\\\"}, \\\"CertificateKeySize\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"2048\\\", \\\"description\\\": \\\"Specifies the private key size used when creating the certificate.\\\"}, \\\"NeutronCertificateKeySize\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Override the private key size used when creating the certificate for this service\\\"}, \\\"MemcacheUseAdvancedPool\\\": {\\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"Use the advanced (eventlet safe) memcached client pool.\\\\n\\\", \\\"default\\\": true}, \\\"NeutronL3HA\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Whether to enable HA for virtual routers. When not set, L3 HA will be\\\\nautomatically enabled if the number of nodes hosting controller\\\\nconfigurations and DVR is disabled. Valid values are \'true\' or \'false\'\\\\nThis parameter is being deprecated in Newton and is scheduled to be\\\\nremoved in Ocata.  Future releases will enable L3 HA by default if it is\\\\nappropriate for the deployment type. Alternate mechanisms will be\\\\navailable to override.\\\\n\\\"}, \\\"NeutronAgentDownTime\\\": {\\\"default\\\": 600, \\\"type\\\": \\\"number\\\", \\\"description\\\": \\\"Seconds to regard the agent as down; should be at least twice\\\\nNeutronGlobalReportInterval, to be sure the agent is down for good.\\\\n\\\"}, \\\"EnforceSecureRbac\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false, \\\"description\\\": \\\"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\\\"}}, \\\"parameter_groups\\\": [{\\\"label\\\": \\\"deprecated\\\", \\\"description\\\": \\\"The following parameters are deprecated and will be removed. They should not\\\\nbe relied on for new deployments. If you have concerns regarding deprecated\\\\nparameters, please contact the TripleO development team on IRC or the\\\\nOpenStack mailing list.\\\\n\\\", \\\"parameters\\\": [\\\"NeutronL3HA\\\"]}], \\\"conditions\\\": {\\\"use_tls_proxy\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, true]}, \\\"neutron_workers_unset\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"NeutronWorkers\\\"}, \\\"\\\"]}, \\\"neutron_rpc_workers_unset\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"NeutronRpcWorkers\\\"}, \\\"\\\"]}, \\\"neutron_ovs_int_br_unset\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"NeutronOvsIntegrationBridge\\\"}, \\\"\\\"]}, \\\"internal_tls_enabled\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, true]}, \\\"neutron_dvr_unset\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"NeutronEnableDVR\\\"}, \\\"\\\"]}, \\\"is_ovn_in_neutron_mechanism_driver\\\": {\\\"contains\\\": [\\\"ovn\\\", {\\\"get_param\\\": \\\"NeutronMechanismDrivers\\\"}]}, \\\"az_unset\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"NeutronDefaultAvailabilityZones\\\"}, []]}, \\\"ovn_and_tls\\\": {\\\"and\\\": [\\\"is_ovn_in_neutron_mechanism_driver\\\", \\\"internal_tls_enabled\\\"]}, \\\"enable_sqlalchemy_collectd\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"EnableSQLAlchemyCollectd\\\"}, true]}, \\\"key_size_override_unset\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"NeutronCertificateKeySize\\\"}, \\\"\\\"]}}, \\\"resources\\\": {\\\"TLSProxyBase\\\": {\\\"type\\\": \\\"OS::TripleO::Services::TLSProxyBase\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}, \\\"EnableInternalTLS\\\": {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}}}, \\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"MySQLClient\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\\\"}, \\\"NeutronBase\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-base.yaml\\\", \\\"properties\\\": {\\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"NeutronLogging\\\": {\\\"type\\\": \\\"OS::TripleO::Services::Logging::NeutronApi\\\", \\\"properties\\\": {\\\"NeutronServiceName\\\": \\\"server\\\"}}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerNeutronApiImage\\\": \\\"ContainerNeutronApiImage\\\", \\\"ContainerNeutronConfigImage\\\": \\\"ContainerNeutronConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerNeutronApiImage\\\": {\\\"get_param\\\": \\\"ContainerNeutronApiImage\\\"}, \\\"ContainerNeutronConfigImage\\\": {\\\"get_param\\\": \\\"ContainerNeutronConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Neutron API role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"neutron_api\\\", \\\"firewall_rules\\\": {\\\"114 neutron api\\\": {\\\"dport\\\": [9696]}}, \\\"firewall_frontend_rules\\\": {\\\"100 neutron_haproxy_frontend\\\": {\\\"dport\\\": [9696]}}, \\\"firewall_ssl_frontend_rules\\\": {\\\"100 neutron_haproxy_frontend_ssl\\\": {\\\"dport\\\": [13696]}}, \\\"keystone_resources\\\": {\\\"neutron\\\": {\\\"endpoints\\\": {\\\"public\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NeutronPublic\\\", \\\"uri\\\"]}, \\\"internal\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NeutronInternal\\\", \\\"uri\\\"]}, \\\"admin\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NeutronAdmin\\\", \\\"uri\\\"]}}, \\\"users\\\": {\\\"neutron\\\": {\\\"password\\\": {\\\"get_param\\\": \\\"NeutronPassword\\\"}}}, \\\"region\\\": {\\\"get_param\\\": \\\"KeystoneRegion\\\"}, \\\"service\\\": \\\"network\\\"}}, \\\"monitoring_subscription\\\": {\\\"get_param\\\": \\\"MonitoringSubscriptionNeutronServer\\\"}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"NeutronBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"get_attr\\\": [\\\"TLSProxyBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"get_attr\\\": [\\\"NeutronLogging\\\", \\\"config_settings\\\"]}, {\\\"neutron::db::database_connection\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"MysqlInternal\\\", \\\"protocol\\\"]}, \\\"username\\\": \\\"neutron\\\", \\\"password\\\": {\\\"get_param\\\": \\\"NeutronPassword\\\"}, \\\"host\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"MysqlInternal\\\", \\\"host\\\"]}, \\\"path\\\": \\\"/ovs_neutron\\\", \\\"query\\\": {\\\"if\\\": [\\\"enable_sqlalchemy_collectd\\\", {\\\"read_default_file\\\": \\\"/etc/my.cnf.d/tripleo.cnf\\\", \\\"read_default_group\\\": \\\"tripleo\\\", \\\"plugin\\\": \\\"collectd\\\", \\\"collectd_program_name\\\": \\\"ovs_neutron\\\", \\\"collectd_host\\\": \\\"localhost\\\"}, {\\\"read_default_file\\\": \\\"/etc/my.cnf.d/tripleo.cnf\\\", \\\"read_default_group\\\": \\\"tripleo\\\"}]}}}, \\\"neutron::policy::policies\\\": {\\\"get_param\\\": \\\"NeutronApiPolicies\\\"}}, {\\\"if\\\": [{\\\"get_param\\\": \\\"EnforceSecureRbac\\\"}, {\\\"neutron::policy::enforce_scope\\\": true, \\\"neutron::policy::enforce_new_defaults\\\": true}], \\\"neutron::keystone::authtoken::www_authenticate_uri\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystonePublic\\\", \\\"uri_no_suffix\\\"]}, \\\"neutron::keystone::authtoken::auth_url\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"uri_no_suffix\\\"]}, \\\"neutron::server::agent_down_time\\\": {\\\"get_param\\\": \\\"NeutronAgentDownTime\\\"}, \\\"neutron::server::allow_automatic_l3agent_failover\\\": {\\\"get_param\\\": \\\"NeutronAllowL3AgentFailover\\\"}, \\\"neutron::server::enable_proxy_headers_parsing\\\": true, \\\"neutron::server::igmp_snooping_enable\\\": {\\\"get_param\\\": \\\"NeutronEnableIgmpSnooping\\\"}, \\\"neutron::keystone::authtoken::password\\\": {\\\"get_param\\\": \\\"NeutronPassword\\\"}, \\\"neutron::server::notifications::nova::auth_url\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"uri_no_suffix\\\"]}, \\\"neutron::server::notifications::nova::project_name\\\": \\\"service\\\", \\\"neutron::server::notifications::nova::user_domain_name\\\": \\\"Default\\\", \\\"neutron::server::notifications::nova::project_domain_name\\\": \\\"Default\\\", \\\"neutron::server::notifications::nova::region_name\\\": {\\\"get_param\\\": \\\"KeystoneRegion\\\"}, \\\"neutron::server::notifications::nova::password\\\": {\\\"get_param\\\": \\\"NovaPassword\\\"}, \\\"neutron::server::notifications::nova::endpoint_type\\\": \\\"internal\\\", \\\"neutron::keystone::authtoken::project_name\\\": \\\"service\\\", \\\"neutron::keystone::authtoken::user_domain_name\\\": \\\"Default\\\", \\\"neutron::keystone::authtoken::project_domain_name\\\": \\\"Default\\\", \\\"neutron::keystone::authtoken::region_name\\\": {\\\"get_param\\\": \\\"KeystoneRegion\\\"}, \\\"neutron::keystone::authtoken::interface\\\": \\\"internal\\\", \\\"neutron::keystone::authtoken::memcache_use_advanced_pool\\\": {\\\"get_param\\\": \\\"MemcacheUseAdvancedPool\\\"}, \\\"neutron::quota::quota_port\\\": {\\\"get_param\\\": \\\"NeutronPortQuota\\\"}, \\\"neutron::quota::quota_security_group\\\": {\\\"get_param\\\": \\\"NeutronSecurityGroupQuota\\\"}, \\\"neutron::server::placement::password\\\": {\\\"get_param\\\": \\\"NovaPassword\\\"}, \\\"neutron::server::placement::project_domain_name\\\": \\\"Default\\\", \\\"neutron::server::placement::project_name\\\": \\\"service\\\", \\\"neutron::server::placement::user_domain_name\\\": \\\"Default\\\", \\\"neutron::server::placement::username\\\": \\\"nova\\\", \\\"neutron::server::placement::auth_url\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"uri_no_suffix\\\"]}, \\\"neutron::server::placement::auth_type\\\": \\\"password\\\", \\\"neutron::server::placement::region_name\\\": {\\\"get_param\\\": \\\"KeystoneRegion\\\"}, \\\"tripleo::profile::base::neutron::server::tls_proxy_bind_ip\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NeutronApiNetwork\\\"]}}}}, \\\"tripleo::profile::base::neutron::server::tls_proxy_fqdn\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'fqdn_$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NeutronApiNetwork\\\"]}}}}, \\\"tripleo::profile::base::neutron::server::tls_proxy_port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NeutronInternal\\\", \\\"port\\\"]}, \\\"neutron::bind_host\\\": {\\\"if\\\": [\\\"use_tls_proxy\\\", \\\"%{hiera(\'localhost_address\')}\\\", {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NeutronApiNetwork\\\"]}}}}]}, \\\"tripleo::profile::base::neutron::server::l3_ha_override\\\": {\\\"get_param\\\": \\\"NeutronL3HA\\\"}}, {\\\"if\\\": [\\\"neutron_dvr_unset\\\", {}, {\\\"neutron::server::router_distributed\\\": {\\\"get_param\\\": \\\"NeutronEnableDVR\\\"}, \\\"neutron::server::enable_dvr\\\": {\\\"get_param\\\": \\\"NeutronEnableDVR\\\"}}]}, {\\\"if\\\": [\\\"neutron_workers_unset\\\", {}, {\\\"neutron::server::api_workers\\\": {\\\"get_param\\\": \\\"NeutronWorkers\\\"}}]}, {\\\"if\\\": [\\\"neutron_rpc_workers_unset\\\", {\\\"if\\\": [\\\"neutron_workers_unset\\\", {}, {\\\"neutron::server::rpc_workers\\\": {\\\"get_param\\\": \\\"NeutronWorkers\\\"}}]}, {\\\"neutron::server::rpc_workers\\\": {\\\"get_param\\\": \\\"NeutronRpcWorkers\\\"}}]}, {\\\"if\\\": [\\\"neutron_ovs_int_br_unset\\\", {}, {\\\"neutron::server::ovs_integration_bridge\\\": {\\\"get_param\\\": \\\"NeutronOvsIntegrationBridge\\\"}}]}, {\\\"if\\\": [\\\"az_unset\\\", {}, {\\\"neutron::server::dhcp_load_type\\\": {\\\"get_param\\\": \\\"NeutronDhcpLoadType\\\"}, \\\"neutron::server::network_scheduler_driver\\\": {\\\"get_param\\\": \\\"NeutronNetworkSchedulerDriver\\\"}, \\\"neutron::server::router_scheduler_driver\\\": {\\\"get_param\\\": \\\"NeutronRouterSchedulerDriver\\\"}, \\\"neutron::server::default_availability_zones\\\": {\\\"get_param\\\": \\\"NeutronDefaultAvailabilityZones\\\"}}]}, {\\\"if\\\": [\\\"ovn_and_tls\\\", {\\\"tripleo::profile::base::neutron::plugins::ml2::ovn::protocol\\\": \\\"ssl\\\", \\\"tripleo::profile::base::neutron::plugins::ml2::ovn::ovn_nb_private_key\\\": \\\"/etc/pki/tls/private/neutron_ovn.key\\\", \\\"tripleo::profile::base::neutron::plugins::ml2::ovn::ovn_nb_certificate\\\": \\\"/etc/pki/tls/certs/neutron_ovn.crt\\\", \\\"tripleo::profile::base::neutron::plugins::ml2::ovn::ovn_sb_private_key\\\": \\\"/etc/pki/tls/private/neutron_ovn.key\\\", \\\"tripleo::profile::base::neutron::plugins::ml2::ovn::ovn_sb_certificate\\\": \\\"/etc/pki/tls/certs/neutron_ovn.crt\\\", \\\"tripleo::profile::base::neutron::plugins::ml2::ovn::ovn_nb_ca_cert\\\": {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, \\\"tripleo::profile::base::neutron::plugins::ml2::ovn::ovn_sb_ca_cert\\\": {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}}, {}]}]}, \\\"service_config_settings\\\": {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_neutron_api\\\": [{\\\"get_param\\\": \\\"NeutronApiLoggingSource\\\"}]}, \\\"mysql\\\": {\\\"neutron::db::mysql::password\\\": {\\\"get_param\\\": \\\"NeutronPassword\\\"}, \\\"neutron::db::mysql::user\\\": \\\"neutron\\\", \\\"neutron::db::mysql::host\\\": \\\"%\\\", \\\"neutron::db::mysql::dbname\\\": \\\"ovs_neutron\\\"}}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"neutron\\\", \\\"puppet_tags\\\": \\\"neutron_config,neutron_api_paste_ini\\\", \\\"step_config\\\": {\\\"list_join\\\": [\\\"\\\\n\\\", [\\\"include tripleo::profile::base::neutron::server\\\", {\\\"get_attr\\\": [\\\"MySQLClient\\\", \\\"role_data\\\", \\\"step_config\\\"]}]]}, \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNeutronConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/neutron_api.json\\\": {\\\"command\\\": {\\\"list_join\\\": [\\\" \\\", [\\\"/usr/bin/neutron-server --config-file /usr/share/neutron/neutron-dist.conf --config-dir /usr/share/neutron/server --config-file /etc/neutron/neutron.conf --config-file /etc/neutron/plugin.ini --config-dir /etc/neutron/conf.d/common --config-dir /etc/neutron/conf.d/neutron-server\\\", {\\\"get_attr\\\": [\\\"NeutronLogging\\\", \\\"cmd_extra_args\\\"]}]]}, \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-tls/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"optional\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/neutron\\\", \\\"owner\\\": \\\"neutron:neutron\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/certs/neutron_ovn.crt\\\", \\\"owner\\\": \\\"neutron:neutron\\\", \\\"optional\\\": true, \\\"perm\\\": \\\"0644\\\"}, {\\\"path\\\": \\\"/etc/pki/tls/private/neutron_ovn.key\\\", \\\"owner\\\": \\\"neutron:neutron\\\", \\\"optional\\\": true, \\\"perm\\\": \\\"0644\\\"}]}, \\\"/var/lib/kolla/config_files/neutron_api_db_sync.json\\\": {\\\"command\\\": \\\"/usr/bin/bootstrap_host_exec neutron_api neutron-db-manage upgrade heads\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-tls/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"optional\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/neutron\\\", \\\"owner\\\": \\\"neutron:neutron\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/certs/neutron_ovn.crt\\\", \\\"owner\\\": \\\"neutron:neutron\\\", \\\"optional\\\": true, \\\"perm\\\": \\\"0644\\\"}, {\\\"path\\\": \\\"/etc/pki/tls/private/neutron_ovn.key\\\", \\\"owner\\\": \\\"neutron:neutron\\\", \\\"optional\\\": true, \\\"perm\\\": \\\"0644\\\"}]}, \\\"/var/lib/kolla/config_files/neutron_server_tls_proxy.json\\\": {\\\"command\\\": \\\"/usr/sbin/httpd -DFOREGROUND\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/etc/httpd/conf.d\\\", \\\"dest\\\": \\\"/etc/httpd/conf.d\\\", \\\"merge\\\": false, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\\\", \\\"dest\\\": \\\"/etc/httpd/conf.modules.d\\\", \\\"merge\\\": false, \\\"preserve_properties\\\": true}]}}, \\\"docker_config\\\": {\\\"step_2\\\": {\\\"get_attr\\\": [\\\"NeutronLogging\\\", \\\"docker_config\\\", \\\"step_2\\\"]}, \\\"step_3\\\": {\\\"neutron_db_sync\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNeutronApiImage\\\"]}, \\\"cap_add\\\": [\\\"AUDIT_WRITE\\\"], \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"detach\\\": false, \\\"user\\\": \\\"root\\\", \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"NeutronLogging\\\", \\\"volumes\\\"]}, {\\\"get_param\\\": \\\"NeutronApiOptVolumes\\\"}, [\\\"/var/lib/kolla/config_files/neutron_api_db_sync.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/neutron:/var/lib/kolla/config_files/src:ro\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\", \\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}}}}, \\\"step_4\\\": {\\\"map_merge\\\": [{\\\"neutron_api\\\": {\\\"start_order\\\": 0, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNeutronApiImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"NeutronLogging\\\", \\\"volumes\\\"]}, {\\\"get_param\\\": \\\"NeutronApiOptVolumes\\\"}, [\\\"/var/lib/kolla/config_files/neutron_api.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/neutron:/var/lib/kolla/config_files/src:ro\\\"], {\\\"if\\\": [\\\"ovn_and_tls\\\", [\\\"/etc/pki/tls/certs/neutron_ovn.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/neutron_ovn.crt:ro\\\", \\\"/etc/pki/tls/private/neutron_ovn.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/neutron_ovn.key:ro\\\"], null]}]}, \\\"environment\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"NeutronApiOptEnvVars\\\"}, {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}]}}}, {\\\"if\\\": [\\\"internal_tls_enabled\\\", {\\\"neutron_server_tls_proxy\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNeutronApiImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"user\\\": \\\"root\\\", \\\"restart\\\": \\\"always\\\", \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"NeutronLogging\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/neutron_server_tls_proxy.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/neutron:/var/lib/kolla/config_files/src:ro\\\", \\\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\\\", \\\"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}, {}]}]}}, \\\"host_prep_tasks\\\": {\\\"get_attr\\\": [\\\"NeutronLogging\\\", \\\"host_prep_tasks\\\"]}, \\\"metadata_settings\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"TLSProxyBase\\\", \\\"role_data\\\", \\\"metadata_settings\\\"]}, {\\\"if\\\": [\\\"ovn_and_tls\\\", [{\\\"service\\\": \\\"neutron_ovn\\\", \\\"network\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NeutronApiNetwork\\\"]}, \\\"type\\\": \\\"node\\\"}], null]}]}, \\\"deploy_steps_tasks\\\": {\\\"if\\\": [\\\"ovn_and_tls\\\", [{\\\"name\\\": \\\"Certificate generation\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"linux-system-roles.certificate\\\"}, \\\"vars\\\": {\\\"certificate_requests\\\": [{\\\"name\\\": \\\"neutron_ovn\\\", \\\"dns\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"{{fqdn_$NETWORK}}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NeutronApiNetwork\\\"]}}}}, \\\"principal\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"neutron_ovn/{{fqdn_$NETWORK}}@{{idm_realm}}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NeutronApiNetwork\\\"]}}}}, \\\"key_size\\\": {\\\"if\\\": [\\\"key_size_override_unset\\\", {\\\"get_param\\\": \\\"CertificateKeySize\\\"}, {\\\"get_param\\\": \\\"NeutronCertificateKeySize\\\"}]}, \\\"ca\\\": \\\"ipa\\\"}]}}]}], null]}, \\\"external_upgrade_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade_transfer_data\\\", \\\"system_upgrade_stop_services\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Stop neutron api container\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_stop\\\"}, \\\"vars\\\": {\\\"tripleo_containers_to_stop\\\": [\\\"neutron_api\\\"], \\\"tripleo_delegate_to\\\": \\\"{{ groups[\'neutron_api\'] | difference(groups[\'excluded_overcloud\']) }}\\\"}}]}], \\\"external_update_tasks\\\": [{\\\"name\\\": \\\"Check if python3-openvswitch3.1 workaround is needed\\\", \\\"delegate_to\\\": \\\"{{groups[\'neutron_api\'][0]}}\\\", \\\"become\\\": true, \\\"tags\\\": [\\\"ovn\\\", \\\"ovn_image\\\"], \\\"when\\\": \\\"step|int == 1\\\", \\\"shell\\\": \\\"podman exec neutron_api rpm -q python3-openvswitch3.1\\\\n\\\", \\\"register\\\": \\\"neutron_python_ovs_3_1\\\", \\\"failed_when\\\": false}, {\\\"name\\\": \\\"Update neutron_api first everywhere\\\", \\\"become\\\": true, \\\"tags\\\": [\\\"ovn\\\", \\\"ovn_image\\\"], \\\"when\\\": [\\\"step|int == 1\\\", \\\"neutron_python_ovs_3_1.rc == 0\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Move virtual IPs to another node before stopping pacemaker\\\", \\\"delegate_to\\\": \\\"{{groups[\'neutron_api\'][0]}}\\\", \\\"when\\\": [\\\"hostvars[groups[\'neutron_api\'][0]][\\\\\\\"haproxy_node_names\\\\\\\"]|default([])|length > 1\\\"], \\\"shell\\\": \\\"CLUSTER_NODE=$(crm_node -n)\\\\necho \\\\\\\"Retrieving all the VIPs which are hosted on this node\\\\\\\"\\\\nVIPS_TO_MOVE=$(crm_mon --as-xml | xmllint --xpath \'//resource[@resource_agent=\\\\\\\"ocf:heartbeat:IPaddr2\\\\\\\" and @role = \\\\\\\"Started\\\\\\\" and @managed = \\\\\\\"true\\\\\\\" and ./node[@name = \\\\\\\"\'${CLUSTER_NODE}\'\\\\\\\"]]/@id\' - | sed -e \'s/id=//g\' -e \'s/\\\\\\\"//g\')\\\\nfor v in ${VIPS_TO_MOVE}; do\\\\n    echo \\\\\\\"Moving VIP $v on another node\\\\\\\"\\\\n    pcs resource ban $v ${CLUSTER_NODE} --wait=300\\\\ndone\\\\necho \\\\\\\"Removing the location constraints that were created to move the VIPs\\\\\\\"\\\\nfor v in ${VIPS_TO_MOVE}; do\\\\n    echo \\\\\\\"Removing location ban for VIP $v\\\\\\\"\\\\n    ban_id=$(cibadmin --query | xmllint --xpath \'string(//rsc_location[@rsc=\\\\\\\"\'${v}\'\\\\\\\" and @node=\\\\\\\"\'${CLUSTER_NODE}\'\\\\\\\" and @score=\\\\\\\"-INFINITY\\\\\\\"]/@id)\' -)\\\\n    if [ -n \\\\\\\"$ban_id\\\\\\\" ]; then\\\\n        pcs constraint remove ${ban_id}\\\\n    else\\\\n        echo \\\\\\\"Could not retrieve and clear location constraint for VIP $v\\\\\\\" 2>&1\\\\n    fi\\\\ndone\\\\n\\\"}, {\\\"name\\\": \\\"Create firewall nat prerouting and postrouting\\\", \\\"delegate_to\\\": \\\"{{groups[\'neutron_api\'][0]}}\\\", \\\"shell\\\": \\\"set -o pipefail\\\\nLOCAL_BACKEND=$(grep {{groups[\'neutron_api\'][0]}} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg | \\\\\\\\\\\\n  grep \\\\\\\":9696 \\\\\\\" | awk \'{print $3}\')\\\\nIP=${LOCAL_BACKEND%:*}\\\\nif [[ $IP =~ .*:.* ]]\\\\n  then\\\\n       PROTOCOL=\\\\\\\"ip6\\\\\\\"\\\\n       # we need to temporarly allow ipv6 forwarding, this will get reset by deployment run\\\\n       sysctl -w net.ipv6.conf.all.forwarding=1\\\\n  else PROTOCOL=\\\\\\\"ip\\\\\\\"\\\\nfi\\\\nnft add table $PROTOCOL nat\\\\nnft -- add chain $PROTOCOL nat prerouting { type nat hook prerouting priority -100 \\\\\\\\; }\\\\nnft add chain $PROTOCOL nat postrouting { type nat hook postrouting priority 100 \\\\\\\\; }\\\\n\\\"}, {\\\"name\\\": \\\"Redirect neutron backend traffic for 60s to other host\\\", \\\"delegate_to\\\": \\\"{{groups[\'neutron_api\'][0]}}\\\", \\\"shell\\\": \\\"set -o pipefail\\\\nsource /etc/os-release; test  \\\\\\\"${VERSION_ID%*}\\\\\\\" = \\\\\\\"9.0\\\\\\\" && exit 0\\\\nLOCAL_BACKEND=$(grep {{groups[\'neutron_api\'][0]}} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg | \\\\\\\\\\\\n  grep \\\\\\\":9696 \\\\\\\" | awk \'{print $3}\')\\\\nREMOTE_BACKEND=$(grep \\\\\\\":9696 \\\\\\\" /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg | \\\\\\\\\\\\n  grep server | grep -v {{groups[\'neutron_api\'][0]}} | head -n1 | awk \'{print $3}\')\\\\nIP=${LOCAL_BACKEND%:*}\\\\nPORT=9696\\\\nif [[ $IP =~ .*:.* ]]\\\\n  then PROTOCOL=\\\\\\\"ip6\\\\\\\"\\\\n  else PROTOCOL=\\\\\\\"ip\\\\\\\"\\\\nfi\\\\nREMOTE_IP=${REMOTE_BACKEND%:*}\\\\nnft add rule $PROTOCOL nat postrouting $PROTOCOL daddr $REMOTE_IP tcp dport 9696 counter meta time $(date +%s)-$(date -d\'+60 seconds\' +%s) masquerade comment neutron_api\\\\nnft add rule $PROTOCOL nat prerouting $PROTOCOL daddr $IP tcp dport 9696 counter meta time $(date +%s)-$(date -d\'+60 seconds\' +%s) dnat to $REMOTE_IP comment neutron_api\\\\n\\\"}, {\\\"name\\\": \\\"Insanity neutron update first\\\", \\\"delegate_to\\\": \\\"{{groups[\'neutron_api\'][0]}}\\\", \\\"become\\\": true, \\\"tripleo_container_manage\\\": {\\\"config_dir\\\": \\\"/var/lib/tripleo-config/container-startup-config/step_4\\\", \\\"config_id\\\": [\\\"neutron_api\\\"], \\\"config_patterns\\\": \\\"*neutron_api.json\\\", \\\"config_overrides\\\": {\\\".*neutron_api\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNeutronApiImage\\\"]}, \\\"name\\\": \\\"neutron_api\\\"}}}}, {\\\"wait_for\\\": {\\\"timeout\\\": 50}}, {\\\"name\\\": \\\"Delete redirect rules\\\", \\\"delegate_to\\\": \\\"{{groups[\'neutron_api\'][0]}}\\\", \\\"shell\\\": \\\"set -o pipefail\\\\nLOCAL_BACKEND=$(grep {{groups[\'neutron_api\'][0]}} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg | \\\\\\\\\\\\n  grep \\\\\\\":9696 \\\\\\\" | awk \'{print $3}\')\\\\nIP=${LOCAL_BACKEND%:*}\\\\nif [[ $IP =~ .*:.* ]]\\\\n  then\\\\n       PROTOCOL=\\\\\\\"ip6\\\\\\\"\\\\n  else PROTOCOL=\\\\\\\"ip\\\\\\\"\\\\nfi\\\\nnft -a list chain $PROTOCOL nat postrouting | grep neutron_api | awk -F# \'{print \\\\\\\"nat postrouting \\\\\\\"$2}\' | \\\\\\\\\\\\nwhile read i; do bash -c \\\\\\\"nft delete rule $PROTOCOL $i\\\\\\\"; done\\\\nnft -a list chain $PROTOCOL nat prerouting | grep neutron_api | awk -F# \'{print \\\\\\\"nat prerouting \\\\\\\"$2}\' | \\\\\\\\\\\\nwhile read i; do bash -c \\\\\\\"nft delete rule $PROTOCOL $i\\\\\\\"; done\\\\n\\\"}, {\\\"name\\\": \\\"Move virtual IPs to another node before stopping pacemaker\\\", \\\"delegate_to\\\": \\\"{{groups[\'neutron_api\'][1]}}\\\", \\\"when\\\": [\\\"hostvars[groups[\'neutron_api\'][1]][\\\\\\\"haproxy_node_names\\\\\\\"]|default([])|length > 1\\\", \\\"groups[\'neutron_api\'] | default([]) | length > 1\\\"], \\\"shell\\\": \\\"CLUSTER_NODE=$(crm_node -n)\\\\necho \\\\\\\"Retrieving all the VIPs which are hosted on this node\\\\\\\"\\\\nVIPS_TO_MOVE=$(crm_mon --as-xml | xmllint --xpath \'//resource[@resource_agent=\\\\\\\"ocf:heartbeat:IPaddr2\\\\\\\" and @role = \\\\\\\"Started\\\\\\\" and @managed = \\\\\\\"true\\\\\\\" and ./node[@name = \\\\\\\"\'${CLUSTER_NODE}\'\\\\\\\"]]/@id\' - | sed -e \'s/id=//g\' -e \'s/\\\\\\\"//g\')\\\\nfor v in ${VIPS_TO_MOVE}; do\\\\n    echo \\\\\\\"Moving VIP $v on another node\\\\\\\"\\\\n    pcs resource ban $v ${CLUSTER_NODE} --wait=300\\\\ndone\\\\necho \\\\\\\"Removing the location constraints that were created to move the VIPs\\\\\\\"\\\\nfor v in ${VIPS_TO_MOVE}; do\\\\n    echo \\\\\\\"Removing location ban for VIP $v\\\\\\\"\\\\n    ban_id=$(cibadmin --query | xmllint --xpath \'string(//rsc_location[@rsc=\\\\\\\"\'${v}\'\\\\\\\" and @node=\\\\\\\"\'${CLUSTER_NODE}\'\\\\\\\" and @score=\\\\\\\"-INFINITY\\\\\\\"]/@id)\' -)\\\\n    if [ -n \\\\\\\"$ban_id\\\\\\\" ]; then\\\\n        pcs constraint remove ${ban_id}\\\\n    else\\\\n        echo \\\\\\\"Could not retrieve and clear location constraint for VIP $v\\\\\\\" 2>&1\\\\n    fi\\\\ndone\\\\n\\\"}, {\\\"name\\\": \\\"Create firewall nat prerouting and postrouting\\\", \\\"delegate_to\\\": \\\"{{groups[\'neutron_api\'][1]}}\\\", \\\"when\\\": [\\\"groups[\'neutron_api\'] | default([]) | length > 1\\\"], \\\"shell\\\": \\\"set -o pipefail\\\\nLOCAL_BACKEND=$(grep {{groups[\'neutron_api\'][1]}} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg | \\\\\\\\\\\\n  grep \\\\\\\":9696 \\\\\\\" | awk \'{print $3}\')\\\\nIP=${LOCAL_BACKEND%:*}\\\\nif [[ $IP =~ .*:.* ]]\\\\n  then\\\\n       PROTOCOL=\\\\\\\"ip6\\\\\\\"\\\\n       # we need to temporarly allow ipv6 forwarding, this will get reset by deployment run\\\\n       sysctl -w net.ipv6.conf.all.forwarding=1\\\\n  else PROTOCOL=\\\\\\\"ip\\\\\\\"\\\\nfi\\\\nnft add table $PROTOCOL nat\\\\nnft -- add chain $PROTOCOL nat prerouting { type nat hook prerouting priority -100 \\\\\\\\; }\\\\nnft add chain $PROTOCOL nat postrouting { type nat hook postrouting priority 100 \\\\\\\\; }\\\\n\\\"}, {\\\"name\\\": \\\"Redirect neutron backend traffic for 60s to other host\\\", \\\"delegate_to\\\": \\\"{{groups[\'neutron_api\'][1]}}\\\", \\\"when\\\": [\\\"groups[\'neutron_api\'] | default([]) | length > 1\\\"], \\\"shell\\\": \\\"set -o pipefail\\\\nsource /etc/os-release; test  \\\\\\\"${VERSION_ID%*}\\\\\\\" = \\\\\\\"9.0\\\\\\\" && exit 0\\\\nLOCAL_BACKEND=$(grep {{groups[\'neutron_api\'][1]}} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg | \\\\\\\\\\\\n  grep \\\\\\\":9696 \\\\\\\" | awk \'{print $3}\')\\\\nREMOTE_BACKEND=$(grep \\\\\\\":9696 \\\\\\\" /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg | \\\\\\\\\\\\n  grep server | grep -v {{groups[\'neutron_api\'][1]}} | head -n1 | awk \'{print $3}\')\\\\nIP=${LOCAL_BACKEND%:*}\\\\nPORT=9696\\\\nif [[ $IP =~ .*:.* ]]\\\\n  then PROTOCOL=\\\\\\\"ip6\\\\\\\"\\\\n  else PROTOCOL=\\\\\\\"ip\\\\\\\"\\\\nfi\\\\nREMOTE_IP=${REMOTE_BACKEND%:*}\\\\nnft add rule $PROTOCOL nat postrouting $PROTOCOL daddr $REMOTE_IP tcp dport 9696 counter meta time $(date +%s)-$(date -d\'+60 seconds\' +%s) masquerade comment neutron_api\\\\nnft add rule $PROTOCOL nat prerouting $PROTOCOL daddr $IP tcp dport 9696 counter meta time $(date +%s)-$(date -d\'+60 seconds\' +%s) dnat to $REMOTE_IP comment neutron_api\\\\n\\\"}, {\\\"name\\\": \\\"Insanity neutron update first\\\", \\\"delegate_to\\\": \\\"{{groups[\'neutron_api\'][1]}}\\\", \\\"become\\\": true, \\\"tripleo_container_manage\\\": {\\\"config_dir\\\": \\\"/var/lib/tripleo-config/container-startup-config/step_4\\\", \\\"config_id\\\": [\\\"neutron_api\\\"], \\\"config_patterns\\\": \\\"*neutron_api.json\\\", \\\"config_overrides\\\": {\\\".*neutron_api\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNeutronApiImage\\\"]}, \\\"name\\\": \\\"neutron_api\\\"}}}, \\\"when\\\": [\\\"groups[\'neutron_api\'] | default([]) | length > 1\\\"]}, {\\\"wait_for\\\": {\\\"timeout\\\": 50}, \\\"when\\\": [\\\"groups[\'neutron_api\'] | default([]) | length > 1\\\"]}, {\\\"name\\\": \\\"Delete redirect rules\\\", \\\"delegate_to\\\": \\\"{{groups[\'neutron_api\'][1]}}\\\", \\\"when\\\": [\\\"groups[\'neutron_api\'] | default([]) | length > 1\\\"], \\\"shell\\\": \\\"set -o pipefail\\\\nLOCAL_BACKEND=$(grep {{groups[\'neutron_api\'][1]}} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg | \\\\\\\\\\\\n  grep \\\\\\\":9696 \\\\\\\" | awk \'{print $3}\')\\\\nIP=${LOCAL_BACKEND%:*}\\\\nif [[ $IP =~ .*:.* ]]\\\\n  then PROTOCOL=\\\\\\\"ip6\\\\\\\"\\\\n  else PROTOCOL=\\\\\\\"ip\\\\\\\"\\\\nfi\\\\nnft -a list chain $PROTOCOL nat postrouting | grep neutron_api | awk -F# \'{print \\\\\\\"nat postrouting \\\\\\\"$2}\' | \\\\\\\\\\\\nwhile read i; do bash -c \\\\\\\"nft delete rule $PROTOCOL $i\\\\\\\"; done\\\\nnft -a list chain $PROTOCOL nat prerouting | grep neutron_api | awk -F# \'{print \\\\\\\"nat prerouting \\\\\\\"$2}\' | \\\\\\\\\\\\nwhile read i; do bash -c \\\\\\\"nft delete rule $PROTOCOL $i\\\\\\\"; done\\\\n\\\"}, {\\\"name\\\": \\\"Move virtual IPs to another node before stopping pacemaker\\\", \\\"delegate_to\\\": \\\"{{groups[\'neutron_api\'][2]}}\\\", \\\"when\\\": [\\\"hostvars[groups[\'neutron_api\'][2]][\\\\\\\"haproxy_node_names\\\\\\\"]|default([])|length > 1\\\", \\\"groups[\'neutron_api\'] | default([]) | length > 2\\\"], \\\"shell\\\": \\\"CLUSTER_NODE=$(crm_node -n)\\\\necho \\\\\\\"Retrieving all the VIPs which are hosted on this node\\\\\\\"\\\\nVIPS_TO_MOVE=$(crm_mon --as-xml | xmllint --xpath \'//resource[@resource_agent=\\\\\\\"ocf:heartbeat:IPaddr2\\\\\\\" and @role = \\\\\\\"Started\\\\\\\" and @managed = \\\\\\\"true\\\\\\\" and ./node[@name = \\\\\\\"\'${CLUSTER_NODE}\'\\\\\\\"]]/@id\' - | sed -e \'s/id=//g\' -e \'s/\\\\\\\"//g\')\\\\nfor v in ${VIPS_TO_MOVE}; do\\\\n    echo \\\\\\\"Moving VIP $v on another node\\\\\\\"\\\\n    pcs resource ban $v ${CLUSTER_NODE} --wait=300\\\\ndone\\\\necho \\\\\\\"Removing the location constraints that were created to move the VIPs\\\\\\\"\\\\nfor v in ${VIPS_TO_MOVE}; do\\\\n    echo \\\\\\\"Removing location ban for VIP $v\\\\\\\"\\\\n    ban_id=$(cibadmin --query | xmllint --xpath \'string(//rsc_location[@rsc=\\\\\\\"\'${v}\'\\\\\\\" and @node=\\\\\\\"\'${CLUSTER_NODE}\'\\\\\\\" and @score=\\\\\\\"-INFINITY\\\\\\\"]/@id)\' -)\\\\n    if [ -n \\\\\\\"$ban_id\\\\\\\" ]; then\\\\n        pcs constraint remove ${ban_id}\\\\n    else\\\\n        echo \\\\\\\"Could not retrieve and clear location constraint for VIP $v\\\\\\\" 2>&1\\\\n    fi\\\\ndone\\\\n\\\"}, {\\\"name\\\": \\\"Create firewall nat prerouting and postrouting\\\", \\\"delegate_to\\\": \\\"{{groups[\'neutron_api\'][2]}}\\\", \\\"when\\\": [\\\"groups[\'neutron_api\'] | default([]) | length > 2\\\"], \\\"shell\\\": \\\"set -o pipefail\\\\nLOCAL_BACKEND=$(grep {{groups[\'neutron_api\'][2]}} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg | \\\\\\\\\\\\n  grep \\\\\\\":9696 \\\\\\\" | awk \'{print $3}\')\\\\nIP=${LOCAL_BACKEND%:*}\\\\nif [[ $IP =~ .*:.* ]]\\\\n  then\\\\n       PROTOCOL=\\\\\\\"ip6\\\\\\\"\\\\n       # we need to temporarly allow ipv6 forwarding, this will get reset by deployment run\\\\n       sysctl -w net.ipv6.conf.all.forwarding=1\\\\n  else PROTOCOL=\\\\\\\"ip\\\\\\\"\\\\nfi\\\\nnft add table $PROTOCOL nat\\\\nnft -- add chain $PROTOCOL nat prerouting { type nat hook prerouting priority -100 \\\\\\\\; }\\\\nnft add chain $PROTOCOL nat postrouting { type nat hook postrouting priority 100 \\\\\\\\; }\\\\n\\\"}, {\\\"name\\\": \\\"Redirect neutron backend traffic for 60s to other host\\\", \\\"delegate_to\\\": \\\"{{groups[\'neutron_api\'][2]}}\\\", \\\"when\\\": [\\\"groups[\'neutron_api\'] | default([]) | length > 2\\\"], \\\"shell\\\": \\\"set -o pipefail\\\\nsource /etc/os-release; test  \\\\\\\"${VERSION_ID%*}\\\\\\\" = \\\\\\\"9.0\\\\\\\" && exit 0\\\\nLOCAL_BACKEND=$(grep {{groups[\'neutron_api\'][2]}} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg | \\\\\\\\\\\\n  grep \\\\\\\":9696 \\\\\\\" | awk \'{print $3}\')\\\\nREMOTE_BACKEND=$(grep \\\\\\\":9696 \\\\\\\" /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg | \\\\\\\\\\\\n  grep server | grep -v {{groups[\'neutron_api\'][2]}} | head -n1 | awk \'{print $3}\')\\\\nIP=${LOCAL_BACKEND%:*}\\\\nPORT=9696\\\\nif [[ $IP =~ .*:.* ]]\\\\n  then PROTOCOL=\\\\\\\"ip6\\\\\\\"\\\\n  else PROTOCOL=\\\\\\\"ip\\\\\\\"\\\\nfi\\\\nREMOTE_IP=${REMOTE_BACKEND%:*}\\\\nnft add rule $PROTOCOL nat postrouting $PROTOCOL daddr $REMOTE_IP tcp dport 9696 counter meta time $(date +%s)-$(date -d\'+60 seconds\' +%s) masquerade comment neutron_api\\\\nnft add rule $PROTOCOL nat prerouting $PROTOCOL daddr $IP tcp dport 9696 counter meta time $(date +%s)-$(date -d\'+60 seconds\' +%s) dnat to $REMOTE_IP comment neutron_api\\\\n\\\"}, {\\\"name\\\": \\\"Insanity neutron update first\\\", \\\"delegate_to\\\": \\\"{{groups[\'neutron_api\'][2]}}\\\", \\\"become\\\": true, \\\"tripleo_container_manage\\\": {\\\"config_dir\\\": \\\"/var/lib/tripleo-config/container-startup-config/step_4\\\", \\\"config_id\\\": [\\\"neutron_api\\\"], \\\"config_patterns\\\": \\\"*neutron_api.json\\\", \\\"config_overrides\\\": {\\\".*neutron_api\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNeutronApiImage\\\"]}, \\\"name\\\": \\\"neutron_api\\\"}}}, \\\"when\\\": [\\\"groups[\'neutron_api\'] | default([]) | length > 2\\\"]}, {\\\"wait_for\\\": {\\\"timeout\\\": 50}, \\\"when\\\": [\\\"groups[\'neutron_api\'] | default([]) | length > 2\\\"]}, {\\\"name\\\": \\\"Delete redirect rules\\\", \\\"delegate_to\\\": \\\"{{groups[\'neutron_api\'][2]}}\\\", \\\"shell\\\": \\\"set -o pipefail\\\\nLOCAL_BACKEND=$(grep {{groups[\'neutron_api\'][2]}} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg | \\\\\\\\\\\\n  grep \\\\\\\":9696 \\\\\\\" | awk \'{print $3}\')\\\\nIP=${LOCAL_BACKEND%:*}\\\\nif [[ $IP =~ .*:.* ]]\\\\n  then PROTOCOL=\\\\\\\"ip6\\\\\\\"\\\\n  else PROTOCOL=\\\\\\\"ip\\\\\\\"\\\\nfi\\\\nnft -a list chain $PROTOCOL nat postrouting | grep neutron_api | awk -F# \'{print \\\\\\\"nat postrouting \\\\\\\"$2}\' | \\\\\\\\\\\\nwhile read i; do bash -c \\\\\\\"nft delete rule $PROTOCOL $i\\\\\\\"; done\\\\nnft -a list chain $PROTOCOL nat prerouting | grep neutron_api | awk -F# \'{print \\\\\\\"nat prerouting \\\\\\\"$2}\' | \\\\\\\\\\\\nwhile read i; do bash -c \\\\\\\"nft delete rule $PROTOCOL $i\\\\\\\"; done\\\\n\\\", \\\"when\\\": [\\\"groups[\'neutron_api\'] | default([]) | length > 2\\\"]}]}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Neutron ML2 Plugin configured with Puppet\\\\n\\\", \\\"parameters\\\": {\\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ContainerNeutronConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the neutron config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"NeutronPluginMl2PuppetTags\\\": {\\\"default\\\": \\\"neutron_plugin_ml2\\\", \\\"description\\\": \\\"Puppet resource tag names that are used to generate config files with puppet\\\", \\\"type\\\": \\\"string\\\"}}, \\\"resources\\\": {\\\"NeutronBase\\\": {\\\"type\\\": \\\"OS::TripleO::Services::NeutronMl2PluginBase\\\", \\\"properties\\\": {\\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerNeutronConfigImage\\\": \\\"ContainerNeutronConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerNeutronConfigImage\\\": {\\\"get_param\\\": \\\"ContainerNeutronConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Neutron ML2 Plugin role.\\\", \\\"value\\\": {\\\"service_name\\\": {\\\"get_attr\\\": [\\\"NeutronBase\\\", \\\"role_data\\\", \\\"service_name\\\"]}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"NeutronBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}]}, \\\"service_config_settings\\\": {\\\"get_attr\\\": [\\\"NeutronBase\\\", \\\"role_data\\\", \\\"service_config_settings\\\"]}, \\\"metadata_settings\\\": {\\\"get_attr\\\": [\\\"NeutronBase\\\", \\\"role_data\\\", \\\"metadata_settings\\\"]}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"neutron\\\", \\\"puppet_tags\\\": {\\\"get_param\\\": \\\"NeutronPluginMl2PuppetTags\\\"}, \\\"step_config\\\": {\\\"get_attr\\\": [\\\"NeutronBase\\\", \\\"role_data\\\", \\\"step_config\\\"]}, \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNeutronConfigImage\\\"]}}, \\\"kolla_config\\\": {}, \\\"docker_config\\\": {}, \\\"host_prep_tasks\\\": []}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack Neutron Compute Nuage plugin\\\\n\\\", \\\"parameters\\\": {\\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"NovaPassword\\\": {\\\"description\\\": \\\"The password for the nova service and db account\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"NuageMetadataPort\\\": {\\\"description\\\": \\\"TCP Port to listen for metadata server requests\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"9697\\\"}, \\\"NuageActiveController\\\": {\\\"description\\\": \\\"IP address of the Active Virtualized Services Controller (VSC)\\\", \\\"type\\\": \\\"string\\\"}, \\\"NuageStandbyController\\\": {\\\"description\\\": \\\"IP address of the Standby Virtualized Services Controller (VSC)\\\", \\\"type\\\": \\\"string\\\"}, \\\"NuageNovaMetadataPort\\\": {\\\"description\\\": \\\"TCP Port used by Nova metadata server\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"8775\\\"}, \\\"NuageMetadataProxySharedSecret\\\": {\\\"description\\\": \\\"Shared secret to sign the instance-id request\\\", \\\"type\\\": \\\"string\\\"}, \\\"NuageNovaClientVersion\\\": {\\\"description\\\": \\\"Client Version Nova\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"2\\\"}, \\\"NuageNovaOsUsername\\\": {\\\"description\\\": \\\"Nova username in keystone_authtoken\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"nova\\\"}, \\\"NuageMetadataAgentStartWithOvs\\\": {\\\"description\\\": \\\"Set to true if nuage-metadata-agent needs to be started with nuage-openvswitch-switch\\\", \\\"type\\\": \\\"boolean\\\", \\\"default\\\": true}, \\\"NuageNovaApiEndpoint\\\": {\\\"description\\\": \\\"One of publicURL, internalURL, adminURL in \\\\\\\"keystone endpoint-list\\\\\\\"\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"publicURL\\\"}, \\\"NuageNovaRegionName\\\": {\\\"description\\\": \\\"Region name in \\\\\\\"keystone endpoint-list\\\\\\\"\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"regionOne\\\"}, \\\"NuageBridgeMTU\\\": {\\\"description\\\": \\\"Support for non-default MTU configured on each VRS node\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\"}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Neutron Compute Nuage plugin\\\", \\\"firewall_rules\\\": {\\\"118 neutron vxlan networks\\\": {\\\"proto\\\": \\\"udp\\\", \\\"dport\\\": 4789}, \\\"100 metadata agent\\\": {\\\"dport\\\": {\\\"get_param\\\": \\\"NuageMetadataPort\\\"}}}, \\\"value\\\": {\\\"service_name\\\": \\\"neutron_compute_plugin_nuage\\\", \\\"config_settings\\\": {\\\"nuage::vrs::active_controller\\\": {\\\"get_param\\\": \\\"NuageActiveController\\\"}, \\\"nuage::vrs::standby_controller\\\": {\\\"get_param\\\": \\\"NuageStandbyController\\\"}, \\\"nuage::vrs::bridge_mtu\\\": {\\\"get_param\\\": \\\"NuageBridgeMTU\\\"}, \\\"nuage::metadataagent::metadata_port\\\": {\\\"get_param\\\": \\\"NuageMetadataPort\\\"}, \\\"nuage::metadataagent::nova_metadata_port\\\": {\\\"get_param\\\": \\\"NuageNovaMetadataPort\\\"}, \\\"nuage::metadataagent::metadata_secret\\\": {\\\"get_param\\\": \\\"NuageMetadataProxySharedSecret\\\"}, \\\"nuage::metadataagent::nova_client_version\\\": {\\\"get_param\\\": \\\"NuageNovaClientVersion\\\"}, \\\"nuage::metadataagent::nova_os_username\\\": {\\\"get_param\\\": \\\"NuageNovaOsUsername\\\"}, \\\"nuage::metadataagent::metadata_agent_start_with_ovs\\\": {\\\"get_param\\\": \\\"NuageMetadataAgentStartWithOvs\\\"}, \\\"nuage::metadataagent::nova_api_endpoint_type\\\": {\\\"get_param\\\": \\\"NuageNovaApiEndpoint\\\"}, \\\"nuage::metadataagent::nova_region_name\\\": {\\\"get_param\\\": \\\"NuageNovaRegionName\\\"}, \\\"tripleo::profile::base::neutron::agents::nuage::nova_os_tenant_name\\\": \\\"service\\\", \\\"tripleo::profile::base::neutron::agents::nuage::nova_os_password\\\": {\\\"get_param\\\": \\\"NovaPassword\\\"}, \\\"tripleo::profile::base::neutron::agents::nuage::nova_auth_ip\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"host\\\"]}}, \\\"step_config\\\": \\\"include tripleo::profile::base::neutron::agents::nuage\\\"}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack Neutron ML2 Plugin configured with Puppet\\\\n\\\", \\\"parameters\\\": {\\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"NeutronMechanismDrivers\\\": {\\\"default\\\": \\\"ovn\\\", \\\"description\\\": \\\"The mechanism drivers for the Neutron tenant network.\\\\n\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"NeutronTypeDrivers\\\": {\\\"default\\\": \\\"geneve,vxlan,vlan,flat\\\", \\\"description\\\": \\\"Comma-separated list of network type driver entrypoints to be loaded.\\\\n\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"NeutronFlatNetworks\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": \\\"datacentre\\\", \\\"description\\\": \\\"If set, flat networks to configure in neutron plugins.\\\"}, \\\"NeutronPluginExtensions\\\": {\\\"default\\\": \\\"qos,port_security,dns_domain_ports\\\", \\\"description\\\": \\\"Comma-separated list of extensions enabled for the Neutron plugin.\\\\n\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"NeutronNetworkVLANRanges\\\": {\\\"default\\\": \\\"datacentre:1:1000\\\", \\\"description\\\": \\\"The Neutron ML2 and OpenVSwitch vlan mapping range to support. See the Neutron documentation for permitted values. Defaults to permitting VLANs 1 to 1000 on the \'datacentre\' physical network (See NeutronBridgeMappings).\\\\n\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"NeutronTunnelIdRanges\\\": {\\\"description\\\": \\\"Comma-separated list of <tun_min>:<tun_max> tuples enumerating ranges\\\\nof GRE tunnel IDs that are available for tenant network allocation\\\\n\\\", \\\"default\\\": [\\\"1:4094\\\"], \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"NeutronVniRanges\\\": {\\\"description\\\": \\\"Comma-separated list of <vni_min>:<vni_max> tuples enumerating ranges\\\\nof VXLAN VNI IDs that are available for tenant network allocation\\\\n\\\", \\\"default\\\": [\\\"1:65536\\\"], \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"NeutronNetworkType\\\": {\\\"default\\\": \\\"geneve\\\", \\\"description\\\": \\\"The tenant network type for Neutron.\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"NeutronOverlayIPVersion\\\": {\\\"default\\\": 4, \\\"description\\\": \\\"IP version used for all overlay network endpoints.\\\", \\\"type\\\": \\\"number\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [4, 6]}]}, \\\"NeutronML2PhysicalNetworkMtus\\\": {\\\"default\\\": [], \\\"description\\\": \\\"A list of mappings of physical networks to MTU values. The format of\\\\nthe mapping is <physnet>:<mtu val>. This mapping allows specifying a\\\\nphysical network MTU value that differs from the default segment_mtu\\\\nvalue in ML2 plugin. And overwrite values from global_physnet_mtu for\\\\nselected network.\\\\n\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"NeutronOvsVnicTypeBlacklist\\\": {\\\"description\\\": \\\"Comma-separated list of VNIC types for which support in Neutron is\\\\nadministratively prohibited by the OVS mechanism driver.\\\\n\\\", \\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": \\\"\\\"}, \\\"NeutronSriovVnicTypeBlacklist\\\": {\\\"description\\\": \\\"Comma-separated list of VNIC types for which support in Neutron is administratively prohibited by the SR-IOV mechanism driver.\\\\n\\\", \\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": \\\"\\\"}, \\\"NeutronFirewallDriver\\\": {\\\"description\\\": \\\"Firewall driver for realizing neutron security group function\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\"}}, \\\"parameter_groups\\\": [{\\\"label\\\": \\\"deprecated\\\", \\\"description\\\": \\\"The following parameters are deprecated and will be removed. They should not\\\\nbe relied on for new deployments. If you have concerns regarding deprecated\\\\nparameters, please contact the TripleO development team on IRC or the\\\\nOpenStack mailing list.\\\\n\\\", \\\"parameters\\\": [\\\"NeutronOverlayIPVersion\\\"]}], \\\"conditions\\\": {\\\"physical_network_mtus_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"NeutronML2PhysicalNetworkMtus\\\"}, []]}}}, \\\"resources\\\": {\\\"NeutronBase\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-base.yaml\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Neutron ML2 plugin.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"neutron_plugin_ml2\\\", \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"NeutronBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"neutron::plugins::ml2::mechanism_drivers\\\": {\\\"get_param\\\": \\\"NeutronMechanismDrivers\\\"}, \\\"neutron::plugins::ml2::type_drivers\\\": {\\\"get_param\\\": \\\"NeutronTypeDrivers\\\"}, \\\"neutron::plugins::ml2::flat_networks\\\": {\\\"get_param\\\": \\\"NeutronFlatNetworks\\\"}, \\\"neutron::plugins::ml2::extension_drivers\\\": {\\\"get_param\\\": \\\"NeutronPluginExtensions\\\"}, \\\"neutron::plugins::ml2::network_vlan_ranges\\\": {\\\"get_param\\\": \\\"NeutronNetworkVLANRanges\\\"}, \\\"neutron::plugins::ml2::tunnel_id_ranges\\\": {\\\"get_param\\\": \\\"NeutronTunnelIdRanges\\\"}, \\\"neutron::plugins::ml2::vni_ranges\\\": {\\\"get_param\\\": \\\"NeutronVniRanges\\\"}, \\\"neutron::plugins::ml2::tenant_network_types\\\": {\\\"get_param\\\": \\\"NeutronNetworkType\\\"}, \\\"neutron::plugins::ml2::ovs_driver::vnic_type_blacklist\\\": {\\\"get_param\\\": \\\"NeutronOvsVnicTypeBlacklist\\\"}, \\\"neutron::plugins::ml2::sriov_driver::vnic_type_blacklist\\\": {\\\"get_param\\\": \\\"NeutronSriovVnicTypeBlacklist\\\"}, \\\"neutron::plugins::ml2::overlay_ip_version\\\": {\\\"get_param\\\": [\\\"ServiceData\\\", \\\"net_ip_version_map\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NeutronTenantNetwork\\\"]}]}}, {\\\"if\\\": [\\\"physical_network_mtus_set\\\", {\\\"neutron::plugins::ml2::physical_network_mtus\\\": {\\\"get_param\\\": \\\"NeutronML2PhysicalNetworkMtus\\\"}}, null]}]}, \\\"step_config\\\": \\\"include tripleo::profile::base::neutron::plugins::ml2\\\\n\\\", \\\"service_config_settings\\\": {\\\"horizon\\\": {\\\"neutron::plugins::ml2::mechanism_drivers\\\": {\\\"get_param\\\": \\\"NeutronMechanismDrivers\\\"}}}, \\\"metadata_settings\\\": {\\\"get_attr\\\": [\\\"NeutronBase\\\", \\\"role_data\\\", \\\"metadata_settings\\\"]}}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack Neutron ML2/OVN plugin configured with Puppet\\\\n\\\", \\\"parameters\\\": {\\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"OVNSouthboundServerPort\\\": {\\\"description\\\": \\\"Port of the OVN Southbound DB server\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 6642}, \\\"OVNNorthboundServerPort\\\": {\\\"description\\\": \\\"Port of the OVN Northbound DB server\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 6641}, \\\"OVNDbConnectionTimeout\\\": {\\\"description\\\": \\\"Timeout in seconds for the OVSDB connection transaction\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 180}, \\\"OVNOvsdbProbeInterval\\\": {\\\"description\\\": \\\"Probe interval in ms for the OVSDB session\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 60000}, \\\"OVNNeutronSyncMode\\\": {\\\"description\\\": \\\"The synchronization mode of OVN with Neutron DB\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"log\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"log\\\", false, \\\"repair\\\"]}]}, \\\"OVNQosDriver\\\": {\\\"description\\\": \\\"OVN notification driver for Neutron QOS service plugin\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"ovn-qos\\\"}, \\\"NeutronGeneveMaxHeaderSize\\\": {\\\"description\\\": \\\"Geneve encapsulation header size\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 38}, \\\"NeutronEnableDVR\\\": {\\\"description\\\": \\\"Enable Neutron DVR.\\\", \\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"NeutronEnableIgmpSnooping\\\": {\\\"description\\\": \\\"Enable IGMP Snooping.\\\", \\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"OVNMetadataEnabled\\\": {\\\"description\\\": \\\"Whether Metadata Service has to be enabled\\\", \\\"type\\\": \\\"boolean\\\", \\\"default\\\": true}, \\\"OVNDnsServers\\\": {\\\"default\\\": [], \\\"description\\\": \\\"List of servers to use as as dns forwarders\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"InternalTLSCAFile\\\": {\\\"default\\\": \\\"/etc/ipa/ca.crt\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Specifies the default CA cert to use if TLS is used for services in the internal network.\\\"}, \\\"NeutronVhostuserSocketDir\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The vhost-user socket directory for OVS\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"OVNEmitNeedToFrag\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": true, \\\"description\\\": \\\"Configure OVN to emit \\\\\\\"need to frag\\\\\\\" packets in case of MTU mismatches. You may have to disable this option if you are running an old host kernel (version < 5.2). You may check the output of the following command: \'ovs-appctl -t ovs-vswitchd dpif/show-dp-features \\\\\\\\ br-int | grep \\\\\\\"Check pkt length action\\\\\\\"\'.\\\\n\\\"}, \\\"NeutronOVNLoggingRateLimit\\\": {\\\"default\\\": 100, \\\"description\\\": \\\"Maximum number of packets logging per second\\\\n\\\", \\\"type\\\": \\\"number\\\"}, \\\"NeutronOVNLoggingBurstLimit\\\": {\\\"default\\\": 25, \\\"description\\\": \\\"Maximum number of packets per rate_limit\\\\n\\\", \\\"type\\\": \\\"number\\\"}, \\\"NeutronOVNLoggingLocalOutputLogBase\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Output logfile path on agent side, default syslog file\\\\n\\\", \\\"type\\\": \\\"string\\\"}}, \\\"conditions\\\": {\\\"neutron_dvr_unset\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"NeutronEnableDVR\\\"}, \\\"\\\"]}, \\\"internal_tls_enabled\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, true]}, \\\"vhostuser_dir_set\\\": {\\\"or\\\": [{\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"NeutronVhostuserSocketDir\\\"}, \\\"\\\"]}}, {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"NeutronVhostuserSocketDir\\\"]}, \\\"\\\"]}}]}, \\\"network_log_local_output_log_base_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"NeutronOVNLoggingLocalOutputLogBase\\\"}, \\\"\\\"]}}}, \\\"resources\\\": {\\\"NeutronMl2Base\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2.yaml\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Neutron ML2/OVN plugin.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"neutron_plugin_ml2_ovn\\\", \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"NeutronMl2Base\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"ovn::southbound::port\\\": {\\\"get_param\\\": \\\"OVNSouthboundServerPort\\\"}, \\\"ovn::northbound::port\\\": {\\\"get_param\\\": \\\"OVNNorthboundServerPort\\\"}, \\\"neutron::plugins::ml2::ovn::ovsdb_connection_timeout\\\": {\\\"get_param\\\": \\\"OVNDbConnectionTimeout\\\"}, \\\"neutron::plugins::ml2::ovn::ovsdb_probe_interval\\\": {\\\"get_param\\\": \\\"OVNOvsdbProbeInterval\\\"}, \\\"neutron::plugins::ml2::ovn::neutron_sync_mode\\\": {\\\"get_param\\\": \\\"OVNNeutronSyncMode\\\"}, \\\"neutron::plugins::ml2::ovn::ovn_metadata_enabled\\\": {\\\"get_param\\\": \\\"OVNMetadataEnabled\\\"}, \\\"neutron::server::qos_notification_drivers\\\": {\\\"get_param\\\": \\\"OVNQosDriver\\\"}, \\\"neutron::server::igmp_snooping_enable\\\": {\\\"get_param\\\": \\\"NeutronEnableIgmpSnooping\\\"}, \\\"neutron::plugins::ml2::max_header_size\\\": {\\\"get_param\\\": \\\"NeutronGeneveMaxHeaderSize\\\"}, \\\"neutron::plugins::ml2::ovn::dns_servers\\\": {\\\"get_param\\\": \\\"OVNDnsServers\\\"}, \\\"neutron::plugins::ml2::ovn::ovn_emit_need_to_frag\\\": {\\\"get_param\\\": \\\"OVNEmitNeedToFrag\\\"}}, {\\\"if\\\": [\\\"internal_tls_enabled\\\", {\\\"neutron::plugins::ml2::ovn::ovn_sb_ca_cert\\\": {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, \\\"neutron::plugins::ml2::ovn::ovn_sb_certificate\\\": \\\"/etc/pki/tls/certs/ovn_neutron_client.crt\\\", \\\"neutron::plugins::ml2::ovn::ovn_sb_private_key\\\": \\\"/etc/pki/tls/private/ovn_neutron_client.key\\\", \\\"neutron::plugins::ml2::ovn::ovn_nb_ca_cert\\\": {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, \\\"neutron::plugins::ml2::ovn::ovn_nb_certificate\\\": \\\"/etc/pki/tls/certs/ovn_neutron_client.crt\\\", \\\"neutron::plugins::ml2::ovn::ovn_nb_private_key\\\": \\\"/etc/pki/tls/private/ovn_neutron_client.key\\\"}, {}]}, {\\\"if\\\": [\\\"neutron_dvr_unset\\\", {\\\"neutron::plugins::ml2::ovn::dvr_enabled\\\": true}, {\\\"neutron::plugins::ml2::ovn::dvr_enabled\\\": {\\\"get_param\\\": \\\"NeutronEnableDVR\\\"}}]}, {\\\"if\\\": [\\\"vhostuser_dir_set\\\", {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"neutron::plugins::ml2::ovn::vhostuser_socket_dir\\\": \\\"NeutronVhostuserSocketDir\\\"}, {\\\"values\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}]}, {\\\"values\\\": {\\\"NeutronVhostuserSocketDir\\\": {\\\"get_param\\\": \\\"NeutronVhostuserSocketDir\\\"}}}]}, {}]}, {\\\"neutron::plugins::ml2::ovn::network_log_rate_limit\\\": {\\\"get_param\\\": \\\"NeutronOVNLoggingRateLimit\\\"}}, {\\\"neutron::plugins::ml2::ovn::network_log_burst_limit\\\": {\\\"get_param\\\": \\\"NeutronOVNLoggingBurstLimit\\\"}}, {\\\"if\\\": [\\\"network_log_local_output_log_base_set\\\", {\\\"neutron::plugins::ml2::ovn::network_log_local_output_log_base\\\": {\\\"get_param\\\": \\\"NeutronOVNLoggingLocalOutputLogBase\\\"}}]}]}, \\\"step_config\\\": \\\"include tripleo::profile::base::neutron::plugins::ml2\\\\n\\\", \\\"metadata_settings\\\": {\\\"get_attr\\\": [\\\"NeutronMl2Base\\\", \\\"role_data\\\", \\\"metadata_settings\\\"]}}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack Neutron Nuage plugin\\\\n\\\", \\\"parameters\\\": {\\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"NeutronNuageNetPartitionName\\\": {\\\"description\\\": \\\"Specifies the title that you will see on the VSD\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"default_name\\\"}, \\\"NeutronNuageVSDIp\\\": {\\\"description\\\": \\\"IP address and port of the Virtual Services Directory\\\", \\\"type\\\": \\\"string\\\"}, \\\"NeutronNuageVSDUsername\\\": {\\\"description\\\": \\\"Username to be used to log into VSD\\\", \\\"type\\\": \\\"string\\\"}, \\\"NeutronNuageVSDPassword\\\": {\\\"description\\\": \\\"Password to be used to log into VSD\\\", \\\"type\\\": \\\"string\\\"}, \\\"NeutronNuageVSDOrganization\\\": {\\\"description\\\": \\\"Organization parameter required to log into VSD\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"organization\\\"}, \\\"NeutronNuageBaseURIVersion\\\": {\\\"description\\\": \\\"URI version to be used based on the VSD release\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"default_uri_version\\\"}, \\\"NeutronNuageCMSId\\\": {\\\"description\\\": \\\"Cloud Management System ID (CMS ID) to distinguish between OS instances on the same VSD\\\", \\\"type\\\": \\\"string\\\"}, \\\"UseForwardedFor\\\": {\\\"description\\\": \\\"Treat X-Forwarded-For as the canonical remote address. Only enable this if you have a sanitizing proxy.\\\", \\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}}, \\\"resources\\\": {\\\"NeutronBase\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-base.yaml\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Neutron Nuage plugin\\\", \\\"value\\\": {\\\"service_name\\\": \\\"neutron_plugin_nuage\\\", \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"NeutronBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"neutron::plugins::nuage::nuage_net_partition_name\\\": {\\\"get_param\\\": \\\"NeutronNuageNetPartitionName\\\"}, \\\"neutron::plugins::nuage::nuage_vsd_ip\\\": {\\\"get_param\\\": \\\"NeutronNuageVSDIp\\\"}, \\\"neutron::plugins::nuage::nuage_vsd_username\\\": {\\\"get_param\\\": \\\"NeutronNuageVSDUsername\\\"}, \\\"neutron::plugins::nuage::nuage_vsd_password\\\": {\\\"get_param\\\": \\\"NeutronNuageVSDPassword\\\"}, \\\"neutron::plugins::nuage::nuage_vsd_organization\\\": {\\\"get_param\\\": \\\"NeutronNuageVSDOrganization\\\"}, \\\"neutron::plugins::nuage::nuage_base_uri_version\\\": {\\\"get_param\\\": \\\"NeutronNuageBaseURIVersion\\\"}, \\\"neutron::plugins::nuage::nuage_cms_id\\\": {\\\"get_param\\\": \\\"NeutronNuageCMSId\\\"}, \\\"nova::api::use_forwarded_for\\\": {\\\"get_param\\\": \\\"UseForwardedFor\\\"}}]}, \\\"step_config\\\": \\\"include tripleo::profile::base::neutron::plugins::nuage\\\\n\\\", \\\"metadata_settings\\\": {\\\"get_attr\\\": [\\\"NeutronBase\\\", \\\"role_data\\\", \\\"metadata_settings\\\"]}}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack Neutron ML2/Nuage plugin configured with Puppet\\\\n\\\", \\\"parameters\\\": {\\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"NeutronNuageNetPartitionName\\\": {\\\"description\\\": \\\"Specifies the title that you will see on the VSD\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"default_name\\\"}, \\\"NeutronNuageVSDIp\\\": {\\\"description\\\": \\\"IP address and port of the Virtual Services Directory\\\", \\\"type\\\": \\\"string\\\"}, \\\"NeutronNuageVSDUsername\\\": {\\\"description\\\": \\\"Username to be used to log into VSD\\\", \\\"type\\\": \\\"string\\\"}, \\\"NeutronNuageVSDPassword\\\": {\\\"description\\\": \\\"Password to be used to log into VSD\\\", \\\"type\\\": \\\"string\\\"}, \\\"NeutronNuageVSDOrganization\\\": {\\\"description\\\": \\\"Organization parameter required to log into VSD\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"organization\\\"}, \\\"NeutronNuageBaseURIVersion\\\": {\\\"description\\\": \\\"URI version to be used based on the VSD release\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"default_uri_version\\\"}, \\\"NeutronNuageCMSId\\\": {\\\"description\\\": \\\"Cloud Management System ID (CMS ID) to distinguish between OS instances on the same VSD\\\", \\\"type\\\": \\\"string\\\"}, \\\"UseForwardedFor\\\": {\\\"description\\\": \\\"Treat X-Forwarded-For as the canonical remote address. Only enable this if you have a sanitizing proxy.\\\", \\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"NovaPatchConfigMonkeyPatch\\\": {\\\"description\\\": \\\"Apply monkey patching or not\\\", \\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"NovaPatchConfigMonkeyPatchModules\\\": {\\\"description\\\": \\\"List of modules/decorators to monkey patch\\\", \\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": \\\"\\\"}, \\\"NuageDefaultAllowNonIP\\\": {\\\"description\\\": \\\"To allow non-IP traffic by default\\\", \\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}}, \\\"resources\\\": {\\\"NeutronMl2Base\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2.yaml\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Neutron ML2/Nuage plugin\\\", \\\"value\\\": {\\\"service_name\\\": \\\"neutron_plugin_ml2_nuage\\\", \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"NeutronMl2Base\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"neutron::plugins::ml2::nuage::nuage_net_partition_name\\\": {\\\"get_param\\\": \\\"NeutronNuageNetPartitionName\\\"}, \\\"neutron::plugins::ml2::nuage::nuage_vsd_ip\\\": {\\\"get_param\\\": \\\"NeutronNuageVSDIp\\\"}, \\\"neutron::plugins::ml2::nuage::nuage_vsd_username\\\": {\\\"get_param\\\": \\\"NeutronNuageVSDUsername\\\"}, \\\"neutron::plugins::ml2::nuage::nuage_vsd_password\\\": {\\\"get_param\\\": \\\"NeutronNuageVSDPassword\\\"}, \\\"neutron::plugins::ml2::nuage::nuage_vsd_organization\\\": {\\\"get_param\\\": \\\"NeutronNuageVSDOrganization\\\"}, \\\"neutron::plugins::ml2::nuage::nuage_base_uri_version\\\": {\\\"get_param\\\": \\\"NeutronNuageBaseURIVersion\\\"}, \\\"neutron::plugins::ml2::nuage::nuage_cms_id\\\": {\\\"get_param\\\": \\\"NeutronNuageCMSId\\\"}, \\\"neutron::plugins::ml2::nuage::nuage_default_allow_non_ip\\\": {\\\"get_param\\\": \\\"NuageDefaultAllowNonIP\\\"}, \\\"nova::api::use_forwarded_for\\\": {\\\"get_param\\\": \\\"UseForwardedFor\\\"}, \\\"nova::patch::config::monkey_patch\\\": {\\\"get_param\\\": \\\"NovaPatchConfigMonkeyPatch\\\"}, \\\"nova::patch::config::monkey_patch_modules\\\": {\\\"get_param\\\": \\\"NovaPatchConfigMonkeyPatchModules\\\"}}]}, \\\"step_config\\\": \\\"include tripleo::profile::base::neutron::plugins::ml2\\\\n\\\", \\\"metadata_settings\\\": {\\\"get_attr\\\": [\\\"NeutronMl2Base\\\", \\\"role_data\\\", \\\"metadata_settings\\\"]}}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Neutron NSX Plugin configured with Puppet\\\\n\\\", \\\"parameters\\\": {\\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ContainerNeutronConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the neutron config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"NeutronPluginNsxPuppetTags\\\": {\\\"default\\\": \\\"neutron_plugin_nsx\\\", \\\"description\\\": \\\"Puppet resource tag names that are used to generate config files with puppet\\\", \\\"type\\\": \\\"string\\\"}, \\\"DefaultOverlayTz\\\": {\\\"description\\\": \\\"Name or UUID of the default NSX overlay transport zone.\\\", \\\"type\\\": \\\"string\\\"}, \\\"DefaultVlanTz\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Name or UUID of the default NSX VLAN transport zone.\\\", \\\"type\\\": \\\"string\\\"}, \\\"DefaultBridgeCluster\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Name or UUID of the default NSX bridge cluster that will be used to perform L2 gateway bridging between VXLAN and VLAN networks.\\\", \\\"type\\\": \\\"string\\\"}, \\\"DefaultTier0Router\\\": {\\\"description\\\": \\\"UUID of the default tier0 router that will be used for connecting to tier1 logical routers and configuring external networks.\\\", \\\"type\\\": \\\"string\\\"}, \\\"NsxApiManagers\\\": {\\\"description\\\": \\\"IP address of one or more NSX managers separated by commas.\\\", \\\"type\\\": \\\"string\\\"}, \\\"NsxApiUser\\\": {\\\"description\\\": \\\"User name of NSX Manager.\\\", \\\"type\\\": \\\"string\\\"}, \\\"NsxApiPassword\\\": {\\\"description\\\": \\\"Password of NSX Manager.\\\", \\\"type\\\": \\\"string\\\"}, \\\"NativeDhcpMetadata\\\": {\\\"default\\\": true, \\\"description\\\": \\\"This is the flag to indicate if using native DHCP/Metadata or not.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"DhcpProfile\\\": {\\\"description\\\": \\\"This is the name or UUID of the NSX DHCP Profile that will be used to enable native DHCP service.\\\", \\\"type\\\": \\\"string\\\"}, \\\"MetadataProxy\\\": {\\\"description\\\": \\\"This is the name or UUID of the NSX Metadata Proxy that will be used to enable native metadata service.\\\", \\\"type\\\": \\\"string\\\"}, \\\"DhcpRelayService\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"This is the name or UUID of the NSX relay service that will be used to enable DHCP relay on router ports.\\\", \\\"type\\\": \\\"string\\\"}}, \\\"resources\\\": {\\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerNeutronConfigImage\\\": \\\"ContainerNeutronConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerNeutronConfigImage\\\": {\\\"get_param\\\": \\\"ContainerNeutronConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Neutron NSX Plugin role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"neutron_plugin_nsx\\\", \\\"config_settings\\\": {\\\"neutron::plugins::nsx::default_overlay_tz\\\": {\\\"get_param\\\": \\\"DefaultOverlayTz\\\"}, \\\"neutron::plugins::nsx::default_vlan_tz\\\": {\\\"get_param\\\": \\\"DefaultVlanTz\\\"}, \\\"neutron::plugins::nsx::default_bridge_cluster\\\": {\\\"get_param\\\": \\\"DefaultBridgeCluster\\\"}, \\\"neutron::plugins::nsx::default_tier0_router\\\": {\\\"get_param\\\": \\\"DefaultTier0Router\\\"}, \\\"neutron::plugins::nsx::nsx_api_managers\\\": {\\\"get_param\\\": \\\"NsxApiManagers\\\"}, \\\"neutron::plugins::nsx::nsx_api_user\\\": {\\\"get_param\\\": \\\"NsxApiUser\\\"}, \\\"neutron::plugins::nsx::nsx_api_password\\\": {\\\"get_param\\\": \\\"NsxApiPassword\\\"}, \\\"neutron::plugins::nsx::native_dhcp_metadata\\\": {\\\"get_param\\\": \\\"NativeDhcpMetadata\\\"}, \\\"neutron::plugins::nsx::dhcp_profile\\\": {\\\"get_param\\\": \\\"DhcpProfile\\\"}, \\\"neutron::plugins::nsx::dhcp_relay_service\\\": {\\\"get_param\\\": \\\"DhcpRelayService\\\"}, \\\"neutron::plugins::nsx::metadata_proxy\\\": {\\\"get_param\\\": \\\"MetadataProxy\\\"}}, \\\"service_config_settings\\\": {}, \\\"metadata_settings\\\": {}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"neutron\\\", \\\"puppet_tags\\\": {\\\"get_param\\\": \\\"NeutronPluginNsxPuppetTags\\\"}, \\\"step_config\\\": {\\\"get_attr\\\": \\\"include tripleo::profile::base::neutron::plugins::nsx\\\\n\\\"}, \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNeutronConfigImage\\\"]}}, \\\"kolla_config\\\": {}, \\\"docker_config\\\": {}}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized OVN DBs service in cluster mode\\\\n\\\", \\\"parameters\\\": {\\\"ContainerOvnNbDbImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerOvnSbDbImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerOvnNorthdImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerNeutronApiImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerOvnMetadataImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry.  This mapping overrides those in ServiceNetMapDefaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"OVNOvsdbProbeInterval\\\": {\\\"description\\\": \\\"Probe interval in ms for the OVSDB session\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 60000}, \\\"OVNNorthboundServerPort\\\": {\\\"description\\\": \\\"Port of the OVN Northbound DB server\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 6641}, \\\"OVNSouthboundServerPort\\\": {\\\"description\\\": \\\"Port of the OVN Southbound DB server\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 6642}, \\\"OVNNorthboundClusterPort\\\": {\\\"description\\\": \\\"Cluster port of the OVN Northbound DB server\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 6643}, \\\"OVNSouthboundClusterPort\\\": {\\\"description\\\": \\\"Cluster port of the OVN Southbound DB server\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 6644}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"InternalTLSCAFile\\\": {\\\"default\\\": \\\"/etc/ipa/ca.crt\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Specifies the default CA cert to use if TLS is used for services in the internal network.\\\"}, \\\"CertificateKeySize\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"2048\\\", \\\"description\\\": \\\"Specifies the private key size used when creating the certificate.\\\"}, \\\"OvnDBSCertificateKeySize\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Override the private key size used when creating the certificate for this service\\\"}}, \\\"conditions\\\": {\\\"key_size_override_unset\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"OvnDBSCertificateKeySize\\\"}, \\\"\\\"]}, \\\"is_ipv6\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"ServiceData\\\", \\\"net_ip_version_map\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OvnDbsNetwork\\\"]}]}, 6]}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerOvnNbDbImage\\\": \\\"ContainerOvnNbDbImage\\\", \\\"ContainerOvnSbDbImage\\\": \\\"ContainerOvnSbDbImage\\\", \\\"ContainerOvnNorthdImage\\\": \\\"ContainerOvnNorthdImage\\\", \\\"ContainerNeutronApiImage\\\": \\\"ContainerNeutronApiImage\\\", \\\"ContainerOvnMetadataImage\\\": \\\"ContainerOvnMetadataImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerOvnNbDbImage\\\": {\\\"get_param\\\": \\\"ContainerOvnNbDbImage\\\"}, \\\"ContainerOvnSbDbImage\\\": {\\\"get_param\\\": \\\"ContainerOvnSbDbImage\\\"}, \\\"ContainerOvnNorthdImage\\\": {\\\"get_param\\\": \\\"ContainerOvnNorthdImage\\\"}, \\\"ContainerNeutronApiImage\\\": {\\\"get_param\\\": \\\"ContainerNeutronApiImage\\\"}, \\\"ContainerOvnMetadataImage\\\": {\\\"get_param\\\": \\\"ContainerOvnMetadataImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the OVN multi-active cluster role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"ovn_dbs\\\", \\\"firewall_rules\\\": {\\\"map_merge\\\": {\\\"repeat\\\": {\\\"for_each\\\": {\\\"<%net_cidr%>\\\": {\\\"get_param\\\": [\\\"ServiceData\\\", \\\"net_cidr_map\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OvnDbsNetwork\\\"]}]}}, \\\"template\\\": {\\\"121 OVN DB server and cluster ports for <%net_cidr%>\\\": {\\\"proto\\\": \\\"tcp\\\", \\\"source\\\": \\\"<%net_cidr%>\\\", \\\"dport\\\": [{\\\"get_param\\\": \\\"OVNNorthboundServerPort\\\"}, {\\\"get_param\\\": \\\"OVNSouthboundServerPort\\\"}, {\\\"get_param\\\": \\\"OVNNorthboundClusterPort\\\"}, {\\\"get_param\\\": \\\"OVNSouthboundClusterPort\\\"}]}}}}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/ovn_cluster_north_db_server.json\\\": {\\\"command\\\": \\\"bash -c $* -- eval source /etc/sysconfig/ovn_cluster; exec /usr/local/bin/start-nb-db-server ${OVN_NB_DB_OPTS}\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-tls/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true, \\\"optional\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/openvswitch\\\", \\\"owner\\\": \\\"root:root\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/var/log/ovn\\\", \\\"owner\\\": \\\"root:root\\\", \\\"recurse\\\": true}]}, \\\"/var/lib/kolla/config_files/ovn_cluster_south_db_server.json\\\": {\\\"command\\\": \\\"bash -c $* -- eval source /etc/sysconfig/ovn_cluster; exec /usr/local/bin/start-sb-db-server ${OVN_SB_DB_OPTS}\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-tls/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true, \\\"optional\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/openvswitch\\\", \\\"owner\\\": \\\"root:root\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/var/log/ovn\\\", \\\"owner\\\": \\\"root:root\\\", \\\"recurse\\\": true}]}, \\\"/var/lib/kolla/config_files/ovn_cluster_northd.json\\\": {\\\"command\\\": \\\"bash -c $* -- eval source /etc/sysconfig/ovn_cluster; exec /usr/bin/ovn-northd ${OVN_NORTHD_OPTS}\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-tls/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true, \\\"optional\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/openvswitch\\\", \\\"owner\\\": \\\"root:root\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/var/log/ovn\\\", \\\"owner\\\": \\\"root:root\\\", \\\"recurse\\\": true}]}}, \\\"docker_config\\\": {\\\"step_0\\\": {\\\"ovn_cluster_north_db_server\\\": {\\\"start_order\\\": 0, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerOvnNbDbImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"restart\\\": \\\"always\\\", \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/ovn_cluster_north_db_server.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/var/lib/openvswitch/ovn:/var/lib/openvswitch:shared,z\\\", \\\"/var/lib/openvswitch/ovn:/run/openvswitch:shared,z\\\", \\\"/var/log/containers/openvswitch:/var/log/openvswitch:z\\\", \\\"/var/lib/openvswitch/ovn:/var/lib/ovn:shared,z\\\", \\\"/var/lib/openvswitch/ovn:/etc/openvswitch:shared,z\\\", \\\"/var/lib/openvswitch/ovn:/etc/ovn:shared,z\\\", \\\"/var/lib/openvswitch/ovn:/run/ovn:shared,z\\\", \\\"/var/log/containers/openvswitch:/var/log/ovn:z\\\", \\\"/var/lib/config-data/ansible-generated/ovn:/var/lib/kolla/config_files/src:ro\\\"], {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, [\\\"/etc/pki/tls/private/ovn_dbs.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/ovn_dbs.key:ro\\\", \\\"/etc/pki/tls/certs/ovn_dbs.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/ovn_dbs.crt:ro\\\"], null]}]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}, \\\"ovn_cluster_south_db_server\\\": {\\\"start_order\\\": 0, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerOvnSbDbImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"restart\\\": \\\"always\\\", \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/ovn_cluster_south_db_server.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/var/lib/openvswitch/ovn:/var/lib/openvswitch:shared,z\\\", \\\"/var/lib/openvswitch/ovn:/run/openvswitch:shared,z\\\", \\\"/var/log/containers/openvswitch:/var/log/openvswitch:z\\\", \\\"/var/lib/openvswitch/ovn:/var/lib/ovn:shared,z\\\", \\\"/var/lib/openvswitch/ovn:/etc/openvswitch:shared,z\\\", \\\"/var/lib/openvswitch/ovn:/etc/ovn:shared,z\\\", \\\"/var/lib/openvswitch/ovn:/run/ovn:shared,z\\\", \\\"/var/log/containers/openvswitch:/var/log/ovn:z\\\", \\\"/var/lib/config-data/ansible-generated/ovn:/var/lib/kolla/config_files/src:ro\\\"], {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, [\\\"/etc/pki/tls/private/ovn_dbs.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/ovn_dbs.key:ro\\\", \\\"/etc/pki/tls/certs/ovn_dbs.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/ovn_dbs.crt:ro\\\"], null]}]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}, \\\"ovn_cluster_northd\\\": {\\\"start_order\\\": 2, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerOvnNorthdImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/ovn_cluster_northd.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/var/lib/openvswitch/ovn:/run/openvswitch:shared,z\\\", \\\"/var/log/containers/openvswitch:/var/log/openvswitch:z\\\", \\\"/var/lib/openvswitch/ovn:/run/ovn:shared,z\\\", \\\"/var/log/containers/openvswitch:/var/log/ovn:z\\\", \\\"/var/lib/config-data/ansible-generated/ovn:/var/lib/kolla/config_files/src:ro\\\"], {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, [\\\"/etc/pki/tls/private/ovn_dbs.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/ovn_dbs.key:ro\\\", \\\"/etc/pki/tls/certs/ovn_dbs.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/ovn_dbs.crt:ro\\\"], null]}]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"global_config_settings\\\": {\\\"ovn_db_clustered\\\": true}, \\\"metadata_settings\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, [{\\\"service\\\": \\\"ovn_dbs\\\", \\\"network\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OvnDbsNetwork\\\"]}, \\\"type\\\": \\\"node\\\"}], null]}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode|default(omit) }}\\\"}, \\\"loop\\\": [{\\\"path\\\": \\\"/var/log/containers/openvswitch\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/lib/openvswitch/ovn\\\", \\\"setype\\\": \\\"container_file_t\\\"}]}], \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"set is_ovn_dbs_bootstrap_node fact\\\", \\\"set_fact\\\": \\\"is_ovn_dbs_bootstrap_node={{ovn_dbs_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\\\", \\\"when\\\": [\\\"step|int == 1\\\"]}, {\\\"name\\\": \\\"Populate ansible service facts so we can check for pacemaker service\\\", \\\"ansible.builtin.service_facts\\\": null, \\\"when\\\": [\\\"is_ovn_dbs_bootstrap_node | bool\\\", \\\"step|int == 1\\\"]}, {\\\"name\\\": \\\"Remove OVNDBs from Pacemaker\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"is_ovn_dbs_bootstrap_node | bool\\\", \\\"ansible_facts[\'services\'][\'pacemaker.service\'][\'state\']  | default(\'unknown\') == \'running\'\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Fetch ovn-dbs-bundle\\\", \\\"shell\\\": \\\"pcs status |grep ovn-dbs-bundle ||true\\\\n\\\", \\\"register\\\": \\\"ovn_dbs\\\"}, {\\\"name\\\": \\\"Fetch ovn VIP\\\", \\\"shell\\\": \\\"pcs constraint config |grep \\\\\\\"with ovn-dbs-bundle\\\\\\\" |awk \'{print $1}\'\\\\n\\\", \\\"register\\\": \\\"ovn_vip\\\"}, {\\\"name\\\": \\\"Remove OVNDBs from pacemaker\\\", \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"ovn-dbs-bundle\\\", \\\"state\\\": \\\"delete\\\"}, \\\"when\\\": \\\"ovn_dbs.stdout |length  > 0\\\"}, {\\\"name\\\": \\\"Remove OVNDBs VIP from pacemaker\\\", \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"{{ ovn_vip.stdout }}\\\", \\\"state\\\": \\\"delete\\\"}, \\\"when\\\": \\\"ovn_vip.stdout |length > 0\\\"}, {\\\"name\\\": \\\"Clean up pacemaker remote nodes cache\\\", \\\"shell\\\": \\\"pcs cluster node clear ovn-dbs-bundle-0\\\\npcs cluster node clear ovn-dbs-bundle-1\\\\npcs cluster node clear ovn-dbs-bundle-2\\\\ncrm_attribute --name OVN_REPL_INFO --delete\\\\n\\\"}, {\\\"name\\\": \\\"Remove pacemaker attributes\\\", \\\"shell\\\": \\\"pcs node attribute \\\\\\\"{{ item }}\\\\\\\" ovn-dbs-role= || true\\\\n\\\", \\\"loop\\\": \\\"{{ ovn_dbs_short_node_names }}\\\"}]}, {\\\"name\\\": \\\"Prepare OVN cluster\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Certificate generation\\\", \\\"when\\\": \\\"enable_internal_tls | bool\\\", \\\"block\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"linux-system-roles.certificate\\\"}, \\\"vars\\\": {\\\"certificate_requests\\\": [{\\\"name\\\": \\\"ovn_dbs\\\", \\\"dns\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"{{fqdn_$NETWORK}}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OvnDbsNetwork\\\"]}}}}, \\\"principal\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"ovn_dbs/{{fqdn_$NETWORK}}@{{idm_realm}}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OvnDbsNetwork\\\"]}}}}, \\\"key_size\\\": {\\\"if\\\": [\\\"key_size_override_unset\\\", {\\\"get_param\\\": \\\"CertificateKeySize\\\"}, {\\\"get_param\\\": \\\"OvnDBSCertificateKeySize\\\"}]}, \\\"ca\\\": \\\"ipa\\\"}]}}]}, {\\\"block\\\": [{\\\"name\\\": \\\"Configure OVN DBs and northd\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_ovn_cluster\\\"}, \\\"vars\\\": {\\\"tripleo_ovn_cluster_dbs_protocol\\\": \\\"{{ enable_internal_tls | ternary(\'ssl\', \'tcp\', \'tcp\') }}\\\", \\\"tripleo_ovn_cluster_network\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OvnDbsNetwork\\\"]}, \\\"tripleo_ovn_cluster_nb_db_port\\\": {\\\"get_param\\\": \\\"OVNNorthboundServerPort\\\"}, \\\"tripleo_ovn_cluster_sb_db_port\\\": {\\\"get_param\\\": \\\"OVNSouthboundServerPort\\\"}, \\\"tripleo_ovn_cluster_nb_local_port\\\": {\\\"get_param\\\": \\\"OVNNorthboundClusterPort\\\"}, \\\"tripleo_ovn_cluster_nb_remote_port\\\": {\\\"get_param\\\": \\\"OVNNorthboundClusterPort\\\"}, \\\"tripleo_ovn_cluster_sb_local_port\\\": {\\\"get_param\\\": \\\"OVNSouthboundClusterPort\\\"}, \\\"tripleo_ovn_cluster_sb_remote_port\\\": {\\\"get_param\\\": \\\"OVNSouthboundClusterPort\\\"}, \\\"tripleo_ovn_cluster_northd_ssl_ca_cert\\\": {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, \\\"tripleo_ovn_cluster_sb_ssl_ca_cert\\\": {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, \\\"tripleo_ovn_cluster_nb_ssl_ca_cert\\\": {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}}}]}]}, {\\\"name\\\": \\\"Start OVN DBs and northd containers (bootstrap node)\\\", \\\"when\\\": [\\\"step|int == 3\\\", \\\"is_ovn_dbs_bootstrap_node | bool\\\"], \\\"block\\\": [{\\\"block\\\": [{\\\"name\\\": \\\"Start OVN container\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_manage\\\"}, \\\"vars\\\": {\\\"tripleo_container_manage_config\\\": \\\"/var/lib/tripleo-config/container-startup-config/step_0\\\", \\\"tripleo_container_manage_config_id\\\": \\\"{{ ovn_container }}\\\", \\\"tripleo_container_manage_config_patterns\\\": \\\"{{ ovn_container }}.json\\\"}, \\\"loop\\\": [\\\"ovn_cluster_north_db_server\\\", \\\"ovn_cluster_south_db_server\\\", \\\"ovn_cluster_northd\\\"], \\\"loop_control\\\": {\\\"loop_var\\\": \\\"ovn_container\\\"}}]}, {\\\"name\\\": \\\"Set NB connection\\\", \\\"become\\\": true, \\\"shell\\\": \\\"podman exec ovn_cluster_north_db_server bash -c \\\\\\\"ovn-nbctl --no-leader-only --inactivity-probe={{ tripleo_ovn_cluster_probe_interval }} set-connection p{{ tripleo_ovn_cluster_dbs_protocol }}:{{ tripleo_ovn_cluster_nb_db_port }}:{{ tripleo_ovn_cluster_dbs_addr }}\\\\\\\"\\\\n\\\", \\\"register\\\": \\\"nb_result\\\", \\\"retries\\\": 20, \\\"delay\\\": 5, \\\"until\\\": \\\"nb_result.rc == 0\\\", \\\"when\\\": [\\\"is_ovn_dbs_bootstrap_node | bool\\\"], \\\"vars\\\": {\\\"tripleo_ovn_cluster_network\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OvnDbsNetwork\\\"]}, \\\"tripleo_ovn_cluster_nb_db_port\\\": {\\\"get_param\\\": \\\"OVNNorthboundServerPort\\\"}, \\\"tripleo_ovn_cluster_dbs_protocol\\\": \\\"{{ enable_internal_tls | ternary(\'ssl\', \'tcp\', \'tcp\') }}\\\", \\\"tripleo_ovn_cluster_dbs_addr\\\": {\\\"if\\\": [\\\"is_ipv6\\\", \\\"[::]\\\", \\\"0.0.0.0\\\"]}, \\\"tripleo_ovn_cluster_probe_interval\\\": {\\\"get_param\\\": \\\"OVNOvsdbProbeInterval\\\"}}}, {\\\"name\\\": \\\"Set SB connection\\\", \\\"become\\\": true, \\\"shell\\\": \\\"podman exec ovn_cluster_south_db_server bash -c \\\\\\\"ovn-sbctl --no-leader-only --inactivity-probe={{ tripleo_ovn_cluster_probe_interval }} set-connection p{{ tripleo_ovn_cluster_dbs_protocol }}:{{ tripleo_ovn_cluster_sb_db_port }}:{{ tripleo_ovn_cluster_dbs_addr }}\\\\\\\"\\\\n\\\", \\\"register\\\": \\\"sb_result\\\", \\\"retries\\\": 20, \\\"delay\\\": 5, \\\"until\\\": \\\"sb_result.rc == 0\\\", \\\"when\\\": [\\\"is_ovn_dbs_bootstrap_node | bool\\\"], \\\"vars\\\": {\\\"tripleo_ovn_cluster_network\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OvnDbsNetwork\\\"]}, \\\"tripleo_ovn_cluster_sb_db_port\\\": {\\\"get_param\\\": \\\"OVNSouthboundServerPort\\\"}, \\\"tripleo_ovn_cluster_dbs_protocol\\\": \\\"{{ enable_internal_tls | ternary(\'ssl\', \'tcp\', \'tcp\') }}\\\", \\\"tripleo_ovn_cluster_dbs_addr\\\": {\\\"if\\\": [\\\"is_ipv6\\\", \\\"[::]\\\", \\\"0.0.0.0\\\"]}, \\\"tripleo_ovn_cluster_probe_interval\\\": {\\\"get_param\\\": \\\"OVNOvsdbProbeInterval\\\"}}}]}, {\\\"name\\\": \\\"Start OVN DBs and northd containers (non-bootstrap nodes)\\\", \\\"when\\\": [\\\"step|int == 4\\\", \\\"not is_ovn_dbs_bootstrap_node | bool\\\"], \\\"block\\\": [{\\\"block\\\": [{\\\"name\\\": \\\"Start OVN container\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_manage\\\"}, \\\"vars\\\": {\\\"tripleo_container_manage_config\\\": \\\"/var/lib/tripleo-config/container-startup-config/step_0\\\", \\\"tripleo_container_manage_config_id\\\": \\\"{{ ovn_container }}\\\", \\\"tripleo_container_manage_config_patterns\\\": \\\"{{ ovn_container }}.json\\\"}, \\\"loop\\\": [\\\"ovn_cluster_north_db_server\\\", \\\"ovn_cluster_south_db_server\\\", \\\"ovn_cluster_northd\\\"], \\\"loop_control\\\": {\\\"loop_var\\\": \\\"ovn_container\\\"}}]}, {\\\"name\\\": \\\"Set NB connection\\\", \\\"become\\\": true, \\\"shell\\\": \\\"podman exec ovn_cluster_north_db_server bash -c \\\\\\\"ovn-nbctl --no-leader-only --inactivity-probe={{ tripleo_ovn_cluster_probe_interval }} set-connection p{{ tripleo_ovn_cluster_dbs_protocol }}:{{ tripleo_ovn_cluster_nb_db_port }}:{{ tripleo_ovn_cluster_dbs_addr }}\\\\\\\"\\\\n\\\", \\\"register\\\": \\\"nb_result\\\", \\\"retries\\\": 20, \\\"delay\\\": 5, \\\"until\\\": \\\"nb_result.rc == 0\\\", \\\"when\\\": [\\\"is_ovn_dbs_bootstrap_node | bool\\\"], \\\"vars\\\": {\\\"tripleo_ovn_cluster_network\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OvnDbsNetwork\\\"]}, \\\"tripleo_ovn_cluster_nb_db_port\\\": {\\\"get_param\\\": \\\"OVNNorthboundServerPort\\\"}, \\\"tripleo_ovn_cluster_dbs_protocol\\\": \\\"{{ enable_internal_tls | ternary(\'ssl\', \'tcp\', \'tcp\') }}\\\", \\\"tripleo_ovn_cluster_dbs_addr\\\": {\\\"if\\\": [\\\"is_ipv6\\\", \\\"[::]\\\", \\\"0.0.0.0\\\"]}, \\\"tripleo_ovn_cluster_probe_interval\\\": {\\\"get_param\\\": \\\"OVNOvsdbProbeInterval\\\"}}}, {\\\"name\\\": \\\"Set SB connection\\\", \\\"become\\\": true, \\\"shell\\\": \\\"podman exec ovn_cluster_south_db_server bash -c \\\\\\\"ovn-sbctl --no-leader-only --inactivity-probe={{ tripleo_ovn_cluster_probe_interval }} set-connection p{{ tripleo_ovn_cluster_dbs_protocol }}:{{ tripleo_ovn_cluster_sb_db_port }}:{{ tripleo_ovn_cluster_dbs_addr }}\\\\\\\"\\\\n\\\", \\\"register\\\": \\\"sb_result\\\", \\\"retries\\\": 20, \\\"delay\\\": 5, \\\"until\\\": \\\"sb_result.rc == 0\\\", \\\"when\\\": [\\\"is_ovn_dbs_bootstrap_node | bool\\\"], \\\"vars\\\": {\\\"tripleo_ovn_cluster_network\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OvnDbsNetwork\\\"]}, \\\"tripleo_ovn_cluster_sb_db_port\\\": {\\\"get_param\\\": \\\"OVNSouthboundServerPort\\\"}, \\\"tripleo_ovn_cluster_dbs_protocol\\\": \\\"{{ enable_internal_tls | ternary(\'ssl\', \'tcp\', \'tcp\') }}\\\", \\\"tripleo_ovn_cluster_dbs_addr\\\": {\\\"if\\\": [\\\"is_ipv6\\\", \\\"[::]\\\", \\\"0.0.0.0\\\"]}, \\\"tripleo_ovn_cluster_probe_interval\\\": {\\\"get_param\\\": \\\"OVNOvsdbProbeInterval\\\"}}}]}], \\\"external_update_tasks\\\": [{\\\"name\\\": \\\"Run ovndbs update\\\", \\\"tags\\\": [\\\"ovn\\\", \\\"ovn_image\\\"], \\\"when\\\": \\\"step|int == 2\\\", \\\"block\\\": [{\\\"name\\\": \\\"Get OVN_Northbound cluster leader\\\", \\\"become\\\": true, \\\"shell\\\": \\\"podman exec -u root ovn_cluster_north_db_server ovs-appctl -t /var/run/ovn/ovnnb_db.ctl cluster/status OVN_Northbound | grep \'Leader: \'\\\\n\\\", \\\"register\\\": \\\"ovn_nb_dbs_cluster_leader\\\", \\\"loop\\\": \\\"{{groups[\'ovn_dbs\'] | difference(groups[\'excluded_overcloud\']) }}\\\", \\\"delegate_to\\\": \\\"{{ item }}\\\"}, {\\\"set_fact\\\": {\\\"ovn_nb_leader\\\": \\\"{{ ovn_nb_dbs_cluster_leader| json_query(\\\\\\\"results[?contains(stdout,\'Leader: self\')].item\\\\\\\") }}\\\"}}, {\\\"name\\\": \\\"Graceful stop OVN NB leader container\\\", \\\"delegate_to\\\": \\\"{{ ovn_nb_leader[0] }}\\\", \\\"become\\\": true, \\\"shell\\\": \\\"podman exec -u root ovn_cluster_north_db_server ovs-appctl -t /var/run/ovn/ovnnb_db.ctl exit\\\\n\\\"}, {\\\"name\\\": \\\"Start OVN NB leader container\\\", \\\"delegate_to\\\": \\\"{{ ovn_nb_leader[0] }}\\\", \\\"become\\\": true, \\\"tripleo_container_manage\\\": {\\\"config_dir\\\": \\\"/var/lib/tripleo-config/container-startup-config/step_0\\\", \\\"config_id\\\": [\\\"ovn_cluster_north_db_server\\\"], \\\"config_patterns\\\": \\\"*ovn_cluster_north_db_server.json\\\", \\\"config_overrides\\\": {\\\".*ovn_cluster_north_db_server\\\": {\\\"image\\\": {\\\"get_param\\\": \\\"ContainerOvnNbDbImage\\\"}, \\\"name\\\": \\\"ovn_cluster_north_db_server\\\"}}}}, {\\\"name\\\": \\\"Get OVN_Southbound cluster leader\\\", \\\"become\\\": true, \\\"shell\\\": \\\"sudo podman exec -u root ovn_cluster_south_db_server ovs-appctl -t /var/run/ovn/ovnsb_db.ctl cluster/status OVN_Southbound | grep \'Leader: \'\\\\n\\\", \\\"register\\\": \\\"ovn_sb_dbs_cluster_leader\\\", \\\"loop\\\": \\\"{{groups[\'ovn_dbs\'] | difference(groups[\'excluded_overcloud\']) }}\\\", \\\"delegate_to\\\": \\\"{{ item }}\\\"}, {\\\"set_fact\\\": {\\\"ovn_sb_leader\\\": \\\"{{ ovn_sb_dbs_cluster_leader | json_query(\\\\\\\"results[?contains(stdout,\'Leader: self\')].item\\\\\\\") }}\\\"}}, {\\\"name\\\": \\\"Graceful stop OVN SB leader container\\\", \\\"delegate_to\\\": \\\"{{ ovn_sb_leader[0] }}\\\", \\\"become\\\": true, \\\"shell\\\": \\\"sudo podman exec -u root ovn_cluster_south_db_server ovs-appctl -t /var/run/ovn/ovnsb_db.ctl exit\\\\n\\\"}, {\\\"name\\\": \\\"Start OVN SB leader container\\\", \\\"delegate_to\\\": \\\"{{ ovn_sb_leader[0] }}\\\", \\\"become\\\": true, \\\"tripleo_container_manage\\\": {\\\"config_dir\\\": \\\"/var/lib/tripleo-config/container-startup-config/step_0\\\", \\\"config_id\\\": [\\\"ovn_cluster_south_db_server\\\"], \\\"config_patterns\\\": \\\"*ovn_cluster_south_db_server.json\\\", \\\"config_overrides\\\": {\\\".*ovn_cluster_south_db_server\\\": {\\\"image\\\": {\\\"get_param\\\": \\\"ContainerOvnSbDbImage\\\"}, \\\"name\\\": \\\"ovn_cluster_south_db_server\\\"}}}}, {\\\"name\\\": \\\"Loop on OVN_Northbound cluster for leader election\\\", \\\"become\\\": true, \\\"shell\\\": \\\"podman exec -u root ovn_cluster_north_db_server ovs-appctl -t /var/run/ovn/ovnnb_db.ctl cluster/status OVN_Northbound | grep \'Leader: \'\\\\n\\\", \\\"register\\\": \\\"wait_leader\\\", \\\"delegate_to\\\": \\\"{{ groups[\'ovn_dbs\'] | difference(groups[\'excluded_overcloud\']) |  difference(ovn_nb_leader[0]) | first }}\\\", \\\"failed_when\\\": \\\"\'Leader: unknown\' in wait_leader.stdout or wait_leader.stderr != \'\'\\\", \\\"until\\\": \\\"\'Leader: unknown\' not in wait_leader.stdout and wait_leader.stderr == \'\'\\\", \\\"retries\\\": 10, \\\"delay\\\": 5}, {\\\"name\\\": \\\"Loop on OVN_Southbound cluster for leader election\\\", \\\"become\\\": true, \\\"shell\\\": \\\"podman exec -u root ovn_cluster_south_db_server ovs-appctl -t /var/run/ovn/ovnsb_db.ctl cluster/status OVN_Southbound | grep \'Leader: \'\\\\n\\\", \\\"register\\\": \\\"wait_leader\\\", \\\"delegate_to\\\": \\\"{{ groups[\'ovn_dbs\'] | difference(groups[\'excluded_overcloud\']) |  difference(ovn_nb_leader[0]) | first }}\\\", \\\"failed_when\\\": \\\"\'Leader: unknown\' in wait_leader.stdout or wait_leader.stderr != \'\'\\\", \\\"until\\\": \\\"\'Leader: unknown\' not in wait_leader.stdout and wait_leader.stderr == \'\'\\\", \\\"retries\\\": 10, \\\"delay\\\": 5}, {\\\"name\\\": \\\"Pause for 30 seconds to ensure ovn db leader knows it was elected and clients reconnect\\\", \\\"wait_for\\\": {\\\"timeout\\\": 30}}, {\\\"name\\\": \\\"Get OVN_Northbound cluster new leader\\\", \\\"become\\\": true, \\\"shell\\\": \\\"podman exec -u root ovn_cluster_north_db_server ovs-appctl -t /var/run/ovn/ovnnb_db.ctl cluster/status OVN_Northbound | grep \'Leader: \'\\\\n\\\", \\\"register\\\": \\\"ovn_nb_dbs_cluster_leader_new\\\", \\\"loop\\\": \\\"{{groups[\'ovn_dbs\'] | difference(groups[\'excluded_overcloud\']) }}\\\", \\\"until\\\": \\\"\'Leader: unknown\' not in ovn_nb_dbs_cluster_leader_new.stdout\\\", \\\"retries\\\": 10, \\\"delay\\\": 5, \\\"delegate_to\\\": \\\"{{ item }}\\\"}, {\\\"set_fact\\\": {\\\"ovn_nb_leader_new\\\": \\\"{{ ovn_nb_dbs_cluster_leader_new| json_query(\\\\\\\"results[?contains(stdout,\'Leader: self\')].item\\\\\\\") }}\\\"}}, {\\\"name\\\": \\\"Get OVN_Southbound cluster new leader\\\", \\\"become\\\": true, \\\"shell\\\": \\\"sudo podman exec -u root ovn_cluster_south_db_server ovs-appctl -t /var/run/ovn/ovnsb_db.ctl cluster/status OVN_Southbound | grep \'Leader: \'\\\\n\\\", \\\"register\\\": \\\"ovn_sb_dbs_cluster_leader_new\\\", \\\"loop\\\": \\\"{{groups[\'ovn_dbs\'] | difference(groups[\'excluded_overcloud\']) }}\\\", \\\"until\\\": \\\"\'Leader: unknown\' not in ovn_sb_dbs_cluster_leader_new.stdout\\\", \\\"retries\\\": 10, \\\"delay\\\": 5, \\\"delegate_to\\\": \\\"{{ item }}\\\"}, {\\\"set_fact\\\": {\\\"ovn_sb_leader_new\\\": \\\"{{ ovn_sb_dbs_cluster_leader_new | json_query(\\\\\\\"results[?contains(stdout,\'Leader: self\')].item\\\\\\\") }}\\\"}}, {\\\"name\\\": \\\"Start OVN NB containers (non-leader nodes)\\\", \\\"delegate_to\\\": \\\"{{ item }}\\\", \\\"become\\\": true, \\\"tripleo_container_manage\\\": {\\\"config_dir\\\": \\\"/var/lib/tripleo-config/container-startup-config/step_0\\\", \\\"config_id\\\": [\\\"ovn_cluster_north_db_server\\\"], \\\"config_patterns\\\": \\\"*ovn_cluster_north_db_server.json\\\", \\\"config_overrides\\\": {\\\".*ovn_cluster_north_db_server\\\": {\\\"image\\\": {\\\"get_param\\\": \\\"ContainerOvnNbDbImage\\\"}, \\\"name\\\": \\\"ovn_cluster_north_db_server\\\"}}}, \\\"loop\\\": \\\"{{groups[\'ovn_dbs\'] | difference(groups[\'excluded_overcloud\']) | difference(ovn_nb_leader[0])| difference(ovn_nb_leader_new[0])}}\\\", \\\"loop_control\\\": {\\\"pause\\\": 15}}, {\\\"name\\\": \\\"Start OVN SB containers (non-leader nodes)\\\", \\\"delegate_to\\\": \\\"{{ item }}\\\", \\\"become\\\": true, \\\"tripleo_container_manage\\\": {\\\"config_dir\\\": \\\"/var/lib/tripleo-config/container-startup-config/step_0\\\", \\\"config_id\\\": [\\\"ovn_cluster_south_db_server\\\"], \\\"config_patterns\\\": \\\"*ovn_cluster_south_db_server.json\\\", \\\"config_overrides\\\": {\\\".*ovn_cluster_south_db_server\\\": {\\\"image\\\": {\\\"get_param\\\": \\\"ContainerOvnSbDbImage\\\"}, \\\"name\\\": \\\"ovn_cluster_south_db_server\\\"}}}, \\\"loop\\\": \\\"{{groups[\'ovn_dbs\'] | difference(groups[\'excluded_overcloud\']) | difference(ovn_sb_leader[0])| difference(ovn_sb_leader_new[0])}}\\\", \\\"loop_control\\\": {\\\"pause\\\": 15}}, {\\\"name\\\": \\\"Pause for 50 seconds before restarting new leaders of OVN\\\", \\\"wait_for\\\": {\\\"timeout\\\": 50}}, {\\\"name\\\": \\\"Graceful stop OVN NB new-leader container\\\", \\\"delegate_to\\\": \\\"{{ ovn_nb_leader_new[0] }}\\\", \\\"become\\\": true, \\\"shell\\\": \\\"podman exec -u root ovn_cluster_north_db_server ovs-appctl -t /var/run/ovn/ovnnb_db.ctl exit\\\\n\\\", \\\"when\\\": \\\"ovn_nb_leader_new[0] != ovn_nb_leader[0]\\\"}, {\\\"name\\\": \\\"Start OVN NB containers (new-leader nodes)\\\", \\\"delegate_to\\\": \\\"{{ ovn_nb_leader_new[0] }}\\\", \\\"become\\\": true, \\\"tripleo_container_manage\\\": {\\\"config_dir\\\": \\\"/var/lib/tripleo-config/container-startup-config/step_0\\\", \\\"config_id\\\": [\\\"ovn_cluster_north_db_server\\\"], \\\"config_patterns\\\": \\\"*ovn_cluster_north_db_server.json\\\", \\\"config_overrides\\\": {\\\".*ovn_cluster_north_db_server\\\": {\\\"image\\\": {\\\"get_param\\\": \\\"ContainerOvnNbDbImage\\\"}, \\\"name\\\": \\\"ovn_cluster_north_db_server\\\"}}}, \\\"when\\\": \\\"ovn_nb_leader_new[0] != ovn_nb_leader[0]\\\"}, {\\\"name\\\": \\\"Graceful stop OVN SB new-leader container\\\", \\\"delegate_to\\\": \\\"{{ ovn_sb_leader_new[0] }}\\\", \\\"become\\\": true, \\\"shell\\\": \\\"sudo podman exec -u root ovn_cluster_south_db_server ovs-appctl -t /var/run/ovn/ovnsb_db.ctl exit\\\\n\\\", \\\"when\\\": \\\"ovn_sb_leader_new[0] != ovn_sb_leader[0]\\\"}, {\\\"name\\\": \\\"Start OVN SB containers (new-leader nodes)\\\", \\\"delegate_to\\\": \\\"{{ ovn_sb_leader_new[0] }}\\\", \\\"become\\\": true, \\\"tripleo_container_manage\\\": {\\\"config_dir\\\": \\\"/var/lib/tripleo-config/container-startup-config/step_0\\\", \\\"config_id\\\": [\\\"ovn_cluster_south_db_server\\\"], \\\"config_patterns\\\": \\\"*ovn_cluster_south_db_server.json\\\", \\\"config_overrides\\\": {\\\".*ovn_cluster_south_db_server\\\": {\\\"image\\\": {\\\"get_param\\\": \\\"ContainerOvnSbDbImage\\\"}, \\\"name\\\": \\\"ovn_cluster_south_db_server\\\"}}}, \\\"when\\\": \\\"ovn_sb_leader_new[0] != ovn_sb_leader[0]\\\"}, {\\\"name\\\": \\\"Start OVN northd container\\\", \\\"delegate_to\\\": \\\"{{ item }}\\\", \\\"become\\\": true, \\\"tripleo_container_manage\\\": {\\\"config_dir\\\": \\\"/var/lib/tripleo-config/container-startup-config/step_0\\\", \\\"config_id\\\": [\\\"ovn_cluster_northd\\\"], \\\"config_patterns\\\": \\\"*ovn_cluster_northd.json\\\", \\\"config_overrides\\\": {\\\".*ovn_cluster_northd\\\": {\\\"image\\\": {\\\"get_param\\\": \\\"ContainerOvnNorthdImage\\\"}, \\\"name\\\": \\\"ovn_cluster_northd\\\"}}}, \\\"loop\\\": \\\"{{groups[\'ovn_dbs\'] | difference(groups[\'excluded_overcloud\'])}}\\\", \\\"loop_control\\\": {\\\"pause\\\": 15}}]}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"Configure OVN cluster during update\\\", \\\"when\\\": \\\"step|int == 4\\\", \\\"block\\\": [{\\\"name\\\": \\\"Configure OVN DBs and northd\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_ovn_cluster\\\"}, \\\"vars\\\": {\\\"tripleo_ovn_cluster_dbs_protocol\\\": \\\"{{ enable_internal_tls | ternary(\'ssl\', \'tcp\', \'tcp\') }}\\\", \\\"tripleo_ovn_cluster_network\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OvnDbsNetwork\\\"]}, \\\"tripleo_ovn_cluster_nb_db_port\\\": {\\\"get_param\\\": \\\"OVNNorthboundServerPort\\\"}, \\\"tripleo_ovn_cluster_sb_db_port\\\": {\\\"get_param\\\": \\\"OVNSouthboundServerPort\\\"}, \\\"tripleo_ovn_cluster_nb_local_port\\\": {\\\"get_param\\\": \\\"OVNNorthboundClusterPort\\\"}, \\\"tripleo_ovn_cluster_nb_remote_port\\\": {\\\"get_param\\\": \\\"OVNNorthboundClusterPort\\\"}, \\\"tripleo_ovn_cluster_sb_local_port\\\": {\\\"get_param\\\": \\\"OVNSouthboundClusterPort\\\"}, \\\"tripleo_ovn_cluster_sb_remote_port\\\": {\\\"get_param\\\": \\\"OVNSouthboundClusterPort\\\"}, \\\"tripleo_ovn_cluster_northd_ssl_ca_cert\\\": {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, \\\"tripleo_ovn_cluster_sb_ssl_ca_cert\\\": {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, \\\"tripleo_ovn_cluster_nb_ssl_ca_cert\\\": {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}}}]}, {\\\"name\\\": \\\"Update OVN cluster containers\\\", \\\"when\\\": \\\"step|int == 4\\\", \\\"block\\\": [{\\\"name\\\": \\\"Start OVN container\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_manage\\\"}, \\\"vars\\\": {\\\"tripleo_container_manage_config\\\": \\\"/var/lib/tripleo-config/container-startup-config/step_0\\\", \\\"tripleo_container_manage_config_id\\\": \\\"{{ ovn_container }}\\\", \\\"tripleo_container_manage_config_patterns\\\": \\\"{{ ovn_container }}.json\\\"}, \\\"loop\\\": [\\\"ovn_cluster_north_db_server\\\", \\\"ovn_cluster_south_db_server\\\", \\\"ovn_cluster_northd\\\"], \\\"loop_control\\\": {\\\"loop_var\\\": \\\"ovn_container\\\"}}]}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-cleanup\": \"#!/usr/bin/bash\\n# Cleanup neutron OVS bridges. To be called on startup to avoid\\n# \\\"difficult-to-debug\\\" issues with partially configured resources.\\n\\nNEUTRON_OVS_CONF=/var/lib/config-data/puppet-generated/neutron/etc/neutron/plugins/ml2/openvswitch_agent.ini\\n\\nif [ -e ${NEUTRON_OVS_CONF} ];\\nthen\\n    INT_BRIDGE=`crudini --get ${NEUTRON_OVS_CONF} ovs integration_bridge`\\n    TUN_BRIDGE=`crudini --get ${NEUTRON_OVS_CONF} ovs tunnel_bridge`\\nfi\\n\\nfor port in `ovs-vsctl list-ports ${INT_BRIDGE:-\\\"br-int\\\"}`;\\ndo\\n    skip_cleanup=`ovs-vsctl --if-exists get Interface $port external_ids:skip_cleanup`\\n    if ! [[ \\\"x$skip_cleanup\\\" == \\\"x\\\\\\\"true\\\\\\\"\\\" ]];\\n    then\\n        ovs-vsctl del-port ${INT_BRIDGE:-\\\"br-int\\\"} $port\\n    fi\\ndone\\n\\novs-vsctl --if-exists del-br ${TUN_BRIDGE:-\\\"br-tun\\\"}\\n\\n# Clean up trunk port bridges\\nfor br in $(ovs-vsctl list-br | egrep \'tbr-[0-9a-f\\\\-]+\'); do\\n    ovs-vsctl --if-exists del-br $br\\ndone\\n\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-cleanup.service\": \"[Unit]\\nDescription=Neutron cleanup on startup\\nAfter=openvswitch.service network.target\\nBefore=tripleo_neutron_ovs_agent.service tripleo_neutron_dhcp.service tripleo_neutron_l3_agent.service tripleo_nova_compute.service\\nRefuseManualStop=yes\\n\\n[Service]\\nType=oneshot\\nExecStart=/usr/libexec/neutron-cleanup\\n\\n[Install]\\nWantedBy=multi-user.target\\n\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Ovn Controller agent.\\\\n\\\", \\\"parameters\\\": {\\\"RootStackName\\\": {\\\"description\\\": \\\"The name of the stack/plan.\\\", \\\"type\\\": \\\"string\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ContainerOvnControllerImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerOvnControllerConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the ovn_controller config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"DeployIdentifier\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\\\n\\\"}, \\\"OVNSouthboundServerPort\\\": {\\\"description\\\": \\\"Port of the Southbound DB Server\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 6642}, \\\"NeutronBridgeMappings\\\": {\\\"description\\\": \\\"The OVS logical->physical bridge mappings to use. See the Neutron documentation for details. Defaults to mapping br-ex - the external bridge on hosts - to a physical name \'datacentre\' which can be used to create provider networks (and we use this for the default floating network) - if changing this either use different post-install network scripts or be sure to keep \'datacentre\' as a mapping network name.\\\\n\\\", \\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": \\\"datacentre:br-ex\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"EnableVLANTransparency\\\": {\\\"default\\\": false, \\\"description\\\": \\\"If True, then allow plugins that support it to create VLAN transparent networks.\\\\n\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"OVNEncapType\\\": {\\\"description\\\": \\\"Type of encapsulation used in OVN. It can be \\\\\\\"geneve\\\\\\\" or \\\\\\\"vxlan\\\\\\\".\\\\n\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"geneve\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"geneve\\\", \\\"vxlan\\\"]}]}, \\\"OVNIntegrationBridge\\\": {\\\"description\\\": \\\"Name of the OVS bridge to use as integration bridge by OVN Controller.\\\\n\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"br-int\\\"}, \\\"OVNMetadataEnabled\\\": {\\\"description\\\": \\\"Whether Metadata Service has to be enabled\\\", \\\"type\\\": \\\"boolean\\\", \\\"default\\\": true}, \\\"OVNAvailabilityZone\\\": {\\\"description\\\": \\\"The az options to configure in ovs db. eg. [\'az-0\', \'az-1\', \'az-2\']\\\", \\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": [], \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"OVNCMSOptions\\\": {\\\"description\\\": \\\"The CMS options to configure in ovs db\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"OVNEncapTos\\\": {\\\"description\\\": \\\"The value to be applied to OVN tunnel interface\'s option:tos as specified in the Open_vSwitch database Interface table. This feature is supported from OVN v21.12.0.\\\\n\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"0\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"OvsHwOffload\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Enable OVS Hardware Offload. This feature supported from OVS 2.8.0\\\\n\\\", \\\"type\\\": \\\"boolean\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"OVNRemoteProbeInterval\\\": {\\\"description\\\": \\\"Probe interval in ms\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 60000}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"InternalTLSCAFile\\\": {\\\"default\\\": \\\"/etc/ipa/ca.crt\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Specifies the default CA cert to use if TLS is used for services in the internal network.\\\"}, \\\"OVNOpenflowProbeInterval\\\": {\\\"description\\\": \\\"The inactivity probe interval of the OpenFlow connection to the OpenvSwitch integration bridge, in seconds.\\\\n\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 60}, \\\"OVNOfctrlWaitBeforeClear\\\": {\\\"description\\\": \\\"Sets the time ovn-controller will wait on startup before clearing all openflow rules and installing the new ones, in ms.\\\\n\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 8000}, \\\"CertificateKeySize\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"2048\\\", \\\"description\\\": \\\"Specifies the private key size used when creating the certificate.\\\"}, \\\"ContainerOvnCertificateKeySize\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Override the private key size used when creating the certificate for this service\\\"}, \\\"OVNContainerCpusetCpus\\\": {\\\"description\\\": \\\"Limit the specific CPUs or cores a container can use. It can be specified as a single core (ex. 0), as a comma-separated list (ex. 0,1), as a range (ex. 0-3) or a combination if previous methods (ex 0-3,7,11-15).  The selected cores should be isolated from guests and hypervisor in order to obtain best possible performance.\\\\n\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"OVNStaticBridgeMacMappings\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {}, \\\"description\\\": \\\"Static OVN Bridge MAC address mappings. Unique OVN bridge mac addresses\\\\nis dynamically allocated by creating neutron ports. When neutron isn\'t\\\\navailable, for instance in the standalone deployment, use this parameter\\\\nto provide static OVN bridge mac addresses. For example:\\\\n   controller-0:\\\\n     datacenter: 00:00:5E:00:53:00\\\\n     provider: 00:00:5E:00:53:01\\\\n   compute-0:\\\\n     datacenter: 00:00:5E:00:54:00\\\\n     provider: 00:00:5E:00:54:01\\\\n\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"AuthCloudName\\\": {\\\"description\\\": \\\"Entry in clouds.yaml to use for authentication\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\"}, \\\"OVNControllerImageUpdateTimeout\\\": {\\\"description\\\": \\\"During update, how long we wait for the container image to be updated, in seconds.\\\\n\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 600}, \\\"OVNControllerUpdateTimeout\\\": {\\\"description\\\": \\\"During update, how long we wait for the container to be updated, in seconds.\\\\n\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 600}, \\\"OVNControllerGarpMaxTimeout\\\": {\\\"description\\\": \\\"When used, this configuration value specifies the maximum timeout (in seconds) between two consecutive GARP packets sent by ovn-controller.\\\\n\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 0}}, \\\"conditions\\\": {\\\"force_config_drive\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"OVNMetadataEnabled\\\"}, false]}, \\\"internal_tls_enabled\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, true]}, \\\"key_size_override_unset\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"ContainerOvnCertificateKeySize\\\"}, \\\"\\\"]}, \\\"enable_vlan_transparency\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"EnableVLANTransparency\\\"}, true]}, \\\"auth_cloud_name_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"AuthCloudName\\\"}, \\\"\\\"]}}, \\\"ovn_cpu_set\\\": {\\\"or\\\": [{\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"OVNContainerCpusetCpus\\\"}, \\\"\\\"]}}, {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"OVNContainerCpusetCpus\\\"]}, \\\"\\\"]}}]}, \\\"key_size_override_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"ContainerOvnCertificateKeySize\\\"}, \\\"\\\"]}}, \\\"az_ovn_unset\\\": {\\\"and\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"OVNAvailabilityZone\\\"}, []]}, {\\\"equals\\\": [{\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"OVNAvailabilityZone\\\"]}, \\\"\\\"]}]}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ovn::controller::ovn_bridge_mappings\\\": \\\"NeutronBridgeMappings\\\", \\\"ovn::controller::ovn_cms_options\\\": {\\\"if\\\": [\\\"az_ovn_unset\\\", \\\"OVNCMSOptions\\\", \\\"OVNCMSOptionsMerged\\\"]}, \\\"ovn::controller::ovn_encap_tos\\\": \\\"OVNEncapTos\\\", \\\"vswitch::ovs::enable_hw_offload\\\": \\\"OvsHwOffload\\\", \\\"container_cpuset_cpus\\\": \\\"OVNContainerCpusetCpus\\\", \\\"ContainerOvnControllerImage\\\": \\\"ContainerOvnControllerImage\\\", \\\"ContainerOvnControllerConfigImage\\\": \\\"ContainerOvnControllerConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"NeutronBridgeMappings\\\": {\\\"get_param\\\": \\\"NeutronBridgeMappings\\\"}, \\\"OVNCMSOptions\\\": {\\\"get_param\\\": \\\"OVNCMSOptions\\\"}, \\\"OVNCMSOptionsMerged\\\": {\\\"list_join\\\": [\\\"\\\", [{\\\"str_replace\\\": {\\\"template\\\": \\\"$OVNCMSOptions\\\", \\\"params\\\": {\\\"if\\\": [{\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"OVNCMSOptions\\\"]}, \\\"\\\"]}}, {\\\"$OVNCMSOptions\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"OVNCMSOptions\\\"]}}, {\\\"$OVNCMSOptions\\\": {\\\"get_param\\\": \\\"OVNCMSOptions\\\"}}]}}}, {\\\"str_replace\\\": {\\\"template\\\": \\\",availability-zones=$OVNAvailabilityZone\\\", \\\"params\\\": {\\\"if\\\": [{\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"OVNAvailabilityZone\\\"]}, \\\"\\\"]}}, {\\\"$OVNAvailabilityZone\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"OVNAvailabilityZone\\\"]}}, {\\\"$OVNAvailabilityZone\\\": {\\\"list_join\\\": [\\\",\\\", {\\\"get_param\\\": \\\"OVNAvailabilityZone\\\"}]}}]}}}]]}, \\\"OVNEncapTos\\\": {\\\"get_param\\\": \\\"OVNEncapTos\\\"}, \\\"OvsHwOffload\\\": {\\\"get_param\\\": \\\"OvsHwOffload\\\"}, \\\"OVNContainerCpusetCpus\\\": {\\\"get_param\\\": \\\"OVNContainerCpusetCpus\\\"}, \\\"ContainerOvnControllerImage\\\": {\\\"get_param\\\": \\\"ContainerOvnControllerImage\\\"}, \\\"ContainerOvnControllerConfigImage\\\": {\\\"get_param\\\": \\\"ContainerOvnControllerConfigImage\\\"}}}]}}}, \\\"OVNBridgeMappingsValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ovn_bridge_mappings\\\": \\\"NeutronBridgeMappings\\\", \\\"ovn_static_bridge_mac_mappings\\\": \\\"OVNStaticBridgeMacMappings\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"NeutronBridgeMappings\\\": {\\\"get_param\\\": \\\"NeutronBridgeMappings\\\"}, \\\"OVNStaticBridgeMacMappings\\\": {\\\"get_param\\\": \\\"OVNStaticBridgeMacMappings\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Ovn Controller agent.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"ovn_controller\\\", \\\"firewall_rules\\\": {\\\"118 neutron vxlan networks\\\": {\\\"proto\\\": \\\"udp\\\", \\\"dport\\\": 4789, \\\"state\\\": []}, \\\"119 neutron geneve networks\\\": {\\\"proto\\\": \\\"udp\\\", \\\"dport\\\": 6081, \\\"state\\\": []}, \\\"120 neutron geneve networks no conntrack\\\": {\\\"proto\\\": \\\"udp\\\", \\\"dport\\\": 6081, \\\"table\\\": \\\"raw\\\", \\\"chain\\\": \\\"OUTPUT\\\", \\\"jump\\\": \\\"NOTRACK\\\", \\\"action\\\": \\\"append\\\", \\\"state\\\": [\\\"INVALID\\\"]}, \\\"121 neutron geneve networks no conntrack\\\": {\\\"proto\\\": \\\"udp\\\", \\\"dport\\\": 6081, \\\"table\\\": \\\"raw\\\", \\\"chain\\\": \\\"PREROUTING\\\", \\\"jump\\\": \\\"NOTRACK\\\", \\\"action\\\": \\\"append\\\", \\\"state\\\": [\\\"INVALID\\\"]}}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\"]}, {\\\"ovn::southbound::port\\\": {\\\"get_param\\\": \\\"OVNSouthboundServerPort\\\"}, \\\"ovn::controller::ovn_encap_ip\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NeutronTenantNetwork\\\"]}}}}, \\\"ovn::controller::ovn_encap_type\\\": {\\\"get_param\\\": \\\"OVNEncapType\\\"}, \\\"ovn::controller::ovn_bridge\\\": {\\\"get_param\\\": \\\"OVNIntegrationBridge\\\"}, \\\"ovn::controller::hostname\\\": \\\"%{hiera(\'fqdn_canonical\')}\\\", \\\"ovn::controller::ovn_remote_probe_interval\\\": {\\\"get_param\\\": \\\"OVNRemoteProbeInterval\\\"}, \\\"ovn::controller::ovn_openflow_probe_interval\\\": {\\\"get_param\\\": \\\"OVNOpenflowProbeInterval\\\"}, \\\"ovn::controller::ovn_ofctrl_wait_before_clear\\\": {\\\"get_param\\\": \\\"OVNOfctrlWaitBeforeClear\\\"}, \\\"ovn::controller::garp_max_timeout_sec\\\": {\\\"get_param\\\": \\\"OVNControllerGarpMaxTimeout\\\"}, \\\"ovn::controller::ovn_monitor_all\\\": true}, {\\\"if\\\": [\\\"force_config_drive\\\", {\\\"nova::compute::force_config_drive\\\": true}, {}]}, {\\\"if\\\": [\\\"internal_tls_enabled\\\", {\\\"tripleo::profile::base::neutron::agents::ovn::protocol\\\": \\\"ssl\\\"}, {}]}, {\\\"if\\\": [\\\"enable_vlan_transparency\\\", {\\\"vswitch::ovs::vlan_limit\\\": 0}, {}]}]}, \\\"service_config_settings\\\": {}, \\\"puppet_config\\\": {\\\"puppet_tags\\\": \\\"vs_config,exec\\\", \\\"config_volume\\\": \\\"ovn_controller\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::neutron::agents::ovn\\\\n\\\", \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerOvnControllerConfigImage\\\"]}, \\\"volumes\\\": [\\\"/lib/modules:/lib/modules:ro\\\", \\\"/run/openvswitch:/run/openvswitch:shared,z\\\", \\\"/etc/sysconfig/modules:/etc/sysconfig/modules\\\"]}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/ovn_controller.json\\\": {\\\"command\\\": {\\\"list_join\\\": [\\\" \\\", [\\\"/usr/bin/ovn-controller --pidfile --log-file unix:/run/openvswitch/db.sock\\\", {\\\"if\\\": [\\\"internal_tls_enabled\\\", {\\\"list_join\\\": [\\\" \\\", [\\\"-p /etc/pki/tls/private/ovn_controller.key -c /etc/pki/tls/certs/ovn_controller.crt -C\\\", {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}]]}, \\\"\\\"]}]]}, \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/openvswitch\\\", \\\"owner\\\": \\\"root:root\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/var/log/ovn\\\", \\\"owner\\\": \\\"root:root\\\", \\\"recurse\\\": true}]}}, \\\"metadata_settings\\\": {\\\"if\\\": [\\\"internal_tls_enabled\\\", [{\\\"service\\\": \\\"ovn_controller\\\", \\\"network\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OvnDbsNetwork\\\"]}, \\\"type\\\": \\\"node\\\"}], null]}, \\\"docker_config\\\": {\\\"step_4\\\": {\\\"configure_cms_options\\\": {\\\"start_order\\\": 0, \\\"detach\\\": false, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"user\\\": \\\"root\\\", \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"CMS_OPTS=$(hiera ovn::controller::ovn_cms_options -c /etc/puppet/hiera.yaml);  if [ X\\\\\\\"$CMS_OPTS\\\\\\\" !=  X ]; then ovs-vsctl set open . external_ids:ovn-cms-options=$CMS_OPTS;else ovs-vsctl remove open . external_ids ovn-cms-options; fi\\\"], \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerOvnControllerImage\\\"]}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/lib/modules:/lib/modules:ro\\\", \\\"/run/openvswitch:/run/openvswitch:shared,z\\\"]]}, \\\"environment\\\": {\\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}}}, \\\"ovn_controller\\\": {\\\"map_merge\\\": [{\\\"start_order\\\": 1, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerOvnControllerImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"user\\\": \\\"root\\\", \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": [\\\"openvswitch.service\\\"]}, {\\\"if\\\": [\\\"ovn_cpu_set\\\", {\\\"cpuset_cpus\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"container_cpuset_cpus\\\"]}}]}, {\\\"healthcheck\\\": {\\\"test\\\": {\\\"list_join\\\": [\\\" \\\", [\\\"/openstack/healthcheck\\\", {\\\"yaql\\\": {\\\"expression\\\": \\\"str($.data.port)\\\", \\\"data\\\": {\\\"port\\\": {\\\"get_param\\\": \\\"OVNSouthboundServerPort\\\"}}}}]]}}, \\\"volumes\\\": {\\\"list_concat\\\": [[\\\"/var/lib/kolla/config_files/ovn_controller.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/run:/run\\\", \\\"/var/lib/openvswitch/ovn:/run/ovn:shared,z\\\", \\\"/var/log/containers/openvswitch:/var/log/openvswitch:z\\\", \\\"/var/log/containers/openvswitch:/var/log/ovn:z\\\"], {\\\"if\\\": [\\\"internal_tls_enabled\\\", [{\\\"list_join\\\": [\\\":\\\", [{\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, \\\"ro\\\"]]}, \\\"/etc/pki/tls/certs/ovn_controller.crt:/etc/pki/tls/certs/ovn_controller.crt\\\", \\\"/etc/pki/tls/private/ovn_controller.key:/etc/pki/tls/private/ovn_controller.key\\\"], null]}]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}]}}}, \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Certificate generation\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"enable_internal_tls\\\"], \\\"block\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"linux-system-roles.certificate\\\"}, \\\"vars\\\": {\\\"certificate_requests\\\": [{\\\"name\\\": \\\"ovn_controller\\\", \\\"dns\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"{{fqdn_$NETWORK}}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OvnDbsNetwork\\\"]}}}}, \\\"principal\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"ovn_controller/{{fqdn_$NETWORK}}@{{idm_realm}}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OvnDbsNetwork\\\"]}}}}, \\\"run_after\\\": \\\"systemctl restart tripleo_ovn_controller\\\\n\\\", \\\"key_size\\\": {\\\"if\\\": [\\\"key_size_override_unset\\\", {\\\"get_param\\\": \\\"CertificateKeySize\\\"}, {\\\"get_param\\\": \\\"ContainerOvnCertificateKeySize\\\"}]}, \\\"ca\\\": \\\"ipa\\\"}]}}]}], \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode|default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/openvswitch\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/lib/openvswitch/ovn\\\", \\\"setype\\\": \\\"container_file_t\\\"}]}, {\\\"name\\\": \\\"enable virt_sandbox_use_netlink for healthcheck\\\", \\\"seboolean\\\": {\\\"name\\\": \\\"virt_sandbox_use_netlink\\\", \\\"persistent\\\": true, \\\"state\\\": true}, \\\"when\\\": [\\\"ansible_facts.selinux is defined\\\", \\\"ansible_facts.selinux.status == \\\\\\\"enabled\\\\\\\"\\\"]}, {\\\"name\\\": \\\"Copy in cleanup script\\\", \\\"copy\\\": {\\\"content\\\": {\\\"get_file\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-cleanup\\\"}, \\\"dest\\\": \\\"/usr/libexec/neutron-cleanup\\\", \\\"force\\\": true, \\\"mode\\\": \\\"0755\\\"}}, {\\\"name\\\": \\\"Copy in cleanup service\\\", \\\"copy\\\": {\\\"content\\\": {\\\"get_file\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-cleanup.service\\\"}, \\\"dest\\\": \\\"/usr/lib/systemd/system/neutron-cleanup.service\\\", \\\"force\\\": true}}, {\\\"name\\\": \\\"Enabling the cleanup service\\\", \\\"service\\\": {\\\"name\\\": \\\"neutron-cleanup\\\", \\\"enabled\\\": true}, \\\"when\\\": \\\"not (ansible_check_mode|bool)\\\"}], \\\"external_deploy_tasks\\\": [{\\\"when\\\": [\\\"step|int == 0\\\"], \\\"name\\\": \\\"ovn_controller_external_deploy_init\\\", \\\"block\\\": [{\\\"name\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"create ovn mac address for $ROLE_NAME role nodes\\\", \\\"params\\\": {\\\"$ROLE_NAME\\\": {\\\"get_param\\\": \\\"RoleName\\\"}}}}, \\\"tripleo_ovn_mac_addresses\\\": {\\\"playbook_dir\\\": \\\"{{ playbook_dir }}\\\", \\\"stack_name\\\": {\\\"get_param\\\": \\\"RootStackName\\\"}, \\\"role_name\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"server_resource_names\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"{{ groups[\\\\\\\"$ROLE_NAME\\\\\\\"] }}\\\", \\\"params\\\": {\\\"$ROLE_NAME\\\": {\\\"get_param\\\": \\\"RoleName\\\"}}}}, \\\"ovn_bridge_mappings\\\": {\\\"get_attr\\\": [\\\"OVNBridgeMappingsValue\\\", \\\"value\\\", \\\"ovn_bridge_mappings\\\"]}, \\\"ovn_static_bridge_mac_mappings\\\": {\\\"get_attr\\\": [\\\"OVNBridgeMappingsValue\\\", \\\"value\\\", \\\"ovn_static_bridge_mac_mappings\\\"]}}}]}], \\\"external_update_tasks\\\": [{\\\"name\\\": \\\"Force pull image in case image name doesn\'t change.\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": [\\\"ovn\\\", \\\"ovn_image\\\"], \\\"become\\\": true, \\\"loop\\\": \\\"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\\\", \\\"delegate_to\\\": \\\"{{ item }}\\\", \\\"async\\\": {\\\"get_param\\\": \\\"OVNControllerImageUpdateTimeout\\\"}, \\\"poll\\\": 0, \\\"register\\\": \\\"ovn_controller_image_update\\\", \\\"containers.podman.podman_image\\\": {\\\"name\\\": {\\\"get_param\\\": \\\"ContainerOvnControllerConfigImage\\\"}, \\\"validate_certs\\\": false, \\\"force\\\": true}}, {\\\"name\\\": \\\"Was the ovn_controller image pull successful.\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"\'results\' in ovn_controller_image_update\\\"], \\\"tags\\\": [\\\"ovn\\\", \\\"ovn_image\\\"], \\\"become\\\": true, \\\"delegate_to\\\": \\\"{{ async_result_item.item }}\\\", \\\"async_status\\\": {\\\"jid\\\": \\\"{{ async_result_item.ansible_job_id }}\\\"}, \\\"loop\\\": \\\"{{ovn_controller_image_update.results }}\\\", \\\"loop_control\\\": {\\\"loop_var\\\": \\\"async_result_item\\\"}, \\\"register\\\": \\\"async_poll_results\\\", \\\"until\\\": \\\"async_poll_results.finished\\\", \\\"retries\\\": {\\\"get_param\\\": \\\"OVNControllerImageUpdateTimeout\\\"}, \\\"delay\\\": 1}, {\\\"name\\\": \\\"OVN Container image used\\\", \\\"debug\\\": {\\\"msg\\\": \\\"ovn container will be using {{ image }}\\\"}, \\\"vars\\\": {\\\"image\\\": {\\\"get_param\\\": \\\"ContainerOvnControllerConfigImage\\\"}}, \\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": \\\"ovn\\\"}, {\\\"name\\\": \\\"Update OVN OVS related parameters before update.\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"ovn\\\"], \\\"become\\\": true, \\\"vars\\\": {\\\"timeout\\\": {\\\"get_param\\\": \\\"OVNOfctrlWaitBeforeClear\\\"}}, \\\"shell\\\": \\\"set -e\\\\novs-vsctl set Open_vSwitch . external_ids:ovn-ofctrl-wait-before-clear={{ timeout }}\\\\novs-vsctl set Open_vSwitch . external_ids:ovn-monitor-all=true\\\\novs-vsctl set Open_vSwitch . external_ids:ovn-match-northd-version=false\\\\n\\\", \\\"async\\\": {\\\"get_param\\\": \\\"OVNControllerUpdateTimeout\\\"}, \\\"poll\\\": 0, \\\"register\\\": \\\"ovs_vsctl\\\", \\\"loop\\\": \\\"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\\\", \\\"delegate_to\\\": \\\"{{ item }}\\\"}, {\\\"name\\\": \\\"Was the update of OVN OVS related parameter successful.\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"\'results\' in ovs_vsctl\\\"], \\\"become\\\": true, \\\"tags\\\": [\\\"ovn\\\"], \\\"delegate_to\\\": \\\"{{ async_result_item.item }}\\\", \\\"async_status\\\": {\\\"jid\\\": \\\"{{ async_result_item.ansible_job_id }}\\\"}, \\\"loop\\\": \\\"{{ovs_vsctl.results }}\\\", \\\"loop_control\\\": {\\\"loop_var\\\": \\\"async_result_item\\\"}, \\\"register\\\": \\\"async_poll_results\\\", \\\"until\\\": \\\"async_poll_results.finished\\\", \\\"retries\\\": {\\\"get_param\\\": \\\"OVNControllerUpdateTimeout\\\"}, \\\"delay\\\": 1}, {\\\"set_fact\\\": {\\\"any_ovn_host\\\": \\\"{{groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) | first }}\\\"}, \\\"tags\\\": \\\"ovn\\\", \\\"when\\\": \\\"step|int == 1\\\"}, {\\\"name\\\": \\\"Find ovn_controller configs in container-startup-configs\\\", \\\"find\\\": {\\\"paths\\\": \\\"/var/lib/tripleo-config/container-startup-config/\\\", \\\"patterns\\\": \\\"*ovn_controller.json\\\", \\\"recurse\\\": true}, \\\"register\\\": \\\"ovn_cont_17_0\\\", \\\"delegate_to\\\": \\\"{{ any_ovn_host }}\\\", \\\"when\\\": \\\"(step|int == 1) and (any_ovn_host is defined) and (any_ovn_host|length > 0)\\\", \\\"tags\\\": [\\\"ovn\\\"], \\\"become\\\": true}, {\\\"name\\\": \\\"get directory path from the ovn_cont_17_0\\\", \\\"set_fact\\\": {\\\"ovn_config_path\\\": \\\"{{ ovn_cont_17_0.files.0.path | dirname }}\\\"}, \\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": \\\"ovn\\\"}, {\\\"name\\\": \\\"Get PIDfile used by systemd on each ovn node\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"ovn\\\"], \\\"become\\\": true, \\\"shell\\\": \\\"set -e\\\\ngrep PID /etc/systemd/system/tripleo_ovn_controller.service | cut -d= -f2\\\\n\\\", \\\"register\\\": \\\"pidfile\\\", \\\"loop\\\": \\\"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\\\", \\\"delegate_to\\\": \\\"{{ item }}\\\"}, {\\\"name\\\": \\\"Update ovn_controller.\\\", \\\"vars\\\": {\\\"config_step\\\": \\\"{{ (\'step_4\' in ovn_config_path) | ternary(\'4\', \'3\')}}\\\", \\\"query\\\": \\\"results[?item == \'{{item}}\'].stdout\\\"}, \\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": \\\"ovn\\\", \\\"become\\\": true, \\\"loop\\\": \\\"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\\\", \\\"delegate_to\\\": \\\"{{ item }}\\\", \\\"async\\\": {\\\"get_param\\\": \\\"OVNControllerUpdateTimeout\\\"}, \\\"poll\\\": 0, \\\"register\\\": \\\"ovn_controller_update\\\", \\\"tripleo_container_manage\\\": {\\\"config_dir\\\": \\\"{{ ovn_config_path }}\\\", \\\"config_patterns\\\": \\\"*ovn_controller.json\\\", \\\"config_id\\\": [\\\"tripleo_step{{config_step}}\\\"], \\\"log_base_path\\\": \\\"{{ container_log_stdout_path }}\\\", \\\"debug\\\": \\\"{{ enable_debug | bool }}\\\", \\\"config_overrides\\\": {\\\".*ovn_controller\\\": {\\\"image\\\": {\\\"get_param\\\": \\\"ContainerOvnControllerConfigImage\\\"}, \\\"conmon_pidfile\\\": \\\"{{ pidfile | json_query(query) | first }}\\\", \\\"name\\\": \\\"ovn_controller\\\"}}}}, {\\\"name\\\": \\\"Was the ovn_controller successful.\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"\'results\' in ovn_controller_update\\\"], \\\"tags\\\": \\\"ovn\\\", \\\"become\\\": true, \\\"delegate_to\\\": \\\"{{ async_result_item.item }}\\\", \\\"async_status\\\": {\\\"jid\\\": \\\"{{ async_result_item.ansible_job_id }}\\\"}, \\\"loop\\\": \\\"{{ovn_controller_update.results }}\\\", \\\"loop_control\\\": {\\\"loop_var\\\": \\\"async_result_item\\\"}, \\\"register\\\": \\\"async_poll_results\\\", \\\"until\\\": \\\"async_poll_results.finished\\\", \\\"retries\\\": {\\\"get_param\\\": \\\"OVNControllerUpdateTimeout\\\"}, \\\"delay\\\": 1}, {\\\"name\\\": \\\"Pause for 30s to give ovn_controllers time to reconnect to dbs\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": \\\"ovn\\\", \\\"wait_for\\\": {\\\"timeout\\\": 30}}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"Fetch running ovn_controller image\\\", \\\"shell\\\": \\\"set -e\\\\npodman inspect --format \\\\\\\"{{\'{{\'}}.ImageName{{\'}}\'}}\\\\\\\" ovn_controller\\\\n\\\", \\\"register\\\": \\\"running_ovn_image\\\", \\\"when\\\": [\\\"step|int == 4\\\"], \\\"tags\\\": [\\\"ovn\\\", \\\"ovn_image\\\"]}, {\\\"name\\\": \\\"Run ovn_controller upgrade\\\", \\\"tags\\\": [\\\"ovn\\\", \\\"ovn_image\\\"], \\\"vars\\\": {\\\"ovn_controller_image\\\": {\\\"get_param\\\": \\\"ContainerOvnControllerConfigImage\\\"}}, \\\"when\\\": [\\\"step|int == 4\\\", \\\"running_ovn_image.stdout != ovn_controller_image\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Force pull image in case image name doesn\'t change.\\\", \\\"when\\\": \\\"step|int == 4\\\", \\\"tags\\\": [\\\"ovn\\\", \\\"ovn_image\\\"], \\\"containers.podman.podman_image\\\": {\\\"name\\\": {\\\"get_param\\\": \\\"ContainerOvnControllerConfigImage\\\"}, \\\"validate_certs\\\": false, \\\"force\\\": true}}, {\\\"name\\\": \\\"Update OVN OVS related parameters before update.\\\", \\\"when\\\": [\\\"step|int == 4\\\"], \\\"tags\\\": [\\\"ovn\\\"], \\\"vars\\\": {\\\"timeout\\\": {\\\"get_param\\\": \\\"OVNOfctrlWaitBeforeClear\\\"}}, \\\"shell\\\": \\\"set -e\\\\novs-vsctl set Open_vSwitch . external_ids:ovn-ofctrl-wait-before-clear={{ timeout }}\\\\novs-vsctl set Open_vSwitch . external_ids:ovn-monitor-all=true\\\\novs-vsctl set Open_vSwitch . external_ids:ovn-match-northd-version=false\\\\n\\\"}, {\\\"name\\\": \\\"Find ovn_controller configs in container-startup-configs\\\", \\\"find\\\": {\\\"paths\\\": \\\"/var/lib/tripleo-config/container-startup-config/\\\", \\\"patterns\\\": \\\"*ovn_controller.json\\\", \\\"recurse\\\": true}, \\\"register\\\": \\\"ovn_cont_17_0\\\", \\\"when\\\": [\\\"step|int == 4\\\"], \\\"tags\\\": [\\\"ovn\\\"]}, {\\\"name\\\": \\\"get directory path from the ovn_cont_17_0\\\", \\\"set_fact\\\": {\\\"ovn_config_path\\\": \\\"{{ ovn_cont_17_0.files.0.path | dirname }}\\\"}, \\\"when\\\": \\\"step|int == 4\\\", \\\"tags\\\": \\\"ovn\\\"}, {\\\"name\\\": \\\"Get PIDfile used by systemd on each ovn node\\\", \\\"when\\\": [\\\"step|int == 4\\\"], \\\"tags\\\": [\\\"ovn\\\"], \\\"shell\\\": \\\"set -e\\\\ngrep PID /etc/systemd/system/tripleo_ovn_controller.service | cut -d= -f2\\\\n\\\", \\\"register\\\": \\\"pidfile\\\"}, {\\\"name\\\": \\\"Update ovn_controller.\\\", \\\"vars\\\": {\\\"config_step\\\": \\\"{{ (\'step_4\' in ovn_config_path) | ternary(\'4\', \'3\')}}\\\"}, \\\"when\\\": \\\"step|int == 4\\\", \\\"tags\\\": \\\"ovn\\\", \\\"tripleo_container_manage\\\": {\\\"config_dir\\\": \\\"{{ ovn_config_path }}\\\", \\\"config_patterns\\\": \\\"*ovn_controller.json\\\", \\\"config_id\\\": [\\\"tripleo_step{{config_step}}\\\"], \\\"log_base_path\\\": \\\"{{ container_log_stdout_path }}\\\", \\\"debug\\\": \\\"{{ enable_debug | bool }}\\\", \\\"config_overrides\\\": {\\\".*ovn_controller\\\": {\\\"image\\\": {\\\"get_param\\\": \\\"ContainerOvnControllerConfigImage\\\"}, \\\"conmon_pidfile\\\": \\\"{{ pidfile.stdout }}\\\", \\\"name\\\": \\\"ovn_controller\\\"}}}}, {\\\"name\\\": \\\"Pause for 30s to give ovn_controllers time to reconnect to dbs\\\", \\\"when\\\": [\\\"step|int == 4\\\"], \\\"tags\\\": \\\"ovn\\\", \\\"wait_for\\\": {\\\"timeout\\\": 30}}]}], \\\"scale_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\", \\\"container_cli == \'podman\'\\\"], \\\"tags\\\": \\\"down\\\", \\\"become\\\": true, \\\"environment\\\": {\\\"OS_CLOUD\\\": {\\\"if\\\": [\\\"auth_cloud_name_set\\\", {\\\"get_param\\\": \\\"AuthCloudName\\\"}, {\\\"get_param\\\": \\\"RootStackName\\\"}]}}, \\\"block\\\": [{\\\"name\\\": \\\"Get neutron agents ID\\\", \\\"command\\\": \\\"openstack network agent list --column ID --column Host --column Binary --format yaml\\\", \\\"register\\\": \\\"neutron_agents_result\\\", \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"check_mode\\\": false, \\\"changed_when\\\": false}, {\\\"name\\\": \\\"Filter only current host\\\", \\\"set_fact\\\": {\\\"neutron_agents\\\": \\\"{{ neutron_agents_result.stdout | from_yaml | selectattr(\'Host\', \'match\', ansible_facts[\'fqdn\'] ~ \'.*\') | list }}\\\"}, \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"check_mode\\\": false}, {\\\"name\\\": \\\"Deleting OVN agents\\\", \\\"block\\\": [{\\\"name\\\": \\\"Stop OVN containers\\\", \\\"loop\\\": [\\\"tripleo_ovn_controller\\\", \\\"tripleo_ovn_metadata_agent\\\"], \\\"service\\\": {\\\"name\\\": \\\"{{ item }}\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}, \\\"become\\\": true, \\\"register\\\": \\\"stop_containers\\\", \\\"failed_when\\\": \\\"(\'msg\' in stop_containers and \'Could not find the requested service\' not in stop_containers.msg) or (\'rc\' in stop_containers and stop_containers.rc != 0)\\\"}, {\\\"name\\\": \\\"Delete neutron agents\\\", \\\"loop\\\": \\\"{{ neutron_agents }}\\\", \\\"loop_control\\\": {\\\"loop_var\\\": \\\"agent\\\", \\\"label\\\": \\\"{{ agent.Host }}/{{ agent.Binary }}\\\"}, \\\"command\\\": \\\"openstack network agent delete {{ agent.ID }}\\\", \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"check_mode\\\": false}]}]}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"MLNX SDN configuration assist for Neutron ML2 Plugin.\\\\n\\\", \\\"parameters\\\": {\\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\\n\\\", \\\"type\\\": \\\"json\\\"}, \\\"ContainerNeutronConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the neutron config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"MlnxSDNUsername\\\": {\\\"description\\\": \\\"The username for the SDN server.\\\", \\\"type\\\": \\\"string\\\"}, \\\"MlnxSDNPassword\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"The password for the SDN server.\\\", \\\"hidden\\\": true}, \\\"MlnxSDNToken\\\": {\\\"description\\\": \\\"The token for the SDN server.\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"MlnxSDNUrl\\\": {\\\"description\\\": \\\"SDN server URL\\\", \\\"type\\\": \\\"string\\\"}, \\\"MlnxSDNDomain\\\": {\\\"description\\\": \\\"SDN server domain\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"cloudx\\\"}, \\\"MlnxSDNSyncEnabled\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": true}, \\\"MultiInterfaceEnabled\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"BindNormalPortsPhysnet\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"datacentre\\\"}}, \\\"conditions\\\": {\\\"multi_interface_enabled\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"MultiInterfaceEnabled\\\"}, true]}}, \\\"resources\\\": {\\\"NeutronMl2Base\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2.yaml\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerNeutronConfigImage\\\": \\\"ContainerNeutronConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerNeutronConfigImage\\\": {\\\"get_param\\\": \\\"ContainerNeutronConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the MLNX SDN ML2 Plugin.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"neutron_plugin_ml2_mlnx_sdn_assist\\\", \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"NeutronMl2Base\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"neutron::plugins::ml2::mellanox::mlnx_sdn_assist::sdn_username\\\": {\\\"get_param\\\": \\\"MlnxSDNUsername\\\"}, \\\"neutron::plugins::ml2::mellanox::mlnx_sdn_assist::sdn_password\\\": {\\\"get_param\\\": \\\"MlnxSDNPassword\\\"}, \\\"neutron::plugins::ml2::mellanox::mlnx_sdn_assist::sdn_token\\\": {\\\"get_param\\\": \\\"MlnxSDNToken\\\"}, \\\"neutron::plugins::ml2::mellanox::mlnx_sdn_assist::sdn_url\\\": {\\\"get_param\\\": \\\"MlnxSDNUrl\\\"}, \\\"neutron::plugins::ml2::mellanox::mlnx_sdn_assist::sdn_domain\\\": {\\\"get_param\\\": \\\"MlnxSDNDomain\\\"}, \\\"neutron::plugins::ml2::mellanox::mlnx_sdn_assist::sync_enabled\\\": {\\\"get_param\\\": \\\"MlnxSDNSyncEnabled\\\"}}, {\\\"if\\\": [\\\"multi_interface_enabled\\\", {\\\"neutron::plugins::ml2::mellanox::mlnx_sdn_assist::bind_normal_ports\\\": {\\\"get_param\\\": \\\"MultiInterfaceEnabled\\\"}, \\\"neutron::plugins::ml2::mellanox::mlnx_sdn_assist::bind_normal_ports_physnets\\\": {\\\"get_param\\\": \\\"BindNormalPortsPhysnet\\\"}}, {}]}]}, \\\"service_config_settings\\\": {}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"neutron\\\", \\\"puppet_tags\\\": \\\"neutron_plugin_ml2\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::neutron::plugins::ml2\\\\n\\\", \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNeutronConfigImage\\\"]}}, \\\"kolla_config\\\": {}, \\\"docker_config\\\": {}}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"VTS Controller Settings for Neutron ML2 Plugin (Docker)\\\\n\\\", \\\"parameters\\\": {\\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ContainerNeutronConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the neutron config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"VTSUsername\\\": {\\\"description\\\": \\\"The username for the VTS server.\\\", \\\"type\\\": \\\"string\\\"}, \\\"VTSPassword\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"The password for the VTS server.\\\", \\\"hidden\\\": true}, \\\"VTSServer\\\": {\\\"description\\\": \\\"VTS Server IP address\\\", \\\"type\\\": \\\"string\\\"}, \\\"VTSVMMID\\\": {\\\"description\\\": \\\"VMM ID used on VTS\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\"}, \\\"VTSSiteId\\\": {\\\"description\\\": \\\"VTS Site Id of the controller\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\"}, \\\"VTSPort\\\": {\\\"description\\\": \\\"Port of the VTS Server\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 8888}, \\\"VTSTimeout\\\": {\\\"description\\\": \\\"Timeout for VTS server\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 120}}, \\\"resources\\\": {\\\"NeutronMl2Base\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2.yaml\\\", \\\"properties\\\": {\\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerNeutronConfigImage\\\": \\\"ContainerNeutronConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerNeutronConfigImage\\\": {\\\"get_param\\\": \\\"ContainerNeutronConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Neutron ML2 Cisco VTS Plugin role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"neutron_plugin_ml2_cisco_vts\\\", \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"NeutronMl2Base\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"vts::vts_ip\\\": {\\\"get_param\\\": \\\"VTSServer\\\"}, \\\"vts::vts_port\\\": {\\\"get_param\\\": \\\"VTSPort\\\"}, \\\"vts::vts_siteid\\\": {\\\"get_param\\\": \\\"VTSSiteId\\\"}, \\\"neutron::plugins::ml2::cisco::vts::vts_username\\\": {\\\"get_param\\\": \\\"VTSUsername\\\"}, \\\"neutron::plugins::ml2::cisco::vts::vts_password\\\": {\\\"get_param\\\": \\\"VTSPassword\\\"}, \\\"neutron::plugins::ml2::cisco::vts::vts_vmmid\\\": {\\\"get_param\\\": \\\"VTSVMMID\\\"}, \\\"neutron::plugins::ml2::cisco::vts::vts_timeout\\\": {\\\"get_param\\\": \\\"VTSTimeout\\\"}}]}, \\\"service_config_settings\\\": {}, \\\"metadata_settings\\\": {\\\"get_attr\\\": [\\\"NeutronMl2Base\\\", \\\"role_data\\\", \\\"metadata_settings\\\"]}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"neutron\\\", \\\"puppet_tags\\\": \\\"neutron_plugin_ml2\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::neutron::plugins::ml2\\\\n\\\", \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNeutronConfigImage\\\"]}}, \\\"kolla_config\\\": {}, \\\"docker_config\\\": {}}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Neutron ML2 networking-ansible Plugin (Docker)\\\\n\\\", \\\"parameters\\\": {\\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ContainerNeutronConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the neutron config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"ML2HostConfigs\\\": {\\\"description\\\": \\\"ML2 config for switches\\\", \\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}, \\\"RedisPassword\\\": {\\\"description\\\": \\\"The password for the redis service account.\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}}, \\\"resources\\\": {\\\"NeutronMl2Base\\\": {\\\"type\\\": \\\"OS::TripleO::Services::NeutronMl2PluginBase\\\", \\\"properties\\\": {\\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerNeutronConfigImage\\\": \\\"ContainerNeutronConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerNeutronConfigImage\\\": {\\\"get_param\\\": \\\"ContainerNeutronConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Neutron ML2 ansible Plugin role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"neutron_plugin_ml2_ansible\\\", \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"NeutronMl2Base\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"neutron::plugins::ml2::networking_ansible::host_configs\\\": {\\\"get_param\\\": \\\"ML2HostConfigs\\\"}}, {\\\"neutron_redis_password\\\": {\\\"get_param\\\": \\\"RedisPassword\\\"}}]}, \\\"service_config_settings\\\": {}, \\\"metadata_settings\\\": {\\\"get_attr\\\": [\\\"NeutronMl2Base\\\", \\\"role_data\\\", \\\"metadata_settings\\\"]}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"neutron\\\", \\\"puppet_tags\\\": \\\"neutron_plugin_ml2\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::neutron::plugins::ml2\\\\n\\\", \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNeutronConfigImage\\\"]}}, \\\"kolla_config\\\": {}, \\\"docker_config\\\": {}}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack Neutron Nuage VRS\\\\n\\\", \\\"parameters\\\": {\\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"NuageActiveController\\\": {\\\"description\\\": \\\"IP address of the Active Virtualized Services Controller (VSC)\\\", \\\"type\\\": \\\"string\\\"}, \\\"NuageStandbyController\\\": {\\\"description\\\": \\\"IP address of the Standby Virtualized Services Controller (VSC)\\\", \\\"type\\\": \\\"string\\\"}, \\\"NuageBridgeMTU\\\": {\\\"description\\\": \\\"Support for non-default MTU configured on each VRS node\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\"}, \\\"NuageDisableDhcp4\\\": {\\\"description\\\": \\\"Make VRS act as Dhcp server or not\\\", \\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"NuageControllerEnableMetadataAgent\\\": {\\\"description\\\": \\\"Enbale Nuage Metadata Agent on Controller or not\\\", \\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"ControllerVxlanIPtableRule\\\": {\\\"description\\\": \\\"Open Vxlan Port on Controller node or not\\\", \\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}}, \\\"conditions\\\": {\\\"apply_vxlan_iptables_rule\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"ControllerVxlanIPtableRule\\\"}, true]}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Neutron Controller  Nuage plugin\\\", \\\"value\\\": {\\\"firewall_rules\\\": [{\\\"if\\\": [\\\"apply_vxlan_iptables_rule\\\", {\\\"118 neutron vxlan networks\\\": {\\\"proto\\\": \\\"udp\\\", \\\"dport\\\": 4789}}, {}]}], \\\"service_name\\\": \\\"neutron_controller_plugin_nuage\\\", \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"nuage::vrs::active_controller\\\": {\\\"get_param\\\": \\\"NuageActiveController\\\"}, \\\"nuage::vrs::standby_controller\\\": {\\\"get_param\\\": \\\"NuageStandbyController\\\"}, \\\"nuage::vrs::bridge_mtu\\\": {\\\"get_param\\\": \\\"NuageBridgeMTU\\\"}, \\\"nuage::vrs::disable_dhcp4\\\": {\\\"get_param\\\": \\\"NuageDisableDhcp4\\\"}, \\\"tripleo::profile::base::neutron::agents::nuage::enable_metadata_agent\\\": {\\\"get_param\\\": \\\"NuageControllerEnableMetadataAgent\\\"}}]}, \\\"step_config\\\": \\\"include tripleo::profile::base::neutron::agents::nuage\\\"}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Pacemaker service configured with Puppet\\\\n\\\", \\\"parameters\\\": {\\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"MonitoringSubscriptionPacemaker\\\": {\\\"default\\\": \\\"overcloud-pacemaker\\\", \\\"type\\\": \\\"string\\\"}, \\\"CorosyncIPv6\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Enable IPv6 in Corosync\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"EnableFencing\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to enable fencing in Pacemaker or not.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"PacemakerTLSPriorities\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Pacemaker TLS Priorities\\\", \\\"default\\\": \\\"\\\"}, \\\"PacemakerRemoteAuthkey\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"The authkey for the pacemaker remote service.\\\", \\\"hidden\\\": true}, \\\"PcsdPassword\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"The password for the \'pcsd\' user for pacemaker.\\\", \\\"hidden\\\": true}, \\\"CorosyncTokenTimeout\\\": {\\\"type\\\": \\\"number\\\", \\\"description\\\": \\\"Time in milliseconds until a token loss is declared after not receiving a token.\\\", \\\"default\\\": 10000}, \\\"CorosyncSettleTries\\\": {\\\"type\\\": \\\"number\\\", \\\"description\\\": \\\"Number of tries for cluster settling. This has the same default as the pacemaker puppet module. Override to a smaller value when in need to replace a controller node.\\\", \\\"default\\\": 360}, \\\"FencingConfig\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Pacemaker fencing configuration. The JSON should have\\\\nthe following structure:\\\\n  {\\\\n    \\\\\\\"devices\\\\\\\": [\\\\n      {\\\\n        \\\\\\\"agent\\\\\\\": \\\\\\\"AGENT_NAME\\\\\\\",\\\\n        \\\\\\\"host_mac\\\\\\\": \\\\\\\"HOST_MAC_ADDRESS\\\\\\\",\\\\n        \\\\\\\"params\\\\\\\": {\\\\\\\"PARAM_NAME\\\\\\\": \\\\\\\"PARAM_VALUE\\\\\\\"}\\\\n      }\\\\n    ]\\\\n  }\\\\nFor instance:\\\\n  {\\\\n    \\\\\\\"devices\\\\\\\": [\\\\n      {\\\\n        \\\\\\\"agent\\\\\\\": \\\\\\\"fence_xvm\\\\\\\",\\\\n        \\\\\\\"host_mac\\\\\\\": \\\\\\\"52:54:00:aa:bb:cc\\\\\\\",\\\\n        \\\\\\\"params\\\\\\\": {\\\\n          \\\\\\\"multicast_address\\\\\\\": \\\\\\\"225.0.0.12\\\\\\\",\\\\n          \\\\\\\"port\\\\\\\": \\\\\\\"baremetal_0\\\\\\\",\\\\n          \\\\\\\"manage_fw\\\\\\\": true,\\\\n          \\\\\\\"manage_key_file\\\\\\\": true,\\\\n          \\\\\\\"key_file\\\\\\\": \\\\\\\"/etc/fence_xvm.key\\\\\\\",\\\\n          \\\\\\\"key_file_password\\\\\\\": \\\\\\\"abcdef\\\\\\\"\\\\n        }\\\\n      }\\\\n    ]\\\\n  }\\\\n\\\", \\\"type\\\": \\\"json\\\"}, \\\"PacemakerLoggingSource\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {\\\"tag\\\": \\\"system.pacemaker\\\", \\\"file\\\": \\\"/var/log/host/pacemaker/pacemaker.log\\\", \\\"startmsg.regex\\\": \\\"^[a-zA-Z]{3} [0-9]{2} [:0-9]{8}\\\"}}, \\\"ContainerCli\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"podman\\\", \\\"description\\\": \\\"CLI tool used to manage containers.\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"docker\\\", \\\"podman\\\"]}]}, \\\"EnableInstanceHA\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to enable an Instance Ha configurarion or not. This setup requires the Compute role to have the PacemakerRemote service added to it.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"PacemakerBundleOperationTimeout\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The timeout for start, monitor and stop operations run by the container resource agent, in seconds. When set to default \'\', the timeout comes from pacemaker\'s default operation timeouts (20s). When set to default and podman is used, force the timeout to 120s.\\\", \\\"constraints\\\": [{\\\"allowed_pattern\\\": \\\"([1-9][0-9]*s)?\\\"}]}}, \\\"parameter_groups\\\": [{\\\"label\\\": \\\"deprecated\\\", \\\"description\\\": \\\"The following parameters are deprecated and will be removed. They should not\\\\nbe relied on for new deployments. If you have concerns regarding deprecated\\\\nparameters, please contact the TripleO development team on IRC or the\\\\nOpenStack mailing list.\\\\n\\\", \\\"parameters\\\": [\\\"CorosyncIPv6\\\"]}], \\\"conditions\\\": {\\\"pcmk_tls_priorities_empty\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"PacemakerTLSPriorities\\\"}, \\\"\\\"]}, \\\"pcmk_bundle_op_timeout_empty\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"PacemakerBundleOperationTimeout\\\"}, \\\"\\\"]}, \\\"podman_enabled\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"podman\\\"]}, \\\"is_ipv6\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"ServiceData\\\", \\\"net_ip_version_map\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PacemakerNetwork\\\"]}]}, 6]}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Pacemaker role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"pacemaker\\\", \\\"monitoring_subscription\\\": {\\\"get_param\\\": \\\"MonitoringSubscriptionPacemaker\\\"}, \\\"firewall_rules\\\": {\\\"130 pacemaker tcp\\\": {\\\"proto\\\": \\\"tcp\\\", \\\"dport\\\": [2224, 3121, 21064]}, \\\"131 pacemaker udp\\\": {\\\"proto\\\": \\\"udp\\\", \\\"dport\\\": 5405}}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"pacemaker::corosync::cluster_name\\\": \\\"tripleo_cluster\\\", \\\"pacemaker::corosync::manage_fw\\\": false, \\\"pacemaker::resource_defaults::defaults\\\": {\\\"resource-stickiness\\\": {\\\"value\\\": \\\"INFINITY\\\"}}, \\\"corosync_token_timeout\\\": {\\\"get_param\\\": \\\"CorosyncTokenTimeout\\\"}, \\\"pacemaker::corosync::settle_tries\\\": {\\\"get_param\\\": \\\"CorosyncSettleTries\\\"}, \\\"pacemaker::resource::bundle::deep_compare\\\": true, \\\"pacemaker::resource::ip::deep_compare\\\": true, \\\"pacemaker::resource::ocf::deep_compare\\\": true, \\\"corosync_ipv6\\\": {\\\"if\\\": [\\\"is_ipv6\\\", true, false]}, \\\"tripleo::fencing::config\\\": {\\\"get_param\\\": \\\"FencingConfig\\\"}, \\\"tripleo::fencing::deep_compare\\\": true, \\\"enable_fencing\\\": {\\\"get_param\\\": \\\"EnableFencing\\\"}, \\\"hacluster_pwd\\\": {\\\"get_param\\\": \\\"PcsdPassword\\\"}, \\\"tripleo::profile::base::pacemaker::remote_authkey\\\": {\\\"get_param\\\": \\\"PacemakerRemoteAuthkey\\\"}, \\\"tripleo::profile::base::pacemaker::pcsd_bind_addr\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PacemakerNetwork\\\"]}}}}}, {\\\"if\\\": [\\\"pcmk_tls_priorities_empty\\\", {}, {\\\"tripleo::pacemaker::tls_priorities\\\": {\\\"get_param\\\": \\\"PacemakerTLSPriorities\\\"}}]}, {\\\"if\\\": [{\\\"and\\\": [\\\"pcmk_bundle_op_timeout_empty\\\", {\\\"not\\\": \\\"podman_enabled\\\"}]}, {}, {\\\"tripleo::profile::base::pacemaker::resource_op_defaults\\\": {\\\"bundle\\\": {\\\"name\\\": \\\"timeout\\\", \\\"value\\\": {\\\"if\\\": [\\\"pcmk_bundle_op_timeout_empty\\\", \\\"120s\\\", {\\\"get_param\\\": \\\"PacemakerBundleOperationTimeout\\\"}]}}}}]}]}, \\\"service_config_settings\\\": {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_pacemaker\\\": [{\\\"get_param\\\": \\\"PacemakerLoggingSource\\\"}]}}, \\\"step_config\\\": \\\"include tripleo::profile::base::pacemaker\\\\n\\\", \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"Make sure python3-novaclient is installed when IHA is enabled\\\", \\\"package\\\": {\\\"name\\\": \\\"python3-novaclient\\\", \\\"state\\\": \\\"present\\\"}, \\\"when\\\": {\\\"get_param\\\": \\\"EnableInstanceHA\\\"}}, {\\\"name\\\": \\\"Remove existing entries from logind conf\\\", \\\"ansible.builtin.lineinfile\\\": {\\\"path\\\": \\\"/etc/systemd/logind.conf\\\", \\\"regexp\\\": \\\"^\\\\\\\\s*#?\\\\\\\\s*HandlePowerKey\\\\\\\\s*=.*\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"Make sure systemd-logind ignores power off\\\", \\\"ansible.builtin.lineinfile\\\": {\\\"path\\\": \\\"/etc/systemd/logind.conf\\\", \\\"regexp\\\": \\\"^#?HandlePowerKey\\\", \\\"line\\\": \\\"HandlePowerKey=ignore\\\"}}, {\\\"name\\\": \\\"Restart systemd-logind\\\", \\\"ansible.builtin.service\\\": {\\\"name\\\": \\\"systemd-logind\\\", \\\"state\\\": \\\"restarted\\\"}}, {\\\"name\\\": \\\"Gather service_facts on pacemaker_bootstrap_node\\\", \\\"ansible.builtin.service_facts\\\": null, \\\"when\\\": [\\\"{{(pacemaker_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower)|bool}}\\\", {\\\"get_param\\\": \\\"EnableInstanceHA\\\"}]}, {\\\"name\\\": \\\"Check and eventually delete duplicate constraints (bootstrap node)\\\", \\\"become\\\": true, \\\"shell\\\": \\\"COUNT=$(cibadmin --query | xmllint --xpath \'//rsc_location[@rsc=\\\\\\\"stonith-fence_compute-fence-nova\\\\\\\"]/@id\' - |grep -oP \'(?<=[\\\\\\\"])[^\\\\\\\"]*\' -c)\\\\nif [[ $COUNT > 1 ]]; then\\\\n    echo \\\\\\\"Detected $COUNT duplicate constraints, deleting them\\\\\\\"\\\\n    # assemble string with current list of computes\\\\n    GOOD=$(echo location-stonith-fence_compute-fence-nova-$(hiera pacemaker_remote_short_node_names |grep -oP \'\\\\\\\".*?\\\\\\\"\' |tr -d \'\\\\\\\"\'|tr -d \'\\\\\\\\n\' )--10000)\\\\n    # delete old constraints\\\\n    for i in $(cibadmin --query | xmllint --xpath \'//rsc_location[@rsc=\\\\\\\"stonith-fence_compute-fence-nova\\\\\\\"]/@id\' - |grep -oP \'(?<=[\\\\\\\"])[^\\\\\\\"]*\' |grep -v $GOOD ); do pcs constraint delete $i ; done\\\\nelse\\\\n    echo \\\\\\\"No duplicate constraint found\\\\\\\"\\\\nfi\\\\n\\\", \\\"when\\\": [\\\"{{(pacemaker_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower)|bool}}\\\", {\\\"get_param\\\": \\\"EnableInstanceHA\\\"}, \\\"ansible_facts[\'services\'][\'pacemaker.service\'][\'state\'] == \'running\'\\\"]}], \\\"scale_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\", \\\"container_cli == \'podman\'\\\", \\\"\\\\\\\"pacemaker_remote\\\\\\\" in enabled_services|list\\\", \\\"inventory_hostname_short in compute_instanceha_short_node_names\\\"], \\\"tags\\\": \\\"down\\\", \\\"become\\\": true, \\\"block\\\": [{\\\"name\\\": \\\"Getting Nova compute hostname\\\", \\\"command\\\": \\\"crm_node -n\\\", \\\"register\\\": \\\"nova_compute_hostname\\\"}, {\\\"name\\\": \\\"Check if pacemaker_short_bootstrap_node_name is a defined variable\\\", \\\"when\\\": \\\"pacemaker_short_bootstrap_node_name is not defined\\\", \\\"fail\\\": {\\\"msg\\\": \\\"Cannot delegate pacemaker cleanup to the bootstrap node. Please delete the resources manually.\\\"}, \\\"ignore_errors\\\": true}, {\\\"name\\\": \\\"Clean up Pacemaker remote and STONITH resources for Compute node\\\", \\\"when\\\": [\\\"nova_compute_hostname.stdout in compute_instanceha_short_node_names\\\", \\\"pacemaker_short_bootstrap_node_name is defined\\\"], \\\"block\\\": [{\\\"name\\\": \\\"List STONITH resource for the Compute node\\\", \\\"command\\\": \\\"stonith_admin -l {{ nova_compute_hostname.stdout }}\\\", \\\"register\\\": \\\"stonith_service_results\\\", \\\"delegate_to\\\": \\\"{{ pacemaker_short_bootstrap_node_name }}\\\"}, {\\\"name\\\": \\\"Disable the STONITH resources for the Compute node\\\", \\\"command\\\": \\\"pcs stonith disable \\\\\\\"{{ item }}\\\\\\\"\\\", \\\"loop\\\": \\\"{{ stonith_service_results.stdout | regex_findall(\'^(stonith-fence(?!_compute-fence-nova).*)\', multiline=True)}}\\\", \\\"delegate_to\\\": \\\"{{ pacemaker_short_bootstrap_node_name }}\\\", \\\"register\\\": \\\"disable_output\\\", \\\"failed_when\\\": \\\"disable_output.rc != 0\\\", \\\"retries\\\": 3, \\\"delay\\\": 5, \\\"until\\\": \\\"disable_output.rc == 0\\\"}, {\\\"name\\\": \\\"Delete the STONITH resources for the Compute node\\\", \\\"command\\\": \\\"pcs stonith delete \\\\\\\"{{ item }}\\\\\\\"\\\", \\\"loop\\\": \\\"{{ stonith_service_results.stdout | regex_findall(\'^(stonith-fence(?!_compute-fence-nova).*)\', multiline=True)}}\\\", \\\"delegate_to\\\": \\\"{{ pacemaker_short_bootstrap_node_name }}\\\", \\\"register\\\": \\\"delete_output\\\", \\\"failed_when\\\": \\\"delete_output.rc != 0\\\", \\\"retries\\\": 3, \\\"delay\\\": 5, \\\"until\\\": \\\"delete_output.rc == 0\\\"}, {\\\"name\\\": \\\"Clear the stonith level hierarchy for the Compute node target\\\", \\\"command\\\": \\\"pcs stonith level clear target {{ nova_compute_hostname.stdout }}\\\", \\\"delegate_to\\\": \\\"{{ pacemaker_short_bootstrap_node_name }}\\\"}, {\\\"name\\\": \\\"Delete Compute node from cluster\\\", \\\"command\\\": \\\"pcs cluster node remove-remote {{ nova_compute_hostname.stdout }}\\\", \\\"delegate_to\\\": \\\"{{ pacemaker_short_bootstrap_node_name }}\\\"}, {\\\"name\\\": \\\"Remove compute node in pcmk_host_list parameter from stonith-fence_compute-fence-nova\\\", \\\"command\\\": \\\"crm_resource --set-parameter=pcmk_host_list -r stonith-fence_compute-fence-nova -v \\\\\\\"{{ pacemaker_remote_short_node_names | reject(\'search\', nova_compute_hostname.stdout) | join(\',\') }}\\\\\\\"\\\", \\\"delegate_to\\\": \\\"{{ pacemaker_short_bootstrap_node_name }}\\\"}]}]}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"Ensure redis is removed\\\", \\\"when\\\": [\\\"step|int == 5\\\", \\\"\\\\\\\"redis\\\\\\\" not in enabled_services|list\\\", \\\"{{ (pacemaker_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower)|bool}}\\\"], \\\"become\\\": true, \\\"shell\\\": \\\"if crm_resource -r redis-bundle -q &>/dev/null; then\\\\n   pcs resource delete redis-bundle || true\\\\n   pcs resource delete ip-$(hiera redis_vip) || true\\\\nfi\\\\n\\\"}, {\\\"name\\\": \\\"Clean up cluster node cache\\\", \\\"when\\\": [\\\"step|int == 5\\\", \\\"\\\\\\\"redis\\\\\\\" not in enabled_services|list\\\", \\\"{{ (pacemaker_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower)|bool}}\\\"], \\\"become\\\": true, \\\"shell\\\": \\\"pcs cluster node clear redis-bundle-0\\\\npcs cluster node clear redis-bundle-1\\\\npcs cluster node clear redis-bundle-2\\\\ncrm_attribute --name redis_REPL_INFO --delete\\\\n\\\"}, {\\\"name\\\": \\\"Clean up redis attribute\\\", \\\"when\\\": [\\\"step|int == 5\\\", \\\"\\\\\\\"redis\\\\\\\" not in enabled_services|list\\\", \\\"{{ (pacemaker_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower)|bool}}\\\"], \\\"become\\\": true, \\\"shell\\\": \\\"pcs node attribute \\\\\\\"{{ item }}\\\\\\\" redis-role= || true\\\\n\\\", \\\"loop\\\": \\\"{{ pacemaker_short_node_names }}\\\"}], \\\"external_upgrade_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade_stop_services\\\", \\\"system_upgrade_transfer_data\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Stop cluster\\\", \\\"become\\\": true, \\\"shell\\\": \\\"set -eu\\\\nFILE=/usr/sbin/pcs\\\\nif test -f \\\\\\\"$FILE\\\\\\\"; then\\\\n  /usr/sbin/pcs cluster stop --force\\\\nfi\\\\n\\\", \\\"delegate_to\\\": \\\"{{ item }}\\\", \\\"with_items\\\": \\\"{{ groups[\'pacemaker\'] | difference(groups[\'excluded_overcloud\']) }}\\\"}]}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"Check pacemaker cluster running before the minor update\\\", \\\"when\\\": \\\"step|int == 0\\\", \\\"pacemaker_cluster\\\": \\\"state=online check_and_fail=true\\\", \\\"async\\\": 30, \\\"poll\\\": 4}, {\\\"name\\\": \\\"Acquire the cluster shutdown lock to stop pacemaker cluster\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"command\\\": \\\"systemd-cat -t ha-shutdown /var/lib/container-config-scripts/pacemaker_mutex_shutdown.sh --acquire\\\"}, {\\\"name\\\": \\\"Stop pacemaker cluster\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"pacemaker_cluster\\\": \\\"state=offline\\\"}, {\\\"name\\\": \\\"Start pacemaker cluster\\\", \\\"when\\\": \\\"step|int == 4\\\", \\\"pacemaker_cluster\\\": \\\"state=online\\\"}, {\\\"name\\\": \\\"Release the cluster shutdown lock\\\", \\\"when\\\": \\\"step|int == 4\\\", \\\"command\\\": \\\"systemd-cat -t ha-shutdown /var/lib/container-config-scripts/pacemaker_mutex_shutdown.sh --release\\\"}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Pacemaker remote service configured with Puppet\\\\n\\\", \\\"parameters\\\": {\\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"PacemakerRemoteAuthkey\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"The authkey for the pacemaker remote service.\\\", \\\"hidden\\\": true}, \\\"PcsdPassword\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"The password for the \'pcsd\' user for pacemaker.\\\", \\\"hidden\\\": true}, \\\"MonitoringSubscriptionPacemakerRemote\\\": {\\\"default\\\": \\\"overcloud-pacemaker_remote\\\", \\\"type\\\": \\\"string\\\"}, \\\"EnableFencing\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to enable fencing in Pacemaker or not.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"FencingConfig\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Pacemaker fencing configuration. The JSON should have\\\\nthe following structure:\\\\n  {\\\\n    \\\\\\\"devices\\\\\\\": [\\\\n      {\\\\n        \\\\\\\"agent\\\\\\\": \\\\\\\"AGENT_NAME\\\\\\\",\\\\n        \\\\\\\"host_mac\\\\\\\": \\\\\\\"HOST_MAC_ADDRESS\\\\\\\",\\\\n        \\\\\\\"params\\\\\\\": {\\\\\\\"PARAM_NAME\\\\\\\": \\\\\\\"PARAM_VALUE\\\\\\\"}\\\\n      }\\\\n    ]\\\\n  }\\\\nFor instance:\\\\n  {\\\\n    \\\\\\\"devices\\\\\\\": [\\\\n      {\\\\n        \\\\\\\"agent\\\\\\\": \\\\\\\"fence_xvm\\\\\\\",\\\\n        \\\\\\\"host_mac\\\\\\\": \\\\\\\"52:54:00:aa:bb:cc\\\\\\\",\\\\n        \\\\\\\"params\\\\\\\": {\\\\n          \\\\\\\"multicast_address\\\\\\\": \\\\\\\"225.0.0.12\\\\\\\",\\\\n          \\\\\\\"port\\\\\\\": \\\\\\\"baremetal_0\\\\\\\",\\\\n          \\\\\\\"manage_fw\\\\\\\": true,\\\\n          \\\\\\\"manage_key_file\\\\\\\": true,\\\\n          \\\\\\\"key_file\\\\\\\": \\\\\\\"/etc/fence_xvm.key\\\\\\\",\\\\n          \\\\\\\"key_file_password\\\\\\\": \\\\\\\"abcdef\\\\\\\"\\\\n        }\\\\n      }\\\\n    ]\\\\n  }\\\\n\\\", \\\"type\\\": \\\"json\\\"}, \\\"PacemakerRemoteLoggingSource\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {\\\"tag\\\": \\\"system.pacemaker_remote\\\", \\\"file\\\": \\\"/var/log/host/pacemaker.log\\\", \\\"startmsg.regex\\\": \\\"^[a-zA-Z]{3} [0-9]{2} [:0-9]{8}\\\"}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Pacemaker remote role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"pacemaker_remote\\\", \\\"firewall_rules\\\": {\\\"130 pacemaker_remote tcp\\\": {\\\"proto\\\": \\\"tcp\\\", \\\"dport\\\": [2224, 3121]}}, \\\"monitoring_subscription\\\": {\\\"get_param\\\": \\\"MonitoringSubscriptionPacemakerRemote\\\"}, \\\"config_settings\\\": {\\\"tripleo::fencing::config\\\": {\\\"get_param\\\": \\\"FencingConfig\\\"}, \\\"tripleo::fencing::deep_compare\\\": true, \\\"enable_fencing\\\": {\\\"get_param\\\": \\\"EnableFencing\\\"}, \\\"tripleo::profile::base::pacemaker_remote::remote_authkey\\\": {\\\"get_param\\\": \\\"PacemakerRemoteAuthkey\\\"}, \\\"tripleo::profile::base::pacemaker_remote::pcsd_bind_addr\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PacemakerRemoteNetwork\\\"]}}}}, \\\"pacemaker::corosync::manage_fw\\\": false, \\\"hacluster_pwd\\\": {\\\"get_param\\\": \\\"PcsdPassword\\\"}}, \\\"service_config_settings\\\": {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_pacemaker_remote\\\": [{\\\"get_param\\\": \\\"PacemakerRemoteLoggingSource\\\"}]}}, \\\"step_config\\\": \\\"include tripleo::profile::base::pacemaker_remote\\\\n\\\", \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"Remove existing entries from logind conf\\\", \\\"ansible.builtin.lineinfile\\\": {\\\"path\\\": \\\"/etc/systemd/logind.conf\\\", \\\"regexp\\\": \\\"^\\\\\\\\s*#?\\\\\\\\s*HandlePowerKey\\\\\\\\s*=.*\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"Make sure systemd-logind ignores power off\\\", \\\"ansible.builtin.lineinfile\\\": {\\\"path\\\": \\\"/etc/systemd/logind.conf\\\", \\\"regexp\\\": \\\"^#?HandlePowerKey\\\", \\\"line\\\": \\\"HandlePowerKey=ignore\\\"}}, {\\\"name\\\": \\\"Restart systemd-logind\\\", \\\"ansible.builtin.service\\\": {\\\"name\\\": \\\"systemd-logind\\\", \\\"state\\\": \\\"restarted\\\"}}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Rabbitmq service\\\\n\\\", \\\"parameters\\\": {\\\"ContainerRabbitmqImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerRabbitmqConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the rabbitmq config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"RabbitCookie\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"hidden\\\": true}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"RabbitUserName\\\": {\\\"default\\\": \\\"guest\\\", \\\"description\\\": \\\"The username for RabbitMQ\\\", \\\"type\\\": \\\"string\\\"}, \\\"RabbitPassword\\\": {\\\"description\\\": \\\"The password for RabbitMQ\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"RabbitFDLimit\\\": {\\\"default\\\": 65536, \\\"description\\\": \\\"Configures RabbitMQ FD limit\\\", \\\"type\\\": \\\"number\\\"}, \\\"RabbitTCPBacklog\\\": {\\\"default\\\": 4096, \\\"description\\\": \\\"Configures RabbitMQ maximum TCP Backlog\\\", \\\"type\\\": \\\"number\\\"}, \\\"RabbitIPv6\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Enable IPv6 in RabbitMQ\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"RabbitHAQueues\\\": {\\\"description\\\": \\\"The number of HA queues to be configured in rabbit. The default is -1 which translates to \\\\\\\"ha-mode all\\\\\\\". The special value 0 will be automatically overridden to CEIL(N/2) where N is the number of nodes running rabbitmq.\\\", \\\"default\\\": 0, \\\"type\\\": \\\"number\\\"}, \\\"RabbitNetTickTime\\\": {\\\"description\\\": \\\"The number of seconds to configure the value of the erlang net_ticktime kernel variable.\\\", \\\"default\\\": 15, \\\"type\\\": \\\"number\\\"}, \\\"RabbitFIPS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false, \\\"description\\\": \\\"Configures RabbitMQ to run in FIPS mode\\\"}, \\\"RabbitAdditionalErlArgs\\\": {\\\"description\\\": \\\"Additional parameters passed to the Erlang subsystem. The string needs to be enclosed in quotes twice. We default to \'+sbwt none +sbwtdcpu none +sbwtdio none\' in order to have the erlang vm be less busy on spinlocks, but we allow a simple way of overriding it.\\\", \\\"default\\\": \\\"\'+sbwt none +sbwtdcpu none +sbwtdio none\'\\\", \\\"type\\\": \\\"string\\\"}, \\\"MonitoringSubscriptionRabbitmq\\\": {\\\"default\\\": \\\"overcloud-rabbitmq\\\", \\\"type\\\": \\\"string\\\"}, \\\"DeployIdentifier\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\\\n\\\"}, \\\"CertificateKeySize\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"2048\\\", \\\"description\\\": \\\"Specifies the private key size used when creating the certificate.\\\"}, \\\"RabbitmqCertificateKeySize\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Override the private key size used when creating the certificate for this service\\\"}, \\\"InternalTLSCAFile\\\": {\\\"default\\\": \\\"/etc/ipa/ca.crt\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Specifies the default CA cert to use if TLS is used for services in the internal network.\\\"}, \\\"RabbitmqEnableManagementAccess\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false, \\\"description\\\": \\\"Allow access to RabbitMQ management plugin over network\\\"}}, \\\"parameter_groups\\\": [{\\\"label\\\": \\\"deprecated\\\", \\\"description\\\": \\\"The following parameters are deprecated and will be removed. They should not\\\\nbe relied on for new deployments. If you have concerns regarding deprecated\\\\nparameters, please contact the TripleO development team on IRC or the\\\\nOpenStack mailing list.\\\\n\\\", \\\"parameters\\\": [\\\"RabbitIPv6\\\"]}], \\\"conditions\\\": {\\\"internal_tls_enabled\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, true]}, \\\"is_ipv6\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"ServiceData\\\", \\\"net_ip_version_map\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"RabbitmqNetwork\\\"]}]}, 6]}, \\\"key_size_override_unset\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"RabbitmqCertificateKeySize\\\"}, \\\"\\\"]}, \\\"rabbitmq_cacert_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, \\\"\\\"]}}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerRabbitmqImage\\\": \\\"ContainerRabbitmqImage\\\", \\\"ContainerRabbitmqConfigImage\\\": \\\"ContainerRabbitmqConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerRabbitmqImage\\\": {\\\"get_param\\\": \\\"ContainerRabbitmqImage\\\"}, \\\"ContainerRabbitmqConfigImage\\\": {\\\"get_param\\\": \\\"ContainerRabbitmqConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Rabbitmq API role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"rabbitmq\\\", \\\"firewall_rules\\\": {\\\"109 rabbitmq\\\": {\\\"dport\\\": {\\\"list_concat\\\": [[4369, 5672, 25672, \\\"25673-25683\\\"], {\\\"if\\\": [{\\\"get_param\\\": \\\"RabbitmqEnableManagementAccess\\\"}, [15672]]}]}}}, \\\"monitoring_subscription\\\": {\\\"get_param\\\": \\\"MonitoringSubscriptionRabbitmq\\\"}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"rabbitmq::file_limit\\\": {\\\"get_param\\\": \\\"RabbitFDLimit\\\"}, \\\"rabbitmq::default_user\\\": {\\\"get_param\\\": \\\"RabbitUserName\\\"}, \\\"rabbitmq::default_pass\\\": {\\\"get_param\\\": \\\"RabbitPassword\\\"}, \\\"rabbit_ipv6\\\": {\\\"if\\\": [\\\"is_ipv6\\\", true, false]}, \\\"rabbitmq::delete_guest_user\\\": false, \\\"rabbitmq::wipe_db_on_cookie_change\\\": true, \\\"rabbitmq::port\\\": 5672, \\\"rabbitmq::loopback_users\\\": [], \\\"rabbitmq::tcp_backlog\\\": {\\\"get_param\\\": \\\"RabbitTCPBacklog\\\"}, \\\"rabbitmq::repos_ensure\\\": false, \\\"rabbitmq::tcp_keepalive\\\": true, \\\"rabbitmq_environment\\\": {\\\"LANG\\\": \\\"en_US.UTF-8\\\", \\\"LC_ALL\\\": \\\"en_US.UTF-8\\\", \\\"NODE_PORT\\\": \\\"\\\", \\\"NODE_IP_ADDRESS\\\": \\\"\\\", \\\"RABBITMQ_NODENAME\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"rabbit@%{hiera(\'fqdn_$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"RabbitmqNetwork\\\"]}}}}, \\\"RABBITMQ_USE_LONGNAME\\\": \\\"true\\\", \\\"RABBITMQ_CTL_DIST_PORT_MIN\\\": \\\"25673\\\", \\\"RABBITMQ_CTL_DIST_PORT_MAX\\\": \\\"25683\\\", \\\"export ERL_EPMD_ADDRESS\\\": \\\"%{hiera(\'rabbitmq::interface\')}\\\"}, \\\"tripleo::profile::base::rabbitmq::additional_erl_args\\\": {\\\"get_param\\\": \\\"RabbitAdditionalErlArgs\\\"}, \\\"rabbitmq_kernel_variables\\\": {\\\"inet_dist_listen_min\\\": \\\"25672\\\", \\\"inet_dist_listen_max\\\": \\\"25672\\\", \\\"net_ticktime\\\": {\\\"get_param\\\": \\\"RabbitNetTickTime\\\"}}, \\\"rabbitmq_config_variables\\\": {\\\"cluster_partition_handling\\\": \\\"ignore\\\", \\\"queue_master_locator\\\": \\\"<<\\\\\\\"min-masters\\\\\\\">>\\\"}, \\\"rabbitmq::config_additional_variables\\\": {\\\"lager\\\": \\\"[{crash_log_count, 0}, { crash_log_date, \\\\\\\"\\\\\\\"}, { crash_log_size, 0 }]\\\"}, \\\"rabbitmq::erlang_cookie\\\": {\\\"get_param\\\": \\\"RabbitCookie\\\"}, \\\"rabbitmq::interface\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"RabbitmqNetwork\\\"]}}}}, \\\"rabbitmq::nr_ha_queues\\\": {\\\"get_param\\\": \\\"RabbitHAQueues\\\"}, \\\"rabbitmq::ssl\\\": {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, \\\"rabbitmq::ssl_erl_dist\\\": {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, \\\"rabbitmq::ssl_port\\\": 5672, \\\"rabbitmq::ssl_depth\\\": 1, \\\"rabbitmq::ssl_only\\\": {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, \\\"rabbitmq::ssl_interface\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"RabbitmqNetwork\\\"]}}}}, \\\"tripleo::profile::base::rabbitmq::enable_internal_tls\\\": {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, \\\"tripleo::profile::base::rabbitmq::fips_mode\\\": {\\\"get_param\\\": \\\"RabbitFIPS\\\"}, \\\"rabbitmq::collect_statistics_interval\\\": 30000}, {\\\"if\\\": [\\\"internal_tls_enabled\\\", {\\\"tripleo::rabbitmq::service_certificate\\\": \\\"/etc/pki/tls/certs/rabbitmq.crt\\\", \\\"tripleo::profile::base::rabbitmq::certificate_specs\\\": {\\\"service_certificate\\\": \\\"/etc/pki/tls/certs/rabbitmq.crt\\\", \\\"service_key\\\": \\\"/etc/pki/tls/private/rabbitmq.key\\\"}, \\\"rabbitmq::ssl_versions\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"RabbitFIPS\\\"}, [\\\"tlsv1.2\\\", \\\"tlsv1.3\\\"], [\\\"tlsv1.2\\\"]]}}, {}]}, {\\\"rabbitmq::admin_enable\\\": false, \\\"rabbitmq::management_enable\\\": true, \\\"rabbitmq::use_config_file_for_plugins\\\": true, \\\"rabbitmq::management_ip_address\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"RabbitmqEnableManagementAccess\\\"}, {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"RabbitmqManagementNetwork\\\"]}}}}, \\\"127.0.0.1\\\"]}, \\\"rabbitmq::management_port\\\": 15672, \\\"rabbitmq::config_management_variables\\\": {\\\"rates_mode\\\": \\\"none\\\"}}, {\\\"if\\\": [\\\"rabbitmq_cacert_set\\\", {\\\"rabbitmq::ssl_cacert\\\": {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, \\\"rabbitmq::ssl_management_cacert\\\": {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}}]}, {\\\"if\\\": [\\\"internal_tls_enabled\\\", {\\\"tripleo::certmonger::rabbitmq::postsave_cmd\\\": \\\"true\\\"}, {}]}]}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"rabbitmq\\\", \\\"step_config\\\": {\\\"list_join\\\": [\\\"\\\\n\\\", [\\\"[\'Rabbitmq_policy\', \'Rabbitmq_user\'].each |String $val| { noop_resource($val) }\\\", \\\"include tripleo::profile::base::rabbitmq\\\"]]}, \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/rabbitmq.json\\\": {\\\"command\\\": \\\"/usr/lib/rabbitmq/bin/rabbitmq-server\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-tls/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true, \\\"optional\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/lib/rabbitmq\\\", \\\"owner\\\": \\\"rabbitmq:rabbitmq\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/certs/rabbitmq.crt\\\", \\\"owner\\\": \\\"rabbitmq:rabbitmq\\\", \\\"optional\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/private/rabbitmq.key\\\", \\\"owner\\\": \\\"rabbitmq:rabbitmq\\\", \\\"optional\\\": true}]}}, \\\"docker_config\\\": {\\\"step_1\\\": {\\\"rabbitmq_init_logs\\\": {\\\"start_order\\\": 0, \\\"detach\\\": false, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}, \\\"net\\\": \\\"none\\\", \\\"privileged\\\": false, \\\"user\\\": \\\"root\\\", \\\"volumes\\\": [\\\"/var/log/containers/rabbitmq:/var/log/rabbitmq\\\"], \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R rabbitmq:rabbitmq /var/log/rabbitmq\\\"]}, \\\"rabbitmq_bootstrap\\\": {\\\"start_order\\\": 1, \\\"detach\\\": false, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"user\\\": \\\"root\\\", \\\"command\\\": [\\\"bash\\\", \\\"-ec\\\", {\\\"list_join\\\": [\\\"\\\\n\\\", [\\\"kolla_set_configs\\\", \\\"if [[ -e \\\\\\\"/var/lib/rabbitmq/.erlang.cookie\\\\\\\" ]]; then rm -f /var/lib/rabbitmq/.erlang.cookie; fi\\\", \\\"hiera \'rabbitmq::erlang_cookie\' > /var/lib/rabbitmq/.erlang.cookie\\\", \\\"chown rabbitmq:rabbitmq /var/lib/rabbitmq/.erlang.cookie\\\", \\\"chmod 400 /var/lib/rabbitmq/.erlang.cookie\\\"]]}], \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/rabbitmq.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/rabbitmq:/var/lib/kolla/config_files/src:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/lib/rabbitmq:/var/lib/rabbitmq\\\", \\\"/var/log/containers/rabbitmq:/var/log/rabbitmq\\\"], {\\\"if\\\": [\\\"internal_tls_enabled\\\", [\\\"/etc/pki/tls/certs/rabbitmq.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/rabbitmq.crt:ro\\\", \\\"/etc/pki/tls/private/rabbitmq.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/rabbitmq.key:ro\\\"], null]}]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\", \\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}}}, \\\"rabbitmq\\\": {\\\"start_order\\\": 2, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/rabbitmq.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/rabbitmq:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/rabbitmq:/var/lib/rabbitmq:z\\\", \\\"/var/log/containers/rabbitmq:/var/log/rabbitmq:z\\\"], {\\\"if\\\": [\\\"internal_tls_enabled\\\", [\\\"/etc/pki/tls/certs/rabbitmq.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/rabbitmq.crt:ro\\\", \\\"/etc/pki/tls/private/rabbitmq.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/rabbitmq.key:ro\\\"], null]}]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"container_puppet_tasks\\\": {\\\"step_2\\\": {\\\"config_volume\\\": \\\"rabbit_init_tasks\\\", \\\"puppet_tags\\\": \\\"rabbitmq_policy,rabbitmq_user\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::rabbitmq\\\", \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqConfigImage\\\"]}, \\\"volumes\\\": [\\\"/var/lib/config-data/puppet-generated/rabbitmq/etc/rabbitmq:/etc/rabbitmq:ro\\\", \\\"/var/lib/rabbitmq:/var/lib/rabbitmq\\\"]}}, \\\"metadata_settings\\\": {\\\"if\\\": [\\\"internal_tls_enabled\\\", [{\\\"service\\\": \\\"rabbitmq\\\", \\\"network\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"RabbitmqNetwork\\\"]}, \\\"type\\\": \\\"node\\\"}], null]}, \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Certificate generation\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"enable_internal_tls\\\"], \\\"block\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"linux-system-roles.certificate\\\"}, \\\"vars\\\": {\\\"certificate_requests\\\": [{\\\"name\\\": \\\"rabbitmq\\\", \\\"dns\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"{{fqdn_$NETWORK}}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"RabbitmqNetwork\\\"]}}}}, \\\"principal\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"rabbitmq/{{fqdn_$NETWORK}}@{{idm_realm}}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"RabbitmqNetwork\\\"]}}}}, \\\"run_after\\\": \\\"container_name=$({{container_cli}} ps --format=\\\\\\\\{\\\\\\\\{.Names\\\\\\\\}\\\\\\\\} | grep -w -E \'rabbitmq(-bundle-.*-[0-9]+)?\')\\\\nservice_crt=\\\\\\\"/etc/pki/tls/certs/rabbitmq.crt\\\\\\\"\\\\nservice_key=\\\\\\\"/etc/pki/tls/private/rabbitmq.key\\\\\\\"\\\\nif echo \\\\\\\"$container_name\\\\\\\" | grep -q \\\\\\\"^rabbitmq-bundle\\\\\\\"; then\\\\n  # lp#1917868: Do not use podman cp with HA containers as they get\\\\n  # frozen temporarily and that can make pacemaker operation fail.\\\\n  tar -c \\\\\\\"$service_crt\\\\\\\" \\\\\\\"$service_key\\\\\\\" | {{container_cli}} exec -i \\\\\\\"$container_name\\\\\\\" tar -C / -xv\\\\n  # no need to update the mount point, because pacemaker\\\\n  # recreates the container when it\'s restarted\\\\nelse\\\\n  # Refresh the cert at the mount-point\\\\n  {{container_cli}} cp $service_crt \\\\\\\"$container_name:/var/lib/kolla/config_files/src-tls/$service_crt\\\\\\\"\\\\n  # Refresh the key at the mount-point\\\\n  {{container_cli}} cp $service_key \\\\\\\"$container_name:/var/lib/kolla/config_files/src-tls/$service_key\\\\\\\"\\\\n  # Copy the new cert from the mount-point to the real path\\\\n  {{container_cli}} exec -u root \\\\\\\"$container_name\\\\\\\" cp \\\\\\\"/var/lib/kolla/config_files/src-tls$service_crt\\\\\\\" \\\\\\\"$service_crt\\\\\\\"\\\\n  # Copy the new key from the mount-point to the real path\\\\n  {{container_cli}} exec -u root \\\\\\\"$container_name\\\\\\\" cp \\\\\\\"/var/lib/kolla/config_files/src-tls$service_key\\\\\\\" \\\\\\\"$service_key\\\\\\\"\\\\nfi\\\\n# Set appropriate permissions\\\\n{{container_cli}} exec -u root \\\\\\\"$container_name\\\\\\\" chown rabbitmq:rabbitmq \\\\\\\"$service_crt\\\\\\\"\\\\n{{container_cli}} exec -u root \\\\\\\"$container_name\\\\\\\" chown rabbitmq:rabbitmq \\\\\\\"$service_key\\\\\\\"\\\\n# Trigger a pem cache clear in RabbitMQ to read the new certificates\\\\n{{container_cli}} exec \\\\\\\"$container_name\\\\\\\" rabbitmqctl eval \\\\\\\"ssl:clear_pem_cache().\\\\\\\"\\\\n\\\", \\\"key_size\\\": {\\\"if\\\": [\\\"key_size_override_unset\\\", {\\\"get_param\\\": \\\"CertificateKeySize\\\"}, {\\\"get_param\\\": \\\"RabbitmqCertificateKeySize\\\"}]}, \\\"ca\\\": \\\"ipa\\\"}]}}]}], \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"creat fcontext entry for rabbitmq data\\\", \\\"community.general.sefcontext\\\": {\\\"target\\\": \\\"/var/lib/rabbitmq(/.*)?\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"state\\\": \\\"present\\\"}}, {\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode|default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/rabbitmq\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/lib/rabbitmq\\\", \\\"setype\\\": \\\"container_file_t\\\"}]}], \\\"upgrade_tasks\\\": [], \\\"update_tasks\\\": null}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Rabbitmq service\\\\n\\\", \\\"parameters\\\": {\\\"ContainerRabbitmqImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerRabbitmqConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the rabbitmq config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"RabbitCookie\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"hidden\\\": true}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"RpcPort\\\": {\\\"default\\\": 5672, \\\"description\\\": \\\"The network port for messaging backend\\\", \\\"type\\\": \\\"number\\\"}, \\\"RpcUserName\\\": {\\\"default\\\": \\\"guest\\\", \\\"description\\\": \\\"The username for messaging backend\\\", \\\"type\\\": \\\"string\\\"}, \\\"RpcPassword\\\": {\\\"description\\\": \\\"The password for messaging backend\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"RpcUseSSL\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Messaging client subscriber parameter to specify an SSL connection to the messaging host.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"DeployIdentifier\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\\\n\\\"}, \\\"CertificateKeySize\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"2048\\\", \\\"description\\\": \\\"Specifies the private key size used when creating the certificate.\\\"}, \\\"RpcCertificateKeySize\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Override the private key size used when creating the certificate for this service\\\"}, \\\"RabbitFIPS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false, \\\"description\\\": \\\"Configures RabbitMQ to run in FIPS mode\\\"}}, \\\"conditions\\\": {\\\"internal_tls_enabled\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, true]}, \\\"key_size_override_unset\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"RpcCertificateKeySize\\\"}, \\\"\\\"]}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"RabbitMQServiceBase\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-container-puppet.yaml\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerRabbitmqImage\\\": \\\"ContainerRabbitmqImage\\\", \\\"ContainerRabbitmqConfigImage\\\": \\\"ContainerRabbitmqConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerRabbitmqImage\\\": {\\\"get_param\\\": \\\"ContainerRabbitmqImage\\\"}, \\\"ContainerRabbitmqConfigImage\\\": {\\\"get_param\\\": \\\"ContainerRabbitmqConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Rabbitmq API role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"oslo_messaging_rpc\\\", \\\"firewall_rules\\\": {\\\"109 rabbitmq\\\": {\\\"dport\\\": [4369, {\\\"get_param\\\": \\\"RpcPort\\\"}, 25672, \\\"25673-25683\\\"]}}, \\\"monitoring_subscription\\\": {\\\"get_attr\\\": [\\\"RabbitMQServiceBase\\\", \\\"role_data\\\", \\\"monitoring_subscription\\\"]}, \\\"global_config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"RabbitMQServiceBase\\\", \\\"role_data\\\", \\\"global_config_settings\\\"]}, {\\\"oslo_messaging_rpc_scheme\\\": \\\"rabbit\\\", \\\"oslo_messaging_rpc_user_name\\\": {\\\"get_param\\\": \\\"RpcUserName\\\"}, \\\"oslo_messaging_rpc_password\\\": {\\\"get_param\\\": \\\"RpcPassword\\\"}, \\\"oslo_messaging_rpc_use_ssl\\\": {\\\"get_param\\\": \\\"RpcUseSSL\\\"}, \\\"oslo_messaging_rpc_port\\\": {\\\"get_param\\\": \\\"RpcPort\\\"}}]}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"RabbitMQServiceBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"rabbitmq::default_user\\\": {\\\"get_param\\\": \\\"RpcUserName\\\"}, \\\"rabbitmq::default_pass\\\": {\\\"get_param\\\": \\\"RpcPassword\\\"}, \\\"rabbitmq::port\\\": {\\\"get_param\\\": \\\"RpcPort\\\"}, \\\"rabbitmq::interface\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OsloMessagingRpcNetwork\\\"]}}}}, \\\"rabbitmq::ssl\\\": {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, \\\"rabbitmq::ssl_erl_dist\\\": {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, \\\"rabbitmq::ssl_port\\\": {\\\"get_param\\\": \\\"RpcPort\\\"}, \\\"rabbitmq::ssl_only\\\": {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, \\\"rabbitmq::ssl_interface\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OsloMessagingRpcNetwork\\\"]}}}}, \\\"tripleo::profile::base::rabbitmq::enable_internal_tls\\\": {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, \\\"rabbitmq::collect_statistics_interval\\\": 30000, \\\"rabbitmq::admin_enable\\\": false, \\\"rabbitmq::management_enable\\\": true, \\\"rabbitmq::use_config_file_for_plugins\\\": true, \\\"rabbitmq::management_ip_address\\\": \\\"127.0.0.1\\\", \\\"rabbitmq::config_management_variables\\\": {\\\"rates_mode\\\": \\\"none\\\"}}, {\\\"if\\\": [\\\"internal_tls_enabled\\\", {\\\"tripleo::rabbitmq::service_certificate\\\": \\\"/etc/pki/tls/certs/rabbitmq.crt\\\", \\\"tripleo::certmonger::rabbitmq::postsave_cmd\\\": \\\"true\\\", \\\"tripleo::profile::base::rabbitmq::certificate_specs\\\": {\\\"service_certificate\\\": \\\"/etc/pki/tls/certs/rabbitmq.crt\\\", \\\"service_key\\\": \\\"/etc/pki/tls/private/rabbitmq.key\\\"}, \\\"rabbitmq::ssl_versions\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"RabbitFIPS\\\"}, [\\\"tlsv1.2\\\", \\\"tlsv1.3\\\"], [\\\"tlsv1.2\\\"]]}}, {}]}]}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"rabbitmq\\\", \\\"step_config\\\": {\\\"list_join\\\": [\\\"\\\\n\\\", [\\\"[\'Rabbitmq_policy\', \'Rabbitmq_user\'].each |String $val| { noop_resource($val) }\\\", \\\"include tripleo::profile::base::rabbitmq\\\"]]}, \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/rabbitmq.json\\\": {\\\"command\\\": \\\"/usr/lib/rabbitmq/bin/rabbitmq-server\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-tls/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true, \\\"optional\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/lib/rabbitmq\\\", \\\"owner\\\": \\\"rabbitmq:rabbitmq\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/certs/rabbitmq.crt\\\", \\\"owner\\\": \\\"rabbitmq:rabbitmq\\\", \\\"optional\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/private/rabbitmq.key\\\", \\\"owner\\\": \\\"rabbitmq:rabbitmq\\\", \\\"optional\\\": true}]}}, \\\"docker_config\\\": {\\\"step_1\\\": {\\\"rabbitmq_init_logs\\\": {\\\"start_order\\\": 0, \\\"detach\\\": false, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}, \\\"net\\\": \\\"none\\\", \\\"privileged\\\": false, \\\"user\\\": \\\"root\\\", \\\"volumes\\\": [\\\"/var/log/containers/rabbitmq:/var/log/rabbitmq:z\\\"], \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R rabbitmq:rabbitmq /var/log/rabbitmq\\\"]}, \\\"rabbitmq_bootstrap\\\": {\\\"start_order\\\": 1, \\\"detach\\\": false, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"user\\\": \\\"root\\\", \\\"command\\\": [\\\"bash\\\", \\\"-ec\\\", {\\\"list_join\\\": [\\\"\\\\n\\\", [\\\"kolla_set_configs\\\", \\\"if [[ -e \\\\\\\"/var/lib/rabbitmq/.erlang.cookie\\\\\\\" ]]; then rm -f /var/lib/rabbitmq/.erlang.cookie; fi\\\", \\\"hiera \'rabbitmq::erlang_cookie\' > /var/lib/rabbitmq/.erlang.cookie\\\", \\\"chown rabbitmq:rabbitmq /var/lib/rabbitmq/.erlang.cookie\\\", \\\"chmod 400 /var/lib/rabbitmq/.erlang.cookie\\\"]]}], \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/rabbitmq.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/rabbitmq:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/rabbitmq:/var/lib/rabbitmq:z\\\", \\\"/var/log/containers/rabbitmq:/var/log/rabbitmq:z\\\"], {\\\"if\\\": [\\\"internal_tls_enabled\\\", [\\\"/etc/pki/tls/certs/rabbitmq.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/rabbitmq.crt:ro\\\", \\\"/etc/pki/tls/private/rabbitmq.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/rabbitmq.key:ro\\\"], null]}]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\", \\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}}}, \\\"rabbitmq\\\": {\\\"start_order\\\": 2, \\\"stop_grace_period\\\": 60, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/rabbitmq.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/rabbitmq:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/rabbitmq:/var/lib/rabbitmq:z\\\", \\\"/var/log/containers/rabbitmq:/var/log/rabbitmq:z\\\"], {\\\"if\\\": [\\\"internal_tls_enabled\\\", [\\\"/etc/pki/tls/certs/rabbitmq.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/rabbitmq.crt:ro\\\", \\\"/etc/pki/tls/private/rabbitmq.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/rabbitmq.key:ro\\\"], null]}]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"container_puppet_tasks\\\": {\\\"step_2\\\": {\\\"config_volume\\\": \\\"rabbit_init_tasks\\\", \\\"puppet_tags\\\": \\\"rabbitmq_policy,rabbitmq_user\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::rabbitmq\\\", \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqConfigImage\\\"]}, \\\"volumes\\\": [\\\"/var/lib/config-data/puppet-generated/rabbitmq/etc/rabbitmq:/etc/rabbitmq:ro\\\", \\\"/var/lib/rabbitmq:/var/lib/rabbitmq:z\\\"]}}, \\\"metadata_settings\\\": {\\\"if\\\": [\\\"internal_tls_enabled\\\", [{\\\"service\\\": \\\"rabbitmq\\\", \\\"network\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OsloMessagingRpcNetwork\\\"]}, \\\"type\\\": \\\"node\\\"}], null]}, \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Certificate generation\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"enable_internal_tls\\\"], \\\"block\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"linux-system-roles.certificate\\\"}, \\\"vars\\\": {\\\"certificate_requests\\\": [{\\\"name\\\": \\\"rabbitmq\\\", \\\"dns\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"{{fqdn_$NETWORK}}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OsloMessagingRpcNetwork\\\"]}}}}, \\\"principal\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"rabbitmq/{{fqdn_$NETWORK}}@{{idm_realm}}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OsloMessagingRpcNetwork\\\"]}}}}, \\\"run_after\\\": \\\"container_name=$({{container_cli}} ps --format=\\\\\\\\{\\\\\\\\{.Names\\\\\\\\}\\\\\\\\} | grep -w -E \'rabbitmq(-bundle-.*-[0-9]+)?\')\\\\nservice_crt=\\\\\\\"/etc/pki/tls/certs/rabbitmq.crt\\\\\\\"\\\\nservice_key=\\\\\\\"/etc/pki/tls/private/rabbitmq.key\\\\\\\"\\\\nif echo \\\\\\\"$container_name\\\\\\\" | grep -q \\\\\\\"^rabbitmq-bundle\\\\\\\"; then\\\\n  # lp#1917868: Do not use podman cp with HA containers as they get\\\\n  # frozen temporarily and that can make pacemaker operation fail.\\\\n  tar -c \\\\\\\"$service_crt\\\\\\\" \\\\\\\"$service_key\\\\\\\" | {{container_cli}} exec -i \\\\\\\"$container_name\\\\\\\" tar -C / -xv\\\\n  # no need to update the mount point, because pacemaker\\\\n  # recreates the container when it\'s restarted\\\\nelse\\\\n  # Refresh the cert at the mount-point\\\\n  {{container_cli}} cp $service_crt \\\\\\\"$container_name:/var/lib/kolla/config_files/src-tls/$service_crt\\\\\\\"\\\\n  # Refresh the key at the mount-point\\\\n  {{container_cli}} cp $service_key \\\\\\\"$container_name:/var/lib/kolla/config_files/src-tls/$service_key\\\\\\\"\\\\n  # Copy the new cert from the mount-point to the real path\\\\n  {{container_cli}} exec -u root \\\\\\\"$container_name\\\\\\\" cp \\\\\\\"/var/lib/kolla/config_files/src-tls$service_crt\\\\\\\" \\\\\\\"$service_crt\\\\\\\"\\\\n  # Copy the new key from the mount-point to the real path\\\\n  {{container_cli}} exec -u root \\\\\\\"$container_name\\\\\\\" cp \\\\\\\"/var/lib/kolla/config_files/src-tls$service_key\\\\\\\" \\\\\\\"$service_key\\\\\\\"\\\\nfi\\\\n# Set appropriate permissions\\\\n{{container_cli}} exec -u root \\\\\\\"$container_name\\\\\\\" chown rabbitmq:rabbitmq \\\\\\\"$service_crt\\\\\\\"\\\\n{{container_cli}} exec -u root \\\\\\\"$container_name\\\\\\\" chown rabbitmq:rabbitmq \\\\\\\"$service_key\\\\\\\"\\\\n# Trigger a pem cache clear in RabbitMQ to read the new certificates\\\\n{{container_cli}} exec \\\\\\\"$container_name\\\\\\\" rabbitmqctl eval \\\\\\\"ssl:clear_pem_cache().\\\\\\\"\\\\n\\\", \\\"key_size\\\": {\\\"if\\\": [\\\"key_size_override_unset\\\", {\\\"get_param\\\": \\\"CertificateKeySize\\\"}, {\\\"get_param\\\": \\\"RpcCertificateKeySize\\\"}]}, \\\"ca\\\": \\\"ipa\\\"}]}}]}], \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create fcontext for rabbitmq data\\\", \\\"community.general.sefcontext\\\": {\\\"target\\\": \\\"/var/lib/rabbitmq(/.*)?\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"state\\\": \\\"present\\\"}}, {\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode|default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/rabbitmq\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/lib/rabbitmq\\\", \\\"setype\\\": \\\"container_file_t\\\"}]}], \\\"upgrade_tasks\\\": [], \\\"update_tasks\\\": null}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Rabbitmq service\\\\n\\\", \\\"parameters\\\": {\\\"ContainerRabbitmqImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerRabbitmqConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the rabbitmq config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ClusterCommonTag\\\": {\\\"default\\\": false, \\\"description\\\": \\\"When set to false, a pacemaker service is configured to use a floating tag for its container image name, e.g. \'REGISTRY/NAMESPACE/IMAGENAME:pcmklatest\'. When set to true, the service uses a floating prefix as well, e.g. \'cluster.common.tag/IMAGENAME:pcmklatest\'.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"ClusterFullTag\\\": {\\\"default\\\": true, \\\"description\\\": \\\"When set to true, the pacemaker service uses a fully constant tag for its container image name, e.g. \'cluster.common.tag/SERVICENAME:pcmklatest\'.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RabbitCookie\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"hidden\\\": true}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"ConfigDebug\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to run config management (e.g. Puppet) in debug mode.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"ContainerCli\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"podman\\\", \\\"description\\\": \\\"CLI tool used to manage containers.\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"docker\\\", \\\"podman\\\"]}]}, \\\"DeployIdentifier\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\\\n\\\"}}, \\\"conditions\\\": {\\\"puppet_debug_enabled\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"docker_enabled\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"docker\\\"]}, \\\"common_tag_enabled\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, true]}, \\\"common_tag_full\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, true]}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"RabbitmqBase\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-container-puppet.yaml\\\", \\\"properties\\\": {\\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerRabbitmqImage\\\": \\\"ContainerRabbitmqImage\\\", \\\"ContainerRabbitmqConfigImage\\\": \\\"ContainerRabbitmqConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerRabbitmqImage\\\": {\\\"get_param\\\": \\\"ContainerRabbitmqImage\\\"}, \\\"ContainerRabbitmqConfigImage\\\": {\\\"get_param\\\": \\\"ContainerRabbitmqConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Rabbitmq API role.\\\", \\\"value\\\": {\\\"service_name\\\": {\\\"get_attr\\\": [\\\"RabbitmqBase\\\", \\\"role_data\\\", \\\"service_name\\\"]}, \\\"firewall_rules\\\": {\\\"109 rabbitmq-bundle\\\": {\\\"dport\\\": [3122, 4369, 5672, 25672, \\\"25673-25683\\\"]}}, \\\"global_config_settings\\\": {\\\"get_attr\\\": [\\\"RabbitmqBase\\\", \\\"role_data\\\", \\\"global_config_settings\\\"]}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"RabbitmqBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"rabbitmq::service_manage\\\": false, \\\"tripleo::profile::pacemaker::rabbitmq_bundle::rabbitmq_docker_image\\\": {\\\"if\\\": [\\\"common_tag_full\\\", \\\"cluster.common.tag/rabbitmq:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [\\\"common_tag_enabled\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"tripleo::profile::pacemaker::rabbitmq_bundle::control_port\\\": 3122, \\\"tripleo::profile::pacemaker::rabbitmq_bundle::container_backend\\\": {\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"tripleo::profile::pacemaker::rabbitmq_bundle::force_ocf\\\": true}]}, \\\"service_config_settings\\\": {\\\"get_attr\\\": [\\\"RabbitmqBase\\\", \\\"role_data\\\", \\\"service_config_settings\\\"]}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"rabbitmq\\\", \\\"puppet_tags\\\": \\\"file,file_line\\\", \\\"step_config\\\": {\\\"list_join\\\": [\\\"\\\\n\\\", [\\\"[\'Rabbitmq_policy\', \'Rabbitmq_user\'].each |String $val| { noop_resource($val) }\\\", \\\"include tripleo::profile::pacemaker::rabbitmq_bundle\\\"]]}, \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/rabbitmq.json\\\": {\\\"command\\\": \\\"/usr/sbin/pacemaker_remoted\\\", \\\"config_files\\\": [{\\\"dest\\\": \\\"/etc/libqb/force-filesystem-sockets\\\", \\\"source\\\": \\\"/dev/null\\\", \\\"owner\\\": \\\"root\\\", \\\"perm\\\": \\\"0644\\\"}, {\\\"dest\\\": \\\"/var/log/btmp\\\", \\\"source\\\": \\\"/dev/null\\\", \\\"owner\\\": \\\"root:utmp\\\", \\\"perm\\\": \\\"0600\\\"}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-tls/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"optional\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/lib/rabbitmq\\\", \\\"owner\\\": \\\"rabbitmq:rabbitmq\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/var/log/rabbitmq\\\", \\\"owner\\\": \\\"rabbitmq:rabbitmq\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/certs/rabbitmq.crt\\\", \\\"owner\\\": \\\"rabbitmq:rabbitmq\\\", \\\"perm\\\": \\\"0600\\\", \\\"optional\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/private/rabbitmq.key\\\", \\\"owner\\\": \\\"rabbitmq:rabbitmq\\\", \\\"perm\\\": \\\"0600\\\", \\\"optional\\\": true}]}}, \\\"container_config_scripts\\\": {\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"container_config_scripts\\\"]}, \\\"docker_config\\\": {\\\"step_1\\\": {\\\"rabbitmq_bootstrap\\\": {\\\"start_order\\\": 0, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"user\\\": \\\"root\\\", \\\"command\\\": [\\\"bash\\\", \\\"-ec\\\", {\\\"list_join\\\": [\\\"\\\\n\\\", [\\\"kolla_set_configs\\\", \\\"if [[ -e \\\\\\\"/var/lib/rabbitmq/.erlang.cookie\\\\\\\" ]]; then rm -f /var/lib/rabbitmq/.erlang.cookie; fi\\\", \\\"hiera \'rabbitmq::erlang_cookie\' > /var/lib/rabbitmq/.erlang.cookie\\\", \\\"chown rabbitmq:rabbitmq /var/lib/rabbitmq/.erlang.cookie\\\", \\\"chmod 400 /var/lib/rabbitmq/.erlang.cookie\\\"]]}], \\\"volumes\\\": [\\\"/var/lib/kolla/config_files/rabbitmq.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/rabbitmq:/var/lib/kolla/config_files/src:ro\\\", \\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/var/lib/rabbitmq:/var/lib/rabbitmq:z\\\", \\\"/etc/puppet:/etc/puppet:ro,z\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\", \\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}}}}, \\\"step_2\\\": {\\\"rabbitmq_wait_bundle\\\": {\\\"start_order\\\": 0, \\\"detach\\\": false, \\\"net\\\": \\\"host\\\", \\\"ipc\\\": \\\"host\\\", \\\"user\\\": \\\"root\\\", \\\"command\\\": {\\\"list_concat\\\": [[\\\"/container_puppet_apply.sh\\\", \\\"2\\\", \\\"file,file_line,concat,augeas,rabbitmq_policy,rabbitmq_user,rabbitmq_ready\\\", \\\"include tripleo::profile::pacemaker::rabbitmq_bundle\\\"], {\\\"if\\\": [\\\"puppet_debug_enabled\\\", [\\\"--debug\\\"], [\\\"\\\"]]}]}, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"container_puppet_apply_volumes\\\"]}, [\\\"/bin/true:/bin/epmd\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\", \\\"KOLLA_BOOTSTRAP\\\": true, \\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}}}}}, \\\"metadata_settings\\\": {\\\"get_attr\\\": [\\\"RabbitmqBase\\\", \\\"role_data\\\", \\\"metadata_settings\\\"]}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create fcontext for rabbitmq data\\\", \\\"community.general.sefcontext\\\": {\\\"target\\\": \\\"/var/lib/rabbitmq(/.*)?\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"state\\\": \\\"present\\\"}}, {\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode|default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/lib/rabbitmq\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/log/containers/rabbitmq\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}, {\\\"name\\\": \\\"stop the Erlang port mapper on the host and make sure it cannot bind to the port used by container\\\", \\\"shell\\\": \\\"echo \'export ERL_EPMD_ADDRESS=127.0.0.1\' > /etc/rabbitmq/rabbitmq-env.conf\\\\necho \'export ERL_EPMD_PORT=4370\' >> /etc/rabbitmq/rabbitmq-env.conf\\\\nfor pid in $(pgrep epmd --ns 1 --nslist pid); do kill $pid; done\\\\n\\\"}], \\\"deploy_steps_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"RabbitmqBase\\\", \\\"role_data\\\", \\\"deploy_steps_tasks\\\"]}, [{\\\"name\\\": \\\"RabbitMQ tag container image for pacemaker\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_tag\\\"}, \\\"vars\\\": {\\\"container_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}, \\\"container_image_latest\\\": {\\\"if\\\": [\\\"common_tag_full\\\", \\\"cluster.common.tag/rabbitmq:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [\\\"common_tag_enabled\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}}}, {\\\"name\\\": \\\"RabbitMQ RPC HA Wrappers Step\\\", \\\"when\\\": \\\"step|int == 2\\\", \\\"block\\\": [{\\\"name\\\": \\\"Rabbitmq rpc puppet bundle\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_ha_wrapper\\\"}, \\\"vars\\\": {\\\"tripleo_ha_wrapper_service_name\\\": \\\"oslo_messaging_rpc\\\", \\\"tripleo_ha_wrapper_resource_name\\\": \\\"rabbitmq\\\", \\\"tripleo_ha_wrapper_bundle_name\\\": \\\"rabbitmq-bundle\\\", \\\"tripleo_ha_wrapper_resource_state\\\": \\\"Started\\\", \\\"tripleo_ha_wrapper_puppet_config_volume\\\": \\\"rabbitmq\\\", \\\"tripleo_ha_wrapper_puppet_execute\\\": \\\"[\\\\\\\"Rabbitmq_policy\\\\\\\", \\\\\\\"Rabbitmq_user\\\\\\\"].each |String $val| { noop_resource($val) }; include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::rabbitmq_bundle\\\", \\\"tripleo_ha_wrapper_puppet_tags\\\": \\\"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\\\", \\\"tripleo_ha_wrapper_puppet_debug\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"tripleo_ha_wrapper_config_suffix\\\": \\\".previous_run\\\"}}]}]]}, \\\"external_update_tasks\\\": [{\\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": \\\"ha_image_update\\\", \\\"block\\\": [{\\\"block\\\": [{\\\"name\\\": \\\"Get rabbitmq image from pacemaker\\\", \\\"become\\\": true, \\\"register\\\": \\\"xmllint_pcmk_rabbitmq_rpc_image\\\", \\\"shell\\\": \\\"xmllint --xpath \\\\\\\"string(//bundle[@id=\'rabbitmq-bundle\']/podman/@image)\\\\\\\" /var/lib/pacemaker/cib/cib.xml\\\"}, {\\\"name\\\": \\\"Get container rabbitmq image\\\", \\\"set_fact\\\": {\\\"rabbitmq_rpc_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}, \\\"rabbitmq_rpc_image_latest\\\": {\\\"if\\\": [\\\"common_tag_full\\\", \\\"cluster.common.tag/rabbitmq:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [\\\"common_tag_enabled\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"pcmk_rabbitmq_rpc_image\\\": \\\"{{xmllint_pcmk_rabbitmq_rpc_image.stdout}}\\\"}}], \\\"delegate_to\\\": \\\"{{ (groups[\\\\\\\"oslo_messaging_rpc\\\\\\\"] | difference(groups[\\\\\\\"excluded_overcloud\\\\\\\"]))[0] }}\\\"}, {\\\"name\\\": \\\"rabbitmq temporary pacemaker container tag in case of image switch\\\", \\\"become\\\": true, \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_ha_image_update\\\"}, \\\"vars\\\": {\\\"tripleo_ha_image_update_node_names\\\": \\\"{{ groups[\\\\\\\"oslo_messaging_rpc\\\\\\\"] | difference(groups[\\\\\\\"excluded_overcloud\\\\\\\"]) }}\\\", \\\"tripleo_ha_image_update_bundle\\\": \\\"rabbitmq-bundle\\\", \\\"tripleo_ha_image_update_new_image\\\": \\\"{{rabbitmq_rpc_image_latest}}\\\", \\\"tripleo_ha_image_update_old_image\\\": \\\"{{pcmk_rabbitmq_rpc_image}}\\\"}, \\\"when\\\": [\\\"(pcmk_rabbitmq_rpc_image != \\\\\\\"\\\\\\\")\\\", \\\"(pcmk_rabbitmq_rpc_image != rabbitmq_rpc_image_latest)\\\"]}]}], \\\"update_tasks\\\": [{\\\"block\\\": [{\\\"name\\\": \\\"Get rabbitmq image from pacemaker\\\", \\\"become\\\": true, \\\"register\\\": \\\"xmllint_pcmk_rabbitmq_rpc_image\\\", \\\"shell\\\": \\\"xmllint --xpath \\\\\\\"string(//bundle[@id=\'rabbitmq-bundle\']/podman/@image)\\\\\\\" /var/lib/pacemaker/cib/cib.xml\\\"}, {\\\"name\\\": \\\"Get container rabbitmq image\\\", \\\"set_fact\\\": {\\\"rabbitmq_rpc_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}, \\\"rabbitmq_rpc_image_latest\\\": {\\\"if\\\": [\\\"common_tag_full\\\", \\\"cluster.common.tag/rabbitmq:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [\\\"common_tag_enabled\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"pcmk_rabbitmq_rpc_image\\\": \\\"{{xmllint_pcmk_rabbitmq_rpc_image.stdout}}\\\"}}], \\\"when\\\": \\\"(step|int == 0 or step|int == 2)\\\"}, {\\\"name\\\": \\\"Check for update of rabbitmq container image name\\\", \\\"when\\\": \\\"step|int == 0\\\", \\\"assert\\\": {\\\"that\\\": \\\"pcmk_rabbitmq_rpc_image == rabbitmq_rpc_image_latest\\\", \\\"fail_msg\\\": \\\"rabbitmq image change detected, run overcloud external-update --tags ha_image_update first\\\"}}, {\\\"name\\\": \\\"Tear-down non-HA rabbitmq container\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Remove non-HA rabbitmq container\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_rm\\\"}, \\\"vars\\\": {\\\"tripleo_container_cli\\\": \\\"{{ container_cli }}\\\", \\\"tripleo_containers_to_rm\\\": [\\\"rabbitmq\\\"]}}]}, {\\\"name\\\": \\\"Rabbitmq fetch and retag container image for pacemaker\\\", \\\"when\\\": \\\"step|int == 2\\\", \\\"block\\\": [{\\\"name\\\": \\\"Retag pcmklatest to latest rabbitmq image\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_tag\\\"}, \\\"vars\\\": {\\\"container_image\\\": \\\"{{rabbitmq_rpc_image}}\\\", \\\"container_image_latest\\\": \\\"{{rabbitmq_rpc_image_latest}}\\\"}}]}], \\\"post_update_tasks\\\": [{\\\"name\\\": \\\"Rabbitmq rpc bundle post update\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Rabbitmq rpc puppet bundle\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_ha_wrapper\\\"}, \\\"vars\\\": {\\\"tripleo_ha_wrapper_service_name\\\": \\\"oslo_messaging_rpc\\\", \\\"tripleo_ha_wrapper_resource_name\\\": \\\"rabbitmq\\\", \\\"tripleo_ha_wrapper_bundle_name\\\": \\\"rabbitmq-bundle\\\", \\\"tripleo_ha_wrapper_resource_state\\\": \\\"Started\\\", \\\"tripleo_ha_wrapper_puppet_config_volume\\\": \\\"rabbitmq\\\", \\\"tripleo_ha_wrapper_puppet_execute\\\": \\\"[\\\\\\\"Rabbitmq_policy\\\\\\\", \\\\\\\"Rabbitmq_user\\\\\\\"].each |String $val| { noop_resource($val) }; include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::rabbitmq_bundle\\\", \\\"tripleo_ha_wrapper_puppet_tags\\\": \\\"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\\\", \\\"tripleo_ha_wrapper_puppet_debug\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"tripleo_ha_wrapper_config_suffix\\\": \\\".previous_run\\\"}}], \\\"vars\\\": {\\\"tripleo_ha_wrapper_minor_update\\\": true}}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"Tear-down non-HA rabbitmq container\\\", \\\"when\\\": [\\\"step|int == 0\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Remove non-HA rabbitmq container\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_rm\\\"}, \\\"vars\\\": {\\\"tripleo_container_cli\\\": \\\"{{ container_cli }}\\\", \\\"tripleo_containers_to_rm\\\": [\\\"rabbitmq\\\"]}}]}, {\\\"name\\\": \\\"Prepare switch of rabbitmq image name\\\", \\\"when\\\": [\\\"step|int == 0\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Get rabbitmq image id currently used by pacemaker\\\", \\\"shell\\\": \\\"pcs resource config rabbitmq-bundle | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\\\", \\\"register\\\": \\\"rabbitmq_rpc_image_current_res\\\", \\\"failed_when\\\": false}, {\\\"name\\\": \\\"Image facts for rabbitmq\\\", \\\"set_fact\\\": {\\\"rabbitmq_rpc_image_latest\\\": {\\\"if\\\": [\\\"common_tag_full\\\", \\\"cluster.common.tag/rabbitmq:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [\\\"common_tag_enabled\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"rabbitmq_rpc_image_current\\\": \\\"{{rabbitmq_rpc_image_current_res.stdout}}\\\"}}, {\\\"name\\\": \\\"Temporarily tag the current rabbitmq image id with the upgraded image name\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_tag\\\"}, \\\"vars\\\": {\\\"container_image\\\": \\\"{{rabbitmq_rpc_image_current}}\\\", \\\"container_image_latest\\\": \\\"{{rabbitmq_rpc_image_latest}}\\\", \\\"pull_image\\\": false}, \\\"when\\\": [\\\"rabbitmq_rpc_image_current != \'\'\\\", \\\"rabbitmq_rpc_image_current != rabbitmq_rpc_image_latest\\\"]}, {\\\"name\\\": \\\"Create rabbitmq_rpc retag statefile\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/tripleo/rabbitmq_rpc_needs_retag\\\", \\\"state\\\": \\\"touch\\\"}, \\\"when\\\": [\\\"rabbitmq_rpc_image_current != \'\'\\\", \\\"rabbitmq_rpc_image_current != rabbitmq_rpc_image_latest\\\"]}]}, {\\\"name\\\": \\\"Update rabbitmq-bundle pcs resource bundle for new container image\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"set is_rpc_rabbitmq_bootstrap_node fact\\\", \\\"set_fact\\\": \\\"is_rpc_rabbitmq_bootstrap_node={{oslo_messaging_rpc_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\\\"}, {\\\"name\\\": \\\"Check for rabbitmq_rpc retag statefile\\\", \\\"stat\\\": {\\\"path\\\": \\\"/var/lib/tripleo/rabbitmq_rpc_needs_retag\\\"}, \\\"register\\\": \\\"rabbitmq_rpc_retag_state_file\\\"}]}, {\\\"name\\\": \\\"Update rabbitmq-bundle pcs resource bundle for new container image\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"is_rpc_rabbitmq_bootstrap_node|bool\\\", \\\"rabbitmq_rpc_retag_state_file.stat.exists|bool\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Disable the rabbitmq cluster resource before container upgrade\\\", \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"rabbitmq-bundle\\\", \\\"state\\\": \\\"disable\\\", \\\"wait_for_resource\\\": true}, \\\"register\\\": \\\"output\\\", \\\"retries\\\": 5, \\\"until\\\": \\\"output.rc == 0\\\"}, {\\\"name\\\": \\\"Check rabbitmq logging configuration in pacemaker\\\", \\\"command\\\": \\\"cibadmin --query --xpath \\\\\\\"//storage-mapping[@id=\'rabbitmq-log\']\\\\\\\"\\\", \\\"failed_when\\\": false, \\\"register\\\": \\\"rabbitmq_logs_moved\\\"}, {\\\"name\\\": \\\"Add a bind mount for logging in the rabbitmq bundle\\\", \\\"when\\\": \\\"rabbitmq_logs_moved.rc == 6\\\", \\\"command\\\": \\\"pcs resource bundle update rabbitmq-bundle storage-map add id=rabbitmq-log source-dir=/var/log/containers/rabbitmq target-dir=/var/log/rabbitmq options=rw\\\"}, {\\\"name\\\": \\\"Update the rabbitmq bundle to use the new container image name\\\", \\\"command\\\": \\\"pcs resource bundle update rabbitmq-bundle container image={{rabbitmq_rpc_image_latest}}\\\"}, {\\\"name\\\": \\\"Enable the rabbitmq cluster resource\\\", \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"rabbitmq-bundle\\\", \\\"state\\\": \\\"enable\\\", \\\"wait_for_resource\\\": true}, \\\"register\\\": \\\"output\\\", \\\"retries\\\": 5, \\\"until\\\": \\\"output.rc == 0\\\"}]}, {\\\"name\\\": \\\"Check for rabbitmq_rpc retag statefile\\\", \\\"when\\\": [\\\"step|int == 3\\\"], \\\"stat\\\": {\\\"path\\\": \\\"/var/lib/tripleo/rabbitmq_rpc_needs_retag\\\"}, \\\"register\\\": \\\"rabbitmq_rpc_retag_state_file\\\"}, {\\\"name\\\": \\\"Retag rabbitmq-bundle container image\\\", \\\"when\\\": [\\\"step|int == 3\\\", \\\"rabbitmq_rpc_retag_state_file.stat.exists|bool\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Disable the rabbitmq cluster resource before container upgrade\\\", \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"rabbitmq-bundle\\\", \\\"state\\\": \\\"disable\\\", \\\"wait_for_resource\\\": true}, \\\"register\\\": \\\"output\\\", \\\"retries\\\": 5, \\\"until\\\": \\\"output.rc == 0\\\"}, {\\\"name\\\": \\\"Retag the pacemaker image if containerized\\\", \\\"block\\\": [{\\\"block\\\": [{\\\"name\\\": \\\"Get rabbitmq image from pacemaker\\\", \\\"become\\\": true, \\\"register\\\": \\\"xmllint_pcmk_rabbitmq_rpc_image\\\", \\\"shell\\\": \\\"xmllint --xpath \\\\\\\"string(//bundle[@id=\'rabbitmq-bundle\']/podman/@image)\\\\\\\" /var/lib/pacemaker/cib/cib.xml\\\"}, {\\\"name\\\": \\\"Get container rabbitmq image\\\", \\\"set_fact\\\": {\\\"rabbitmq_rpc_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}, \\\"rabbitmq_rpc_image_latest\\\": {\\\"if\\\": [\\\"common_tag_full\\\", \\\"cluster.common.tag/rabbitmq:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [\\\"common_tag_enabled\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"pcmk_rabbitmq_rpc_image\\\": \\\"{{xmllint_pcmk_rabbitmq_rpc_image.stdout}}\\\"}}]}, {\\\"block\\\": [{\\\"name\\\": \\\"Retag pcmklatest to latest rabbitmq image\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_tag\\\"}, \\\"vars\\\": {\\\"container_image\\\": \\\"{{rabbitmq_rpc_image}}\\\", \\\"container_image_latest\\\": \\\"{{rabbitmq_rpc_image_latest}}\\\"}}]}]}, {\\\"name\\\": \\\"Enable the rabbitmq cluster resource\\\", \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"rabbitmq-bundle\\\", \\\"state\\\": \\\"enable\\\", \\\"wait_for_resource\\\": true}, \\\"register\\\": \\\"output\\\", \\\"retries\\\": 5, \\\"until\\\": \\\"output.rc == 0\\\"}, {\\\"name\\\": \\\"Remove rabbitmq_rpc retag statefile\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/tripleo/rabbitmq_rpc_needs_retag\\\", \\\"state\\\": \\\"absent\\\"}}]}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Oslo Notify using a shared OpenStack containerized Rabbitmq service\\\\n\\\", \\\"parameters\\\": {\\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"RpcPort\\\": {\\\"default\\\": 5672, \\\"description\\\": \\\"The network port for messaging backend\\\", \\\"type\\\": \\\"number\\\"}, \\\"RpcUserName\\\": {\\\"default\\\": \\\"guest\\\", \\\"description\\\": \\\"The username for messaging backend\\\", \\\"type\\\": \\\"string\\\"}, \\\"RpcPassword\\\": {\\\"description\\\": \\\"The password for messaging backend\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"RpcUseSSL\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Messaging client subscriber parameter to specify an SSL connection to the messaging host.\\\\n\\\", \\\"type\\\": \\\"string\\\"}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\\\"}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the oslo messaging notify role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"oslo_messaging_notify\\\", \\\"global_config_settings\\\": {\\\"oslo_messaging_notify_scheme\\\": \\\"rabbit\\\", \\\"oslo_messaging_notify_user_name\\\": {\\\"get_param\\\": \\\"RpcUserName\\\"}, \\\"oslo_messaging_notify_password\\\": {\\\"get_param\\\": \\\"RpcPassword\\\"}, \\\"oslo_messaging_notify_use_ssl\\\": {\\\"get_param\\\": \\\"RpcUseSSL\\\"}, \\\"oslo_messaging_notify_port\\\": {\\\"get_param\\\": \\\"RpcPort\\\"}}}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized HAproxy service\\\\n\\\", \\\"parameters\\\": {\\\"ContainerHAProxyImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerHAProxyConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the haproxy config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"HAProxyStatsPassword\\\": {\\\"description\\\": \\\"Password for HAProxy stats endpoint\\\", \\\"hidden\\\": true, \\\"type\\\": \\\"string\\\"}, \\\"HAProxyStatsUser\\\": {\\\"description\\\": \\\"User for HAProxy stats endpoint\\\", \\\"default\\\": \\\"admin\\\", \\\"type\\\": \\\"string\\\"}, \\\"HAProxyLoggingSource\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {\\\"tag\\\": \\\"openstack.haproxy\\\", \\\"file\\\": \\\"/var/log/containers/haproxy/haproxy.log\\\", \\\"startmsg.regex\\\": \\\"^[a-zA-Z]{3} [ 123][0-9] [:0-9]{8}\\\"}}, \\\"HAProxySyslogAddress\\\": {\\\"default\\\": \\\"/dev/log\\\", \\\"description\\\": \\\"Syslog address where HAproxy will send its log\\\", \\\"type\\\": \\\"string\\\"}, \\\"HAProxySyslogFacility\\\": {\\\"default\\\": \\\"local0\\\", \\\"description\\\": \\\"Syslog facility HAProxy will use for its logs\\\", \\\"type\\\": \\\"string\\\"}, \\\"SSLCertificate\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The content of the SSL certificate (without Key) in PEM format.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"PublicSSLCertificateAutogenerated\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether the public SSL certificate was autogenerated or not.\\\\n\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"EnablePublicTLS\\\": {\\\"default\\\": true, \\\"description\\\": \\\"Whether to enable TLS on the public interface or not.\\\\n\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"DeployedSSLCertificatePath\\\": {\\\"default\\\": \\\"/etc/pki/tls/private/overcloud_endpoint.pem\\\", \\\"description\\\": \\\"The filepath of the certificate as it will be stored in the controller.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"RedisPassword\\\": {\\\"description\\\": \\\"The password for the redis service account.\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"MonitoringSubscriptionHaproxy\\\": {\\\"default\\\": \\\"overcloud-haproxy\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"InternalTLSCAFile\\\": {\\\"default\\\": \\\"/etc/ipa/ca.crt\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Specifies the default CA cert to use if TLS is used for services in the internal network.\\\"}, \\\"ConfigDebug\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to run config management (e.g. Puppet) in debug mode.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"EnableLoadBalancer\\\": {\\\"default\\\": true, \\\"description\\\": \\\"Whether to deploy a LoadBalancer, set to false when an external load balancer is used.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"HAProxyStatsEnabled\\\": {\\\"default\\\": true, \\\"description\\\": \\\"Whether or not to enable the HAProxy stats interface.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"InternalTLSCRLPEMFile\\\": {\\\"default\\\": \\\"/etc/pki/CA/crl/overcloud-crl.pem\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Specifies the default CRL PEM file to use for revocation if TLS is used for services in the internal network.\\\"}, \\\"InternalTLSCRLPEMDir\\\": {\\\"default\\\": \\\"/etc/pki/CA/crl/\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"The directory of the CRL PEM file to be mounted.\\\"}}, \\\"conditions\\\": {\\\"public_tls_enabled\\\": {\\\"and\\\": [{\\\"get_param\\\": \\\"EnablePublicTLS\\\"}, {\\\"or\\\": [{\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"SSLCertificate\\\"}, \\\"\\\"]}}, {\\\"get_param\\\": \\\"PublicSSLCertificateAutogenerated\\\"}]}]}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"HAProxyLogging\\\": {\\\"type\\\": \\\"OS::TripleO::Services::Logging::HAProxy\\\"}, \\\"HAProxyPublicTLS\\\": {\\\"type\\\": \\\"OS::TripleO::Services::HAProxyPublicTLS\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"HAProxyInternalTLS\\\": {\\\"type\\\": \\\"OS::TripleO::Services::HAProxyInternalTLS\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerHAProxyImage\\\": \\\"ContainerHAProxyImage\\\", \\\"ContainerHAProxyConfigImage\\\": \\\"ContainerHAProxyConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerHAProxyImage\\\": {\\\"get_param\\\": \\\"ContainerHAProxyImage\\\"}, \\\"ContainerHAProxyConfigImage\\\": {\\\"get_param\\\": \\\"ContainerHAProxyConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the HAproxy role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"haproxy\\\", \\\"firewall_rules\\\": {\\\"107 haproxy stats\\\": {\\\"dport\\\": 1993}}, \\\"monitoring_subscription\\\": {\\\"get_param\\\": \\\"MonitoringSubscriptionHaproxy\\\"}, \\\"ansible_group_vars\\\": {\\\"tripleo_firewall_frontend_enabled\\\": true, \\\"tripleo_firewall_ssl_frontend_enabled\\\": {\\\"if\\\": [\\\"public_tls_enabled\\\", true]}}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"HAProxyLogging\\\", \\\"config_settings\\\"]}, {\\\"tripleo::haproxy::haproxy_service_manage\\\": false, \\\"tripleo::haproxy::haproxy_log_address\\\": {\\\"get_param\\\": \\\"HAProxySyslogAddress\\\"}, \\\"tripleo::haproxy::haproxy_log_facility\\\": {\\\"get_param\\\": \\\"HAProxySyslogFacility\\\"}, \\\"tripleo::haproxy::haproxy_stats_user\\\": {\\\"get_param\\\": \\\"HAProxyStatsUser\\\"}, \\\"tripleo::haproxy::haproxy_stats_password\\\": {\\\"get_param\\\": \\\"HAProxyStatsPassword\\\"}, \\\"tripleo::haproxy::haproxy_stats_bind_address\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HaproxyNetwork\\\"]}}}}, \\\"tripleo::haproxy::redis_password\\\": {\\\"get_param\\\": \\\"RedisPassword\\\"}, \\\"tripleo::haproxy::crl_file\\\": null, \\\"tripleo::haproxy::haproxy_stats\\\": {\\\"get_param\\\": \\\"HAProxyStatsEnabled\\\"}, \\\"enable_load_balancer\\\": {\\\"get_param\\\": \\\"EnableLoadBalancer\\\"}, \\\"tripleo::profile::base::haproxy::certificates_specs\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"HAProxyPublicTLS\\\", \\\"role_data\\\", \\\"certificates_specs\\\"]}, {\\\"get_attr\\\": [\\\"HAProxyInternalTLS\\\", \\\"role_data\\\", \\\"certificates_specs\\\"]}]}, \\\"tripleo::haproxy::service_certificate\\\": {\\\"if\\\": [\\\"public_tls_enabled\\\", {\\\"get_param\\\": \\\"DeployedSSLCertificatePath\\\"}]}, \\\"tripleo::haproxy::ca_bundle\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}]}}, {\\\"get_attr\\\": [\\\"HAProxyPublicTLS\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"get_attr\\\": [\\\"HAProxyInternalTLS\\\", \\\"role_data\\\", \\\"config_settings\\\"]}]}, \\\"service_config_settings\\\": {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_haproxy\\\": [{\\\"get_param\\\": \\\"HAProxyLoggingSource\\\"}]}}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"haproxy\\\", \\\"puppet_tags\\\": \\\"haproxy_config\\\", \\\"step_config\\\": \\\"class {\'tripleo::profile::base::haproxy\': manage_firewall => false}\\\\n\\\", \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHAProxyConfigImage\\\"]}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"if\\\": [\\\"public_tls_enabled\\\", [{\\\"list_join\\\": [\\\":\\\", [{\\\"get_param\\\": \\\"DeployedSSLCertificatePath\\\"}, {\\\"get_param\\\": \\\"DeployedSSLCertificatePath\\\"}, \\\"ro,shared\\\"]]}]]}, {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, [\\\"/etc/pki/tls/certs/haproxy:/etc/pki/tls/certs/haproxy:ro,shared\\\", \\\"/etc/pki/tls/private/haproxy:/etc/pki/tls/private/haproxy:ro,shared\\\", {\\\"list_join\\\": [\\\":\\\", [{\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, \\\"ro,shared\\\"]]}, {\\\"list_join\\\": [\\\":\\\", [{\\\"get_param\\\": \\\"InternalTLSCRLPEMDir\\\"}, {\\\"get_param\\\": \\\"InternalTLSCRLPEMDir\\\"}, \\\"ro,shared\\\"]]}]]}]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/haproxy.json\\\": {\\\"command\\\": \\\"bash -c $* -- eval if [ -f /usr/sbin/haproxy-systemd-wrapper ]; then exec /usr/sbin/haproxy-systemd-wrapper -f /etc/haproxy/haproxy.cfg; else exec /usr/sbin/haproxy -f /etc/haproxy/haproxy.cfg -Ws; fi\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-tls/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true, \\\"optional\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/lib/haproxy\\\", \\\"owner\\\": \\\"haproxy:haproxy\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/certs/haproxy\\\", \\\"owner\\\": \\\"haproxy:haproxy\\\", \\\"recurse\\\": true, \\\"optional\\\": true}]}}, \\\"container_config_scripts\\\": {\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"container_config_scripts\\\"]}, \\\"docker_config\\\": {\\\"step_1\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"HAProxyLogging\\\", \\\"docker_config\\\", \\\"step_1\\\"]}, {\\\"haproxy\\\": {\\\"start_order\\\": 1, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHAProxyImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"restart\\\": \\\"always\\\", \\\"security_opt\\\": [\\\"label=disable\\\"], \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"HAProxyLogging\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/haproxy.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/haproxy:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/haproxy:/var/lib/haproxy:rw,z\\\"], {\\\"if\\\": [\\\"public_tls_enabled\\\", [{\\\"list_join\\\": [\\\":\\\", [{\\\"get_param\\\": \\\"DeployedSSLCertificatePath\\\"}, {\\\"list_join\\\": [\\\"\\\", [\\\"/var/lib/kolla/config_files/src-tls\\\", {\\\"get_param\\\": \\\"DeployedSSLCertificatePath\\\"}]]}, \\\"ro,shared\\\"]]}]]}, {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, [\\\"/etc/pki/tls/certs/haproxy:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/haproxy:ro,shared\\\", \\\"/etc/pki/tls/private/haproxy:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/haproxy:ro,shared\\\", {\\\"list_join\\\": [\\\":\\\", [{\\\"get_param\\\": \\\"InternalTLSCRLPEMDir\\\"}, {\\\"get_param\\\": \\\"InternalTLSCRLPEMDir\\\"}, \\\"ro\\\"]]}]]}]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}]}}, \\\"deploy_steps_tasks\\\": {\\\"list_concat\\\": [[{\\\"name\\\": \\\"Configure rsyslog for HAproxy container\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Check if rsyslog exists\\\", \\\"shell\\\": \\\"systemctl is-active rsyslog\\\", \\\"register\\\": \\\"rsyslog_config\\\"}, {\\\"when\\\": [\\\"rsyslog_config is changed\\\", \\\"rsyslog_config.rc == 0\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Forward logging to haproxy.log file\\\", \\\"blockinfile\\\": {\\\"content\\\": \\\"if $syslogfacility-text == \'{{facility}}\' and $programname == \'haproxy\' then -/var/log/containers/haproxy/haproxy.log\\\\n& stop\\\\n\\\", \\\"create\\\": true, \\\"path\\\": \\\"/etc/rsyslog.d/openstack-haproxy.conf\\\"}, \\\"vars\\\": {\\\"facility\\\": {\\\"get_param\\\": \\\"HAProxySyslogFacility\\\"}}, \\\"register\\\": \\\"logconfig\\\"}, {\\\"name\\\": \\\"restart rsyslog service after logging conf change\\\", \\\"service\\\": {\\\"name\\\": \\\"rsyslog\\\", \\\"state\\\": \\\"restarted\\\"}, \\\"when\\\": \\\"logconfig is changed\\\"}]}]}, {\\\"name\\\": \\\"Run puppet on the host to apply IPtables rules\\\", \\\"no_log\\\": true, \\\"when\\\": \\\"step|int == 1\\\", \\\"register\\\": \\\"puppet_host_outputs\\\", \\\"shell\\\": \\\"puppet apply {{ (puppet_debug|bool) | ternary(\'--debug --verbose\', \'\') }} --detailed-exitcodes --summarize --color=false \\\\\\\\\\\\n    --modulepath \'{{ puppet_modulepath }}\' --tags \'{{ puppet_tags }}\' -e \'{{ puppet_execute }}\'\\\\n\\\", \\\"changed_when\\\": \\\"puppet_host_outputs.rc == 2\\\", \\\"failed_when\\\": false, \\\"vars\\\": {\\\"puppet_execute\\\": \\\"include tripleo::profile::base::haproxy\\\", \\\"puppet_tags\\\": \\\"tripleo::firewall::rule\\\", \\\"puppet_modulepath\\\": \\\"/etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules\\\", \\\"puppet_debug\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}}}, {\\\"name\\\": \\\"Debug output for task: Run puppet on the host to apply IPtables rules\\\", \\\"debug\\\": {\\\"var\\\": \\\"puppet_host_outputs.stdout_lines | default([]) | union(puppet_host_outputs.stderr_lines | default([]))\\\"}, \\\"when\\\": [\\\"not (ansible_check_mode | bool)\\\", \\\"puppet_host_outputs.rc is defined\\\"], \\\"failed_when\\\": \\\"puppet_host_outputs.rc not in [0, 2]\\\"}], {\\\"if\\\": [\\\"public_tls_enabled\\\", {\\\"get_attr\\\": [\\\"HAProxyPublicTLS\\\", \\\"role_data\\\", \\\"deploy_steps_tasks\\\"]}]}, {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, {\\\"get_attr\\\": [\\\"HAProxyInternalTLS\\\", \\\"role_data\\\", \\\"deploy_steps_tasks\\\"]}]}]}, \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"ensure we have haproxy log dir with the correct setype\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/log/containers/haproxy\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"var_log_t\\\", \\\"recurse\\\": true}, \\\"when\\\": \\\"step|int == 1\\\"}], \\\"external_upgrade_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade_transfer_data\\\", \\\"system_upgrade_stop_services\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Stop haproxy container\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_stop\\\"}, \\\"vars\\\": {\\\"tripleo_containers_to_stop\\\": [\\\"haproxy\\\"], \\\"tripleo_delegate_to\\\": \\\"{{ groups[\'haproxy\'] | difference(groups[\'excluded_overcloud\']) }}\\\"}}]}], \\\"host_prep_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"HAProxyPublicTLS\\\", \\\"role_data\\\", \\\"host_prep_tasks\\\"]}, [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode|default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/haproxy\\\", \\\"setype\\\": \\\"var_log_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/lib/haproxy\\\", \\\"setype\\\": \\\"container_file_t\\\"}]}]]}, \\\"metadata_settings\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"HAProxyPublicTLS\\\", \\\"role_data\\\", \\\"metadata_settings\\\"]}, {\\\"get_attr\\\": [\\\"HAProxyInternalTLS\\\", \\\"role_data\\\", \\\"metadata_settings\\\"]}]}}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized HAproxy service for pacemaker\\\\n\\\", \\\"parameters\\\": {\\\"ContainerHAProxyImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerHAProxyConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the haproxy config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ClusterCommonTag\\\": {\\\"default\\\": false, \\\"description\\\": \\\"When set to false, a pacemaker service is configured to use a floating tag for its container image name, e.g. \'REGISTRY/NAMESPACE/IMAGENAME:pcmklatest\'. When set to true, the service uses a floating prefix as well, e.g. \'cluster.common.tag/IMAGENAME:pcmklatest\'.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"ClusterFullTag\\\": {\\\"default\\\": true, \\\"description\\\": \\\"When set to true, the pacemaker service uses a fully constant tag for its container image name, e.g. \'cluster.common.tag/SERVICENAME:pcmklatest\'.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"SSLCertificate\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The content of the SSL certificate (without Key) in PEM format.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"PublicSSLCertificateAutogenerated\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether the public SSL certificate was autogenerated or not.\\\\n\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"EnablePublicTLS\\\": {\\\"default\\\": true, \\\"description\\\": \\\"Whether to enable TLS on the public interface or not.\\\\n\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"DeployedSSLCertificatePath\\\": {\\\"default\\\": \\\"/etc/pki/tls/private/overcloud_endpoint.pem\\\", \\\"description\\\": \\\"The filepath of the certificate as it will be stored in the controller.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"InternalTLSCAFile\\\": {\\\"default\\\": \\\"/etc/ipa/ca.crt\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Specifies the default CA cert to use if TLS is used for services in the internal network.\\\"}, \\\"HAProxyInternalTLSCertsDirectory\\\": {\\\"default\\\": \\\"/etc/pki/tls/certs/haproxy\\\", \\\"type\\\": \\\"string\\\"}, \\\"HAProxyInternalTLSKeysDirectory\\\": {\\\"default\\\": \\\"/etc/pki/tls/private/haproxy\\\", \\\"type\\\": \\\"string\\\"}, \\\"HAProxyLoggingSource\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {\\\"tag\\\": \\\"openstack.haproxy\\\", \\\"file\\\": \\\"/var/log/containers/haproxy/haproxy.log\\\", \\\"startmsg.regex\\\": \\\"^[a-zA-Z]{3} [ 123][0-9] [:0-9]{8}\\\"}}, \\\"HAProxySyslogAddress\\\": {\\\"default\\\": \\\"/dev/log\\\", \\\"description\\\": \\\"Syslog address where HAproxy will send its log\\\", \\\"type\\\": \\\"string\\\"}, \\\"HAProxySyslogFacility\\\": {\\\"default\\\": \\\"local0\\\", \\\"description\\\": \\\"Syslog facility HAProxy will use for its logs\\\", \\\"type\\\": \\\"string\\\"}, \\\"ConfigDebug\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to run config management (e.g. Puppet) in debug mode.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"ContainerCli\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"podman\\\", \\\"description\\\": \\\"CLI tool used to manage containers.\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"docker\\\", \\\"podman\\\"]}]}, \\\"DeployIdentifier\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\\\n\\\"}}, \\\"conditions\\\": {\\\"public_tls_enabled\\\": {\\\"and\\\": [{\\\"get_param\\\": \\\"EnablePublicTLS\\\"}, {\\\"or\\\": [{\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"SSLCertificate\\\"}, \\\"\\\"]}}, {\\\"get_param\\\": \\\"PublicSSLCertificateAutogenerated\\\"}]}]}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"HAProxyBase\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-container-puppet.yaml\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"HAProxyPublicTLS\\\": {\\\"type\\\": \\\"OS::TripleO::Services::HAProxyPublicTLS\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"HAProxyInternalTLS\\\": {\\\"type\\\": \\\"OS::TripleO::Services::HAProxyInternalTLS\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerHAProxyImage\\\": \\\"ContainerHAProxyImage\\\", \\\"ContainerHAProxyConfigImage\\\": \\\"ContainerHAProxyConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerHAProxyImage\\\": {\\\"get_param\\\": \\\"ContainerHAProxyImage\\\"}, \\\"ContainerHAProxyConfigImage\\\": {\\\"get_param\\\": \\\"ContainerHAProxyConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the HAproxy role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"haproxy\\\", \\\"firewall_rules\\\": {\\\"get_attr\\\": [\\\"HAProxyBase\\\", \\\"role_data\\\", \\\"firewall_rules\\\"]}, \\\"monitoring_subscription\\\": {\\\"get_attr\\\": [\\\"HAProxyBase\\\", \\\"role_data\\\", \\\"monitoring_subscription\\\"]}, \\\"ansible_group_vars\\\": {\\\"get_attr\\\": [\\\"HAProxyBase\\\", \\\"role_data\\\", \\\"ansible_group_vars\\\"]}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"HAProxyBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"tripleo::haproxy::haproxy_service_manage\\\": false, \\\"tripleo::haproxy::mysql_clustercheck\\\": true, \\\"tripleo::haproxy::haproxy_log_address\\\": {\\\"get_param\\\": \\\"HAProxySyslogAddress\\\"}, \\\"tripleo::haproxy::haproxy_log_facility\\\": {\\\"get_param\\\": \\\"HAProxySyslogFacility\\\"}}, {\\\"haproxy_docker\\\": true, \\\"tripleo::profile::pacemaker::haproxy_bundle::container_backend\\\": {\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"tripleo::profile::pacemaker::haproxy_bundle::tls_mapping\\\": {\\\"list_concat\\\": [{\\\"if\\\": [\\\"public_tls_enabled\\\", [{\\\"get_param\\\": \\\"DeployedSSLCertificatePath\\\"}]]}, {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, [{\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, {\\\"get_param\\\": \\\"HAProxyInternalTLSKeysDirectory\\\"}, {\\\"get_param\\\": \\\"HAProxyInternalTLSCertsDirectory\\\"}]]}]}, \\\"tripleo::profile::pacemaker::haproxy_bundle::tls_mapping_init_bundle\\\": {\\\"list_concat\\\": [{\\\"if\\\": [\\\"public_tls_enabled\\\", [{\\\"get_param\\\": \\\"DeployedSSLCertificatePath\\\"}]]}, {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, [{\\\"get_param\\\": \\\"HAProxyInternalTLSKeysDirectory\\\"}, {\\\"get_param\\\": \\\"HAProxyInternalTLSCertsDirectory\\\"}]]}]}, \\\"tripleo::profile::pacemaker::haproxy_bundle::internal_certs_directory\\\": {\\\"get_param\\\": \\\"HAProxyInternalTLSCertsDirectory\\\"}, \\\"tripleo::profile::pacemaker::haproxy_bundle::internal_keys_directory\\\": {\\\"get_param\\\": \\\"HAProxyInternalTLSKeysDirectory\\\"}, \\\"tripleo::profile::pacemaker::haproxy_bundle::haproxy_docker_image\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/haproxy:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHAProxyImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHAProxyImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}}]}, \\\"service_config_settings\\\": {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_haproxy\\\": [{\\\"get_param\\\": \\\"HAProxyLoggingSource\\\"}]}}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"haproxy\\\", \\\"puppet_tags\\\": \\\"haproxy_config\\\", \\\"step_config\\\": {\\\"list_join\\\": [\\\"\\\\n\\\", [\\\"exec {\'wait-for-settle\': command => \'/bin/true\' }\\\", \\\"class tripleo::firewall(){}; define tripleo::firewall::rule( $port = undef, $dport = undef, $sport = undef, $proto = undef, $action = undef, $state = undef, $source = undef, $iniface = undef, $chain = undef, $destination = undef, $extras = undef){}\\\", \\\"[\'pcmk_bundle\', \'pcmk_resource\', \'pcmk_property\', \'pcmk_constraint\', \'pcmk_resource_default\'].each |String $val| { noop_resource($val) }\\\", \\\"include tripleo::profile::pacemaker::haproxy_bundle\\\"]]}, \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHAProxyConfigImage\\\"]}, \\\"volumes\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"$.data.select($+\\\\\\\":\\\\\\\"+$+\\\\\\\":ro\\\\\\\")\\\", \\\"data\\\": {\\\"list_concat\\\": [{\\\"if\\\": [\\\"public_tls_enabled\\\", [{\\\"get_param\\\": \\\"DeployedSSLCertificatePath\\\"}]]}, {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, [{\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, {\\\"get_param\\\": \\\"HAProxyInternalTLSKeysDirectory\\\"}, {\\\"get_param\\\": \\\"HAProxyInternalTLSCertsDirectory\\\"}]]}]}}}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/haproxy.json\\\": {\\\"command\\\": \\\"bash -c $* -- eval if [ -f /usr/sbin/haproxy-systemd-wrapper ]; then exec /usr/sbin/haproxy-systemd-wrapper -f /etc/haproxy/haproxy.cfg; else exec /usr/sbin/haproxy -f /etc/haproxy/haproxy.cfg -Ws; fi\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true, \\\"optional\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-tls/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"optional\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/lib/haproxy\\\", \\\"owner\\\": \\\"haproxy:haproxy\\\", \\\"recurse\\\": true}, {\\\"path\\\": {\\\"list_join\\\": [\\\"\\\", [{\\\"get_param\\\": \\\"HAProxyInternalTLSCertsDirectory\\\"}, \\\"/*\\\"]]}, \\\"owner\\\": \\\"haproxy:haproxy\\\", \\\"perm\\\": \\\"0600\\\", \\\"optional\\\": true}, {\\\"path\\\": {\\\"list_join\\\": [\\\"\\\", [{\\\"get_param\\\": \\\"HAProxyInternalTLSKeysDirectory\\\"}, \\\"/*\\\"]]}, \\\"owner\\\": \\\"haproxy:haproxy\\\", \\\"perm\\\": \\\"0600\\\", \\\"optional\\\": true}]}}, \\\"container_config_scripts\\\": {\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"container_config_scripts\\\"]}, \\\"host_prep_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"HAProxyBase\\\", \\\"role_data\\\", \\\"host_prep_tasks\\\"]}, [{\\\"name\\\": \\\"Run puppet on the host to apply IPtables rules\\\", \\\"no_log\\\": true, \\\"shell\\\": \\\"puppet apply {{ (puppet_debug|bool) | ternary(\'--debug --verbose\', \'\') }} --detailed-exitcodes --summarize --color=false \\\\\\\\\\\\n    --modulepath \'{{ puppet_modulepath }}\' --tags \'{{ puppet_tags }}\' -e \'{{ puppet_execute }}\'\\\\n\\\", \\\"register\\\": \\\"puppet_host_outputs\\\", \\\"changed_when\\\": \\\"puppet_host_outputs.rc == 2\\\", \\\"failed_when\\\": false, \\\"vars\\\": {\\\"puppet_execute\\\": \\\"if hiera(\'enable_load_balancer\', true) { class {\'::tripleo::haproxy\': use_internal_certificates => false, manage_firewall => hiera(\'tripleo::firewall::manage_firewall\', true), }}\\\", \\\"puppet_tags\\\": \\\"tripleo::firewall::rule\\\", \\\"puppet_modulepath\\\": \\\"/etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules\\\", \\\"puppet_debug\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}}}, {\\\"name\\\": \\\"Debug output for task: Run puppet on the host to apply IPtables rules\\\", \\\"debug\\\": {\\\"var\\\": \\\"puppet_host_outputs.stdout_lines | default([]) | union(puppet_host_outputs.stderr_lines | default([]))\\\"}, \\\"when\\\": [\\\"not (ansible_check_mode | bool)\\\", \\\"puppet_host_outputs.rc is defined\\\"], \\\"failed_when\\\": \\\"puppet_host_outputs.rc not in [0, 2]\\\"}]]}, \\\"metadata_settings\\\": {\\\"get_attr\\\": [\\\"HAProxyBase\\\", \\\"role_data\\\", \\\"metadata_settings\\\"]}, \\\"deploy_steps_tasks\\\": {\\\"list_concat\\\": [[{\\\"name\\\": \\\"Configure rsyslog for HAproxy container managed by Pacemaker\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Check if rsyslog exists\\\", \\\"shell\\\": \\\"systemctl is-active rsyslog\\\", \\\"register\\\": \\\"rsyslog_config\\\"}, {\\\"when\\\": [\\\"rsyslog_config is changed\\\", \\\"rsyslog_config.rc == 0\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Forward logging to haproxy.log file\\\", \\\"blockinfile\\\": {\\\"content\\\": \\\"if $syslogfacility-text == \'{{facility}}\' and $programname == \'haproxy\' then -/var/log/containers/haproxy/haproxy.log\\\\n& stop\\\\n\\\", \\\"create\\\": true, \\\"path\\\": \\\"/etc/rsyslog.d/openstack-haproxy.conf\\\"}, \\\"vars\\\": {\\\"facility\\\": {\\\"get_param\\\": \\\"HAProxySyslogFacility\\\"}}, \\\"register\\\": \\\"logconfig\\\"}, {\\\"name\\\": \\\"restart rsyslog service after logging conf change\\\", \\\"service\\\": {\\\"name\\\": \\\"rsyslog\\\", \\\"state\\\": \\\"restarted\\\"}, \\\"when\\\": \\\"logconfig is changed\\\"}]}]}, {\\\"name\\\": \\\"HAproxy tag container image for pacemaker\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_tag\\\"}, \\\"vars\\\": {\\\"container_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHAProxyImage\\\"]}, \\\"container_image_latest\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/haproxy:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHAProxyImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHAProxyImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}}}, {\\\"name\\\": \\\"HAproxy HA Wrappers Step\\\", \\\"when\\\": \\\"step|int == 2\\\", \\\"block\\\": [{\\\"name\\\": \\\"HAproxy puppet bundle\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_ha_wrapper\\\"}, \\\"vars\\\": {\\\"tripleo_ha_wrapper_service_name\\\": \\\"haproxy\\\", \\\"tripleo_ha_wrapper_resource_name\\\": \\\"haproxy-bundle\\\", \\\"tripleo_ha_wrapper_bundle_name\\\": \\\"haproxy-bundle\\\", \\\"tripleo_ha_wrapper_resource_state\\\": \\\"Started\\\", \\\"tripleo_ha_wrapper_puppet_config_volume\\\": \\\"haproxy\\\", \\\"tripleo_ha_wrapper_puppet_execute\\\": \\\"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::haproxy_bundle\\\", \\\"tripleo_ha_wrapper_puppet_tags\\\": \\\"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\\\", \\\"tripleo_ha_wrapper_puppet_debug\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"tripleo_ha_wrapper_config_suffix\\\": \\\".previous_run\\\"}}]}], {\\\"if\\\": [\\\"public_tls_enabled\\\", {\\\"get_attr\\\": [\\\"HAProxyPublicTLS\\\", \\\"role_data\\\", \\\"deploy_steps_tasks\\\"]}, []]}, {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, {\\\"get_attr\\\": [\\\"HAProxyInternalTLS\\\", \\\"role_data\\\", \\\"deploy_steps_tasks\\\"]}]}]}, \\\"external_update_tasks\\\": [{\\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": \\\"ha_image_update\\\", \\\"block\\\": [{\\\"block\\\": [{\\\"name\\\": \\\"Get haproxy image from pacemaker\\\", \\\"become\\\": true, \\\"register\\\": \\\"xmllint_pcmk_haproxy_image\\\", \\\"shell\\\": \\\"xmllint --xpath \\\\\\\"string(//bundle[@id=\'haproxy-bundle\']/podman/@image)\\\\\\\" /var/lib/pacemaker/cib/cib.xml\\\"}, {\\\"name\\\": \\\"Get container haproxy image\\\", \\\"set_fact\\\": {\\\"haproxy_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHAProxyImage\\\"]}, \\\"haproxy_image_latest\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/haproxy:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHAProxyImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHAProxyImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"pcmk_haproxy_image\\\": \\\"{{xmllint_pcmk_haproxy_image.stdout}}\\\"}}], \\\"delegate_to\\\": \\\"{{ (groups[\\\\\\\"haproxy\\\\\\\"] | difference(groups[\\\\\\\"excluded_overcloud\\\\\\\"]))[0] }}\\\"}, {\\\"name\\\": \\\"haproxy temporary pacemaker container tag in case of image switch\\\", \\\"become\\\": true, \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_ha_image_update\\\"}, \\\"vars\\\": {\\\"tripleo_ha_image_update_node_names\\\": \\\"{{ groups[\\\\\\\"haproxy\\\\\\\"] | difference(groups[\\\\\\\"excluded_overcloud\\\\\\\"]) }}\\\", \\\"tripleo_ha_image_update_bundle\\\": \\\"haproxy-bundle\\\", \\\"tripleo_ha_image_update_new_image\\\": \\\"{{haproxy_image_latest}}\\\", \\\"tripleo_ha_image_update_old_image\\\": \\\"{{pcmk_haproxy_image}}\\\"}, \\\"when\\\": [\\\"(pcmk_haproxy_image != \\\\\\\"\\\\\\\")\\\", \\\"(pcmk_haproxy_image != haproxy_image_latest)\\\"]}]}], \\\"update_tasks\\\": [{\\\"block\\\": [{\\\"name\\\": \\\"Get haproxy image from pacemaker\\\", \\\"become\\\": true, \\\"register\\\": \\\"xmllint_pcmk_haproxy_image\\\", \\\"shell\\\": \\\"xmllint --xpath \\\\\\\"string(//bundle[@id=\'haproxy-bundle\']/podman/@image)\\\\\\\" /var/lib/pacemaker/cib/cib.xml\\\"}, {\\\"name\\\": \\\"Get container haproxy image\\\", \\\"set_fact\\\": {\\\"haproxy_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHAProxyImage\\\"]}, \\\"haproxy_image_latest\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/haproxy:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHAProxyImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHAProxyImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"pcmk_haproxy_image\\\": \\\"{{xmllint_pcmk_haproxy_image.stdout}}\\\"}}], \\\"when\\\": \\\"(step|int == 0 or step|int == 2)\\\"}, {\\\"name\\\": \\\"Check for update of haproxy container image name\\\", \\\"when\\\": \\\"step|int == 0\\\", \\\"assert\\\": {\\\"that\\\": \\\"pcmk_haproxy_image == haproxy_image_latest\\\", \\\"fail_msg\\\": \\\"haproxy image change detected, run overcloud external-update --tags ha_image_update first\\\"}}, {\\\"name\\\": \\\"Tear-down non-HA haproxy container\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Remove non-HA haproxy container\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_rm\\\"}, \\\"vars\\\": {\\\"tripleo_container_cli\\\": \\\"{{ container_cli }}\\\", \\\"tripleo_containers_to_rm\\\": [\\\"haproxy\\\"]}}]}, {\\\"name\\\": \\\"Set HAProxy upgrade facts\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"set is_haproxy_bootstrap_node fact\\\", \\\"tags\\\": \\\"common\\\", \\\"set_fact\\\": \\\"is_haproxy_bootstrap_node={{haproxy_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\\\", \\\"when\\\": [\\\"haproxy_short_bootstrap_node_name|default(false)\\\"]}]}, {\\\"name\\\": \\\"Mount TLS cert if needed\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"is_haproxy_bootstrap_node\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Check haproxy public certificate configuration in pacemaker\\\", \\\"command\\\": \\\"cibadmin --query --xpath \\\\\\\"//storage-mapping[@id=\'haproxy-cert\']\\\\\\\"\\\", \\\"failed_when\\\": false, \\\"register\\\": \\\"haproxy_cert_mounted\\\"}, {\\\"name\\\": \\\"Disable the haproxy cluster resource\\\", \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"haproxy-bundle\\\", \\\"state\\\": \\\"disable\\\", \\\"wait_for_resource\\\": true}, \\\"register\\\": \\\"output\\\", \\\"retries\\\": 5, \\\"until\\\": \\\"output.rc == 0\\\", \\\"when\\\": \\\"haproxy_cert_mounted.rc == 6\\\"}, {\\\"name\\\": \\\"Set HAProxy public cert volume mount fact\\\", \\\"set_fact\\\": {\\\"haproxy_public_cert_path\\\": {\\\"get_param\\\": \\\"DeployedSSLCertificatePath\\\"}, \\\"haproxy_public_tls_enabled\\\": {\\\"if\\\": [\\\"public_tls_enabled\\\", true, false]}}}, {\\\"name\\\": \\\"Add a bind mount for public certificate in the haproxy bundle\\\", \\\"command\\\": \\\"pcs resource bundle update haproxy-bundle storage-map add id=haproxy-cert source-dir={{ haproxy_public_cert_path }} target-dir=/var/lib/kolla/config_files/src-tls/{{ haproxy_public_cert_path }} options=ro\\\", \\\"when\\\": \\\"haproxy_cert_mounted.rc == 6 and haproxy_public_tls_enabled|bool\\\"}, {\\\"name\\\": \\\"Enable the haproxy cluster resource\\\", \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"haproxy-bundle\\\", \\\"state\\\": \\\"enable\\\", \\\"wait_for_resource\\\": true}, \\\"register\\\": \\\"output\\\", \\\"retries\\\": 5, \\\"until\\\": \\\"output.rc == 0\\\", \\\"when\\\": \\\"haproxy_cert_mounted.rc == 6\\\"}]}, {\\\"name\\\": \\\"Haproxy fetch and retag container image for pacemaker\\\", \\\"tags\\\": \\\"haproxy_syn_block\\\", \\\"when\\\": [\\\"step|int == 2\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Retag pcmklatest to latest haproxy image\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_tag\\\"}, \\\"vars\\\": {\\\"container_image\\\": \\\"{{haproxy_image}}\\\", \\\"container_image_latest\\\": \\\"{{haproxy_image_latest}}\\\"}}]}, {\\\"name\\\": \\\"Move virtual IPs to another node before stopping pacemaker\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"hostvars[inventory_hostname][\\\\\\\"haproxy_node_names\\\\\\\"]|default([])|length > 1\\\"], \\\"shell\\\": \\\"CLUSTER_NODE=$(crm_node -n)\\\\necho \\\\\\\"Retrieving all the VIPs which are hosted on this node\\\\\\\"\\\\nVIPS_TO_MOVE=$(crm_mon --as-xml | xmllint --xpath \'//resource[@resource_agent=\\\\\\\"ocf:heartbeat:IPaddr2\\\\\\\" and @role = \\\\\\\"Started\\\\\\\" and @managed = \\\\\\\"true\\\\\\\" and ./node[@name = \\\\\\\"\'${CLUSTER_NODE}\'\\\\\\\"]]/@id\' - | sed -e \'s/id=//g\' -e \'s/\\\\\\\"//g\')\\\\nfor v in ${VIPS_TO_MOVE}; do\\\\n    echo \\\\\\\"Moving VIP $v on another node\\\\\\\"\\\\n    pcs resource ban $v ${CLUSTER_NODE} --wait=300\\\\ndone\\\\necho \\\\\\\"Removing the location constraints that were created to move the VIPs\\\\\\\"\\\\nfor v in ${VIPS_TO_MOVE}; do\\\\n    echo \\\\\\\"Removing location ban for VIP $v\\\\\\\"\\\\n    ban_id=$(cibadmin --query | xmllint --xpath \'string(//rsc_location[@rsc=\\\\\\\"\'${v}\'\\\\\\\" and @node=\\\\\\\"\'${CLUSTER_NODE}\'\\\\\\\" and @score=\\\\\\\"-INFINITY\\\\\\\"]/@id)\' -)\\\\n    if [ -n \\\\\\\"$ban_id\\\\\\\" ]; then\\\\n        pcs constraint remove ${ban_id}\\\\n    else\\\\n        echo \\\\\\\"Could not retrieve and clear location constraint for VIP $v\\\\\\\" 2>&1\\\\n    fi\\\\ndone\\\\n\\\"}, {\\\"name\\\": \\\"Wait for 10s to settle connections on new VIPs\\\", \\\"wait_for\\\": {\\\"timeout\\\": 10}, \\\"when\\\": [\\\"step|int == 1\\\", \\\"hostvars[inventory_hostname][\\\\\\\"haproxy_node_names\\\\\\\"]|default([])|length > 1\\\"]}, {\\\"name\\\": \\\"Block local INPUT SYN packets on the backends except mysql\\\", \\\"tags\\\": \\\"haproxy_syn_block\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"shell\\\": \\\"# server controller-0.storage.redhat.local 172.17.3.93:8080 check fall 5 inter 2000 rise 2\\\\n# server controller-0.internalapi.redhat.local fd00:fd00:fd00:2000::176:9292 check fall 5 inter 2000 rise 2\\\\nset -o pipefail\\\\nsource /etc/os-release; test  \\\\\\\"${VERSION_ID%*}\\\\\\\" = \\\\\\\"9.0\\\\\\\" && exit 0\\\\ngrep {{ ansible_facts[\\\\\\\"hostname\\\\\\\"]|lower }} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg  | grep -v \\\\\\\":3306 \\\\\\\" | \\\\\\\\\\\\nawk \'{print $3}\' | \\\\\\\\\\\\nwhile read BACKEND; do\\\\n    IP=${BACKEND%:*}\\\\n    PORT=${BACKEND#\\\\\\\"$IP:\\\\\\\"}\\\\n    if [[ $IP =~ .*:.* ]]\\\\n      then PROTOCOL=\\\\\\\"ip6\\\\\\\"\\\\n      else PROTOCOL=\\\\\\\"ip\\\\\\\"\\\\n    fi\\\\necho \\\\\\\"insert rule $PROTOCOL filter INPUT $PROTOCOL daddr $IP tcp dport $PORT tcp flags syn / fin,syn,rst,ack meta time\\\\\\\"\\\\ndone | xargs -i nft {} $(date +%s)-$(date -d\'+20 minutes\' +%s) counter drop comment \\\\\\\"{{ ansible_facts[\\\\\\\"hostname\\\\\\\"]|lower }}_haproxy_drop\\\\\\\"\\\\n\\\"}, {\\\"name\\\": \\\"Generate block for other nodes OUTPUT SYN packets on the backends except mysql\\\", \\\"tags\\\": \\\"haproxy_syn_block\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"shell\\\": \\\"set -o pipefail\\\\nsource /etc/os-release; test  \\\\\\\"${VERSION_ID%*}\\\\\\\" = \\\\\\\"9.0\\\\\\\" && exit 0\\\\ngrep {{ ansible_facts[\\\\\\\"hostname\\\\\\\"]|lower }} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg  | grep -v \\\\\\\":3306 \\\\\\\" | \\\\\\\\\\\\nawk \'{print $3}\' | \\\\\\\\\\\\nwhile read BACKEND; do\\\\n    IP=${BACKEND%:*}\\\\n    PORT=${BACKEND#\\\\\\\"$IP:\\\\\\\"}\\\\n    if [[ $IP =~ .*:.* ]]\\\\n      then PROTOCOL=\\\\\\\"ip6\\\\\\\"\\\\n      else PROTOCOL=\\\\\\\"ip\\\\\\\"\\\\n    fi\\\\n echo \\\\\\\"nft insert rule $PROTOCOL \\\\\\\\$TABLE OUTPUT $PROTOCOL daddr $IP tcp dport $PORT tcp flags syn / fin,syn,rst,ack meta time $(date +%s)-$(date -d\'+20 minutes\' +%s) counter drop comment \\\\\\\\\\\\\\\"{{ ansible_facts[\\\\\\\"hostname\\\\\\\"]|lower }}_haproxy_drop\\\\\\\\\\\\\\\" \\\\\\\"\\\\ndone\\\\n\\\", \\\"register\\\": \\\"haproxy_iptables_block\\\"}, {\\\"name\\\": \\\"Block OUTPUT SYN packets to this node on other haproxy nodes\\\", \\\"tags\\\": \\\"haproxy_syn_block\\\", \\\"delegate_to\\\": \\\"{{ item }}\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"shell\\\": \\\"set -o pipefail\\\\ngrep {{ ansible_facts[\\\\\\\"hostname\\\\\\\"]|lower }} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg | head -n 1 \\\\\\\\\\\\nawk \'{print $3}\' | while read BACKEND; do\\\\n    IP=${BACKEND%:*}\\\\n    if [[ $IP =~ .*:.* ]]\\\\n      then PROTOCOL=\\\\\\\"ip6\\\\\\\"\\\\n      else PROTOCOL=\\\\\\\"ip\\\\\\\"\\\\n    fi\\\\ndone\\\\nTABLE=$(nft list tables | grep -q \\\\\\\"$PROTOCOL raw\\\\\\\" && echo raw || echo filter )\\\\necho \\\\\\\"{{ haproxy_iptables_block.stdout}}\\\\\\\" | while read i; do bash -c \\\\\\\"$i\\\\\\\"; done\\\\n\\\", \\\"loop\\\": \\\"{{ groups[\\\\\\\"haproxy\\\\\\\"] | difference(groups[\\\\\\\"excluded_overcloud\\\\\\\"]) | difference(ansible_facts[\\\\\\\"hostname\\\\\\\"]|lower) }}\\\"}], \\\"post_update_tasks\\\": [{\\\"name\\\": \\\"HAProxy bundle post update\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"HAproxy puppet bundle\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_ha_wrapper\\\"}, \\\"vars\\\": {\\\"tripleo_ha_wrapper_service_name\\\": \\\"haproxy\\\", \\\"tripleo_ha_wrapper_resource_name\\\": \\\"haproxy-bundle\\\", \\\"tripleo_ha_wrapper_bundle_name\\\": \\\"haproxy-bundle\\\", \\\"tripleo_ha_wrapper_resource_state\\\": \\\"Started\\\", \\\"tripleo_ha_wrapper_puppet_config_volume\\\": \\\"haproxy\\\", \\\"tripleo_ha_wrapper_puppet_execute\\\": \\\"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::haproxy_bundle\\\", \\\"tripleo_ha_wrapper_puppet_tags\\\": \\\"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\\\", \\\"tripleo_ha_wrapper_puppet_debug\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"tripleo_ha_wrapper_config_suffix\\\": \\\".previous_run\\\"}}], \\\"vars\\\": {\\\"tripleo_ha_wrapper_minor_update\\\": true}}, {\\\"name\\\": \\\"Cleanup local SYN DROP rules\\\", \\\"tags\\\": \\\"haproxy_syn_block\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"shell\\\": \\\"nft -a list chain filter INPUT | grep {{ ansible_facts[\\\\\\\"hostname\\\\\\\"]|lower }} | grep haproxy_drop | \\\\\\\\\\\\nawk -F# \'{print \\\\\\\"nft delete rule filter INPUT \\\\\\\"$2}\' | \\\\\\\\\\\\nwhile read i; do bash -c \\\\\\\"$i\\\\\\\"; done\\\\n\\\"}, {\\\"name\\\": \\\"Cleanup SYN DROP rules from other haproxy nodes\\\", \\\"tags\\\": \\\"haproxy_syn_block\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"delegate_to\\\": \\\"{{ item }}\\\", \\\"loop\\\": \\\"{{ groups[\\\\\\\"haproxy\\\\\\\"] | difference(groups[\\\\\\\"excluded_overcloud\\\\\\\"]) | difference(ansible_facts[\\\\\\\"hostname\\\\\\\"]|lower) }}\\\", \\\"shell\\\": \\\"nft -a list chain raw OUTPUT | grep {{ ansible_facts[\\\\\\\"hostname\\\\\\\"]|lower }} | grep haproxy_drop | \\\\\\\\\\\\nawk -F# \'{print \\\\\\\"nft delete rule raw OUTPUT \\\\\\\"$2}\' | \\\\\\\\\\\\nwhile read i; do bash -c \\\\\\\"$i\\\\\\\"; done\\\\n\\\"}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"Tear-down non-HA haproxy container\\\", \\\"when\\\": [\\\"step|int == 0\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Remove non-HA haproxy container\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_rm\\\"}, \\\"vars\\\": {\\\"tripleo_container_cli\\\": \\\"{{ container_cli }}\\\", \\\"tripleo_containers_to_rm\\\": [\\\"haproxy\\\"]}}]}, {\\\"name\\\": \\\"Prepare switch of haproxy image name\\\", \\\"when\\\": [\\\"step|int == 0\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Get haproxy image id currently used by pacemaker\\\", \\\"shell\\\": \\\"pcs resource config haproxy-bundle | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\\\", \\\"register\\\": \\\"haproxy_image_current_res\\\", \\\"failed_when\\\": false}, {\\\"name\\\": \\\"Image facts for haproxy\\\", \\\"set_fact\\\": {\\\"haproxy_image_latest\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/haproxy:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHAProxyImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHAProxyImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"haproxy_image_current\\\": \\\"{{haproxy_image_current_res.stdout}}\\\"}}, {\\\"name\\\": \\\"Temporarily tag the current haproxy image id with the upgraded image name\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_tag\\\"}, \\\"vars\\\": {\\\"container_image\\\": \\\"{{haproxy_image_current}}\\\", \\\"container_image_latest\\\": \\\"{{haproxy_image_latest}}\\\", \\\"pull_image\\\": false}, \\\"when\\\": [\\\"haproxy_image_current != \'\'\\\", \\\"haproxy_image_current != haproxy_image_latest\\\"]}, {\\\"name\\\": \\\"Create haproxy retag statefile\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/tripleo/haproxy_needs_retag\\\", \\\"state\\\": \\\"touch\\\"}, \\\"when\\\": [\\\"haproxy_image_current != \'\'\\\", \\\"haproxy_image_current != haproxy_image_latest\\\"]}]}, {\\\"name\\\": \\\"Update haproxy pcs resource bundle for new container image\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Set upgrade haproxy facts\\\", \\\"set_fact\\\": {\\\"is_haproxy_bootstrap_node\\\": \\\"{{haproxy_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\\\"}}, {\\\"name\\\": \\\"Check for haproxy retag statefile\\\", \\\"stat\\\": {\\\"path\\\": \\\"/var/lib/tripleo/haproxy_needs_retag\\\"}, \\\"register\\\": \\\"haproxy_retag_state_file\\\"}]}, {\\\"name\\\": \\\"Update haproxy pcs resource bundle for new container image\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"is_haproxy_bootstrap_node|bool\\\", \\\"haproxy_retag_state_file.stat.exists|bool\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Disable the haproxy cluster resource before container upgrade\\\", \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"haproxy-bundle\\\", \\\"state\\\": \\\"disable\\\", \\\"wait_for_resource\\\": true}, \\\"register\\\": \\\"output\\\", \\\"retries\\\": 5, \\\"until\\\": \\\"output.rc == 0\\\"}, {\\\"name\\\": \\\"Expose HAProxy stats socket on the host and mount TLS cert if needed\\\", \\\"block\\\": [{\\\"name\\\": \\\"Check haproxy stats socket configuration in pacemaker\\\", \\\"command\\\": \\\"cibadmin --query --xpath \\\\\\\"//storage-mapping[@id=\'haproxy-var-lib\']\\\\\\\"\\\", \\\"failed_when\\\": false, \\\"register\\\": \\\"haproxy_stats_exposed\\\"}, {\\\"name\\\": \\\"Check haproxy public certificate configuration in pacemaker\\\", \\\"command\\\": \\\"cibadmin --query --xpath \\\\\\\"//storage-mapping[@id=\'haproxy-cert\']\\\\\\\"\\\", \\\"failed_when\\\": false, \\\"register\\\": \\\"haproxy_cert_mounted\\\"}, {\\\"name\\\": \\\"Add a bind mount for stats socket in the haproxy bundle\\\", \\\"command\\\": \\\"pcs resource bundle update haproxy-bundle storage-map add id=haproxy-var-lib source-dir=/var/lib/haproxy target-dir=/var/lib/haproxy options=rw\\\", \\\"when\\\": \\\"haproxy_stats_exposed.rc == 6\\\"}, {\\\"name\\\": \\\"Set HAProxy public cert volume mount fact\\\", \\\"set_fact\\\": {\\\"haproxy_public_cert_path\\\": {\\\"get_param\\\": \\\"DeployedSSLCertificatePath\\\"}, \\\"haproxy_public_tls_enabled\\\": {\\\"if\\\": [\\\"public_tls_enabled\\\", true, false]}}}, {\\\"name\\\": \\\"Add a bind mount for public certificate in the haproxy bundle\\\", \\\"command\\\": \\\"pcs resource bundle update haproxy-bundle storage-map add id=haproxy-cert source-dir={{ haproxy_public_cert_path }} target-dir=/var/lib/kolla/config_files/src-tls/{{ haproxy_public_cert_path }} options=ro\\\", \\\"when\\\": [\\\"haproxy_cert_mounted.rc == 6\\\", \\\"haproxy_public_tls_enabled|bool\\\"]}]}, {\\\"name\\\": \\\"Update the haproxy bundle to use the new container image name\\\", \\\"command\\\": \\\"pcs resource bundle update haproxy-bundle container image={{haproxy_image_latest}}\\\"}, {\\\"name\\\": \\\"Enable the haproxy cluster resource\\\", \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"haproxy-bundle\\\", \\\"state\\\": \\\"enable\\\", \\\"wait_for_resource\\\": true}, \\\"register\\\": \\\"output\\\", \\\"retries\\\": 5, \\\"until\\\": \\\"output.rc == 0\\\"}, {\\\"name\\\": \\\"Remove haproxy retag statefile\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/tripleo/haproxy_needs_retag\\\", \\\"state\\\": \\\"absent\\\"}}]}, {\\\"name\\\": \\\"Retag the pacemaker image if containerized\\\", \\\"when\\\": [\\\"step|int == 3\\\"], \\\"block\\\": [{\\\"block\\\": [{\\\"name\\\": \\\"Get haproxy image from pacemaker\\\", \\\"become\\\": true, \\\"register\\\": \\\"xmllint_pcmk_haproxy_image\\\", \\\"shell\\\": \\\"xmllint --xpath \\\\\\\"string(//bundle[@id=\'haproxy-bundle\']/podman/@image)\\\\\\\" /var/lib/pacemaker/cib/cib.xml\\\"}, {\\\"name\\\": \\\"Get container haproxy image\\\", \\\"set_fact\\\": {\\\"haproxy_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHAProxyImage\\\"]}, \\\"haproxy_image_latest\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/haproxy:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHAProxyImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHAProxyImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"pcmk_haproxy_image\\\": \\\"{{xmllint_pcmk_haproxy_image.stdout}}\\\"}}]}, {\\\"block\\\": [{\\\"name\\\": \\\"Retag pcmklatest to latest haproxy image\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_tag\\\"}, \\\"vars\\\": {\\\"container_image\\\": \\\"{{haproxy_image}}\\\", \\\"container_image_latest\\\": \\\"{{haproxy_image_latest}}\\\"}}]}, {\\\"name\\\": \\\"Ensure config works for the new config\\\", \\\"shell\\\": \\\"set -o pipefail\\\\nawk -i inplace -v INPLACE_SUFFIX=.bak \'/  rsprep/ {print \\\\\\\"  http-response replace-header Location \\\\\\\" $3\\\\\\\" \\\\\\\"$5; next;}; {print} \' /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg\\\"}]}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"HAProxy deployment with TLS enabled, with an injected certificate\\\\n\\\", \\\"parameters\\\": {\\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"SSLCertificate\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The content of the SSL certificate (without Key) in PEM format.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"SSLIntermediateCertificate\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The content of an SSL intermediate CA certificate in PEM format.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"SSLKey\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The content of the SSL Key in PEM format.\\\\n\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"DeployedSSLCertificatePath\\\": {\\\"default\\\": \\\"/etc/pki/tls/private/overcloud_endpoint.pem\\\", \\\"description\\\": \\\"The filepath of the certificate as it will be stored in the controller.\\\\n\\\", \\\"type\\\": \\\"string\\\"}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the HAProxy public TLS injection.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"haproxy_public_tls_inject\\\", \\\"config_settings\\\": {}, \\\"certificates_specs\\\": {}, \\\"metadata_settings\\\": null, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"get parameters\\\", \\\"set_fact\\\": {\\\"cert_path\\\": {\\\"get_param\\\": \\\"DeployedSSLCertificatePath\\\"}, \\\"cert_content\\\": {\\\"get_param\\\": \\\"SSLCertificate\\\"}, \\\"chain_content\\\": {\\\"get_param\\\": \\\"SSLIntermediateCertificate\\\"}, \\\"key_content\\\": {\\\"get_param\\\": \\\"SSLKey\\\"}}, \\\"no_log\\\": \\\"{{ hide_sensitive_logs | bool }}\\\"}, {\\\"name\\\": \\\"manage certificate\\\", \\\"when\\\": [\\\"cert_content is defined\\\", \\\"cert_content != \'\'\\\"], \\\"block\\\": [{\\\"name\\\": \\\"get DeployedSSLCertificatePath attributes\\\", \\\"register\\\": \\\"attr_cert_path\\\", \\\"stat\\\": {\\\"path\\\": \\\"{{cert_path}}\\\"}}, {\\\"name\\\": \\\"set is_haproxy_bootstrap_node fact\\\", \\\"set_fact\\\": \\\"is_haproxy_bootstrap_node={{haproxy_short_bootstrap_node_name | lower == ansible_facts[\'hostname\'] | lower}}\\\", \\\"when\\\": [\\\"haproxy_short_bootstrap_node_name|default(false)\\\"]}, {\\\"name\\\": \\\"get haproxy status\\\", \\\"register\\\": \\\"haproxy_state\\\", \\\"systemd\\\": {\\\"name\\\": \\\"haproxy\\\"}}, {\\\"name\\\": \\\"get pacemaker status\\\", \\\"register\\\": \\\"pacemaker_state\\\", \\\"systemd\\\": {\\\"name\\\": \\\"pacemaker\\\"}}, {\\\"name\\\": \\\"get docker status\\\", \\\"register\\\": \\\"docker_state\\\", \\\"systemd\\\": {\\\"name\\\": \\\"docker\\\"}}, {\\\"name\\\": \\\"get container_id\\\", \\\"when\\\": [\\\"docker_state.status.ActiveState == \'active\' or container_cli == \'podman\'\\\", \\\"attr_cert_path.stat.exists\\\", \\\"attr_cert_path.stat.isdir == False\\\"], \\\"command\\\": \\\"{{ container_cli }} ps -q -f name=\'^haproxy(-bundle)?\'\\\", \\\"register\\\": \\\"container_id\\\"}, {\\\"name\\\": \\\"get pcs resource name for haproxy container\\\", \\\"when\\\": [\\\"bootstrap_node is defined\\\", \\\"is_haproxy_bootstrap_node\\\", \\\"pacemaker_state.status.ActiveState == \'active\'\\\", \\\"attr_cert_path.stat.exists\\\", \\\"attr_cert_path.stat.isdir\\\"], \\\"shell\\\": \\\"pcs status resources | sed -n \'s/^.*container.*: \\\\\\\\(haproxy.*\\\\\\\\) .*/\\\\\\\\1/p\'\\\\n\\\", \\\"register\\\": \\\"pacemaker_resource\\\"}, {\\\"name\\\": \\\"remove DeployedSSLCertificatePath if is dir\\\", \\\"when\\\": \\\"attr_cert_path.stat.isdir is defined and attr_cert_path.stat.isdir\\\", \\\"file\\\": {\\\"path\\\": \\\"{{cert_path}}\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"push certificate content\\\", \\\"no_log\\\": \\\"{{ hide_sensitive_logs | bool }}\\\", \\\"copy\\\": {\\\"dest\\\": \\\"{{cert_path}}\\\", \\\"mode\\\": 288, \\\"owner\\\": \\\"root\\\", \\\"content\\\": \\\"{{cert_content}}\\\\n{{chain_content}}\\\\n{{key_content}}\\\\n\\\"}}, {\\\"name\\\": \\\"BM haproxy non-pacemaker context\\\", \\\"when\\\": \\\"haproxy_state.status.ActiveState == \'active\'\\\", \\\"block\\\": [{\\\"name\\\": \\\"set certificate ownership\\\", \\\"file\\\": {\\\"path\\\": \\\"{{cert_path}}\\\", \\\"group\\\": \\\"haproxy\\\"}}, {\\\"name\\\": \\\"reload haproxy if enabled\\\", \\\"service\\\": {\\\"name\\\": \\\"haproxy\\\", \\\"state\\\": \\\"reloaded\\\"}}]}, {\\\"name\\\": \\\"restart pacemaker resource for haproxy\\\", \\\"when\\\": [\\\"pacemaker_resource is defined\\\", \\\"pacemaker_resource.stdout is defined\\\", \\\"pacemaker_resource.stdout != \'\'\\\"], \\\"command\\\": \\\"pcs resource restart \\\\\\\"{{pacemaker_resource.stdout}}\\\\\\\"\\\"}, {\\\"name\\\": \\\"dedicated part for containers\\\", \\\"when\\\": [\\\"container_id is defined\\\", \\\"container_id.stdout is defined\\\", \\\"container_id.stdout != \'\'\\\"], \\\"block\\\": [{\\\"name\\\": \\\"copy certificate, chgrp, restart haproxy\\\", \\\"shell\\\": \\\"set -e\\\\nif {{ container_cli }} ps -f \\\\\\\"id={{ item }}\\\\\\\" --format \\\\\\\"{{ \'{{\' }}.Names{{ \'}}\' }}\\\\\\\" | grep -q \\\\\\\"^haproxy-bundle\\\\\\\"; then\\\\n  tar -c {{ cert_path }} | {{container_cli}} exec -i {{ item }} tar -C / -xv\\\\nelse\\\\n  {{ container_cli }} cp {{ cert_path }} {{ item }}:{{ cert_path }}\\\\nfi\\\\n{{ container_cli }} exec --user root {{ item }} chgrp haproxy {{ cert_path }}\\\\n{{ container_cli }} kill --signal=HUP {{ item }}\\\\n\\\", \\\"register\\\": \\\"container_kill_result\\\", \\\"failed_when\\\": [\\\"container_kill_result.rc != 0\\\", \\\"(\\\\\\\"no such container\\\\\\\" not in container_kill_result.stderr)\\\", \\\"(\\\\\\\"container state improper\\\\\\\" not in container_kill_result.stderr)\\\"], \\\"with_items\\\": \\\"{{ container_id.stdout.split(\'\\\\n\') }}\\\"}]}]}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Iscsid service\\\\n\\\", \\\"parameters\\\": {\\\"ContainerIscsidImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerIscsidConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the iscsid config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"LVMFilterEnabled\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Enables configuration of LVM2 with a filter so that devices not in use on the host or explicitly allowed are ignored by LVM2. Can be configured per-role. When disabled, the proposed lvm.conf file will be created regardless and left in /tmp/tripleo_lvmfilter.conf for debugging purposes.\\\", \\\"type\\\": \\\"boolean\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"LVMFilterAllowlist\\\": {\\\"default\\\": [], \\\"description\\\": \\\"A list of block devices which should be allowed in the LVM2 `global_filter`. Supports regular expressions, like `/dev/sd.*` and can be configured per-role. Any block device in use at boot time will be automatically allowed.\\\", \\\"type\\\": \\\"comma_delimited_list\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"LVMFilterDenylist\\\": {\\\"default\\\": [\\\".*\\\"], \\\"description\\\": \\\"A list of block devices which should be disallowed in the LVM2 `global_filter`. Supports regular expressions, like `/dev/sd.*` and can be configured per-role.\\\", \\\"type\\\": \\\"comma_delimited_list\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"IscsidCHAPAlgorithms\\\": {\\\"default\\\": \\\"SHA3-256,SHA256,SHA1,MD5\\\", \\\"description\\\": \\\"A comma separated list of algorithms to be used for the CHAP algorithm.\\\", \\\"type\\\": \\\"string\\\"}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"tripleo_tripleo_lvmfilter_enabled\\\": \\\"LVMFilterEnabled\\\", \\\"tripleo_tripleo_lvmfilter_devices_allowlist\\\": \\\"LVMFilterAllowlist\\\", \\\"tripleo_tripleo_lvmfilter_devices_denylist\\\": \\\"LVMFilterDenylist\\\", \\\"ContainerIscsidImage\\\": \\\"ContainerIscsidImage\\\", \\\"ContainerIscsidConfigImage\\\": \\\"ContainerIscsidConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"LVMFilterEnabled\\\": {\\\"get_param\\\": \\\"LVMFilterEnabled\\\"}, \\\"LVMFilterAllowlist\\\": {\\\"get_param\\\": \\\"LVMFilterAllowlist\\\"}, \\\"LVMFilterDenylist\\\": {\\\"get_param\\\": \\\"LVMFilterDenylist\\\"}, \\\"ContainerIscsidImage\\\": {\\\"get_param\\\": \\\"ContainerIscsidImage\\\"}, \\\"ContainerIscsidConfigImage\\\": {\\\"get_param\\\": \\\"ContainerIscsidConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Iscsid role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"iscsid\\\", \\\"config_settings\\\": {\\\"tripleo::profile::base::iscsid::chap_algs\\\": {\\\"get_param\\\": \\\"IscsidCHAPAlgorithms\\\"}}, \\\"service_config_settings\\\": {}, \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Run lvmfilter role\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_lvmfilter\\\"}, \\\"when\\\": [\\\"step|int == 1\\\"]}], \\\"ansible_group_vars\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\"]}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"iscsid\\\", \\\"puppet_tags\\\": \\\"iscsid_config\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::iscsid\\\\n\\\", \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerIscsidConfigImage\\\"]}, \\\"volumes\\\": [\\\"/etc/iscsi:/tmp/iscsi.host:z\\\"]}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/iscsid.json\\\": {\\\"command\\\": \\\"/usr/sbin/iscsid -f\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src-iscsid/\\\", \\\"dest\\\": \\\"/etc/iscsi/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}}, \\\"docker_config\\\": {\\\"step_3\\\": {\\\"iscsid\\\": {\\\"start_order\\\": 2, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerIscsidImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/iscsid.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/dev:/dev\\\", \\\"/run:/run\\\", \\\"/sys:/sys\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\\\", \\\"/etc/target:/etc/target:z\\\", \\\"/var/lib/iscsi:/var/lib/iscsi:z\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create fcontext entry for iscsi\\\", \\\"community.general.sefcontext\\\": {\\\"target\\\": \\\"{{ item.path }}(/.*)?\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"state\\\": \\\"present\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/etc/iscsi\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/etc/target\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/lib/iscsi\\\", \\\"setype\\\": \\\"container_file_t\\\"}]}, {\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/etc/iscsi\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/etc/target\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/lib/iscsi\\\", \\\"setype\\\": \\\"container_file_t\\\"}]}, {\\\"name\\\": \\\"stat /lib/systemd/system/iscsid.socket\\\", \\\"stat\\\": \\\"path=/lib/systemd/system/iscsid.socket\\\", \\\"register\\\": \\\"stat_iscsid_socket\\\"}, {\\\"name\\\": \\\"Stop and disable iscsid.socket service\\\", \\\"service\\\": \\\"name=iscsid.socket state=stopped enabled=no\\\", \\\"when\\\": \\\"stat_iscsid_socket.stat.exists\\\"}, {\\\"name\\\": \\\"Check if iscsi.service is enabled\\\", \\\"command\\\": \\\"systemctl is-enabled --quiet iscsi.service\\\", \\\"failed_when\\\": false, \\\"register\\\": \\\"iscsi_service_enabled_result\\\"}, {\\\"name\\\": \\\"Stop iscsi.service\\\", \\\"service\\\": \\\"name=iscsi.service state=stopped enabled=no\\\", \\\"when\\\": [\\\"iscsi_service_enabled_result is changed\\\", \\\"iscsi_service_enabled_result.rc == 0\\\"]}], \\\"upgrade_tasks\\\": []}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Memcached services\\\\n\\\", \\\"parameters\\\": {\\\"ContainerMemcachedImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerMemcachedConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the memcached config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"MemcachedMaxMemory\\\": {\\\"default\\\": \\\"50%\\\", \\\"description\\\": \\\"The maximum amount of memory for memcached to be configured to use when installed. This can be either a percentage (\'50%\') or a fixed value (\'2048\').\\\", \\\"type\\\": \\\"string\\\"}, \\\"MemcachedMaxConnections\\\": {\\\"default\\\": 8192, \\\"description\\\": \\\"The maximum number of connections to be accepted by memcached\\\", \\\"type\\\": \\\"number\\\"}, \\\"MonitoringSubscriptionMemcached\\\": {\\\"default\\\": \\\"overcloud-memcached\\\", \\\"type\\\": \\\"string\\\"}, \\\"Debug\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Set to True to enable debugging on all services.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"MemcachedDebug\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Set to True to enable debugging Memcached service.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"MemcachedIpSubnet\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"IP address/subnet on the memcached network. If empty (default), MemcachedNetwork will be taken. Useful in the case where an operator wants to open Memcached outside of the internal network. Use this parameter with caution and be aware of opening memcached to external network can be dangerous.\\\", \\\"type\\\": \\\"string\\\"}, \\\"MemcachedPort\\\": {\\\"default\\\": 11211, \\\"description\\\": \\\"Port to have Memcached listening at. When using MemcachedTLS, this has to be set to a different port then the default - see below.\\\", \\\"type\\\": \\\"number\\\"}, \\\"MemcachedTLS\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"CertificateKeySize\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"2048\\\", \\\"description\\\": \\\"Specifies the private key size used when creating the certificate.\\\"}, \\\"MemcachedCertificateKeySize\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Override the private key size used when creating the certificate for this service\\\"}}, \\\"conditions\\\": {\\\"enable_non_tls_port\\\": {\\\"and\\\": [{\\\"get_param\\\": \\\"MemcachedTLS\\\"}, {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"MemcachedPort\\\"}, 11211]}}]}, \\\"memcached_network_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"MemcachedIpSubnet\\\"}, \\\"\\\"]}}, \\\"memcached_debug\\\": {\\\"or\\\": [{\\\"get_param\\\": \\\"Debug\\\"}, {\\\"get_param\\\": \\\"MemcachedDebug\\\"}]}, \\\"is_ipv6\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"ServiceData\\\", \\\"net_ip_version_map\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MemcachedNetwork\\\"]}]}, 6]}, \\\"key_size_override_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"MemcachedCertificateKeySize\\\"}, \\\"\\\"]}}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerMemcachedImage\\\": \\\"ContainerMemcachedImage\\\", \\\"ContainerMemcachedConfigImage\\\": \\\"ContainerMemcachedConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerMemcachedImage\\\": {\\\"get_param\\\": \\\"ContainerMemcachedImage\\\"}, \\\"ContainerMemcachedConfigImage\\\": {\\\"get_param\\\": \\\"ContainerMemcachedConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Memcached API role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"memcached\\\", \\\"firewall_rules\\\": {\\\"if\\\": [\\\"memcached_network_set\\\", {\\\"121 memcached\\\": {\\\"dport\\\": {\\\"list_concat\\\": [[{\\\"get_param\\\": \\\"MemcachedPort\\\"}], {\\\"if\\\": [\\\"enable_non_tls_port\\\", [11211]]}]}, \\\"proto\\\": \\\"tcp\\\", \\\"source\\\": {\\\"get_param\\\": \\\"MemcachedIpSubnet\\\"}}}, {\\\"map_merge\\\": {\\\"repeat\\\": {\\\"for_each\\\": {\\\"<%net_cidr%>\\\": {\\\"get_param\\\": [\\\"ServiceData\\\", \\\"net_cidr_map\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MemcachedNetwork\\\"]}]}}, \\\"template\\\": {\\\"121 memcached <%net_cidr%>\\\": {\\\"dport\\\": {\\\"list_concat\\\": [[{\\\"get_param\\\": \\\"MemcachedPort\\\"}], {\\\"if\\\": [\\\"enable_non_tls_port\\\", [11211]]}]}, \\\"proto\\\": \\\"tcp\\\", \\\"source\\\": \\\"<%net_cidr%>\\\"}}}}}]}, \\\"monitoring_subscription\\\": {\\\"get_param\\\": \\\"MonitoringSubscriptionMemcached\\\"}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"memcached::listen\\\": {\\\"list_concat\\\": [[{\\\"if\\\": [\\\"is_ipv6\\\", \\\"::1\\\", \\\"127.0.0.1\\\"]}, {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MemcachedNetwork\\\"]}}}}], {\\\"if\\\": [\\\"enable_non_tls_port\\\", [{\\\"str_replace\\\": {\\\"template\\\": \\\"notls:%{hiera(\'$NETWORK_uri\')}:11211\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MemcachedNetwork\\\"]}}}}, {\\\"if\\\": [\\\"is_ipv6\\\", \\\"notls:[::1]:11211\\\", \\\"notls:127.0.0.1:11211\\\"]}]]}]}, \\\"memcached::listen_ip\\\": [{\\\"if\\\": [\\\"is_ipv6\\\", \\\"::1\\\", \\\"127.0.0.1\\\"]}, {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MemcachedNetwork\\\"]}}}}], \\\"memcached::listen_ip_uri\\\": [{\\\"if\\\": [\\\"is_ipv6\\\", \\\"::1\\\", \\\"127.0.0.1\\\"]}, {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK_uri\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MemcachedNetwork\\\"]}}}}], \\\"memcached::tcp_port\\\": {\\\"get_param\\\": \\\"MemcachedPort\\\"}, \\\"memcached::max_connections\\\": {\\\"get_param\\\": \\\"MemcachedMaxConnections\\\"}, \\\"memcached::max_memory\\\": {\\\"get_param\\\": \\\"MemcachedMaxMemory\\\"}, \\\"memcached::udp_port\\\": 0, \\\"memcached::verbosity\\\": {\\\"list_join\\\": [\\\"\\\", [\\\"v\\\", {\\\"if\\\": [\\\"memcached_debug\\\", \\\"v\\\", \\\"\\\"]}]]}, \\\"memcached::disable_cachedump\\\": true, \\\"memcached::logstdout\\\": true, \\\"tripleo::profile::base::memcached::enable_internal_memcached_tls\\\": {\\\"get_param\\\": \\\"MemcachedTLS\\\"}}, {\\\"if\\\": [{\\\"get_param\\\": \\\"MemcachedTLS\\\"}, {\\\"tripleo::memcached::service_certificate\\\": \\\"/etc/pki/tls/certs/memcached.crt\\\", \\\"tripleo::profile::base::memcached::certificate_specs\\\": {\\\"service_certificate\\\": \\\"/etc/pki/tls/certs/memcached.crt\\\", \\\"service_key\\\": \\\"/etc/pki/tls/private/memcached.key\\\"}}]}]}, \\\"service_config_settings\\\": {\\\"collectd\\\": {\\\"tripleo.collectd.plugins.memcached\\\": [\\\"memcached\\\"], \\\"collectd::plugin::memcached::instances\\\": {\\\"local\\\": {\\\"host\\\": \\\"%{hiera(\'memcached::listen_ip_uri\')}\\\", \\\"port\\\": [{\\\"if\\\": [\\\"enable_non_tls_port\\\", 11211, {\\\"get_param\\\": \\\"MemcachedPort\\\"}]}]}}}}, \\\"global_config_settings\\\": {\\\"map_merge\\\": [{\\\"if\\\": [\\\"enable_non_tls_port\\\", {\\\"memcached_port\\\": {\\\"get_param\\\": \\\"MemcachedPort\\\"}, \\\"memcached_authtoken_port\\\": 11211}, {\\\"memcached_port\\\": {\\\"get_param\\\": \\\"MemcachedPort\\\"}, \\\"memcached_authtoken_port\\\": {\\\"get_param\\\": \\\"MemcachedPort\\\"}}]}, {\\\"if\\\": [\\\"is_ipv6\\\", {\\\"memcached_ipv6\\\": true}]}]}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"memcached\\\", \\\"puppet_tags\\\": \\\"file\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::memcached\\\\n\\\", \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMemcachedConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/memcached.json\\\": {\\\"command\\\": \\\"bash -c $* -- eval source /etc/sysconfig/memcached; exec /usr/bin/memcached -p ${PORT} -u ${USER} -m ${CACHESIZE} -c ${MAXCONN} $OPTIONS >> /var/log/memcached/memcached.log 2>&1\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-tls/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true, \\\"optional\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/memcached\\\", \\\"owner\\\": \\\"memcached:memcached\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/certs/memcached.crt\\\", \\\"owner\\\": \\\"memcached:memcached\\\", \\\"optional\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/private/memcached.key\\\", \\\"owner\\\": \\\"memcached:memcached\\\", \\\"optional\\\": true}]}}, \\\"docker_config\\\": {\\\"step_1\\\": {\\\"memcached\\\": {\\\"start_order\\\": 0, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMemcachedImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/memcached.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/memcached:/var/lib/kolla/config_files/src:rw,z\\\", \\\"/var/log/containers/memcached:/var/log/memcached:rw\\\"], {\\\"if\\\": [{\\\"get_param\\\": \\\"MemcachedTLS\\\"}, [\\\"/etc/pki/tls/certs/memcached.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/memcached.crt:ro\\\", \\\"/etc/pki/tls/private/memcached.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/memcached.key:ro\\\"]]}]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"metadata_settings\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"MemcachedTLS\\\"}, [{\\\"service\\\": \\\"memcached\\\", \\\"network\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MemcachedNetwork\\\"]}, \\\"type\\\": \\\"node\\\"}]]}, \\\"deploy_steps_tasks\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"MemcachedTLS\\\"}, [{\\\"name\\\": \\\"Certificate generation\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"linux-system-roles.certificate\\\"}, \\\"vars\\\": {\\\"certificate_requests\\\": [{\\\"name\\\": \\\"memcached\\\", \\\"dns\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"{{fqdn_$NETWORK}}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MemcachedNetwork\\\"]}}}}, \\\"principal\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"memcached/{{fqdn_$NETWORK}}@{{idm_realm}}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MemcachedNetwork\\\"]}}}}, \\\"run_after\\\": \\\"container_name=$({{container_cli}} ps --format=\\\\\\\\{\\\\\\\\{.Names\\\\\\\\}\\\\\\\\} | grep memcached)\\\\nservice_crt=\\\\\\\"/etc/pki/tls/certs/memcached.crt\\\\\\\"\\\\nservice_key=\\\\\\\"/etc/pki/tls/private/memcached.key\\\\\\\"\\\\n# Copy the new cert from the mount-point to the real path\\\\n{{container_cli}} exec -u root \\\\\\\"$container_name\\\\\\\" cp \\\\\\\"/var/lib/kolla/config_files/src-tls$service_crt\\\\\\\" \\\\\\\"$service_crt\\\\\\\"\\\\n# Copy the new key from the mount-point to the real path\\\\n{{container_cli}} exec -u root \\\\\\\"$container_name\\\\\\\" cp \\\\\\\"/var/lib/kolla/config_files/src-tls$service_key\\\\\\\" \\\\\\\"$service_key\\\\\\\"\\\\n# Set appropriate permissions\\\\n{{container_cli}} exec -u root \\\\\\\"$container_name\\\\\\\" chown memcached:memcached \\\\\\\"$service_crt\\\\\\\"\\\\n{{container_cli}} exec -u root \\\\\\\"$container_name\\\\\\\" chown memcached:memcached \\\\\\\"$service_key\\\\\\\"\\\\n# Send refresh_certs command to memcached to read the new certificate\\\\nmemcached_ip=\\\\\\\"$(hiera -c /etc/puppet/hiera.yaml memcached::listen_ip.0 127.0.0.1)\\\\\\\"\\\\nmemcached_port=\\\\\\\"$(hiera -c /etc/puppet/hiera.yaml memcached::tcp_port 11211)\\\\\\\"\\\\necho refresh_certs | openssl s_client -connect $memcached_ip:$memcached_port\\\\n\\\", \\\"key_size\\\": {\\\"if\\\": [\\\"key_size_override_set\\\", {\\\"get_param\\\": \\\"MemcachedCertificateKeySize\\\"}, {\\\"get_param\\\": \\\"CertificateKeySize\\\"}]}, \\\"ca\\\": \\\"ipa\\\"}]}}]}]]}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/memcached\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}], \\\"upgrade_tasks\\\": [], \\\"external_upgrade_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade_transfer_data\\\", \\\"system_upgrade_stop_services\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Stop memcached container\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_stop\\\"}, \\\"vars\\\": {\\\"tripleo_containers_to_stop\\\": [\\\"memcached\\\"], \\\"tripleo_delegate_to\\\": \\\"{{ groups[\'memcached\'] | difference(groups[\'excluded_overcloud\']) }}\\\"}}]}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Configure tuned\\\\n\\\", \\\"parameters\\\": {\\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"TunedCustomProfile\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The definition of a new tuned profile in INI format which will be named after the TunedProfileName and applied to the host. E.g. if TunedProfileName is \'my_profile\', it creates the file \'/etc/tuned/my_profile/tuned.conf\' on host whose content is the value of TunedCustomProfile, e.g. \\\\\\\"[main]\\\\\\\\n include=throughput-performance\\\\\\\\n[sysctl]\\\\\\\\nvm.dirty_ratio=10\\\\\\\"\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"TunedProfileName\\\": {\\\"default\\\": \\\"throughput-performance\\\", \\\"description\\\": \\\"Tuned Profile to apply to the host\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}}, \\\"resources\\\": {\\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"tuned_profile\\\": \\\"TunedProfileName\\\", \\\"tuned_custom_profile\\\": \\\"TunedCustomProfile\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"TunedProfileName\\\": {\\\"get_param\\\": \\\"TunedProfileName\\\"}, \\\"TunedCustomProfile\\\": {\\\"get_param\\\": \\\"TunedCustomProfile\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for tuned\\\", \\\"value\\\": {\\\"service_name\\\": \\\"tuned\\\", \\\"host_prep_tasks\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"tuned\\\"}}], \\\"ansible_group_vars\\\": {\\\"tuned_profile\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"tuned_profile\\\"]}, \\\"tuned_custom_profile\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"tuned_custom_profile\\\"]}}}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Configure sshd_config\\\\n\\\", \\\"parameters\\\": {\\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"BannerText\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Configures Banner text in sshd_config\\\", \\\"type\\\": \\\"string\\\"}, \\\"MessageOfTheDay\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Configures /etc/motd text\\\", \\\"type\\\": \\\"string\\\"}, \\\"SshServerOptions\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of sshd_config values\\\", \\\"type\\\": \\\"json\\\"}, \\\"PasswordAuthentication\\\": {\\\"default\\\": \\\"no\\\", \\\"description\\\": \\\"Whether or not disable password authentication\\\", \\\"type\\\": \\\"string\\\"}, \\\"SshFirewallAllowAll\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Set this to true to open up ssh access from all sources.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"SshServerOptionsOverrides\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of sshd_config values to override definitions in SshServerOptions\\\", \\\"type\\\": \\\"json\\\"}}, \\\"parameter_groups\\\": [{\\\"label\\\": \\\"deprecated\\\", \\\"description\\\": \\\"The following parameters are deprecated and will be removed. They should not\\\\nbe relied on for new deployments. If you have concerns regarding deprecated\\\\nparameters, please contact the TripleO development team on IRC or the\\\\nOpenStack mailing list.\\\\n\\\", \\\"parameters\\\": [\\\"SshServerOptionsOverrides\\\"]}], \\\"conditions\\\": {\\\"ssh_firewall_allow_all\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"SshFirewallAllowAll\\\"}, true]}, \\\"ssh_banner_text_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"BannerText\\\"}, \\\"\\\"]}}, \\\"ssh_motd_text_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"MessageOfTheDay\\\"}, \\\"\\\"]}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the ssh\\\", \\\"value\\\": {\\\"service_name\\\": \\\"sshd\\\", \\\"firewall_rules\\\": {\\\"003 accept ssh from all\\\": {\\\"proto\\\": \\\"tcp\\\", \\\"dport\\\": 22, \\\"extras\\\": {\\\"ensure\\\": {\\\"if\\\": [\\\"ssh_firewall_allow_all\\\", \\\"present\\\", \\\"absent\\\"]}}}}, \\\"host_prep_tasks\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"tripleo_sshd\\\"}, \\\"vars\\\": {\\\"tripleo_sshd_server_options\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"SshServerOptions\\\"}, {\\\"get_param\\\": \\\"SshServerOptionsOverrides\\\"}]}, \\\"tripleo_sshd_password_authentication\\\": {\\\"get_param\\\": \\\"PasswordAuthentication\\\"}, \\\"tripleo_sshd_banner_enabled\\\": {\\\"if\\\": [\\\"ssh_banner_text_set\\\", true, false]}, \\\"tripleo_sshd_banner_text\\\": {\\\"get_param\\\": \\\"BannerText\\\"}, \\\"tripleo_sshd_motd_enabled\\\": {\\\"if\\\": [\\\"ssh_motd_text_set\\\", true, false]}, \\\"tripleo_sshd_message_of_the_day\\\": {\\\"get_param\\\": \\\"MessageOfTheDay\\\"}}}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack Nova base service. Shared for all Nova services.\\\\n\\\", \\\"parameters\\\": {\\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"KeystoneRegion\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"regionOne\\\", \\\"description\\\": \\\"Keystone region for endpoint\\\"}, \\\"NotificationDriver\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": \\\"noop\\\", \\\"description\\\": \\\"Driver or drivers to handle sending notifications.\\\"}, \\\"NovaPassword\\\": {\\\"description\\\": \\\"The password for the nova service and db account\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"NeutronPassword\\\": {\\\"description\\\": \\\"The password for the neutron service and db account, used by neutron agents.\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"PlacementPassword\\\": {\\\"description\\\": \\\"The password for the Placement service and db account\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"PlacementAPIInterface\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Endpoint interface to be used for the placement API.\\\\n\\\", \\\"default\\\": \\\"internal\\\"}, \\\"NovaOVSBridge\\\": {\\\"default\\\": \\\"br-int\\\", \\\"description\\\": \\\"Name of integration bridge used by Open vSwitch\\\", \\\"type\\\": \\\"string\\\"}, \\\"Debug\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false, \\\"description\\\": \\\"Set to True to enable debugging on all services.\\\"}, \\\"NovaDebug\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Set to True to enable debugging Nova services.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"EnableCache\\\": {\\\"description\\\": \\\"Enable caching with memcached\\\", \\\"type\\\": \\\"boolean\\\", \\\"default\\\": true}, \\\"EnableSQLAlchemyCollectd\\\": {\\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"Set to true to enable the SQLAlchemy-collectd server plugin\\\\n\\\", \\\"default\\\": false}, \\\"EnableConfigPurge\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false, \\\"description\\\": \\\"Remove configuration that is not generated by TripleO. Used to avoid configuration remnants after upgrades.\\\\n\\\"}, \\\"UpgradeLevelNovaCompute\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Nova Compute upgrade level\\\", \\\"default\\\": \\\"\\\"}, \\\"NovaOVSDBConnection\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"OVS DB connection string to used by Nova\\\", \\\"default\\\": \\\"\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaSyncPowerStateInterval\\\": {\\\"type\\\": \\\"number\\\", \\\"description\\\": \\\"Interval to sync power states between the database and the hypervisor. Set to -1 to disable. Setting this to 0 will run at the default rate(60) defined in oslo.service.\\\", \\\"default\\\": 600}, \\\"RpcUseSSL\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Messaging client subscriber parameter to specify an SSL connection to the messaging host.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"NovaAdditionalCell\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether this is an cell additional to the default cell.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"NovaCrossAZAttach\\\": {\\\"default\\\": true, \\\"description\\\": \\\"Whether instances can attach cinder volumes from a different availability zone.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"MemcachedTLS\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\\\", \\\"type\\\": \\\"boolean\\\"}}, \\\"conditions\\\": {\\\"compute_upgrade_level_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"UpgradeLevelNovaCompute\\\"}, \\\"\\\"]}}, \\\"tls_cache_enabled\\\": {\\\"and\\\": [{\\\"get_param\\\": \\\"EnableCache\\\"}, {\\\"get_param\\\": \\\"MemcachedTLS\\\"}]}}, \\\"resources\\\": {\\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"nova::ovsdb_connection\\\": \\\"NovaOVSDBConnection\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"NovaOVSDBConnection\\\": {\\\"get_param\\\": \\\"NovaOVSDBConnection\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Nova base service.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"nova_base\\\", \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"nova::my_ip\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaApiNetwork\\\"]}}}}, \\\"nova::rabbit_use_ssl\\\": {\\\"get_param\\\": \\\"RpcUseSSL\\\"}, \\\"nova::keystone::service_user::send_service_user_token\\\": true, \\\"nova::keystone::service_user::project_name\\\": \\\"service\\\", \\\"nova::keystone::service_user::password\\\": {\\\"get_param\\\": \\\"NovaPassword\\\"}, \\\"nova::keystone::service_user::auth_url\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"uri_no_suffix\\\"]}, \\\"nova::keystone::service_user::region_name\\\": {\\\"get_param\\\": \\\"KeystoneRegion\\\"}, \\\"nova::placement::project_name\\\": \\\"service\\\", \\\"nova::placement::password\\\": {\\\"get_param\\\": \\\"PlacementPassword\\\"}, \\\"nova::placement::auth_url\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"uri_no_suffix\\\"]}, \\\"nova::placement::region_name\\\": {\\\"get_param\\\": \\\"KeystoneRegion\\\"}, \\\"nova::placement::valid_interfaces\\\": {\\\"get_param\\\": \\\"PlacementAPIInterface\\\"}, \\\"nova::os_region_name\\\": {\\\"get_param\\\": \\\"KeystoneRegion\\\"}, \\\"nova::logging::debug\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"NovaDebug\\\"}, true, {\\\"get_param\\\": \\\"Debug\\\"}]}, \\\"nova::purge_config\\\": {\\\"get_param\\\": \\\"EnableConfigPurge\\\"}, \\\"nova::network::neutron::project_name\\\": \\\"service\\\", \\\"nova::network::neutron::username\\\": \\\"neutron\\\", \\\"nova::network::neutron::region_name\\\": {\\\"get_param\\\": \\\"KeystoneRegion\\\"}, \\\"nova::dhcp_domain\\\": \\\"\\\", \\\"nova::network::neutron::password\\\": {\\\"get_param\\\": \\\"NeutronPassword\\\"}, \\\"nova::network::neutron::auth_url\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneV3Internal\\\", \\\"uri\\\"]}, \\\"nova::network::neutron::valid_interfaces\\\": \\\"internal\\\", \\\"nova::glance::valid_interfaces\\\": \\\"internal\\\", \\\"nova::rabbit_heartbeat_timeout_threshold\\\": 60, \\\"nova::cinder_catalog_info\\\": \\\"volumev3:cinderv3:internalURL\\\", \\\"nova::host\\\": \\\"%{hiera(\'fqdn_canonical\')}\\\", \\\"nova::notify_on_state_change\\\": \\\"vm_and_task_state\\\", \\\"nova::notification_driver\\\": {\\\"get_param\\\": \\\"NotificationDriver\\\"}, \\\"nova::notification_format\\\": \\\"unversioned\\\", \\\"nova::network::neutron::auth_type\\\": \\\"v3password\\\", \\\"nova::db::database_db_max_retries\\\": -1, \\\"nova::db::database_max_retries\\\": -1, \\\"nova::network::neutron::ovs_bridge\\\": {\\\"get_param\\\": \\\"NovaOVSBridge\\\"}, \\\"nova::compute::sync_power_state_interval\\\": {\\\"get_param\\\": \\\"NovaSyncPowerStateInterval\\\"}, \\\"nova_is_additional_cell\\\": {\\\"get_param\\\": \\\"NovaAdditionalCell\\\"}, \\\"nova::cross_az_attach\\\": {\\\"get_param\\\": \\\"NovaCrossAZAttach\\\"}, \\\"nova::cache::enabled\\\": {\\\"get_param\\\": \\\"EnableCache\\\"}, \\\"nova::cache::tls_enabled\\\": {\\\"get_param\\\": \\\"MemcachedTLS\\\"}, \\\"nova::cache::backend\\\": {\\\"if\\\": [\\\"tls_cache_enabled\\\", \\\"dogpile.cache.pymemcache\\\", \\\"dogpile.cache.memcached\\\"]}, \\\"nova::rabbit_heartbeat_in_pthread\\\": false, \\\"nova::upgrade_level_compute\\\": {\\\"if\\\": [\\\"compute_upgrade_level_set\\\", {\\\"get_param\\\": \\\"UpgradeLevelNovaCompute\\\"}]}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\"]}]}, \\\"service_config_settings\\\": {\\\"rabbitmq\\\": {\\\"nova::rabbit_use_ssl\\\": {\\\"get_param\\\": \\\"RpcUseSSL\\\"}}}}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack Nova database client service.\\\\n\\\", \\\"parameters\\\": {\\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"NovaPassword\\\": {\\\"description\\\": \\\"The password for the nova service and db account\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"EnableSQLAlchemyCollectd\\\": {\\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"Set to true to enable the SQLAlchemy-collectd server plugin\\\\n\\\", \\\"default\\\": false}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Nova base service.\\\", \\\"value\\\": {\\\"config_settings\\\": {\\\"nova::api_database_connection\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"MysqlInternal\\\", \\\"protocol\\\"]}, \\\"username\\\": \\\"nova_api\\\", \\\"password\\\": {\\\"get_param\\\": \\\"NovaPassword\\\"}, \\\"host\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"MysqlInternal\\\", \\\"host\\\"]}, \\\"path\\\": \\\"/nova_api\\\", \\\"query\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableSQLAlchemyCollectd\\\"}, {\\\"read_default_file\\\": \\\"/etc/my.cnf.d/tripleo.cnf\\\", \\\"read_default_group\\\": \\\"tripleo\\\", \\\"plugin\\\": \\\"collectd\\\", \\\"collectd_program_name\\\": \\\"nova_api\\\", \\\"collectd_host\\\": \\\"localhost\\\"}, {\\\"read_default_file\\\": \\\"/etc/my.cnf.d/tripleo.cnf\\\", \\\"read_default_group\\\": \\\"tripleo\\\"}]}}}}, \\\"service_config_settings\\\": {\\\"mysql\\\": {\\\"nova::db::mysql_api::password\\\": {\\\"get_param\\\": \\\"NovaPassword\\\"}, \\\"nova::db::mysql_api::user\\\": \\\"nova_api\\\", \\\"nova::db::mysql_api::host\\\": \\\"%\\\", \\\"nova::db::mysql_api::dbname\\\": \\\"nova_api\\\"}}}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack Nova database client service.\\\\n\\\", \\\"parameters\\\": {\\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"NovaPassword\\\": {\\\"description\\\": \\\"The password for the nova service and db account\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"EnableSQLAlchemyCollectd\\\": {\\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"Set to true to enable the SQLAlchemy-collectd server plugin\\\\n\\\", \\\"default\\\": false}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Nova base service.\\\", \\\"value\\\": {\\\"config_settings\\\": {\\\"nova::database_connection\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"MysqlCellInternal\\\", \\\"protocol\\\"]}, \\\"username\\\": \\\"nova\\\", \\\"password\\\": {\\\"get_param\\\": \\\"NovaPassword\\\"}, \\\"host\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"MysqlCellInternal\\\", \\\"host\\\"]}, \\\"path\\\": \\\"/nova\\\", \\\"query\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableSQLAlchemyCollectd\\\"}, {\\\"read_default_file\\\": \\\"/etc/my.cnf.d/tripleo.cnf\\\", \\\"read_default_group\\\": \\\"tripleo\\\", \\\"plugin\\\": \\\"collectd\\\", \\\"collectd_program_name\\\": \\\"nova\\\", \\\"collectd_host\\\": \\\"localhost\\\"}, {\\\"read_default_file\\\": \\\"/etc/my.cnf.d/tripleo.cnf\\\", \\\"read_default_group\\\": \\\"tripleo\\\"}]}}}}, \\\"service_config_settings\\\": {\\\"mysql\\\": {\\\"nova::db::mysql::password\\\": {\\\"get_param\\\": \\\"NovaPassword\\\"}, \\\"nova::db::mysql::user\\\": \\\"nova\\\", \\\"nova::db::mysql::host\\\": \\\"%\\\", \\\"nova::db::mysql::dbname\\\": \\\"nova\\\"}}}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/nova_wait_for_api_service.py\": \"#!/usr/bin/python3\\n#\\n# Copyright 2018 Red Hat Inc.\\n#\\n# Licensed under the Apache License, Version 2.0 (the \\\"License\\\"); you may\\n# not use this file except in compliance with the License. You may obtain\\n# a copy of the License at\\n#\\n#      http://www.apache.org/licenses/LICENSE-2.0\\n#\\n# Unless required by applicable law or agreed to in writing, software\\n# distributed under the License is distributed on an \\\"AS IS\\\" BASIS, WITHOUT\\n# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the\\n# License for the specific language governing permissions and limitations\\n# under the License.\\nimport argparse\\nimport logging\\nimport os\\nimport six\\nimport sys\\nimport time\\n\\n\\nfrom keystoneauth1 import loading\\nfrom keystoneauth1 import session\\n\\nfrom novaclient import client\\nfrom novaclient.exceptions import ClientException\\n\\n# In python3 SafeConfigParser was renamed to ConfigParser and the default\\n# for duplicate options default to true. In case of nova it is valid to\\n# have duplicate option lines, e.g. passthrough_whitelist which leads to\\n# issues reading the nova.conf\\n# https://bugs.launchpad.net/tripleo/+bug/1827775\\nif six.PY3:\\n    from six.moves.configparser import ConfigParser\\n    config = ConfigParser(strict=False)\\nelse:\\n    from six.moves.configparser import SafeConfigParser\\n    config = SafeConfigParser()\\n\\ndebug = os.getenv(\'__OS_DEBUG\', \'false\')\\n\\nif debug.lower() == \'true\':\\n    loglevel = logging.DEBUG\\nelse:\\n    loglevel = logging.INFO\\n\\nlogging.basicConfig(stream=sys.stdout, level=loglevel)\\nLOG = logging.getLogger(\'nova_wait_for_api_service\')\\n\\niterations = 60\\ntimeout = 10\\nnova_cfg = \'/etc/nova/nova.conf\'\\n\\nif __name__ == \'__main__\':\\n    parser = argparse.ArgumentParser(usage=\'%(prog)s [options]\')\\n    parser.add_argument(\'-k\', \'--insecure\',\\n                        action=\\\"store_false\\\",\\n                        dest=\'insecure\',\\n                        default=True,\\n                        help=\'Allow insecure connection when using SSL\')\\n\\n    args = parser.parse_args()\\n    LOG.debug(\'Running with parameter insecure = %s\',\\n              args.insecure)\\n\\n    if os.path.isfile(nova_cfg):\\n        try:\\n            config.read(nova_cfg)\\n        except Exception:\\n            LOG.exception(\'Error while reading nova.conf:\')\\n    else:\\n        LOG.error(\'Nova configuration file %s does not exist\', nova_cfg)\\n        sys.exit(1)\\n\\n    loader = loading.get_plugin_loader(\'password\')\\n    auth = loader.load_from_options(\\n        auth_url=config.get(\'neutron\',\\n                            \'auth_url\'),\\n        username=config.get(\'neutron\',\\n                            \'username\'),\\n        password=config.get(\'neutron\',\\n                            \'password\'),\\n        project_name=config.get(\'neutron\',\\n                                \'project_name\'),\\n        project_domain_name=config.get(\'neutron\',\\n                                       \'project_domain_name\'),\\n        user_domain_name=config.get(\'neutron\',\\n                                    \'user_domain_name\'))\\n    sess = session.Session(auth=auth, verify=args.insecure)\\n\\n    # Wait until this host is listed in the service list\\n    for i in range(iterations):\\n        try:\\n            nova = client.Client(\'2.11\', session=sess, endpoint_type=\'internal\')\\n            nova.versions.list()\\n            LOG.info(\'Nova-api service active\')\\n            sys.exit(0)\\n        except ClientException:\\n            LOG.info(\'Waiting for nova-api service\')\\n        except Exception:\\n            LOG.exception(\\n                \'Error while waiting for nova-api service\')\\n        time.sleep(timeout)\\nsys.exit(1)\\n\\n# vim: set et ts=4 sw=4 :\\n\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/nova_api_ensure_default_cells.py\": \"#!/usr/bin/python3\\n#\\n# Copyright 2022 Red Hat Inc.\\n#\\n# Licensed under the Apache License, Version 2.0 (the \\\"License\\\"); you may\\n# not use this file except in compliance with the License. You may obtain\\n# a copy of the License at\\n#\\n#      http://www.apache.org/licenses/LICENSE-2.0\\n#\\n# Unless required by applicable law or agreed to in writing, software\\n# distributed under the License is distributed on an \\\"AS IS\\\" BASIS, WITHOUT\\n# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the\\n# License for the specific language governing permissions and limitations\\n# under the License.\\n\\nfrom configparser import ConfigParser\\nimport logging\\nimport os\\nimport subprocess\\nimport sys\\nfrom urllib import parse as urlparse\\n\\nconfig = ConfigParser(strict=False)\\n\\ndebug = os.getenv(\'__OS_DEBUG\', \'false\')\\n\\nif debug.lower() == \'true\':\\n    loglevel = logging.DEBUG\\nelse:\\n    loglevel = logging.INFO\\n\\nlogging.basicConfig(stream=sys.stdout, level=loglevel)\\nLOG = logging.getLogger(\'nova_api_ensure_default_cells\')\\n\\nNOVA_CFG = \'/etc/nova/nova.conf\'\\nCELL0_ID = \'00000000-0000-0000-0000-000000000000\'\\nDEFAULT_CELL_NAME = \'default\'\\n\\n\\ndef template_netloc_credentials(netloc, index=None):\\n    if \'@\' in netloc:\\n        userpass, hostport = netloc.split(\'@\', 1)\\n        has_pass = \':\' in userpass\\n        if index is None:\\n            cred_template = \'{username}\'\\n            if has_pass:\\n                cred_template += \':{password}\'\\n        else:\\n            cred_template = \'{{username{index}}}\'.format(index=index)\\n            if has_pass:\\n                cred_template += \':{{password{index}}}\'.format(index=index)\\n        return \'@\'.join((cred_template, hostport))\\n    else:\\n        return netloc\\n\\n\\ndef template_url(url):\\n    parsed = urlparse.urlparse(url)\\n    if \',\' in parsed.netloc:\\n        orig_netlocs = parsed.netloc.split(\',\')\\n        templ_netlocs = []\\n        index = 0\\n        for netloc in orig_netlocs:\\n            index += 1\\n            templ_netlocs.append(template_netloc_credentials(netloc, index))\\n        new_netloc = \',\'.join(templ_netlocs)\\n    else:\\n        new_netloc = template_netloc_credentials(parsed.netloc)\\n    return parsed._replace(netloc=new_netloc).geturl()\\n\\n\\ndef parse_list_cells(list_cells_output):\\n    list_cells_lines = list_cells_output.split(\'\\\\n\')\\n    if len(list_cells_lines) < 5:\\n        raise ValueError(\'Invalid nova-manage cell_v2 list_cells output\')\\n\\n    data_rows = list_cells_lines[3:-2]\\n    by_name = {}\\n    by_uuid = {}\\n\\n    for row in data_rows:\\n        parts = row.split(\'|\')\\n        entry = {\\n            \'name\': parts[1].strip(),\\n            \'uuid\': parts[2].strip(),\\n            \'transport_url\': parts[3].strip(),\\n            \'database_connection\': parts[4].strip(),\\n        }\\n        by_name[entry[\'name\']] = entry\\n        by_uuid[entry[\'uuid\']] = entry\\n\\n    return by_name, by_uuid\\n\\n\\ndef create_or_update_default_cells(cell0_db, default_db, default_transport_url):\\n    list_cells_cmd = [\'/usr/bin/nova-manage\', \'cell_v2\', \'list_cells\', \'--verbose\']\\n    list_cells_output = subprocess.check_output(list_cells_cmd, encoding=\'utf-8\')\\n    cells_by_name, cells_by_uuid = parse_list_cells(list_cells_output)\\n\\n    if CELL0_ID in cells_by_uuid:\\n        LOG.info(\'Setting cell0 database connection to \\\\\'{}\\\\\'\'.format(cell0_db))\\n        cmd = [\\n            \'/usr/bin/nova-manage\', \'cell_v2\', \'update_cell\',\\n            \'--cell_uuid\', CELL0_ID,\\n            \'--database_connection\', cell0_db,\\n            \'--transport-url\', \'none:///\'\\n        ]\\n    else:\\n        LOG.info(\'Creating cell0 with database connection \\\\\'{}\\\\\'\'.format(cell0_db))\\n        cmd = [\\n            \'/usr/bin/nova-manage\', \'cell_v2\', \'map_cell0\',\\n             \'--database_connection\', cell0_db\\n        ]\\n    subprocess.check_call(cmd)\\n\\n    if DEFAULT_CELL_NAME in cells_by_name:\\n        LOG.info(\'Setting default cell database connection to \\\\\'{}\\\\\' and transport url to \\\\\'{}\\\\\'\'.format(\\n            default_db, default_transport_url))\\n        cmd = [\\n            \'/usr/bin/nova-manage\', \'cell_v2\', \'update_cell\',\\n            \'--cell_uuid\', cells_by_name[DEFAULT_CELL_NAME][\'uuid\'],\\n            \'--database_connection\', default_db,\\n            \'--transport-url\', default_transport_url\\n        ]\\n    else:\\n        LOG.info(\'Creating default cell with database connection \\\\\'{}\\\\\' and transport url \\\\\'{}\\\\\'\'.format(\\n            default_db, default_transport_url))\\n        cmd = [\\n            \'/usr/bin/nova-manage\', \'cell_v2\', \'create_cell\',\\n            \'--name\', DEFAULT_CELL_NAME,\\n             \'--database_connection\', default_db,\\n            \'--transport-url\', default_transport_url\\n        ]\\n    subprocess.check_call(cmd)\\n\\n\\ndef replace_db_name(db_url, db_name):\\n    return urlparse.urlparse(db_url)._replace(path=db_name).geturl()\\n\\n\\nif __name__ == \'__main__\':\\n    if os.path.isfile(NOVA_CFG):\\n        try:\\n            config.read(NOVA_CFG)\\n        except Exception:\\n            LOG.exception(\'Error while reading nova.conf:\')\\n            sys.exit(1)\\n    else:\\n        LOG.error(\'Nova configuration file %s does not exist\', NOVA_CFG)\\n        sys.exit(1)\\n\\n    default_database_connection = config.get(\'database\', \'connection\')\\n    cell0_database_connection = replace_db_name(default_database_connection, \'nova_cell0\')\\n    default_transport_url = config.get(\'DEFAULT\', \'transport_url\')\\n\\n    create_or_update_default_cells(\\n        template_url(cell0_database_connection),\\n        template_url(default_database_connection),\\n        template_url(default_transport_url)\\n    )\\n\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Nova API service\\\\n\\\", \\\"parameters\\\": {\\\"ContainerNovaApiImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerNovaConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the nova config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaApiLoggingSource\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {\\\"tag\\\": \\\"openstack.nova.api\\\", \\\"file\\\": \\\"/var/log/containers/nova/nova-api.log\\\"}}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"DeployIdentifier\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\\\n\\\"}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"NovaPassword\\\": {\\\"description\\\": \\\"The password for the nova service and db account\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"MysqlIPv6\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Enable IPv6 in MySQL\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"NovaWorkers\\\": {\\\"default\\\": 0, \\\"description\\\": \\\"Number of workers for Nova services.\\\", \\\"type\\\": \\\"number\\\"}, \\\"EnforceSecureRbac\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false, \\\"description\\\": \\\"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\\\"}, \\\"KeystoneRegion\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"regionOne\\\", \\\"description\\\": \\\"Keystone region for endpoint\\\"}, \\\"InstanceNameTemplate\\\": {\\\"default\\\": \\\"instance-%08x\\\", \\\"description\\\": \\\"Template string to be used to generate instance names\\\", \\\"type\\\": \\\"string\\\"}, \\\"NovaEnableDBPurge\\\": {\\\"default\\\": true, \\\"description\\\": \\\"Whether to create cron job for purging soft deleted rows in Nova database.\\\\n\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"NovaEnableDBArchive\\\": {\\\"default\\\": true, \\\"description\\\": \\\"Whether to create cron job for archiving soft deleted rows in Nova database.\\\\n\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"MonitoringSubscriptionNovaApi\\\": {\\\"default\\\": \\\"overcloud-nova-api\\\", \\\"type\\\": \\\"string\\\"}, \\\"NovaDefaultFloatingPool\\\": {\\\"default\\\": \\\"public\\\", \\\"description\\\": \\\"Default pool for floating IP addresses\\\", \\\"type\\\": \\\"string\\\"}, \\\"NovaApiPolicies\\\": {\\\"description\\\": \\\"A hash of policies to configure for Nova API.\\\\ne.g. { nova-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\\\n\\\", \\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}, \\\"NovaAllowResizeToSameHost\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Allow destination machine to match source for resize.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"NovaApiMaxLimit\\\": {\\\"default\\\": 1000, \\\"description\\\": \\\"Max number of objects returned per API query\\\", \\\"type\\\": \\\"number\\\"}, \\\"NovaCronPurgeShadowTablesMinute\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge shadow tables - Minute\\\\n\\\", \\\"default\\\": \\\"0\\\"}, \\\"NovaCronPurgeShadowTablesHour\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge shadow tables - Hour\\\\n\\\", \\\"default\\\": \\\"5\\\"}, \\\"NovaCronPurgeShadowTablesMonthday\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge shadow tables - Month Day\\\\n\\\", \\\"default\\\": \\\"*\\\"}, \\\"NovaCronPurgeShadowTablesMonth\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge shadow tables - Month\\\\n\\\", \\\"default\\\": \\\"*\\\"}, \\\"NovaCronPurgeShadowTablesWeekday\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge shadow tables - Week Day\\\\n\\\", \\\"default\\\": \\\"*\\\"}, \\\"NovaCronPurgeShadowTablesUser\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge shadow tables - User\\\\n\\\", \\\"default\\\": \\\"nova\\\"}, \\\"NovaCronPurgeShadowTablesDestination\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge shadow tables - Log destination\\\\n\\\", \\\"default\\\": \\\"/var/log/nova/nova-rowspurge.log\\\"}, \\\"NovaCronPurgeShadowTablesMaxDelay\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge shadow tables - Max Delay\\\\n\\\", \\\"default\\\": \\\"3600\\\"}, \\\"NovaCronPurgeShadowTablesAge\\\": {\\\"type\\\": \\\"number\\\", \\\"description\\\": \\\"Cron to purge shadow tables - Age This will define the retention policy when purging the shadow tables in days. 0 means, purge data older than today in shadow tables.\\\\n\\\", \\\"default\\\": 14}, \\\"NovaCronPurgeShadowTablesVerbose\\\": {\\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"Cron to purge shadow tables - Verbose\\\\n\\\", \\\"default\\\": false}, \\\"NovaCronPurgeShadowTablesAllCells\\\": {\\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"Cron to purge shadow tables - All cells\\\\n\\\", \\\"default\\\": true}, \\\"NovaCronArchiveDeleteRowsMinute\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to move deleted instances to another table - Minute\\\\n\\\", \\\"default\\\": \\\"1\\\"}, \\\"NovaCronArchiveDeleteRowsHour\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to move deleted instances to another table - Hour\\\\n\\\", \\\"default\\\": \\\"0\\\"}, \\\"NovaCronArchiveDeleteRowsMonthday\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to move deleted instances to another table - Month Day\\\\n\\\", \\\"default\\\": \\\"*\\\"}, \\\"NovaCronArchiveDeleteRowsMonth\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to move deleted instances to another table - Month\\\\n\\\", \\\"default\\\": \\\"*\\\"}, \\\"NovaCronArchiveDeleteRowsWeekday\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to move deleted instances to another table - Week Day\\\\n\\\", \\\"default\\\": \\\"*\\\"}, \\\"NovaCronArchiveDeleteRowsMaxRows\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to move deleted instances to another table - Max Rows\\\\n\\\", \\\"default\\\": \\\"1000\\\"}, \\\"NovaCronArchiveDeleteRowsUser\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to move deleted instances to another table - User\\\\n\\\", \\\"default\\\": \\\"nova\\\"}, \\\"NovaCronArchiveDeleteRowsDestination\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to move deleted instances to another table - Log destination\\\\n\\\", \\\"default\\\": \\\"/var/log/nova/nova-rowsflush.log\\\"}, \\\"NovaCronArchiveDeleteRowsMaxDelay\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to move deleted instances to another table - Max Delay\\\\n\\\", \\\"default\\\": \\\"3600\\\"}, \\\"NovaCronArchiveDeleteRowsUntilComplete\\\": {\\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"Cron to move deleted instances to another table - Until complete\\\\n\\\", \\\"default\\\": true}, \\\"NovaCronArchiveDeleteRowsPurge\\\": {\\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"Purge shadow tables immediately after scheduled archiving\\\\n\\\", \\\"default\\\": false}, \\\"NovaCronArchiveDeleteAllCells\\\": {\\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"Archive deleted instances from all cells\\\\n\\\", \\\"default\\\": true}, \\\"NovaCronArchiveDeleteRowsAge\\\": {\\\"type\\\": \\\"number\\\", \\\"description\\\": \\\"Cron to archive deleted instances - Age This will define the retention policy when archiving the deleted instances entries in days. 0 means, purge data older than today in shadow tables.\\\\n\\\", \\\"default\\\": 90}, \\\"MemcacheUseAdvancedPool\\\": {\\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"Use the advanced (eventlet safe) memcached client pool.\\\\n\\\", \\\"default\\\": true}, \\\"NovaShowHostStatus\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Allow overriding API policies to access the compute host status in the\\\\nrequested Nova server details. The default value \'hidden\' allows only admins to\\\\naccess it. Setting it to \'all\' (\'unknown-only\') without additional fine-grained\\\\ntuning of NovaApiHostStatusPolicy shows the full (limited) host_status\\\\nto the system/project readers.\\\\n\\\", \\\"default\\\": \\\"hidden\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"all\\\", \\\"unknown-only\\\", \\\"hidden\\\"]}]}, \\\"NovaApiHostStatusPolicy\\\": {\\\"description\\\": \\\"A custom API policy for os_compute_api:servers:show:host_status and\\\\nos_compute_api:servers:show:host_status:unknown-only.\\\\nThese rules, or roles, replace the admins-only policies based on the given\\\\nNovaShowHostStatus: \'unknown-only\' shows the limited host status UNKNOWN\\\\nwhenever a heartbeat was not received within the configured threshold, and\\\\n\'all\' also reveals UP, DOWN, or MAINTENANCE statuses in the Nova server\\\\ndetails. NovaShowHostStatus \'hidden\' puts it back being visible only for admins.\\\\nAdditional policies specified using NovaApiPolicies get merged with this\\\\npolicy.\\\\n\\\", \\\"default\\\": \\\"role:reader\\\", \\\"type\\\": \\\"string\\\"}}, \\\"parameter_groups\\\": [{\\\"label\\\": \\\"deprecated\\\", \\\"description\\\": \\\"The following parameters are deprecated and will be removed. They should not\\\\nbe relied on for new deployments. If you have concerns regarding deprecated\\\\nparameters, please contact the TripleO development team on IRC or the\\\\nOpenStack mailing list.\\\\n\\\", \\\"parameters\\\": [\\\"MysqlIPv6\\\"]}], \\\"conditions\\\": {\\\"mysql_ipv6_use_ip_address\\\": {\\\"and\\\": [{\\\"equals\\\": [{\\\"get_param\\\": [\\\"ServiceData\\\", \\\"net_ip_version_map\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MysqlNetwork\\\"]}]}, 6]}, {\\\"not\\\": {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}}]}, \\\"nova_workers_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"NovaWorkers\\\"}, 0]}}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"MySQLClient\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\\\"}, \\\"NovaApiLogging\\\": {\\\"type\\\": \\\"OS::TripleO::Services::Logging::NovaApi\\\"}, \\\"ApacheServiceBase\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}, \\\"EnableInternalTLS\\\": {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}}}, \\\"NovaBase\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"NovaApiDBClient\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"NovaDBClient\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerNovaApiImage\\\": \\\"ContainerNovaApiImage\\\", \\\"ContainerNovaConfigImage\\\": \\\"ContainerNovaConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerNovaApiImage\\\": {\\\"get_param\\\": \\\"ContainerNovaApiImage\\\"}, \\\"ContainerNovaConfigImage\\\": {\\\"get_param\\\": \\\"ContainerNovaConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Nova API role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"nova_api\\\", \\\"firewall_rules\\\": {\\\"113 nova_api\\\": {\\\"dport\\\": [8774]}}, \\\"firewall_frontend_rules\\\": {\\\"100 nova_osapi_haproxy_frontend\\\": {\\\"dport\\\": [8774]}}, \\\"firewall_ssl_frontend_rules\\\": {\\\"100 nova_osapi_haproxy_frontend_ssl\\\": {\\\"dport\\\": [13774]}}, \\\"keystone_resources\\\": {\\\"nova\\\": {\\\"endpoints\\\": {\\\"public\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaPublic\\\", \\\"uri\\\"]}, \\\"internal\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaInternal\\\", \\\"uri\\\"]}, \\\"admin\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaAdmin\\\", \\\"uri\\\"]}}, \\\"users\\\": {\\\"nova\\\": {\\\"roles\\\": [\\\"admin\\\", \\\"service\\\"], \\\"password\\\": {\\\"get_param\\\": \\\"NovaPassword\\\"}}}, \\\"region\\\": {\\\"get_param\\\": \\\"KeystoneRegion\\\"}, \\\"service\\\": \\\"compute\\\"}}, \\\"monitoring_subscription\\\": {\\\"get_param\\\": \\\"MonitoringSubscriptionNovaApi\\\"}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"NovaBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"get_attr\\\": [\\\"NovaApiDBClient\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"get_attr\\\": [\\\"NovaDBClient\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"get_attr\\\": [\\\"NovaApiLogging\\\", \\\"config_settings\\\"]}, {\\\"apache::default_vhost\\\": false, \\\"nova::keystone::authtoken::project_name\\\": \\\"service\\\", \\\"nova::keystone::authtoken::user_domain_name\\\": \\\"Default\\\", \\\"nova::keystone::authtoken::project_domain_name\\\": \\\"Default\\\", \\\"nova::keystone::authtoken::password\\\": {\\\"get_param\\\": \\\"NovaPassword\\\"}, \\\"nova::keystone::authtoken::www_authenticate_uri\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystonePublic\\\", \\\"uri_no_suffix\\\"]}, \\\"nova::keystone::authtoken::auth_url\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"uri_no_suffix\\\"]}, \\\"nova::keystone::authtoken::region_name\\\": {\\\"get_param\\\": \\\"KeystoneRegion\\\"}, \\\"nova::keystone::authtoken::interface\\\": \\\"internal\\\", \\\"nova::keystone::authtoken::memcache_use_advanced_pool\\\": {\\\"get_param\\\": \\\"MemcacheUseAdvancedPool\\\"}, \\\"nova::api::max_limit\\\": {\\\"get_param\\\": \\\"NovaApiMaxLimit\\\"}, \\\"nova::api::enabled\\\": true, \\\"nova::network::neutron::default_floating_pool\\\": {\\\"get_param\\\": \\\"NovaDefaultFloatingPool\\\"}, \\\"nova::api::enable_proxy_headers_parsing\\\": true, \\\"nova::api::api_bind_address\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'fqdn_$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaApiNetwork\\\"]}}}}, \\\"nova::api::service_name\\\": \\\"httpd\\\", \\\"nova::wsgi::apache_api::ssl\\\": {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, \\\"nova::wsgi::apache_api::bind_host\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaApiNetwork\\\"]}}}}, \\\"nova::wsgi::apache_api::servername\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'fqdn_$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaApiNetwork\\\"]}}}}, \\\"nova::api::instance_name_template\\\": {\\\"get_param\\\": \\\"InstanceNameTemplate\\\"}, \\\"nova::policy::policies\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"NovaApiPolicies\\\"}, {\\\"if\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"NovaShowHostStatus\\\"}, \\\"all\\\"]}, {\\\"nova-os_compute_api_servers_show_host_status\\\": {\\\"key\\\": \\\"os_compute_api:servers:show:host_status\\\", \\\"value\\\": {\\\"get_param\\\": \\\"NovaApiHostStatusPolicy\\\"}}}, {}]}, {\\\"if\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"NovaShowHostStatus\\\"}, \\\"unknown-only\\\"]}, {\\\"nova-os_compute_api_servers_show_host_status_unknown-only\\\": {\\\"key\\\": \\\"os_compute_api:servers:show:host_status:unknown-only\\\", \\\"value\\\": {\\\"get_param\\\": \\\"NovaApiHostStatusPolicy\\\"}}}, {}]}]}, \\\"nova::api::allow_resize_to_same_host\\\": {\\\"get_param\\\": \\\"NovaAllowResizeToSameHost\\\"}, \\\"nova_enable_db_purge\\\": {\\\"get_param\\\": \\\"NovaEnableDBPurge\\\"}, \\\"nova::cron::purge_shadow_tables::minute\\\": {\\\"get_param\\\": \\\"NovaCronPurgeShadowTablesMinute\\\"}, \\\"nova::cron::purge_shadow_tables::hour\\\": {\\\"get_param\\\": \\\"NovaCronPurgeShadowTablesHour\\\"}, \\\"nova::cron::purge_shadow_tables::monthday\\\": {\\\"get_param\\\": \\\"NovaCronPurgeShadowTablesMonthday\\\"}, \\\"nova::cron::purge_shadow_tables::month\\\": {\\\"get_param\\\": \\\"NovaCronPurgeShadowTablesMonth\\\"}, \\\"nova::cron::purge_shadow_tables::weekday\\\": {\\\"get_param\\\": \\\"NovaCronPurgeShadowTablesWeekday\\\"}, \\\"nova::cron::purge_shadow_tables::user\\\": {\\\"get_param\\\": \\\"NovaCronPurgeShadowTablesUser\\\"}, \\\"nova::cron::purge_shadow_tables::destination\\\": {\\\"get_param\\\": \\\"NovaCronPurgeShadowTablesDestination\\\"}, \\\"nova::cron::purge_shadow_tables::maxdelay\\\": {\\\"get_param\\\": \\\"NovaCronPurgeShadowTablesMaxDelay\\\"}, \\\"nova::cron::purge_shadow_tables::age\\\": {\\\"get_param\\\": \\\"NovaCronPurgeShadowTablesAge\\\"}, \\\"nova::cron::purge_shadow_tables::verbose\\\": {\\\"get_param\\\": \\\"NovaCronPurgeShadowTablesVerbose\\\"}, \\\"nova::cron::purge_shadow_tables::all_cells\\\": {\\\"get_param\\\": \\\"NovaCronPurgeShadowTablesAllCells\\\"}, \\\"nova_enable_db_archive\\\": {\\\"get_param\\\": \\\"NovaEnableDBArchive\\\"}, \\\"nova::cron::archive_deleted_rows::minute\\\": {\\\"get_param\\\": \\\"NovaCronArchiveDeleteRowsMinute\\\"}, \\\"nova::cron::archive_deleted_rows::hour\\\": {\\\"get_param\\\": \\\"NovaCronArchiveDeleteRowsHour\\\"}, \\\"nova::cron::archive_deleted_rows::monthday\\\": {\\\"get_param\\\": \\\"NovaCronArchiveDeleteRowsMonthday\\\"}, \\\"nova::cron::archive_deleted_rows::month\\\": {\\\"get_param\\\": \\\"NovaCronArchiveDeleteRowsMonth\\\"}, \\\"nova::cron::archive_deleted_rows::weekday\\\": {\\\"get_param\\\": \\\"NovaCronArchiveDeleteRowsWeekday\\\"}, \\\"nova::cron::archive_deleted_rows::max_rows\\\": {\\\"get_param\\\": \\\"NovaCronArchiveDeleteRowsMaxRows\\\"}, \\\"nova::cron::archive_deleted_rows::user\\\": {\\\"get_param\\\": \\\"NovaCronArchiveDeleteRowsUser\\\"}, \\\"nova::cron::archive_deleted_rows::destination\\\": {\\\"get_param\\\": \\\"NovaCronArchiveDeleteRowsDestination\\\"}, \\\"nova::cron::archive_deleted_rows::maxdelay\\\": {\\\"get_param\\\": \\\"NovaCronArchiveDeleteRowsMaxDelay\\\"}, \\\"nova::cron::archive_deleted_rows::until_complete\\\": {\\\"get_param\\\": \\\"NovaCronArchiveDeleteRowsUntilComplete\\\"}, \\\"nova::cron::archive_deleted_rows::purge\\\": {\\\"get_param\\\": \\\"NovaCronArchiveDeleteRowsPurge\\\"}, \\\"nova::cron::archive_deleted_rows::all_cells\\\": {\\\"get_param\\\": \\\"NovaCronArchiveDeleteAllCells\\\"}, \\\"nova::cron::archive_deleted_rows::age\\\": {\\\"get_param\\\": \\\"NovaCronArchiveDeleteRowsAge\\\"}, \\\"nova::policy::enforce_new_defaults\\\": {\\\"get_param\\\": \\\"EnforceSecureRbac\\\"}, \\\"nova::policy::enforce_scope\\\": {\\\"get_param\\\": \\\"EnforceSecureRbac\\\"}}, {\\\"if\\\": [\\\"nova_workers_set\\\", {\\\"nova::api::osapi_compute_workers\\\": {\\\"get_param\\\": \\\"NovaWorkers\\\"}, \\\"nova::wsgi::apache_api::workers\\\": {\\\"get_param\\\": \\\"NovaWorkers\\\"}}]}]}, \\\"service_config_settings\\\": {\\\"rabbitmq\\\": {\\\"get_attr\\\": [\\\"NovaBase\\\", \\\"role_data\\\", \\\"service_config_settings\\\"], \\\"rabbitmq\\\": null}, \\\"mysql\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"NovaApiDBClient\\\", \\\"role_data\\\", \\\"service_config_settings\\\", \\\"mysql\\\"]}, {\\\"get_attr\\\": [\\\"NovaDBClient\\\", \\\"role_data\\\", \\\"service_config_settings\\\", \\\"mysql\\\"]}]}, \\\"rsyslog\\\": {\\\"tripleo_logging_sources_nova_api\\\": [{\\\"get_param\\\": \\\"NovaApiLoggingSource\\\"}]}}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"nova\\\", \\\"puppet_tags\\\": \\\"nova_config,nova_api_paste_ini\\\", \\\"step_config\\\": {\\\"list_join\\\": [\\\"\\\\n\\\", [\\\"[\'Nova_cell_v2\'].each |String $val| { noop_resource($val) }\\\", \\\"include tripleo::profile::base::nova::api\\\", {\\\"get_attr\\\": [\\\"MySQLClient\\\", \\\"role_data\\\", \\\"step_config\\\"]}]]}, \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/nova_api.json\\\": {\\\"command\\\": \\\"/usr/sbin/httpd -DFOREGROUND\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/etc/httpd/conf.d\\\", \\\"dest\\\": \\\"/etc/httpd/conf.d\\\", \\\"merge\\\": false, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\\\", \\\"dest\\\": \\\"/etc/httpd/conf.modules.d\\\", \\\"merge\\\": false, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/nova\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"recurse\\\": true}]}, \\\"/var/lib/kolla/config_files/nova_api_db_sync.json\\\": {\\\"command\\\": \\\"/usr/bin/bootstrap_host_exec nova_api su nova -s /bin/bash -c \'/usr/bin/nova-manage api_db sync\'\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/etc/httpd/conf.d\\\", \\\"dest\\\": \\\"/etc/httpd/conf.d\\\", \\\"merge\\\": false, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\\\", \\\"dest\\\": \\\"/etc/httpd/conf.modules.d\\\", \\\"merge\\\": false, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/nova\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"recurse\\\": true}]}, \\\"/var/lib/kolla/config_files/nova_api_ensure_default_cells.json\\\": {\\\"command\\\": \\\"/usr/bin/bootstrap_host_exec nova_api su nova -s /bin/bash -c \'/container-config-scripts/pyshim.sh /container-config-scripts/nova_api_ensure_default_cells.py\'\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/etc/httpd/conf.d\\\", \\\"dest\\\": \\\"/etc/httpd/conf.d\\\", \\\"merge\\\": false, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\\\", \\\"dest\\\": \\\"/etc/httpd/conf.modules.d\\\", \\\"merge\\\": false, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/nova\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"recurse\\\": true}]}, \\\"/var/lib/kolla/config_files/nova_api_cron.json\\\": {\\\"command\\\": \\\"/usr/sbin/crond -n\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/nova\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"recurse\\\": true}]}, \\\"/var/lib/kolla/config_files/nova_wait_for_api_service.json\\\": {\\\"command\\\": \\\"/usr/bin/bootstrap_host_exec nova_api su nova -s /bin/bash -c \'/container-config-scripts/pyshim.sh /container-config-scripts/nova_wait_for_api_service.py\'\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/etc/httpd/conf.d\\\", \\\"dest\\\": \\\"/etc/httpd/conf.d\\\", \\\"merge\\\": false, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\\\", \\\"dest\\\": \\\"/etc/httpd/conf.modules.d\\\", \\\"merge\\\": false, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/nova\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"recurse\\\": true}]}}, \\\"container_config_scripts\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"container_config_scripts\\\"]}, {\\\"nova_wait_for_api_service.py\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": {\\\"get_file\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/nova_wait_for_api_service.py\\\"}}, \\\"nova_api_ensure_default_cells.py\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": {\\\"get_file\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/nova_api_ensure_default_cells.py\\\"}}}]}, \\\"docker_config\\\": {\\\"step_2\\\": {\\\"get_attr\\\": [\\\"NovaApiLogging\\\", \\\"docker_config\\\", \\\"step_2\\\"]}, \\\"step_3\\\": {\\\"nova_api_db_sync\\\": {\\\"start_order\\\": 0, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaApiImage\\\"]}, \\\"cap_add\\\": [\\\"AUDIT_WRITE\\\"], \\\"net\\\": \\\"host\\\", \\\"detach\\\": false, \\\"user\\\": \\\"root\\\", \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"NovaApiLogging\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/nova_api_db_sync.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/nova:/var/lib/kolla/config_files/src:ro\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\", \\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}}}, \\\"nova_api_ensure_default_cells\\\": {\\\"start_order\\\": 1, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaApiImage\\\"]}, \\\"user\\\": \\\"root\\\", \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"detach\\\": false, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"NovaApiLogging\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/nova_api_ensure_default_cells.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/nova:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/container-config-scripts:/container-config-scripts:z\\\"]]}, \\\"environment\\\": {\\\"__OS_DEBUG\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"str($.data.debug)\\\", \\\"data\\\": {\\\"debug\\\": {\\\"get_attr\\\": [\\\"NovaBase\\\", \\\"role_data\\\", \\\"config_settings\\\", \\\"nova::logging::debug\\\"]}}}}, \\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}, \\\"step_4\\\": {\\\"nova_api\\\": {\\\"start_order\\\": 2, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaApiImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"user\\\": \\\"root\\\", \\\"privileged\\\": false, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"NovaApiLogging\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/nova_api.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/nova:/var/lib/kolla/config_files/src:ro\\\"], {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, [\\\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\\\", \\\"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\\\"]]}]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}, \\\"nova_wait_for_api_service\\\": {\\\"start_order\\\": 3, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaApiImage\\\"]}, \\\"user\\\": \\\"root\\\", \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"detach\\\": false, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"NovaApiLogging\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/nova_wait_for_api_service.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/nova:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/container-config-scripts:/container-config-scripts:z\\\"]]}, \\\"environment\\\": {\\\"__OS_DEBUG\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"str($.data.debug)\\\", \\\"data\\\": {\\\"debug\\\": {\\\"get_attr\\\": [\\\"NovaBase\\\", \\\"role_data\\\", \\\"config_settings\\\", \\\"nova::logging::debug\\\"]}}}}, \\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}, \\\"nova_api_cron\\\": {\\\"start_order\\\": 4, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaApiImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"user\\\": \\\"root\\\", \\\"privileged\\\": false, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/usr/share/openstack-tripleo-common/healthcheck/cron nova\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"NovaApiLogging\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/nova_api_cron.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/nova:/var/lib/kolla/config_files/src:ro\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"metadata_settings\\\": {\\\"get_attr\\\": [\\\"ApacheServiceBase\\\", \\\"role_data\\\", \\\"metadata_settings\\\"]}, \\\"deploy_steps_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ApacheServiceBase\\\", \\\"role_data\\\", \\\"deploy_steps_tasks\\\"]}, [{\\\"name\\\": \\\"validate nova-api container state\\\", \\\"containers.podman.podman_container_info\\\": {\\\"name\\\": \\\"nova_api\\\"}, \\\"register\\\": \\\"nova_api_infos\\\", \\\"failed_when\\\": [\\\"nova_api_infos.containers.0.Healthcheck.Status is defined\\\", \\\"\'healthy\' not in nova_api_infos.containers.0.Healthcheck.Status\\\"], \\\"retries\\\": 10, \\\"delay\\\": 30, \\\"tags\\\": [\\\"opendev-validation\\\", \\\"opendev-validation-nova\\\"], \\\"when\\\": [\\\"container_cli == \'podman\'\\\", \\\"not container_healthcheck_disabled\\\", \\\"step|int == 4\\\"]}]]}, \\\"host_prep_tasks\\\": {\\\"get_attr\\\": [\\\"NovaApiLogging\\\", \\\"host_prep_tasks\\\"]}, \\\"external_upgrade_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade_transfer_data\\\", \\\"system_upgrade_stop_services\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Stop nova api container\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_stop\\\"}, \\\"vars\\\": {\\\"tripleo_containers_to_stop\\\": [\\\"nova_api\\\", \\\"nova_api_cron\\\"], \\\"tripleo_delegate_to\\\": \\\"{{ groups[\'nova_api\'] | difference(groups[\'excluded_overcloud\']) }}\\\"}}]}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/nova_statedir_ownership.py\": \"#!/usr/bin/python3\\n#\\n# Copyright 2018 Red Hat Inc.\\n#\\n# Licensed under the Apache License, Version 2.0 (the \\\"License\\\"); you may\\n# not use this file except in compliance with the License. You may obtain\\n# a copy of the License at\\n#\\n#      http://www.apache.org/licenses/LICENSE-2.0\\n#\\n# Unless required by applicable law or agreed to in writing, software\\n# distributed under the License is distributed on an \\\"AS IS\\\" BASIS, WITHOUT\\n# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the\\n# License for the specific language governing permissions and limitations\\n# under the License.\\nimport logging\\nimport os\\nimport pwd\\nimport selinux\\nimport stat\\nimport sys\\n\\ndebug = os.getenv(\'__OS_DEBUG\', \'false\')\\n\\nif debug.lower() == \'true\':\\n    loglevel = logging.DEBUG\\nelse:\\n    loglevel = logging.INFO\\n\\nlogging.basicConfig(stream=sys.stdout, level=loglevel)\\nLOG = logging.getLogger(\'nova_statedir\')\\n\\n\\nclass PathManager(object):\\n    \\\"\\\"\\\"Helper class to manipulate ownership of a given path\\\"\\\"\\\"\\n    def __init__(self, path):\\n        self.path = path\\n        self.uid = None\\n        self.gid = None\\n        self.is_dir = None\\n        self.secontext = None\\n        self._update()\\n\\n    def _update(self):\\n        try:\\n            statinfo = os.stat(self.path)\\n            self.is_dir = stat.S_ISDIR(statinfo.st_mode)\\n            self.uid = statinfo.st_uid\\n            self.gid = statinfo.st_gid\\n            self.secontext = selinux.lgetfilecon(self.path)[1]\\n        except Exception:\\n            LOG.exception(\'Could not update metadata for %s\', self.path)\\n            raise\\n\\n    def __str__(self):\\n        return \\\"uid: {} gid: {} path: {}{}\\\".format(\\n            self.uid,\\n            self.gid,\\n            self.path,\\n            \'/\' if self.is_dir else \'\'\\n        )\\n\\n    def has_owner(self, uid, gid):\\n        return self.uid == uid and self.gid == gid\\n\\n    def has_either(self, uid, gid):\\n        return self.uid == uid or self.gid == gid\\n\\n    def chown(self, uid, gid):\\n        target_uid = -1\\n        target_gid = -1\\n        if self.uid != uid:\\n            target_uid = uid\\n        if self.gid != gid:\\n            target_gid = gid\\n        if (target_uid, target_gid) != (-1, -1):\\n            LOG.info(\'Changing ownership of %s from %d:%d to %d:%d\',\\n                     self.path,\\n                     self.uid,\\n                     self.gid,\\n                     self.uid if target_uid == -1 else target_uid,\\n                     self.gid if target_gid == -1 else target_gid)\\n            try:\\n                os.chown(self.path, target_uid, target_gid)\\n                self._update()\\n            except Exception:\\n                LOG.exception(\'Could not change ownership of %s: \',\\n                              self.path)\\n                raise\\n        else:\\n            LOG.info(\'Ownership of %s already %d:%d\',\\n                     self.path,\\n                     uid,\\n                     gid)\\n\\n    def chcon(self, context):\\n        # If dir returns whether to recusively set context\\n        try:\\n            try:\\n                selinux.lsetfilecon(self.path, context)\\n                LOG.info(\'Setting selinux context of %s to %s\',\\n                     self.path, context)\\n                return True\\n            except OSError as e:\\n                if self.is_dir and e.errno == 95:\\n                    # Operation not supported, assume NFS mount and skip\\n                    LOG.info(\'Setting selinux context not supported for %s\',\\n                             self.path)\\n                    return False\\n                else:\\n                    raise\\n        except Exception:\\n            LOG.exception(\'Could not set selinux context of %s to %s:\',\\n                          self.path, context)\\n            raise\\n\\n\\nclass NovaStatedirOwnershipManager(object):\\n    \\\"\\\"\\\"Class to manipulate the ownership of the nova statedir (/var/lib/nova).\\n\\n       The nova uid/gid differ on the host and container images. An upgrade\\n       that switches from host systemd services to docker requires a change in\\n       ownership. Previously this was a naive recursive chown, however this\\n       causes issues if nova instance are shared via an NFS mount: any open\\n       filehandles in qemu/libvirt fail with an I/O error (LP1778465).\\n\\n       Instead the upgrade/FFU ansible tasks now lay down a marker file when\\n       stopping and disabling the host systemd services. We use this file to\\n       determine the host nova uid/gid. We then walk the tree and update any\\n       files that have the host uid/gid to the docker nova uid/gid. As files\\n       owned by root/qemu etc... are ignored this avoids the issues with open\\n       filehandles. The marker is removed once the tree has been walked.\\n\\n       For subsequent runs, or for a new deployment, we simply ensure that the\\n       docker nova user/group owns all directories. This is required as the\\n       directories are created with root ownership in host_prep_tasks (the\\n       docker nova uid/gid is not known in this context).\\n    \\\"\\\"\\\"\\n    def __init__(self, statedir, upgrade_marker=\'upgrade_marker\',\\n                 nova_user=\'nova\', secontext_marker=\'../_nova_secontext\',\\n                 exclude_paths=None):\\n        self.statedir = statedir\\n        self.nova_user = nova_user\\n\\n        self.upgrade_marker_path = os.path.join(statedir, upgrade_marker)\\n        self.secontext_marker_path = os.path.normpath(os.path.join(statedir, secontext_marker))\\n        self.upgrade = os.path.exists(self.upgrade_marker_path)\\n\\n        self.exclude_paths = [self.upgrade_marker_path]\\n        if exclude_paths is not None:\\n            for p in exclude_paths:\\n                if not p.startswith(os.path.sep):\\n                    p = os.path.join(self.statedir, p)\\n                self.exclude_paths.append(p)\\n\\n        self.target_uid, self.target_gid = self._get_nova_ids()\\n        self.previous_uid, self.previous_gid = self._get_previous_nova_ids()\\n        self.id_change = (self.target_uid, self.target_gid) != \\\\\\n            (self.previous_uid, self.previous_gid)\\n        self.target_secontext = self._get_secontext()\\n\\n    def _get_nova_ids(self):\\n        nova_uid, nova_gid = pwd.getpwnam(self.nova_user)[2:4]\\n        return nova_uid, nova_gid\\n\\n    def _get_previous_nova_ids(self):\\n        if self.upgrade:\\n            statinfo = os.stat(self.upgrade_marker_path)\\n            return statinfo.st_uid, statinfo.st_gid\\n        else:\\n            return self._get_nova_ids()\\n\\n    def _get_secontext(self):\\n        if os.path.exists(self.secontext_marker_path):\\n            return selinux.lgetfilecon(self.secontext_marker_path)[1]\\n        else:\\n            return None\\n\\n    def _walk(self, top, chcon=True):\\n        for f in os.listdir(top):\\n            pathname = os.path.join(top, f)\\n\\n            if pathname in self.exclude_paths:\\n                continue\\n\\n            try:\\n                pathinfo = PathManager(pathname)\\n                LOG.info(\\\"Checking %s\\\", pathinfo)\\n                if pathinfo.is_dir:\\n                    # Always chown the directories\\n                    pathinfo.chown(self.target_uid, self.target_gid)\\n                    chcon_r = chcon\\n                    if chcon:\\n                        chcon_r = pathinfo.chcon(self.target_secontext)\\n                    self._walk(pathname, chcon_r)\\n                elif self.id_change:\\n                    # Only chown files if it\'s an upgrade and the file is owned by\\n                    # the host nova uid/gid\\n                    pathinfo.chown(\\n                        self.target_uid if pathinfo.uid == self.previous_uid\\n                        else pathinfo.uid,\\n                        self.target_gid if pathinfo.gid == self.previous_gid\\n                        else pathinfo.gid\\n                    )\\n                    if chcon:\\n                        pathinfo.chcon(self.target_secontext)\\n            except Exception:\\n                # Likely to have been caused by external systems\\n                # interacting with this directory tree,\\n                # especially on NFS e.g snapshot dirs.\\n                # Just ignore it and continue on to the next entry\\n                continue\\n\\n    def run(self):\\n        LOG.info(\'Applying nova statedir ownership\')\\n        LOG.info(\'Target ownership for %s: %d:%d\',\\n                 self.statedir,\\n                 self.target_uid,\\n                 self.target_gid)\\n\\n        pathinfo = PathManager(self.statedir)\\n        LOG.info(\\\"Checking %s\\\", pathinfo)\\n        pathinfo.chown(self.target_uid, self.target_gid)\\n        chcon = self.target_secontext is not None\\n\\n        if chcon:\\n            pathinfo.chcon(self.target_secontext)\\n\\n        self._walk(self.statedir, chcon)\\n\\n        if self.upgrade:\\n            LOG.info(\'Removing upgrade_marker %s\',\\n                     self.upgrade_marker_path)\\n            os.unlink(self.upgrade_marker_path)\\n\\n        LOG.info(\'Nova statedir ownership complete\')\\n\\n\\ndef get_exclude_paths():\\n    exclude_paths = os.environ.get(\'NOVA_STATEDIR_OWNERSHIP_SKIP\')\\n    if exclude_paths is not None:\\n        exclude_paths = exclude_paths.split(os.pathsep)\\n    return exclude_paths\\n\\n\\nif __name__ == \'__main__\':\\n    NovaStatedirOwnershipManager(\'/var/lib/nova\', exclude_paths=get_exclude_paths()).run()\\n\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/nova_wait_for_compute_service.py\": \"#!/usr/bin/python3\\n#\\n# Copyright 2018 Red Hat Inc.\\n#\\n# Licensed under the Apache License, Version 2.0 (the \\\"License\\\"); you may\\n# not use this file except in compliance with the License. You may obtain\\n# a copy of the License at\\n#\\n#      http://www.apache.org/licenses/LICENSE-2.0\\n#\\n# Unless required by applicable law or agreed to in writing, software\\n# distributed under the License is distributed on an \\\"AS IS\\\" BASIS, WITHOUT\\n# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the\\n# License for the specific language governing permissions and limitations\\n# under the License.\\nimport argparse\\nimport logging\\nimport os\\nimport six\\nimport socket\\nimport sys\\nimport time\\n\\n\\nfrom keystoneauth1 import loading\\nfrom keystoneauth1 import session\\n\\nfrom novaclient import client\\n\\n# In python3 SafeConfigParser was renamed to ConfigParser and the default\\n# for duplicate options default to true. In case of nova it is valid to\\n# have duplicate option lines, e.g. passthrough_whitelist which leads to\\n# issues reading the nova.conf\\n# https://bugs.launchpad.net/tripleo/+bug/1827775\\nif six.PY3:\\n    from six.moves.configparser import ConfigParser\\n    config = ConfigParser(strict=False)\\nelse:\\n    from six.moves.configparser import SafeConfigParser\\n    config = SafeConfigParser()\\n\\ndebug = os.getenv(\'__OS_DEBUG\', \'false\')\\n\\nif debug.lower() == \'true\':\\n    loglevel = logging.DEBUG\\nelse:\\n    loglevel = logging.INFO\\n\\nlogging.basicConfig(stream=sys.stdout, level=loglevel)\\nLOG = logging.getLogger(\'nova_wait_for_compute_service\')\\n\\niterations = 60\\ntimeout = 10\\nnova_cfg = \'/etc/nova/nova.conf\'\\n\\nif __name__ == \'__main__\':\\n    parser = argparse.ArgumentParser(usage=\'%(prog)s [options]\')\\n    parser.add_argument(\'-k\', \'--insecure\',\\n                        action=\\\"store_false\\\",\\n                        dest=\'insecure\',\\n                        default=True,\\n                        help=\'Allow insecure connection when using SSL\')\\n\\n    args = parser.parse_args()\\n    LOG.debug(\'Running with parameter insecure = %s\',\\n              args.insecure)\\n\\n    if os.path.isfile(nova_cfg):\\n        try:\\n            config.read(nova_cfg)\\n        except Exception:\\n            LOG.exception(\'Error while reading nova.conf:\')\\n    else:\\n        LOG.error(\'Nova configuration file %s does not exist\', nova_cfg)\\n        sys.exit(1)\\n\\n    my_host = config.get(\'DEFAULT\', \'host\')\\n    if not my_host:\\n        # If host isn\'t set nova defaults to this\\n        my_host = socket.gethostname()\\n\\n    loader = loading.get_plugin_loader(\'password\')\\n    auth = loader.load_from_options(\\n        auth_url=config.get(\'neutron\',\\n                            \'auth_url\'),\\n        username=config.get(\'neutron\',\\n                            \'username\'),\\n        password=config.get(\'neutron\',\\n                            \'password\'),\\n        project_name=config.get(\'neutron\',\\n                                \'project_name\'),\\n        project_domain_name=config.get(\'neutron\',\\n                                       \'project_domain_name\'),\\n        user_domain_name=config.get(\'neutron\',\\n                                    \'user_domain_name\'))\\n    sess = session.Session(auth=auth, verify=args.insecure)\\n    nova = client.Client(\'2.11\', session=sess, endpoint_type=\'internal\',\\n                         region_name=config.get(\'neutron\', \'region_name\'))\\n\\n    # Wait until this host is listed in the service list\\n    for i in range(iterations):\\n        try:\\n            service_list = nova.services.list(binary=\'nova-compute\')\\n            for entry in service_list:\\n                host = getattr(entry, \'host\', \'\')\\n                zone = getattr(entry, \'zone\', \'\')\\n                if host == my_host and zone != \'internal\':\\n                    LOG.info(\'Nova-compute service registered\')\\n                    sys.exit(0)\\n            LOG.info(\'Waiting for nova-compute service to register\')\\n        except Exception:\\n            LOG.exception(\\n                \'Error while waiting for nova-compute service to register\')\\n        time.sleep(timeout)\\nsys.exit(1)\\n\\n# vim: set et ts=4 sw=4 :\\n\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-common-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Contains a static list of common things necessary for nova-compute containers\\\\n\\\", \\\"parameters\\\": {\\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"NovaAdditionalCell\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether this is an cell additional to the default cell.\\\", \\\"type\\\": \\\"boolean\\\"}}, \\\"outputs\\\": {\\\"container_config_scripts\\\": {\\\"description\\\": \\\"Shared docker config scripts\\\", \\\"value\\\": {\\\"nova_statedir_ownership.py\\\": {\\\"mode\\\": \\\"0700\\\", \\\"content\\\": {\\\"get_file\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/nova_statedir_ownership.py\\\"}}, \\\"nova_wait_for_compute_service.py\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": {\\\"get_file\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/nova_wait_for_compute_service.py\\\"}}}}, \\\"nova_compute_common_deploy_steps_tasks\\\": {\\\"description\\\": \\\"Common host prep tasks for nova-compute services (compute + ironic)\\\", \\\"value\\\": [{\\\"block\\\": [{\\\"name\\\": \\\"is additonal Cell?\\\", \\\"set_fact\\\": {\\\"nova_additional_cell\\\": {\\\"get_param\\\": \\\"NovaAdditionalCell\\\"}}}, {\\\"name\\\": \\\"check if discover hosts is required\\\", \\\"when\\\": [\\\"not nova_additional_cell|bool\\\", \\\"nova_cellv2_discovery_done is not defined\\\"], \\\"block\\\": [{\\\"name\\\": \\\"discover via nova_manager?\\\", \\\"set_fact\\\": {\\\"nova_cellv2_discovery_delegate_host\\\": \\\"{{ groups[\'nova_manager\'][0] }}\\\", \\\"nova_cellv2_discovery_container\\\": \\\"nova_manager\\\"}, \\\"when\\\": [\\\"groups[\'nova_manager\'] is defined and (groups[\'nova_manager\']|length>0)\\\"]}, {\\\"name\\\": \\\"discover via nova_api?\\\", \\\"set_fact\\\": {\\\"nova_cellv2_discovery_delegate_host\\\": \\\"{{ groups[\'nova_api\'][0] }}\\\", \\\"nova_cellv2_discovery_container\\\": \\\"nova_api\\\"}, \\\"when\\\": [\\\"nova_cellv2_discovery_delegate_host is not defined\\\", \\\"groups[\'nova_api\'] is defined and (groups[\'nova_api\']|length>0)\\\"]}, {\\\"name\\\": \\\"Warn if no discovery host available\\\", \\\"fail\\\": {\\\"msg\\\": \\\"No hosts available to run nova cell_v2 host discovery.\\\"}, \\\"ignore_errors\\\": true, \\\"when\\\": [\\\"nova_cellv2_discovery_delegate_host is not defined\\\"]}, {\\\"name\\\": \\\"Discovering nova hosts\\\", \\\"command\\\": \\\"{{ container_cli }} exec {{ nova_cellv2_discovery_container }} nova-manage cell_v2 discover_hosts --by-service\\\", \\\"become\\\": true, \\\"changed_when\\\": false, \\\"delegate_to\\\": \\\"{{ nova_cellv2_discovery_delegate_host }}\\\", \\\"when\\\": [\\\"nova_cellv2_discovery_delegate_host is defined\\\"]}, {\\\"set_fact\\\": {\\\"nova_cellv2_discovery_done\\\": true}}]}]}]}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/scripts/delay-nova-compute\": \"#!/usr/libexec/platform-python\\n\\\"\\\"\\\"\\nThis wrapper was created to add an optional delay to the startup of nova-compute.\\nWe know that instances will fail to boot, after a compute reboot, if ceph is not\\nhealthy.\\n\\nIdeally, we would poll ceph to get its health, but it\'s not guaranteed that the\\ncompute node will have access to the keys.\\n\\\"\\\"\\\"\\n\\nimport os\\nimport sys\\nimport time\\nimport logging\\nimport argparse\\n\\nparser = argparse.ArgumentParser(description=\'Process some integers.\')\\nparser.add_argument(\'--config-file\', dest=\'nova_config\', action=\'store\',\\n                    default=\\\"/etc/nova/nova.conf\\\",\\n                    help=\'path to nova configuration (default: /etc/nova/nova.conf)\')\\nparser.add_argument(\'--nova-binary\', dest=\'nova_binary\', action=\'store\',\\n                    default=\\\"/usr/bin/nova-compute\\\",\\n                    help=\'path to nova compute binary (default: /usr/bin/nova-compute)\')\\nparser.add_argument(\'--delay\', dest=\'delay\', action=\'store\',\\n                    default=120, type=int,\\n                    help=\'Number of seconds to wait until nova-compute is started\')\\nparser.add_argument(\'--state-dir\', dest=\'state_dir\', action=\'store\',\\n                    default=\\\"/run/nova/startup\\\", help=\'state-file directory\')\\nparser.add_argument(\'--state-file\', dest=\'state_file\', action=\'store\',\\n                    default=\\\"nova-compute-delayed\\\",\\n                    help=\'file exists if we already delayed nova-compute startup\')\\n\\n\\nsections = {}\\n(args, remaining) = parser.parse_known_args(sys.argv)\\n\\nreal_args = [args.nova_binary, \'--config-file\', args.nova_config]\\nreal_args.extend(remaining[1:])\\n\\nif not os.path.isdir(args.state_dir):\\n  os.makedirs(args.state_dir, mode = 0o751)\\n\\nstate_file_name = os.path.join(args.state_dir, args.state_file)\\n\\nif not os.path.isfile(state_file_name):\\n    logging.info(\\\"Delaying nova-compute startup by %s seconds\\\" % args.delay)\\n    time.sleep(args.delay)\\n    open(state_file_name, \'a\').close()\\n\\nlogging.info(\\\"Executing %s\\\" % real_args)\\nos.execv(args.nova_binary, real_args)\\n\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Nova Compute service\\\\n\\\", \\\"parameters\\\": {\\\"ContainerNovaComputeImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerNovaLibvirtConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the nova_libvirt config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"DockerNovaComputeUlimit\\\": {\\\"default\\\": [\\\"nofile=131072\\\", \\\"memlock=67108864\\\"], \\\"description\\\": \\\"ulimit for Nova Compute Container\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"NovaComputeLoggingSource\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {\\\"tag\\\": \\\"openstack.nova.compute\\\", \\\"file\\\": \\\"/var/log/containers/nova/nova-compute.log\\\"}}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"CephClientUserName\\\": {\\\"default\\\": \\\"openstack\\\", \\\"type\\\": \\\"string\\\"}, \\\"CephClusterName\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"ceph\\\", \\\"description\\\": \\\"The Ceph cluster name.\\\", \\\"constraints\\\": [{\\\"allowed_pattern\\\": \\\"[a-zA-Z0-9]+\\\", \\\"description\\\": \\\"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\\\n\\\"}]}, \\\"CephConfigPath\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"/var/lib/tripleo-config/ceph\\\", \\\"description\\\": \\\"The path where the Ceph Cluster config files are stored on the host.\\\\n\\\"}, \\\"CinderRbdMultiConfig\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {}, \\\"description\\\": \\\"Dictionary of settings when configuring multiple RBD backends. The\\\\nhash key is the backend name, and the value is a dictionary of parameter\\\\nvalues unique to that backend. The following parameters are required,\\\\nand must match the corresponding value defined in CephExternalMultiConfig.\\\\n  CephClusterName (must match the CephExternalMultiConfig entry\'s \'cluster\')\\\\n  CephClusterFSID (must match the CephExternalMultiConfig entry\'s \'fsid\')\\\\nThe following parameters are optional, and override the corresponding\\\\nparameter\'s default value.\\\\n  CephClientUserName\\\\n  CinderRbdPoolName\\\\n  CinderRbdExtraPools\\\\n  CinderRbdAvailabilityZone\\\\n  CinderRbdFlattenVolumeFromSnapshot\\\\n\\\"}, \\\"NovaComputeOptVolumes\\\": {\\\"default\\\": [], \\\"description\\\": \\\"list of optional volumes to be mounted\\\", \\\"type\\\": \\\"comma_delimited_list\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaComputeOptEnvVars\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"hash of optional environment variables\\\", \\\"type\\\": \\\"json\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaComputeStartupDelay\\\": {\\\"default\\\": 0, \\\"description\\\": \\\"Delays the startup of nova-compute service after compute node is booted. This is to give a chance to ceph to get back healthy before booting instances after and overcloud reboot.\\\", \\\"type\\\": \\\"number\\\", \\\"constraints\\\": [{\\\"range\\\": {\\\"min\\\": 0, \\\"max\\\": 600}}], \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"EnableInstanceHA\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to enable an Instance Ha configurarion or not. This setup requires the Compute role to have the PacemakerRemote service added to it.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"NovaRbdPoolName\\\": {\\\"default\\\": \\\"vms\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"The pool name for RBD backend ephemeral storage.\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"CephClientKey\\\": {\\\"description\\\": \\\"The Ceph client key. Can be created with ceph-authtool --gen-print-key.\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true, \\\"constraints\\\": [{\\\"allowed_pattern\\\": \\\"^[a-zA-Z0-9+/]{38}==$\\\"}]}, \\\"CephClusterFSID\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"The Ceph cluster FSID. Must be a UUID.\\\"}, \\\"CinderEnableNfsBackend\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to enable or not the NFS backend for Cinder\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"NovaMkisofsCmd\\\": {\\\"default\\\": \\\"mkisofs\\\", \\\"description\\\": \\\"Name or path of the tool used for ISO image creation.\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaNfsEnabled\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to enable or not the NFS backend for Nova\\\", \\\"type\\\": \\\"boolean\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaNfsShare\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"NFS share to mount for nova storage (when NovaNfsEnabled is true)\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaNfsOptions\\\": {\\\"default\\\": \\\"context=system_u:object_r:nfs_t:s0\\\", \\\"description\\\": \\\"NFS mount options for nova storage (when NovaNfsEnabled is true)\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaNfsVersion\\\": {\\\"default\\\": \\\"4.2\\\", \\\"description\\\": \\\"NFS version used for nova storage (when NovaNfsEnabled is true). Since NFSv3 does not support full locking a NFSv4 version need to be used.\\\\n\\\", \\\"type\\\": \\\"string\\\", \\\"constraints\\\": [{\\\"allowed_pattern\\\": \\\"^4.?[0-9]?\\\"}], \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"CinderEnableRbdBackend\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to enable or not the Rbd backend for Cinder\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"NovaEnableRbdBackend\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to enable the Rbd backend for Nova ephemeral storage.\\\", \\\"type\\\": \\\"boolean\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaComputeForceRawImages\\\": {\\\"default\\\": true, \\\"description\\\": \\\"Set to \\\\\\\"True\\\\\\\" to convert non-raw cached base images to raw format.\\\\nSet to \\\\\\\"False\\\\\\\" if you have a system with slow I/O or low available space,\\\\ntrading the higher CPU requirements of compression for that of minimized input\\\\nbandwidth.\\\\nNotes::\\\\n- The Compute service removes any compression from the base image during\\\\n  compression, to avoid CPU bottlenecks. Converted images cannot have backing\\\\n  files, which might be a security issue.\\\\n- The raw image format uses more space than other image formats, for example,\\\\n  qcow2.\\\\n  Raw base images are always used with libvirt_images_type=lvm.\\\\n\\\", \\\"type\\\": \\\"boolean\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaComputeUseCowImages\\\": {\\\"default\\\": true, \\\"description\\\": \\\"Set to \\\\\\\"True\\\\\\\" to use CoW (Copy on Write) images in cqow2 format for libvirt\\\\ninstance disks. With CoW, depending on the backing store and host caching,\\\\nthere might be better concurrency achieved by having each instance operate\\\\non its own copy.\\\\nSet to \\\\\\\"False\\\\\\\" to use the raw format. Raw format uses more space for common\\\\nparts of the disk image.\\\\n\\\", \\\"type\\\": \\\"boolean\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaComputeLibvirtPreAllocateImages\\\": {\\\"default\\\": \\\"none\\\", \\\"description\\\": \\\"Specifies the preallocation mode for libvirt instance disks.\\\\nSet to one of the following valid values::\\\\n- none - No storage is provisioned at instance start.\\\\n- space - Storage is fully allocated at instance start using fallocate,\\\\n          which can help with both space guarantees and I/O performance.\\\\n\\\\nEven when not using CoW instance disks, the copy each instance gets is sparse\\\\nand so the instance might fail unexpectedly at run time with ENOSPC. By\\\\nrunning fallocate(1) on the instance disk images, the Compute service\\\\nimmediately and efficiently allocates the space for them in the file system,\\\\nif supported. Run time performance should also be improved because the file\\\\nsystem does not have to dynamically allocate blocks at run time, which reduces\\\\nCPU overhead and file fragmentation.\\\\n\\\", \\\"type\\\": \\\"string\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"none\\\", \\\"space\\\"]}], \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaComputeImageCacheManagerInterval\\\": {\\\"default\\\": 2400, \\\"description\\\": \\\"Specifies the number of seconds to wait between runs of the image cache\\\\nmanager, which impacts base image caching on Compute nodes. This period\\\\nis used in the auto removal of unused cached images configured with\\\\nremove_unused_base_images and remove_unused_original_minimum_age_seconds.\\\\n\\\\nSet to \\\\\\\"0\\\\\\\" to run at the default interval of 60 seconds (not recommended)\\\\n\\\", \\\"type\\\": \\\"number\\\", \\\"constraints\\\": [{\\\"range\\\": {\\\"min\\\": -1}}], \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaComputeImageCacheRemoveUnusedBaseImages\\\": {\\\"default\\\": true, \\\"description\\\": \\\"Set to \\\\\\\"True\\\\\\\" to automatically remove unused base images from the cache\\\\nat intervals configured by using image_cache_manager_interval. Images\\\\nare defined as unused if they have not been accessed during the time\\\\nspecified by using remove_unused_original_minimum_age_seconds.\\\\n\\\", \\\"type\\\": \\\"boolean\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaComputeImageCacheRemoveUnusedResizedMinimumAge\\\": {\\\"default\\\": 3600, \\\"description\\\": \\\"Specifies the minimum age that an unused resized base image must be to\\\\nbe removed from the cache, in seconds. Unused unresized base images\\\\nyounger than this will not be removed.\\\\n\\\", \\\"type\\\": \\\"number\\\", \\\"constraints\\\": [{\\\"range\\\": {\\\"min\\\": 1}}], \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaComputeImageCachePrecacheConcurrency\\\": {\\\"default\\\": 1, \\\"description\\\": \\\"Maximum number of Compute nodes to trigger image precaching in parallel.\\\\nWhen an image precache request is made, Compute nodes are contacted {by\\\\nwho/which service} to initiate the download.\\\\n\\\\nHigher numbers will cause more computes to work in parallel and may result\\\\nin reduced time to complete the operation, but may also DDoS the image\\\\nservice. Lower numbers will result in more sequential operation, lower\\\\nimage service load, but likely longer runtime to completion.\\\\n\\\", \\\"type\\\": \\\"number\\\", \\\"constraints\\\": [{\\\"range\\\": {\\\"min\\\": 1}}], \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaPCIPassthrough\\\": {\\\"description\\\": \\\"List of PCI Passthrough whitelist parameters. Example - NovaPCIPassthrough:\\\\n  - vendor_id: \\\\\\\"8086\\\\\\\"\\\\n    product_id: \\\\\\\"154c\\\\\\\"\\\\n    address: \\\\\\\"0000:05:00.0\\\\\\\"\\\\n    physical_network: \\\\\\\"datacentre\\\\\\\"\\\\nFor different formats, refer to the nova.conf documentation for pci_passthrough_whitelist configuration\\\\n\\\", \\\"type\\\": \\\"json\\\", \\\"default\\\": \\\"\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaComputeCpuSharedSet\\\": {\\\"description\\\": \\\"The behavior of this option depends on the deprecated `NovaVcpuPinSet` option:\\\\n\\\\n* `NovaVcpuPinSet` is not set: `NovaComputeCpuSharedSet` is set to a\\\\n  comma-separated list or range of physical host CPU numbers used to:\\\\n\\\\n  - provide vCPU inventory\\\\n  - determine the host CPUs that unpinned instances can be scheduled to\\\\n  - determine the host CPUS that instance emulator threads should be\\\\n    offloaded to for instances configured with the share emulator thread\\\\n    policy, `hw:emulator_threads_policy=share`\\\\n\\\\n* `NovaVcpuPinSet` is set: `NovaComputeCpuSharedSet` is set to a list or\\\\n  range of host CPU cores used to determine the host CPUs that instance\\\\n  emulator threads should be offloaded to for instances configured with\\\\n  the share emulator thread policy (`hw:emulator_threads_policy=share`).\\\\n  In this case, `NovaVcpuPinSet` is used to provide vCPU inventory and to\\\\n  determine the host CPUs that both pinned and unpinned instances can be\\\\n  scheduled to.\\\\n\\\\nEx. NovaComputeCpuSharedSet: [4-12,^8,15] will reserve cores from 4-12\\\\nand 15, excluding 8.\\\\n\\\", \\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": [], \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaComputeCpuDedicatedSet\\\": {\\\"description\\\": \\\"A list or range of host CPU cores to which processes for pinned instance CPUs (PCPUs) can be scheduled. Ex. NovaComputeCpuDedicatedSet: [4-12,^8,15] will reserve cores from 4-12 and 15, excluding 8.\\\\n\\\", \\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": [], \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaReservedHostMemory\\\": {\\\"description\\\": \\\"Reserved RAM for host processes.\\\\n\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 4096, \\\"constraints\\\": [{\\\"range\\\": {\\\"min\\\": 512}}], \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaReservedHugePages\\\": {\\\"description\\\": \\\"A list of valid key=value which reflect NUMA node ID, page size (Default unit is KiB) and number of pages to be reserved. Example - NovaReservedHugePages: [\\\\\\\"node:0,size:2048,count:64\\\\\\\",\\\\\\\"node:1,size:1GB,count:1\\\\\\\"] will reserve on NUMA node 0 64 pages of 2MiB and on NUMA node 1 1 page of 1GiB\\\\n\\\", \\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": [], \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"KernelArgs\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Kernel Args to apply to the host\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"OvsDpdkSocketMemory\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Sets the amount of hugepage memory to assign per NUMA node. It is recommended to use the socket closest to the PCIe slot used for the desired DPDK NIC.  The format should be in \\\\\\\"<socket 0 mem>, <socket 1 mem>, <socket n mem>\\\\\\\", where the value is specified in MB.  For example: \\\\\\\"1024,0\\\\\\\".\\\\n\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"MonitoringSubscriptionNovaCompute\\\": {\\\"default\\\": \\\"overcloud-nova-compute\\\", \\\"type\\\": \\\"string\\\"}, \\\"MigrationSshKey\\\": {\\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"SSH key for migration. Expects a dictionary with keys \'public_key\' and \'private_key\'. Values should be identical to SSH public/private key files.\\\\n\\\", \\\"default\\\": {\\\"public_key\\\": \\\"\\\", \\\"private_key\\\": \\\"\\\"}}, \\\"MigrationSshPort\\\": {\\\"default\\\": 2022, \\\"description\\\": \\\"Target port for migration over ssh\\\", \\\"type\\\": \\\"number\\\"}, \\\"VerifyGlanceSignatures\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to verify image signatures.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"NovaAutoDisabling\\\": {\\\"default\\\": \\\"10\\\", \\\"description\\\": \\\"Max number of consecutive build failures before the nova-compute will disable itself.\\\", \\\"type\\\": \\\"string\\\"}, \\\"NeutronPhysnetNUMANodesMapping\\\": {\\\"description\\\": \\\"Map of physnet name as key and NUMA nodes as value.\\\\nEx. NeutronPhysnetNUMANodesMapping: {\'foo\': [0, 1], \'bar\': [1]} where `foo` and `bar` are\\\\nphysnet names and corresponding values are list of associated numa_nodes.\\\\n\\\", \\\"type\\\": \\\"json\\\", \\\"default\\\": {}, \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NeutronTunnelNUMANodes\\\": {\\\"description\\\": \\\"Used to configure NUMA affinity for all tunneled networks.\\\", \\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": [], \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaResumeGuestsStateOnHostBoot\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to start running instance on compute host reboot\\\", \\\"type\\\": \\\"boolean\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaLibvirtRxQueueSize\\\": {\\\"description\\\": \\\"virtio-net RX queue size. Valid values are 256, 512, 1024\\\\n\\\", \\\"default\\\": 512, \\\"type\\\": \\\"number\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [256, 512, 1024]}], \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaLibvirtTxQueueSize\\\": {\\\"description\\\": \\\"virtio-net TX queue size. Valid values are 256, 512, 1024\\\\n\\\", \\\"default\\\": 512, \\\"type\\\": \\\"number\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [256, 512, 1024]}], \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaLibvirtFileBackedMemory\\\": {\\\"description\\\": \\\"Available capacity in MiB for file-backed memory. When configured, the ``NovaRAMAllocationRatio`` and ``NovaReservedHostMemory`` parameters must be set to 0.\\\\n\\\", \\\"default\\\": 0, \\\"type\\\": \\\"number\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaLibvirtVolumeUseMultipath\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to enable or not the multipath connection of the volumes.\\\", \\\"type\\\": \\\"boolean\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaHWMachineType\\\": {\\\"description\\\": \\\"To specify a default machine type per host architecture.\\\\n\\\", \\\"default\\\": \\\"x86_64=pc-q35-rhel9.0.0\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"DeployIdentifier\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\\\n\\\"}, \\\"NovaAdditionalCell\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether this is an cell additional to the default cell.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"NovaComputeEnableKsm\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to enable KSM on compute nodes or not. Especially in NFV use case one wants to keep it disabled.\\\", \\\"type\\\": \\\"boolean\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"AdminPassword\\\": {\\\"description\\\": \\\"The password for the keystone admin account, used for monitoring, querying neutron etc.\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"CinderPassword\\\": {\\\"description\\\": \\\"The password for the cinder service and db account.\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"KeystoneRegion\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"regionOne\\\", \\\"description\\\": \\\"Keystone region for endpoint\\\"}, \\\"NovaLibvirtNumPciePorts\\\": {\\\"description\\\": \\\"Set `num_pcie_ports` to specify the number of PCIe ports an instance will get. Libvirt allows a custom number of PCIe ports (pcie-root-port controllers) a target instance will get. Some will be used by default, rest will be available for hotplug use.\\\\n\\\", \\\"default\\\": 16, \\\"type\\\": \\\"number\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaLibvirtMemStatsPeriodSeconds\\\": {\\\"description\\\": \\\"A number of seconds to memory usage statistics period, zero or negative value mean to disable memory usage statistics.\\\\n\\\", \\\"default\\\": 10, \\\"type\\\": \\\"number\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaLiveMigrationWaitForVIFPlug\\\": {\\\"description\\\": \\\"Whether to wait for `network-vif-plugged` events before starting guest transfer.\\\", \\\"default\\\": true, \\\"type\\\": \\\"boolean\\\"}, \\\"NovaLiveMigrationPermitPostCopy\\\": {\\\"description\\\": \\\"If \\\\\\\"True\\\\\\\" activates the instance on the destination node before migration is complete, and to set an upper bound on the memory that needs to be transferred. Post copy gets enabled per default if the compute roles is not a realtime role or disabled by this parameter.\\\\n\\\", \\\"default\\\": true, \\\"type\\\": \\\"boolean\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaLiveMigrationPermitAutoConverge\\\": {\\\"description\\\": \\\"Defaults to \\\\\\\"True\\\\\\\" to slow down the instance CPU until the memory copy process is faster than the instance\'s memory writes when the migration performance is slow and might not complete. Auto converge will only be used if this flag is set to True and post copy is not permitted or post copy is unavailable due to the version of libvirt and QEMU.\\\\n\\\", \\\"default\\\": true, \\\"type\\\": \\\"boolean\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"MultipathdEnable\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to enable the multipath daemon\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"NovaCPUAllocationRatio\\\": {\\\"type\\\": \\\"number\\\", \\\"description\\\": \\\"Virtual CPU to physical CPU allocation ratio.\\\", \\\"default\\\": 0.0, \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaRAMAllocationRatio\\\": {\\\"type\\\": \\\"number\\\", \\\"description\\\": \\\"Virtual RAM to physical RAM allocation ratio.\\\", \\\"default\\\": 1.0, \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaDiskAllocationRatio\\\": {\\\"type\\\": \\\"number\\\", \\\"description\\\": \\\"Virtual disk to physical disk allocation ratio.\\\", \\\"default\\\": 0.0, \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaEnableVTPM\\\": {\\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"Whether to enable support for enumlated Trusted Platform Module (TPM) devices.\\\\n\\\", \\\"default\\\": false, \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaMaxDiskDevicesToAttach\\\": {\\\"type\\\": \\\"number\\\", \\\"description\\\": \\\"Maximum number of disk devices allowed to attach to a single server. Note that the number of disks supported by an server depends on the bus used. For example, the ide disk bus is limited to 4 attached devices. The configured maximum is enforced during server create, rebuild, evacuate, unshelve, live migrate, and attach volume. Operators changing this parameter on a compute service that is hosting servers should be aware that it could cause rebuilds to fail, if the maximum is decreased lower than the number of devices already attached to servers. Operators should also be aware that during a cold migration, the configured maximum is only enforced in-place and the destination is not checked before the move. -1 means unlimited\\\\n\\\", \\\"default\\\": -1, \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaPMEMMappings\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"PMEM namespace mappings as backend for vPMEM feature. This parameter sets Nova\'s `pmem_namespaces` configuration options. PMEM namespaces needs to be create manually or with conjunction with `NovaPMEMNamespaces` parameter. Requires format: $LABEL:$NSNAME[|$NSNAME][,$LABEL:$NSNAME[|$NSNAME]].\\\\n\\\", \\\"default\\\": \\\"\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaPMEMNamespaces\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Creates PMEM namespaces on the host server using `ndctl` tool through Ansible. Requires format: $SIZE:$NSNAME[,$SIZE:$NSNAME...]. $SIZE supports the suffixes \\\\\\\"k\\\\\\\" or \\\\\\\"K\\\\\\\" for KiB, \\\\\\\"m\\\\\\\" or \\\\\\\"M\\\\\\\" for MiB, \\\\\\\"g\\\\\\\" or \\\\\\\"G\\\\\\\" for GiB and \\\\\\\"t\\\\\\\" or \\\\\\\"T\\\\\\\" for TiB. NOTE: This requires properly configured NVDIMM regions and enough space for requested namespaces.\\\\n\\\", \\\"default\\\": \\\"\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaImageCacheTTL\\\": {\\\"type\\\": \\\"number\\\", \\\"description\\\": \\\"Time in seconds that nova compute should continue caching an image once it is no longer used by any instances on the host\\\\n\\\", \\\"default\\\": 86400, \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaVGPUTypesDeviceAddressesMapping\\\": {\\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"Map of vgpu type(s) the instances can get as key and list of corresponding device addresses as value. Ex. NovaVGPUTypesDeviceAddressesMapping: {\'nvidia-35\': [\'0000:84:00.0\', \'0000:85:00.0\'],\\\\n                                  \'nvidia-36\': [\'0000:86:00.0\']}\\\\nwhere `nvidia-35` and `nvidia-36` are vgpu types and corresponding values are list of associated device addresses.\\\\n\\\", \\\"default\\\": {}, \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaComputeDisableIrqBalance\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to disable irqbalance on compute nodes or not. Especially in Realtime Compute role one wants to keep it disabled.\\\", \\\"type\\\": \\\"boolean\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaLibvirtCPUMode\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"The libvirt CPU mode to configure. Defaults to \'host-model\' if virt_type is set to kvm, otherwise defaults to \'none\'\\\\n\\\", \\\"default\\\": \\\"host-model\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"custom\\\", \\\"host-model\\\", \\\"none\\\", \\\"host-passthrough\\\"]}], \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaLibvirtCPUModels\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"description\\\": \\\"The named libvirt CPU model (see names listed in /usr/share/libvirt/cpu_map.xml). Only has effect if cpu_mode=\\\\\\\"custom\\\\\\\" and virt_type=\\\\\\\"kvm|qemu\\\\\\\"\\\\n\\\", \\\"default\\\": [], \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaLibvirtCPUModelExtraFlags\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"This allows specifying granular CPU feature flags when specifying CPU models. Only has effect if cpu_mode is not set to \'none\'.\\\\n\\\", \\\"default\\\": \\\"\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaDisableImageDownloadToRbd\\\": {\\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"Refuse to boot an instance if it would require downloading from glance and uploading to ceph instead of a COW clone.\\\\n\\\", \\\"default\\\": false, \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaDisableComputeServiceCheckForFfu\\\": {\\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"Facilitate a Fast-Forward upgrade where new control services are being started before compute nodes have been able to update their service record.\\\\n\\\", \\\"default\\\": false}, \\\"NovaStatedirOwnershipSkip\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"description\\\": \\\"List of paths relative to nova_statedir to ignore when recursively setting the ownership and selinux context.\\\\n\\\", \\\"default\\\": [\\\"triliovault-mounts\\\"]}, \\\"NovaImageTypeExcludeList\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"description\\\": \\\"List of image formats that should not be advertised as supported by the compute service.\\\\n\\\", \\\"default\\\": [], \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaLibvirtMaxQueues\\\": {\\\"type\\\": \\\"number\\\", \\\"description\\\": \\\"Add parameter to configure the libvirt max_queues. The maximum number of virtio queue pairs that can be enabled when creating a multiqueue guest. The number of virtio queues allocated will be the lesser of the CPUs requested by the guest and the max value defined. Default 0 corresponds to not set\\\\n\\\", \\\"default\\\": 0, \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"GlanceRbdPoolName\\\": {\\\"default\\\": \\\"images\\\", \\\"type\\\": \\\"string\\\"}, \\\"GlanceMultistoreConfig\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {}, \\\"description\\\": \\\"Dictionary of settings when configuring additional glance backends. The\\\\nhash key is the backend ID, and the value is a dictionary of parameter\\\\nvalues unique to that backend. Multiple rbd and cinder backends are allowed, but\\\\nfile and swift backends are limited to one each. Example:\\\\n  # Default glance store is rbd.\\\\n  GlanceBackend: rbd\\\\n  GlanceStoreDescription: \'Default rbd store\'\\\\n  # GlanceMultistoreConfig specifies a second rbd backend, plus a cinder\\\\n  # backend.\\\\n  GlanceMultistoreConfig:\\\\n    rbd2_store:\\\\n      GlanceBackend: rbd\\\\n      GlanceStoreDescription: \'Second rbd store\'\\\\n      CephClusterName: ceph2\\\\n      # Override CephClientUserName if this cluster uses a different\\\\n      # client name.\\\\n      CephClientUserName: client2\\\\n    cinder1_store:\\\\n      GlanceBackend: cinder\\\\n      GlanceCinderVolumeType: \'volume-type-1\'\\\\n      GlanceStoreDescription: \'First cinder store\'\\\\n    cinder2_store:\\\\n      GlanceBackend: cinder\\\\n      GlanceCinderVolumeType: \'volume-type-2\'\\\\n      GlanceStoreDescription: \'Seconde cinder store\'\\\\n\\\"}, \\\"NovaGlanceEnableRbdDownload\\\": {\\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"Enable download of Glance images directly via RBD.\\\\n\\\", \\\"default\\\": false, \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaGlanceRbdDownloadMultistoreID\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"The hash key, which is the backend ID, of the GlanceMultistoreConfig to be used for the role where NovaGlanceEnableRbdDownload is enabled and defaults should be overridden. If CephClientUserName or GlanceRbdPoolName are not set in the GlanceMultistoreConfig, the global values of those parameters will be used.\\\\n\\\", \\\"default\\\": \\\"\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"GlanceBackendID\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"default_backend\\\", \\\"description\\\": \\\"The default backend\'s identifier.\\\", \\\"constraints\\\": [{\\\"allowed_pattern\\\": \\\"[a-zA-Z0-9_-]+\\\"}]}, \\\"NovaGlanceRbdCopyPollInterval\\\": {\\\"type\\\": \\\"number\\\", \\\"description\\\": \\\"The interval in seconds with which to poll Glance after asking for it to copy an image to the local rbd store.\\\\n\\\", \\\"default\\\": 15, \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaGlanceRbdCopyTimeout\\\": {\\\"type\\\": \\\"number\\\", \\\"description\\\": \\\"The overall maximum time we will wait for Glance to complete an image copy to our local rbd store.\\\\n\\\", \\\"default\\\": 600, \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"CustomProviderInventories\\\": {\\\"description\\\": \\\"Array of hashes describing the custom providers for the compute role.\\\\nFormat:\\\\nname/uuid - Resource providers to target can be identified by either\\\\nUUID or name. In addition, the value $COMPUTE_NODE can be used in\\\\nthe UUID field to identify all nodes managed by the service.\\\\nExactly one of uuid or name is mandatory. If neither uuid or name\\\\nis provided, the special uuid $COMPUTE_NODE gets set in the template.\\\\n\\\\ninventories - (Optional) Hash of custom provider inventories. \'total\' is\\\\na mandatory property. Any other optional properties not populated will\\\\nbe given a default value by placement. If overriding a pre-existing\\\\nprovider values will not be preserved from the existing inventory.\\\\n\\\\ntraits - (Optional) Array of additional traits.\\\\nExample:\\\\nComputeParameters:\\\\n  CustomProviderInventories:\\\\n    - uuid: $COMPUTE_NODE\\\\n      inventories:\\\\n        CUSTOM_EXAMPLE_RESOURCE_CLASS:\\\\n          total: 100\\\\n          reserved: 0\\\\n          min_unit: 1\\\\n          max_unit: 10\\\\n          step_size: 1\\\\n          allocation_ratio: 1.0\\\\n        CUSTOM_ANOTHER_EXAMPLE_RESOURCE_CLASS:\\\\n          total: 100\\\\n      traits:\\\\n        - CUSTOM_P_STATE_ENABLED\\\\n        - CUSTOM_C_STATE_ENABLED\\\\n\\\", \\\"type\\\": \\\"json\\\", \\\"default\\\": {}, \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"UseTLSTransportForLiveMigration\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": true, \\\"description\\\": \\\"If set to true and if EnableInternalTLS is enabled, it will set the libvirt URI\'s transport to tls and configure the relevant keys for libvirt.\\\"}, \\\"NovaVcpuPinSet\\\": {\\\"description\\\": \\\"A list or range of host CPU cores to which processes for unpinned instance CPUs (VCPUs) can be scheduled, if NovaCpuSharedSet is set, or to which both emulator threads and processes for unpinned instance CPUs (VCPUs) can be scheduled, if NovaCpuSharedSet is unset. Ex. NovaVcpuPinSet: [\'4-12\',\'^8\'] will reserve cores from 4-12 excluding 8\\\\n\\\", \\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": [], \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"RootStackName\\\": {\\\"description\\\": \\\"The name of the stack/plan.\\\", \\\"type\\\": \\\"string\\\"}, \\\"RbdDiskCachemodes\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": [\\\"network=writeback\\\"], \\\"description\\\": \\\"Disk cachemodes for RBD backend.\\\\n\\\"}, \\\"AuthCloudName\\\": {\\\"description\\\": \\\"Entry in clouds.yaml to use for authentication\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\"}}, \\\"parameter_groups\\\": [{\\\"label\\\": \\\"deprecated\\\", \\\"description\\\": \\\"The following parameters are deprecated and will be removed. They should not\\\\nbe relied on for new deployments. If you have concerns regarding deprecated\\\\nparameters, please contact the TripleO development team on IRC or the\\\\nOpenstack mailing list.\\\\n\\\", \\\"parameters\\\": [\\\"NovaVcpuPinSet\\\"]}], \\\"conditions\\\": {\\\"auth_cloud_name_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"AuthCloudName\\\"}, \\\"\\\"]}}, \\\"compute_startup_delay\\\": {\\\"and\\\": [{\\\"not\\\": {\\\"get_param\\\": \\\"EnableInstanceHA\\\"}}, {\\\"not\\\": {\\\"and\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"NovaComputeStartupDelay\\\"}, 0]}, {\\\"or\\\": [{\\\"equals\\\": [{\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"NovaComputeStartupDelay\\\"]}, 0]}, {\\\"equals\\\": [{\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"NovaComputeStartupDelay\\\"]}, \\\"\\\"]}]}]}}]}, \\\"use_tls_for_live_migration\\\": {\\\"and\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, {\\\"get_param\\\": \\\"UseTLSTransportForLiveMigration\\\"}]}, \\\"enable_live_migration_tunnelled\\\": {\\\"and\\\": [{\\\"or\\\": [{\\\"and\\\": [{\\\"get_param\\\": \\\"NovaNfsEnabled\\\"}, {\\\"equals\\\": [{\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"NovaNfsEnabled\\\"]}, \\\"\\\"]}]}, {\\\"equals\\\": [{\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"NovaNfsEnabled\\\"]}, true]}, {\\\"equals\\\": [{\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"NovaEnableRbdBackend\\\"]}, true]}, {\\\"and\\\": [{\\\"equals\\\": [{\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"NovaEnableRbdBackend\\\"]}, \\\"\\\"]}, {\\\"get_param\\\": \\\"NovaEnableRbdBackend\\\"}]}]}, {\\\"not\\\": \\\"use_tls_for_live_migration\\\"}]}, \\\"libvirt_file_backed_memory_enabled\\\": {\\\"not\\\": {\\\"and\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"NovaLibvirtFileBackedMemory\\\"}, 0]}, {\\\"or\\\": [{\\\"equals\\\": [{\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"NovaLibvirtFileBackedMemory\\\"]}, 0]}, {\\\"equals\\\": [{\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"NovaLibvirtFileBackedMemory\\\"]}, \\\"\\\"]}]}]}}, \\\"reserved_huge_pages_set\\\": {\\\"not\\\": {\\\"and\\\": [{\\\"equals\\\": [{\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"NovaReservedHugePages\\\"]}, \\\"\\\"]}, {\\\"equals\\\": [{\\\"get_param\\\": \\\"NovaReservedHugePages\\\"}, []]}]}}, \\\"is_realtime\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"TunedProfileName\\\"]}, \\\"realtime-virtual-host\\\"]}, \\\"ovs_dpdk_socket_memory_not_set\\\": {\\\"and\\\": [{\\\"equals\\\": [{\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"OvsDpdkSocketMemory\\\"]}, \\\"\\\"]}, {\\\"equals\\\": [{\\\"get_param\\\": \\\"OvsDpdkSocketMemory\\\"}, \\\"\\\"]}]}, \\\"nova_libvirt_max_queues_set\\\": {\\\"not\\\": {\\\"and\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"NovaLibvirtMaxQueues\\\"}, 0]}, {\\\"or\\\": [{\\\"equals\\\": [{\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"NovaLibvirtMaxQueues\\\"]}, \\\"\\\"]}, {\\\"equals\\\": [{\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"NovaLibvirtMaxQueues\\\"]}, 0]}]}]}}, \\\"glance_enable_rbd_download_set\\\": {\\\"or\\\": [{\\\"and\\\": [{\\\"get_param\\\": \\\"NovaGlanceEnableRbdDownload\\\"}, {\\\"equals\\\": [{\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"NovaGlanceEnableRbdDownload\\\"]}, \\\"\\\"]}]}, {\\\"equals\\\": [{\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"NovaGlanceEnableRbdDownload\\\"]}, true]}]}, \\\"nova_glance_rbd_download_multistore_id_set\\\": {\\\"not\\\": {\\\"and\\\": [{\\\"equals\\\": [{\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"NovaGlanceRbdDownloadMultistoreID\\\"]}, \\\"\\\"]}, {\\\"equals\\\": [{\\\"get_param\\\": \\\"NovaGlanceRbdDownloadMultistoreID\\\"}, \\\"\\\"]}]}}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"CinderNVMeOF\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\\\"}, \\\"NovaComputeCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-common-container-puppet.yaml\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"NovaLogging\\\": {\\\"type\\\": \\\"OS::TripleO::Services::Logging::NovaCommon\\\", \\\"properties\\\": {\\\"ContainerNovaImage\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaComputeImage\\\"]}, \\\"NovaServiceName\\\": \\\"compute\\\"}}, \\\"NovaBase\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"nova::compute::vcpu_pin_set\\\": \\\"NovaVcpuPinSet\\\", \\\"nova::compute::cpu_shared_set\\\": \\\"NovaComputeCpuSharedSet\\\", \\\"nova::compute::cpu_dedicated_set\\\": \\\"NovaComputeCpuDedicatedSet\\\", \\\"nova::compute::reserved_host_memory\\\": \\\"NovaReservedHostMemory\\\", \\\"nova::compute::reserved_huge_pages\\\": \\\"NovaReservedHugePages\\\", \\\"nova::compute::neutron_physnets_numa_nodes_mapping\\\": \\\"NeutronPhysnetNUMANodesMapping\\\", \\\"nova::compute::neutron_tunnel_numa_nodes\\\": \\\"NeutronTunnelNUMANodes\\\", \\\"nova::compute::resume_guests_state_on_host_boot\\\": \\\"NovaResumeGuestsStateOnHostBoot\\\", \\\"nova::compute::libvirt::rx_queue_size\\\": \\\"NovaLibvirtRxQueueSize\\\", \\\"nova::compute::libvirt::tx_queue_size\\\": \\\"NovaLibvirtTxQueueSize\\\", \\\"nova::compute::libvirt::file_backed_memory\\\": \\\"NovaLibvirtFileBackedMemory\\\", \\\"nova::compute::libvirt::volume_use_multipath\\\": \\\"NovaLibvirtVolumeUseMultipath\\\", \\\"nova::compute::libvirt::hw_machine_type\\\": \\\"NovaHWMachineType\\\", \\\"nova::compute::mkisofs_cmd\\\": \\\"NovaMkisofsCmd\\\", \\\"compute_enable_ksm\\\": \\\"NovaComputeEnableKsm\\\", \\\"nova::compute::rbd::libvirt_images_rbd_pool\\\": \\\"NovaRbdPoolName\\\", \\\"tripleo::profile::base::nova::compute::nova_nfs_enabled\\\": \\\"NovaNfsEnabled\\\", \\\"nfs_backend_enable\\\": \\\"NovaNfsEnabled\\\", \\\"nfs_share\\\": \\\"NovaNfsShare\\\", \\\"nfs_options\\\": \\\"NovaNfsOptions\\\", \\\"nfs_vers\\\": \\\"NovaNfsVersion\\\", \\\"nova::compute::libvirt::num_pcie_ports\\\": \\\"NovaLibvirtNumPciePorts\\\", \\\"nova::compute::libvirt::mem_stats_period_seconds\\\": \\\"NovaLibvirtMemStatsPeriodSeconds\\\", \\\"nova::compute::rbd::ephemeral_storage\\\": \\\"NovaEnableRbdBackend\\\", \\\"resume_guests_state_on_host_boot\\\": \\\"NovaResumeGuestsStateOnHostBoot\\\", \\\"nova::cpu_allocation_ratio\\\": \\\"NovaCPUAllocationRatio\\\", \\\"nova::ram_allocation_ratio\\\": \\\"NovaRAMAllocationRatio\\\", \\\"nova::disk_allocation_ratio\\\": \\\"NovaDiskAllocationRatio\\\", \\\"nova::compute::max_disk_devices_to_attach\\\": \\\"NovaMaxDiskDevicesToAttach\\\", \\\"nova::compute::libvirt::pmem_namespaces\\\": \\\"NovaPMEMMappings\\\", \\\"nova_pmem_namespaces\\\": \\\"NovaPMEMNamespaces\\\", \\\"nova::compute::image_cache::remove_unused_original_minimum_age_seconds\\\": \\\"NovaImageCacheTTL\\\", \\\"nova::compute::libvirt::swtpm_enabled\\\": \\\"NovaEnableVTPM\\\", \\\"nova::compute::vgpu::vgpu_types_device_addresses_mapping\\\": \\\"NovaVGPUTypesDeviceAddressesMapping\\\", \\\"compute_disable_irqbalance\\\": \\\"NovaComputeDisableIrqBalance\\\", \\\"nova::compute::libvirt::cpu_mode\\\": \\\"NovaLibvirtCPUMode\\\", \\\"nova::compute::libvirt::cpu_models\\\": \\\"NovaLibvirtCPUModels\\\", \\\"nova::compute::libvirt::cpu_model_extra_flags\\\": \\\"NovaLibvirtCPUModelExtraFlags\\\", \\\"nova_compute_opt_volumes\\\": \\\"NovaComputeOptVolumes\\\", \\\"nova_compute_startup_delay\\\": \\\"NovaComputeStartupDelay\\\", \\\"nova_compute_opt_env_vars\\\": \\\"NovaComputeOptEnvVars\\\", \\\"nova::workarounds::never_download_image_if_on_rbd\\\": \\\"NovaDisableImageDownloadToRbd\\\", \\\"nova::compute::image_type_exclude_list\\\": \\\"NovaImageTypeExcludeList\\\", \\\"nova_permit_post_copy\\\": \\\"NovaLiveMigrationPermitPostCopy\\\", \\\"nova_permit_auto_converge\\\": \\\"NovaLiveMigrationPermitAutoConverge\\\", \\\"nova_libvirt_max_queues\\\": \\\"NovaLibvirtMaxQueues\\\", \\\"nova_glance_enable_rbd_download\\\": \\\"NovaGlanceEnableRbdDownload\\\", \\\"nova_glance_rbd_download_multistore_id\\\": \\\"NovaGlanceRbdDownloadMultistoreID\\\", \\\"nova::compute::force_raw_images\\\": \\\"NovaComputeForceRawImages\\\", \\\"nova::compute::use_cow_images\\\": \\\"NovaComputeUseCowImages\\\", \\\"nova::compute::libvirt::preallocate_images\\\": \\\"NovaComputeLibvirtPreAllocateImages\\\", \\\"nova::compute::image_cache::manager_interval\\\": \\\"NovaComputeImageCacheManagerInterval\\\", \\\"nova::compute::image_cache::remove_unused_base_images\\\": \\\"NovaComputeImageCacheRemoveUnusedBaseImages\\\", \\\"nova::compute::image_cache::remove_unused_resized_minimum_age_seconds\\\": \\\"NovaComputeImageCacheRemoveUnusedResizedMinimumAge\\\", \\\"nova::compute::image_cache::precache_concurrency\\\": \\\"NovaComputeImageCachePrecacheConcurrency\\\", \\\"nova::compute::provider::custom_inventories\\\": \\\"CustomProviderInventories\\\", \\\"nova::compute::rbd::libvirt_images_rbd_glance_copy_poll_interval\\\": \\\"NovaGlanceRbdCopyPollInterval\\\", \\\"nova::compute::rbd::libvirt_images_rbd_glance_copy_timeout\\\": \\\"NovaGlanceRbdCopyTimeout\\\", \\\"ContainerNovaComputeImage\\\": \\\"ContainerNovaComputeImage\\\", \\\"ContainerNovaLibvirtConfigImage\\\": \\\"ContainerNovaLibvirtConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"NovaVcpuPinSet\\\": {\\\"get_param\\\": \\\"NovaVcpuPinSet\\\"}, \\\"NovaComputeCpuSharedSet\\\": {\\\"get_param\\\": \\\"NovaComputeCpuSharedSet\\\"}, \\\"NovaComputeCpuDedicatedSet\\\": {\\\"get_param\\\": \\\"NovaComputeCpuDedicatedSet\\\"}, \\\"NovaReservedHostMemory\\\": {\\\"get_param\\\": \\\"NovaReservedHostMemory\\\"}, \\\"NovaReservedHugePages\\\": {\\\"if\\\": [\\\"reserved_huge_pages_set\\\", {\\\"get_param\\\": \\\"NovaReservedHugePages\\\"}, {\\\"if\\\": [\\\"ovs_dpdk_socket_memory_not_set\\\", {\\\"get_param\\\": \\\"NovaReservedHugePages\\\"}, {\\\"repeat\\\": {\\\"for_each\\\": {\\\"<%node%>\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"range(0,len($.data.dpdk_p)).join(\\\\\\\",\\\\\\\").split(\\\\\\\",\\\\\\\")\\\", \\\"data\\\": {\\\"dpdk_p\\\": {\\\"if\\\": [{\\\"equals\\\": [{\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"OvsDpdkSocketMemory\\\"]}, \\\"\\\"]}, {\\\"str_split\\\": [\\\",\\\", {\\\"get_param\\\": \\\"OvsDpdkSocketMemory\\\"}]}, {\\\"str_split\\\": [\\\",\\\", {\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"OvsDpdkSocketMemory\\\"]}]}]}}}}, \\\"<%size%>\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"let(hzx => regex(\\\\\\\"([0-9]+[K|M|G])\\\\\\\").search($.data.kern_p+$.data.kern_g)) -> let(hz =>switch($hzx = \\\\\\\"4K\\\\\\\" => \\\\\\\"4\\\\\\\", $hzx = \\\\\\\"2M\\\\\\\" => \\\\\\\"2048\\\\\\\", $hzx = \\\\\\\"1G\\\\\\\" => \\\\\\\"1048576\\\\\\\", $hzx  => \\\\\\\"2048\\\\\\\", $hzx = null => \\\\\\\"2048\\\\\\\")) -> [$hz]*len($.data.dpdk_p)\\\", \\\"data\\\": {\\\"dpdk_p\\\": {\\\"if\\\": [{\\\"equals\\\": [{\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"OvsDpdkSocketMemory\\\"]}, \\\"\\\"]}, {\\\"str_split\\\": [\\\",\\\", {\\\"get_param\\\": \\\"OvsDpdkSocketMemory\\\"}]}, {\\\"str_split\\\": [\\\",\\\", {\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"OvsDpdkSocketMemory\\\"]}]}]}, \\\"kern_p\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"KernelArgs\\\"]}, \\\"kern_g\\\": {\\\"get_param\\\": \\\"KernelArgs\\\"}}}}, \\\"<%count%>\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"let(hzx => regex(\\\\\\\"([0-9]+[K|M|G])\\\\\\\").search($.data.kern_p+$.data.kern_g)) -> let(hz =>int(switch($hzx = \\\\\\\"4K\\\\\\\" => \\\\\\\"4\\\\\\\", $hzx = \\\\\\\"2M\\\\\\\" => \\\\\\\"2048\\\\\\\", $hzx = \\\\\\\"1G\\\\\\\" => \\\\\\\"1048576\\\\\\\", $hzx  => \\\\\\\"2048\\\\\\\", $hzx = null => \\\\\\\"2048\\\\\\\"))) -> $.data.dpdk_p.select(int($)*1024/$hz).join(\\\\\\\",\\\\\\\").split(\',\')\\\", \\\"data\\\": {\\\"dpdk_p\\\": {\\\"if\\\": [{\\\"equals\\\": [{\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"OvsDpdkSocketMemory\\\"]}, \\\"\\\"]}, {\\\"str_split\\\": [\\\",\\\", {\\\"get_param\\\": \\\"OvsDpdkSocketMemory\\\"}]}, {\\\"str_split\\\": [\\\",\\\", {\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"OvsDpdkSocketMemory\\\"]}]}]}, \\\"kern_p\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"KernelArgs\\\"]}, \\\"kern_g\\\": {\\\"get_param\\\": \\\"KernelArgs\\\"}}}}}, \\\"template\\\": \\\"node:<%node%>,size:<%size%>,count:<%count%>\\\", \\\"permutations\\\": false}}]}]}, \\\"NeutronPhysnetNUMANodesMapping\\\": {\\\"get_param\\\": \\\"NeutronPhysnetNUMANodesMapping\\\"}, \\\"NeutronTunnelNUMANodes\\\": {\\\"get_param\\\": \\\"NeutronTunnelNUMANodes\\\"}, \\\"NovaResumeGuestsStateOnHostBoot\\\": {\\\"get_param\\\": \\\"NovaResumeGuestsStateOnHostBoot\\\"}, \\\"NovaLibvirtRxQueueSize\\\": {\\\"get_param\\\": \\\"NovaLibvirtRxQueueSize\\\"}, \\\"NovaLibvirtTxQueueSize\\\": {\\\"get_param\\\": \\\"NovaLibvirtTxQueueSize\\\"}, \\\"NovaLibvirtFileBackedMemory\\\": {\\\"get_param\\\": \\\"NovaLibvirtFileBackedMemory\\\"}, \\\"NovaLibvirtVolumeUseMultipath\\\": {\\\"get_param\\\": \\\"NovaLibvirtVolumeUseMultipath\\\"}, \\\"NovaHWMachineType\\\": {\\\"get_param\\\": \\\"NovaHWMachineType\\\"}, \\\"NovaComputeEnableKsm\\\": {\\\"get_param\\\": \\\"NovaComputeEnableKsm\\\"}, \\\"NovaRbdPoolName\\\": {\\\"get_param\\\": \\\"NovaRbdPoolName\\\"}, \\\"NovaMkisofsCmd\\\": {\\\"get_param\\\": \\\"NovaMkisofsCmd\\\"}, \\\"NovaNfsEnabled\\\": {\\\"get_param\\\": \\\"NovaNfsEnabled\\\"}, \\\"NovaNfsShare\\\": {\\\"get_param\\\": \\\"NovaNfsShare\\\"}, \\\"NovaNfsOptions\\\": {\\\"get_param\\\": \\\"NovaNfsOptions\\\"}, \\\"NovaNfsVersion\\\": {\\\"get_param\\\": \\\"NovaNfsVersion\\\"}, \\\"NovaLibvirtNumPciePorts\\\": {\\\"get_param\\\": \\\"NovaLibvirtNumPciePorts\\\"}, \\\"NovaLibvirtMemStatsPeriodSeconds\\\": {\\\"get_param\\\": \\\"NovaLibvirtMemStatsPeriodSeconds\\\"}, \\\"NovaEnableRbdBackend\\\": {\\\"get_param\\\": \\\"NovaEnableRbdBackend\\\"}, \\\"NovaCPUAllocationRatio\\\": {\\\"get_param\\\": \\\"NovaCPUAllocationRatio\\\"}, \\\"NovaRAMAllocationRatio\\\": {\\\"get_param\\\": \\\"NovaRAMAllocationRatio\\\"}, \\\"NovaDiskAllocationRatio\\\": {\\\"get_param\\\": \\\"NovaDiskAllocationRatio\\\"}, \\\"NovaEnableVTPM\\\": {\\\"get_param\\\": \\\"NovaEnableVTPM\\\"}, \\\"NovaMaxDiskDevicesToAttach\\\": {\\\"get_param\\\": \\\"NovaMaxDiskDevicesToAttach\\\"}, \\\"NovaPMEMMappings\\\": {\\\"get_param\\\": \\\"NovaPMEMMappings\\\"}, \\\"NovaPMEMNamespaces\\\": {\\\"get_param\\\": \\\"NovaPMEMNamespaces\\\"}, \\\"NovaImageCacheTTL\\\": {\\\"get_param\\\": \\\"NovaImageCacheTTL\\\"}, \\\"NovaVGPUTypesDeviceAddressesMapping\\\": {\\\"get_param\\\": \\\"NovaVGPUTypesDeviceAddressesMapping\\\"}, \\\"NovaComputeDisableIrqBalance\\\": {\\\"get_param\\\": \\\"NovaComputeDisableIrqBalance\\\"}, \\\"NovaLibvirtCPUMode\\\": {\\\"get_param\\\": \\\"NovaLibvirtCPUMode\\\"}, \\\"NovaLibvirtCPUModels\\\": {\\\"get_param\\\": \\\"NovaLibvirtCPUModels\\\"}, \\\"NovaLibvirtCPUModelExtraFlags\\\": {\\\"get_param\\\": \\\"NovaLibvirtCPUModelExtraFlags\\\"}, \\\"NovaComputeOptVolumes\\\": {\\\"get_param\\\": \\\"NovaComputeOptVolumes\\\"}, \\\"NovaComputeStartupDelay\\\": {\\\"get_param\\\": \\\"NovaComputeStartupDelay\\\"}, \\\"NovaComputeOptEnvVars\\\": {\\\"get_param\\\": \\\"NovaComputeOptEnvVars\\\"}, \\\"NovaDisableImageDownloadToRbd\\\": {\\\"get_param\\\": \\\"NovaDisableImageDownloadToRbd\\\"}, \\\"NovaImageTypeExcludeList\\\": {\\\"get_param\\\": \\\"NovaImageTypeExcludeList\\\"}, \\\"NovaLiveMigrationPermitPostCopy\\\": {\\\"get_param\\\": \\\"NovaLiveMigrationPermitPostCopy\\\"}, \\\"NovaLiveMigrationPermitAutoConverge\\\": {\\\"get_param\\\": \\\"NovaLiveMigrationPermitAutoConverge\\\"}, \\\"NovaLibvirtMaxQueues\\\": {\\\"get_param\\\": \\\"NovaLibvirtMaxQueues\\\"}, \\\"NovaGlanceEnableRbdDownload\\\": {\\\"get_param\\\": \\\"NovaGlanceEnableRbdDownload\\\"}, \\\"NovaGlanceRbdDownloadMultistoreID\\\": {\\\"get_param\\\": \\\"NovaGlanceRbdDownloadMultistoreID\\\"}, \\\"NovaComputeForceRawImages\\\": {\\\"get_param\\\": \\\"NovaComputeForceRawImages\\\"}, \\\"NovaComputeUseCowImages\\\": {\\\"get_param\\\": \\\"NovaComputeUseCowImages\\\"}, \\\"NovaComputeLibvirtPreAllocateImages\\\": {\\\"get_param\\\": \\\"NovaComputeLibvirtPreAllocateImages\\\"}, \\\"NovaComputeImageCacheManagerInterval\\\": {\\\"get_param\\\": \\\"NovaComputeImageCacheManagerInterval\\\"}, \\\"NovaComputeImageCacheRemoveUnusedBaseImages\\\": {\\\"get_param\\\": \\\"NovaComputeImageCacheRemoveUnusedBaseImages\\\"}, \\\"NovaComputeImageCacheRemoveUnusedResizedMinimumAge\\\": {\\\"get_param\\\": \\\"NovaComputeImageCacheRemoveUnusedResizedMinimumAge\\\"}, \\\"NovaComputeImageCachePrecacheConcurrency\\\": {\\\"get_param\\\": \\\"NovaComputeImageCachePrecacheConcurrency\\\"}, \\\"CustomProviderInventories\\\": {\\\"get_param\\\": \\\"CustomProviderInventories\\\"}, \\\"NovaGlanceRbdCopyPollInterval\\\": {\\\"get_param\\\": \\\"NovaGlanceRbdCopyPollInterval\\\"}, \\\"NovaGlanceRbdCopyTimeout\\\": {\\\"get_param\\\": \\\"NovaGlanceRbdCopyTimeout\\\"}, \\\"ContainerNovaComputeImage\\\": {\\\"get_param\\\": \\\"ContainerNovaComputeImage\\\"}, \\\"ContainerNovaLibvirtConfigImage\\\": {\\\"get_param\\\": \\\"ContainerNovaLibvirtConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"nova_compute_host_prep_and_system_upgrade_post_tasks\\\": {\\\"description\\\": \\\"Common host_prep and system_upgrade post tasks for nova_compute\\\", \\\"value\\\": [{\\\"name\\\": \\\"Mount Nova NFS Share\\\", \\\"vars\\\": {\\\"nfs_backend_enable\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"nfs_backend_enable\\\"]}, \\\"nfs_share\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"nfs_share\\\"]}, \\\"nfs_options\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"nfs_options\\\"]}, \\\"nfs_vers\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"nfs_vers\\\"]}}, \\\"mount\\\": {\\\"name\\\": \\\"/var/lib/nova/instances\\\", \\\"state\\\": \\\"mounted\\\", \\\"fstype\\\": \\\"nfs4\\\", \\\"src\\\": \\\"{{nfs_share}}\\\", \\\"opts\\\": \\\"_netdev,bg,{{nfs_options}},nfsvers={{nfs_vers}}\\\"}, \\\"when\\\": \\\"nfs_backend_enable|bool\\\"}]}, \\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Nova Compute service.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"nova_compute\\\", \\\"monitoring_subscription\\\": {\\\"get_param\\\": \\\"MonitoringSubscriptionNovaCompute\\\"}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"NovaLogging\\\", \\\"config_settings\\\"]}, {\\\"get_attr\\\": [\\\"NovaBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\"]}, {\\\"nova::compute::libvirt::manage_libvirt_services\\\": false, \\\"nova::compute::pci::passthrough\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"JSON_PARAM\\\", \\\"params\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"JSON_PARAM\\\": \\\"NovaPCIPassthrough\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"NovaPCIPassthrough\\\": {\\\"get_param\\\": \\\"NovaPCIPassthrough\\\"}}}]}}}, \\\"nova::compute::libvirt::migration_support\\\": false, \\\"tripleo::profile::base::nova::migration::client::nova_compute_enabled\\\": true, \\\"tripleo::profile::base::nova::migration::client::ssh_private_key\\\": {\\\"get_param\\\": [\\\"MigrationSshKey\\\", \\\"private_key\\\"]}, \\\"tripleo::profile::base::nova::migration::client::ssh_port\\\": {\\\"get_param\\\": \\\"MigrationSshPort\\\"}, \\\"nova::compute::rbd::libvirt_images_rbd_glance_store_name\\\": {\\\"get_param\\\": \\\"GlanceBackendID\\\"}, \\\"nova::compute::rbd::libvirt_images_rbd_ceph_conf\\\": {\\\"list_join\\\": [\\\"\\\", [\\\"/etc/ceph/\\\", {\\\"get_param\\\": \\\"CephClusterName\\\"}, \\\".conf\\\"]]}, \\\"nova::compute::rbd::libvirt_rbd_user\\\": {\\\"get_param\\\": \\\"CephClientUserName\\\"}, \\\"nova::compute::rbd::rbd_keyring\\\": {\\\"list_join\\\": [\\\".\\\", [\\\"client\\\", {\\\"get_param\\\": \\\"CephClientUserName\\\"}]]}, \\\"tripleo::profile::base::nova::compute::cinder_nfs_backend\\\": {\\\"get_param\\\": \\\"CinderEnableNfsBackend\\\"}, \\\"rbd_persistent_storage\\\": {\\\"get_param\\\": \\\"CinderEnableRbdBackend\\\"}, \\\"rbd_disk_cachemodes\\\": {\\\"get_param\\\": \\\"RbdDiskCachemodes\\\"}, \\\"nova::cinder::username\\\": \\\"cinder\\\", \\\"nova::cinder::auth_type\\\": \\\"v3password\\\", \\\"nova::cinder::project_name\\\": \\\"service\\\", \\\"nova::cinder::password\\\": {\\\"get_param\\\": \\\"CinderPassword\\\"}, \\\"nova::cinder::auth_url\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneV3Internal\\\", \\\"uri\\\"]}, \\\"nova::cinder::region_name\\\": {\\\"get_param\\\": \\\"KeystoneRegion\\\"}, \\\"nova::compute::rbd::libvirt_rbd_secret_key\\\": {\\\"get_param\\\": \\\"CephClientKey\\\"}, \\\"nova::compute::rbd::libvirt_rbd_secret_uuid\\\": {\\\"get_param\\\": \\\"CephClusterFSID\\\"}, \\\"nova::compute::instance_usage_audit\\\": true, \\\"nova::compute::instance_usage_audit_period\\\": \\\"hour\\\", \\\"nova::compute::consecutive_build_service_disable_threshold\\\": {\\\"get_param\\\": \\\"NovaAutoDisabling\\\"}, \\\"nova::compute::live_migration_wait_for_vif_plug\\\": {\\\"get_param\\\": \\\"NovaLiveMigrationWaitForVIFPlug\\\"}, \\\"nova::migration::libvirt::live_migration_permit_post_copy\\\": {\\\"if\\\": [\\\"is_realtime\\\", false, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"nova_permit_post_copy\\\"]}]}, \\\"nova::migration::libvirt::live_migration_permit_auto_converge\\\": {\\\"if\\\": [\\\"is_realtime\\\", false, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"nova_permit_auto_converge\\\"]}]}, \\\"nova::migration::libvirt::live_migration_tunnelled\\\": false, \\\"nova::compute::vncserver_proxyclient_address\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaLibvirtNetwork\\\"]}}}}, \\\"nova::compute::vncproxy_host\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaPublic\\\", \\\"host_nobrackets\\\"]}, \\\"nova::vncproxy::common::vncproxy_protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaVNCProxyCellPublic\\\", \\\"protocol\\\"]}, \\\"nova::vncproxy::common::vncproxy_host\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaVNCProxyCellPublic\\\", \\\"host_nobrackets\\\"]}, \\\"nova::vncproxy::common::vncproxy_port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaVNCProxyCellPublic\\\", \\\"port\\\"]}, \\\"nova::compute::verify_glance_signatures\\\": {\\\"get_param\\\": [\\\"VerifyGlanceSignatures\\\"]}, \\\"nova::ram_allocation_ratio\\\": {\\\"if\\\": [\\\"libvirt_file_backed_memory_enabled\\\", \\\"1.0\\\", {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"nova::ram_allocation_ratio\\\"]}]}, \\\"nova::compute::libvirt::max_queues\\\": {\\\"if\\\": [\\\"nova_libvirt_max_queues_set\\\", {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"nova_libvirt_max_queues\\\"]}]}, \\\"nova::workarounds::disable_compute_service_check_for_ffu\\\": {\\\"get_param\\\": \\\"NovaDisableComputeServiceCheckForFfu\\\"}}, {\\\"if\\\": [\\\"glance_enable_rbd_download_set\\\", {\\\"nova::glance::enable_rbd_download\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"nova_glance_enable_rbd_download\\\"]}, \\\"nova::glance::rbd_user\\\": {\\\"if\\\": [\\\"nova_glance_rbd_download_multistore_id_set\\\", {\\\"yaql\\\": {\\\"expression\\\": \\\"let(k => $.data.key, d => $.data.default_ceph_client_user_name) -> $.data.multistore.get($k).get(\\\\\\\"CephClientUserName\\\\\\\", $d)\\\", \\\"data\\\": {\\\"key\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"nova_glance_rbd_download_multistore_id\\\"]}, \\\"multistore\\\": {\\\"get_param\\\": \\\"GlanceMultistoreConfig\\\"}, \\\"default_ceph_client_user_name\\\": {\\\"get_param\\\": \\\"CephClientUserName\\\"}}}}, {\\\"get_param\\\": \\\"CephClientUserName\\\"}]}, \\\"nova::glance::rbd_pool\\\": {\\\"if\\\": [\\\"nova_glance_rbd_download_multistore_id_set\\\", {\\\"yaql\\\": {\\\"expression\\\": \\\"let(k => $.data.key, d => $.data.default_glance_rbd_pool_name) -> $.data.multistore.get($k).get(\\\\\\\"GlanceRbdPoolName\\\\\\\", $d)\\\", \\\"data\\\": {\\\"key\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"nova_glance_rbd_download_multistore_id\\\"]}, \\\"multistore\\\": {\\\"get_param\\\": \\\"GlanceMultistoreConfig\\\"}, \\\"default_glance_rbd_pool_name\\\": {\\\"get_param\\\": \\\"GlanceRbdPoolName\\\"}}}}, {\\\"get_param\\\": \\\"GlanceRbdPoolName\\\"}]}, \\\"nova::glance::rbd_ceph_conf\\\": {\\\"list_join\\\": [\\\"\\\", [\\\"/etc/ceph/\\\", {\\\"if\\\": [\\\"nova_glance_rbd_download_multistore_id_set\\\", {\\\"yaql\\\": {\\\"expression\\\": \\\"let(k => $.data.key) -> list(coalesce($.data.multistore, {}).get($k)).flatten().select($.get(\\\\\\\"CephClusterName\\\\\\\"))\\\", \\\"data\\\": {\\\"key\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"nova_glance_rbd_download_multistore_id\\\"]}, \\\"multistore\\\": {\\\"get_param\\\": \\\"GlanceMultistoreConfig\\\"}}}}, {\\\"get_param\\\": \\\"CephClusterName\\\"}]}, \\\".conf\\\"]]}}]}]}, \\\"service_config_settings\\\": {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_nova_compute\\\": [{\\\"get_param\\\": \\\"NovaComputeLoggingSource\\\"}]}, \\\"collectd\\\": {\\\"tripleo.collectd.plugins.nova_compute\\\": [\\\"virt\\\"], \\\"collectd::plugin::virt::connection\\\": \\\"qemu:///system\\\"}}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"nova_libvirt\\\", \\\"puppet_tags\\\": \\\"nova_config\\\", \\\"step_config\\\": \\\"# TODO(emilien): figure how to deal with libvirt profile.\\\\n# We\'ll probably treat it like we do with Neutron plugins.\\\\n# Until then, just include it in the default nova-compute role.\\\\ninclude tripleo::profile::base::nova::compute::libvirt\\\\n\\\", \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaLibvirtConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/nova_compute.json\\\": {\\\"command\\\": {\\\"list_join\\\": [\\\" \\\", [{\\\"if\\\": [\\\"compute_startup_delay\\\", {\\\"str_replace\\\": {\\\"template\\\": \\\"/var/lib/nova/delay-nova-compute --delay DELAY --nova-binary\\\", \\\"params\\\": {\\\"DELAY\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"nova_compute_startup_delay\\\"]}}}}]}, \\\"/usr/bin/nova-compute\\\", {\\\"get_attr\\\": [\\\"NovaLogging\\\", \\\"cmd_extra_args\\\"]}]]}, \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-iscsid/*\\\", \\\"dest\\\": \\\"/etc/iscsi/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-ceph/\\\", \\\"dest\\\": \\\"/etc/ceph/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": {\\\"list_concat\\\": [[{\\\"path\\\": \\\"/var/log/nova\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"recurse\\\": true}, {\\\"path\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"/etc/ceph/CLUSTER.client.USER.keyring\\\", \\\"params\\\": {\\\"CLUSTER\\\": {\\\"get_param\\\": \\\"CephClusterName\\\"}, \\\"USER\\\": {\\\"get_param\\\": \\\"CephClientUserName\\\"}}}}, \\\"owner\\\": \\\"nova:nova\\\", \\\"perm\\\": \\\"0600\\\"}], {\\\"repeat\\\": {\\\"template\\\": {\\\"path\\\": \\\"/etc/ceph/<%keyring%>\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"perm\\\": \\\"0600\\\"}, \\\"for_each\\\": {\\\"<%keyring%>\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"let(u => $.data.user) -> $.data.multistore.values().where($.get(\\\\\\\"CephClusterName\\\\\\\")).select($.CephClusterName + \\\\\\\".client.\\\\\\\" + $.get(\\\\\\\"CephClientUserName\\\\\\\", $u) + \\\\\\\".keyring\\\\\\\")\\\", \\\"data\\\": {\\\"user\\\": {\\\"get_param\\\": \\\"CephClientUserName\\\"}, \\\"multistore\\\": {\\\"get_param\\\": \\\"GlanceMultistoreConfig\\\"}}}}}}}, {\\\"repeat\\\": {\\\"template\\\": {\\\"path\\\": \\\"/etc/ceph/<%keyring%>\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"perm\\\": \\\"0600\\\"}, \\\"for_each\\\": {\\\"<%keyring%>\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"let(u => $.data.default_user) -> $.data.multiconfig.values().select($.CephClusterName + \\\\\\\".client.\\\\\\\" + $.get(\\\\\\\"CephClientUserName\\\\\\\", $u) + \\\\\\\".keyring\\\\\\\")\\\", \\\"data\\\": {\\\"default_user\\\": {\\\"get_param\\\": \\\"CephClientUserName\\\"}, \\\"multiconfig\\\": {\\\"get_param\\\": \\\"CinderRbdMultiConfig\\\"}}}}}}}]}}, \\\"/var/lib/kolla/config_files/nova_compute_wait_for_compute_service.json\\\": {\\\"command\\\": \\\"/container-config-scripts/pyshim.sh /container-config-scripts/nova_wait_for_compute_service.py\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/nova\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"recurse\\\": true}]}}, \\\"container_config_scripts\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"container_config_scripts\\\"]}, {\\\"get_attr\\\": [\\\"NovaComputeCommon\\\", \\\"container_config_scripts\\\"]}]}, \\\"docker_config\\\": {\\\"step_2\\\": {\\\"get_attr\\\": [\\\"NovaLogging\\\", \\\"docker_config\\\", \\\"step_2\\\"]}, \\\"step_3\\\": {\\\"nova_statedir_owner\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaComputeImage\\\"]}, \\\"net\\\": \\\"none\\\", \\\"user\\\": \\\"root\\\", \\\"security_opt\\\": [\\\"label=disable\\\"], \\\"privileged\\\": false, \\\"detach\\\": false, \\\"volumes\\\": [\\\"/var/lib/nova:/var/lib/nova:shared\\\", \\\"/var/lib/_nova_secontext:/var/lib/_nova_secontext:shared,z\\\", \\\"/var/lib/container-config-scripts:/container-config-scripts:z\\\"], \\\"command\\\": \\\"/container-config-scripts/pyshim.sh /container-config-scripts/nova_statedir_ownership.py\\\", \\\"environment\\\": {\\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}, \\\"__OS_DEBUG\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"str($.data.debug)\\\", \\\"data\\\": {\\\"debug\\\": {\\\"get_attr\\\": [\\\"NovaBase\\\", \\\"role_data\\\", \\\"config_settings\\\", \\\"nova::logging::debug\\\"]}}}}, \\\"NOVA_STATEDIR_OWNERSHIP_SKIP\\\": {\\\"list_join\\\": [\\\":\\\", {\\\"get_param\\\": \\\"NovaStatedirOwnershipSkip\\\"}]}}}}, \\\"step_5\\\": {\\\"map_merge\\\": [{\\\"nova_compute\\\": {\\\"start_order\\\": 3, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaComputeImage\\\"]}, \\\"ulimit\\\": {\\\"get_param\\\": \\\"DockerNovaComputeUlimit\\\"}, \\\"ipc\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"user\\\": \\\"nova\\\", \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": {\\\"list_concat\\\": [[\\\"tripleo_nova_libvirt.target\\\"], {\\\"if\\\": [{\\\"get_param\\\": \\\"NovaNfsEnabled\\\"}, [\\\"var-lib-nova-instances.mount\\\"]]}]}, \\\"healthcheck\\\": {\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"healthcheck_rpc_port\\\"]}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"NovaLogging\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"nova_compute_opt_volumes\\\"]}, [\\\"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\\\", \\\"/var/lib/kolla/config_files/nova_compute.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\\\", {\\\"list_join\\\": [\\\":\\\", [{\\\"get_param\\\": \\\"CephConfigPath\\\"}], [\\\"/var/lib/kolla/config_files/src-ceph\\\"], [\\\"z\\\"]]}, \\\"/dev:/dev\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/run:/run\\\", \\\"/run/nova:/run/nova:z\\\", \\\"/var/lib/iscsi:/var/lib/iscsi:z\\\", \\\"/var/lib/libvirt:/var/lib/libvirt:shared\\\", \\\"/sys/class/net:/sys/class/net\\\", \\\"/sys/bus/pci:/sys/bus/pci\\\", \\\"/boot:/boot:ro\\\", \\\"/var/lib/nova:/var/lib/nova:shared\\\"], {\\\"if\\\": [{\\\"get_param\\\": \\\"MultipathdEnable\\\"}, [\\\"/etc/multipath:/etc/multipath:z\\\", \\\"/etc/multipath.conf:/etc/multipath.conf:ro\\\"]]}, {\\\"get_attr\\\": [\\\"CinderNVMeOF\\\", \\\"cinder_nvmeof_volumes\\\"]}]}, \\\"environment\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"nova_compute_opt_env_vars\\\"]}, {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}, {\\\"LIBGUESTFS_BACKEND\\\": \\\"direct\\\"}]}}}, {\\\"if\\\": [{\\\"not\\\": {\\\"get_param\\\": \\\"NovaAdditionalCell\\\"}}, {\\\"nova_wait_for_compute_service\\\": {\\\"start_order\\\": 4, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaComputeImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"detach\\\": false, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/nova_compute_wait_for_compute_service.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/log/containers/nova:/var/log/nova\\\", \\\"/var/lib/container-config-scripts:/container-config-scripts\\\"]]}, \\\"user\\\": \\\"nova\\\", \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\", \\\"__OS_DEBUG\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"str($.data.debug)\\\", \\\"data\\\": {\\\"debug\\\": {\\\"get_attr\\\": [\\\"NovaBase\\\", \\\"role_data\\\", \\\"config_settings\\\", \\\"nova::logging::debug\\\"]}}}}}}}]}]}}, \\\"host_prep_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"NovaLogging\\\", \\\"host_prep_tasks\\\"]}, [{\\\"name\\\": \\\"Check for /var/lib/nova/instances directory exitance\\\", \\\"stat\\\": {\\\"path\\\": \\\"/var/lib/nova/instances\\\"}, \\\"register\\\": \\\"check_nova_instances_result\\\"}, {\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype | default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/lib/nova\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/lib/_nova_secontext\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/lib/nova/instances\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/lib/libvirt\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/etc/tmpfiles.d\\\"}]}, {\\\"name\\\": \\\"ensure /run/nova is present upon reboot\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/tmpfiles.d/run-nova.conf\\\", \\\"content\\\": \\\"d /run/nova 0777 root root - -\\\\n\\\"}}, {\\\"name\\\": \\\"create tempfiles\\\", \\\"command\\\": \\\"systemd-tmpfiles --create\\\"}], [{\\\"name\\\": \\\"Mount Nova NFS Share\\\", \\\"vars\\\": {\\\"nfs_backend_enable\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"nfs_backend_enable\\\"]}, \\\"nfs_share\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"nfs_share\\\"]}, \\\"nfs_options\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"nfs_options\\\"]}, \\\"nfs_vers\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"nfs_vers\\\"]}}, \\\"mount\\\": {\\\"name\\\": \\\"/var/lib/nova/instances\\\", \\\"state\\\": \\\"mounted\\\", \\\"fstype\\\": \\\"nfs4\\\", \\\"src\\\": \\\"{{nfs_share}}\\\", \\\"opts\\\": \\\"_netdev,bg,{{nfs_options}},nfsvers={{nfs_vers}}\\\"}, \\\"when\\\": \\\"nfs_backend_enable|bool\\\"}], [{\\\"name\\\": \\\"delay installation of systemd-container\\\", \\\"when\\\": \\\"check_nova_instances_result.stat.exists\\\", \\\"block\\\": [{\\\"name\\\": \\\"check systemd-container package installed or not\\\", \\\"package\\\": {\\\"name\\\": \\\"systemd-container\\\", \\\"state\\\": \\\"present\\\"}, \\\"check_mode\\\": true, \\\"register\\\": \\\"is_systemd_container_package\\\", \\\"failed_when\\\": false}, {\\\"name\\\": \\\"get latest package from downloaded package versions\\\", \\\"shell\\\": \\\"ls -1t /var/tmp/systemd-container* | head -1\\\", \\\"register\\\": \\\"latest_systemd_container_package\\\", \\\"when\\\": [\\\"is_systemd_container_package is defined\\\", \\\"(\'changed\' in is_systemd_container_package)\\\", \\\"is_systemd_container_package.changed\\\"], \\\"failed_when\\\": false}, {\\\"name\\\": \\\"Install systemd-container package on boot\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/install-systemd-container.service\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Install systemd container package on system boot\\\\nBefore=tripleo_nova_virtqemud.service\\\\n\\\\n[Service]\\\\nType=oneshot\\\\nExecStart=/usr/bin/rpm -ivh {{ latest_systemd_container_package.stdout }}\\\\nExecStartPost=rm -f /var/tmp/systemd-container*\\\\n\\\\n[Install]\\\\nWantedBy=multi-user.target\\\\n\\\"}, \\\"when\\\": [\\\"latest_systemd_container_package is defined\\\", \\\"(\'stdout\' in latest_systemd_container_package)\\\", \\\"is_systemd_container_package is defined\\\", \\\"(\'changed\' in is_systemd_container_package)\\\", \\\"is_systemd_container_package.changed\\\"]}, {\\\"name\\\": \\\"enable install-systemd-container on compute boot\\\", \\\"systemd\\\": {\\\"name\\\": \\\"install-systemd-container\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": true, \\\"daemon_reload\\\": true}, \\\"when\\\": [\\\"is_systemd_container_package is defined\\\", \\\"(\'changed\' in is_systemd_container_package)\\\", \\\"is_systemd_container_package.changed\\\"]}, {\\\"name\\\": \\\"check if install-systemd-container service exists\\\", \\\"stat\\\": {\\\"path\\\": \\\"/etc/systemd/system/install-systemd-container.service\\\"}, \\\"register\\\": \\\"install_systemd_container_result\\\"}, {\\\"name\\\": \\\"disable and mask install-systemd-container on compute boot\\\", \\\"systemd\\\": {\\\"name\\\": \\\"install-systemd-container\\\", \\\"enabled\\\": false, \\\"masked\\\": true, \\\"daemon_reload\\\": true}, \\\"when\\\": [\\\"is_systemd_container_package is defined\\\", \\\"(\'changed\' in is_systemd_container_package)\\\", \\\"not is_systemd_container_package.changed\\\", \\\"install_systemd_container_result.stat.exists\\\"]}]}, {\\\"name\\\": \\\"is Nova Resume Guests State On Host Boot enabled\\\", \\\"set_fact\\\": {\\\"resume_guests_state_on_host_boot_enabled\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"resume_guests_state_on_host_boot\\\"]}}}, {\\\"name\\\": \\\"install libvirt-guests systemd unit file (docker)\\\", \\\"when\\\": [\\\"resume_guests_state_on_host_boot_enabled|bool\\\", \\\"container_cli == \'docker\'\\\"], \\\"block\\\": [{\\\"name\\\": \\\"libvirt-guests unit to stop nova_compute container before shutdown VMs\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/libvirt-guests.service\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Suspend/Resume Running libvirt Guests\\\\nAfter=network.target\\\\nAfter=time-sync.target\\\\nAfter=virt-guest-shutdown.target\\\\nAfter=docker.service\\\\nAfter=tripleo-container-shutdown.service\\\\nAfter=rhel-push-plugin.service\\\\nDocumentation=man:libvirtd(8)\\\\nDocumentation=https://libvirt.org\\\\n\\\\n[Service]\\\\nEnvironmentFile=-/var/lib/config-data/puppet-generated/nova_libvirt/etc/sysconfig/libvirt-guests\\\\n# Hack just call traditional service until we factor\\\\n# out the code\\\\nExecStart=/bin/{{container_cli}} exec nova_libvirt /bin/sh -x /usr/libexec/libvirt-guests.sh start\\\\nExecStop=/bin/{{container_cli}} stop nova_compute\\\\nExecStop=/bin/{{container_cli}}  exec nova_libvirt /bin/sh -x /usr/libexec/libvirt-guests.sh stop\\\\nType=oneshot\\\\nRemainAfterExit=yes\\\\nStandardOutput=journal+console\\\\nTimeoutStopSec=0\\\\n\\\\n[Install]\\\\nWantedBy=multi-user.target\\\\n\\\"}}, {\\\"name\\\": \\\"Making sure virt-guest-shutdown.target is present\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/virt-guest-shutdown.target\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Libvirt guests shutdown\\\\nDocumentation=https://libvirt.org\\\\nAfter=systemd-machined.service\\\\nAfter=network-online.target\\\\nAfter=tripleo_nova_libvirt.target\\\\nBefore=tripleo_nova_compute.service\\\\n\\\"}}, {\\\"name\\\": \\\"libvirt-guests enable VM shutdown on compute reboot/shutdown\\\", \\\"systemd\\\": {\\\"name\\\": \\\"libvirt-guests\\\", \\\"enabled\\\": true, \\\"daemon_reload\\\": true}}]}, {\\\"name\\\": \\\"install tripleo_nova_libvirt_guests systemd unit file (podman)\\\", \\\"when\\\": [\\\"resume_guests_state_on_host_boot_enabled|bool\\\", \\\"container_cli == \'podman\'\\\"], \\\"block\\\": [{\\\"name\\\": \\\"libvirt-guests unit to stop nova_compute container before shutdown VMs (monolithic libvirt)\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/tripleo_nova_libvirt_guests.service\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Suspend libvirt Guests in tripleo\\\\nRequires=virt-guest-shutdown.target\\\\nAfter=systemd-machined.service\\\\nAfter=network-online.target\\\\nAfter=tripleo_nova_libvirt.target\\\\nBefore=tripleo_nova_compute.service\\\\nDocumentation=man:libvirtd(8)\\\\nDocumentation=https://libvirt.org\\\\n\\\\n[Service]\\\\nEnvironmentFile=-/etc/sysconfig/libvirt-guests\\\\nExecStart=/bin/podman exec nova_libvirt /bin/rm -f /var/lib/libvirt/libvirt-guests\\\\nExecStop=/bin/podman exec nova_libvirt /bin/sh -x /usr/libexec/libvirt-guests.sh shutdown\\\\nType=oneshot\\\\nRemainAfterExit=yes\\\\nStandardOutput=journal+console\\\\nTimeoutStopSec=0\\\\n\\\\n[Install]\\\\nWantedBy=multi-user.target\\\\n\\\"}, \\\"when\\\": \\\"tripleo_nova_libvirt_virsh_container | default(\'nova_libvirt\') == \'nova_libvirt\'\\\"}, {\\\"name\\\": \\\"libvirt-guests unit to stop nova_compute container before shutdown VMs (modular libvirt)\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/tripleo_nova_libvirt_guests.service\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Suspend libvirt Guests in tripleo\\\\nRequires=virt-guest-shutdown.target\\\\nAfter=systemd-machined.service\\\\nAfter=network-online.target\\\\nAfter=tripleo_nova_libvirt.target\\\\nBefore=tripleo_nova_compute.service\\\\nDocumentation=man:libvirtd(8)\\\\nDocumentation=https://libvirt.org\\\\n\\\\n[Service]\\\\nEnvironmentFile=-/etc/sysconfig/libvirt-guests\\\\nExecStart=/bin/podman exec nova_virtproxyd /bin/rm -f /var/lib/libvirt/libvirt-guests\\\\nExecStop=/bin/podman exec nova_virtproxyd /bin/sh -x /usr/libexec/libvirt-guests.sh shutdown\\\\nType=oneshot\\\\nRemainAfterExit=yes\\\\nStandardOutput=journal+console\\\\nTimeoutStopSec=0\\\\n\\\\n[Install]\\\\nWantedBy=multi-user.target\\\\n\\\"}, \\\"when\\\": \\\"tripleo_nova_libvirt_virsh_container | default(\'nova_libvirt\') != \'nova_libvirt\'\\\"}, {\\\"name\\\": \\\"Making sure virt-guest-shutdown.target is present\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/virt-guest-shutdown.target\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Libvirt guests shutdown\\\\nDocumentation=https://libvirt.org\\\\nAfter=systemd-machined.service\\\\nAfter=network-online.target\\\\nAfter=tripleo_nova_libvirt.target\\\\nBefore=tripleo_nova_compute.service\\\\n\\\"}}, {\\\"name\\\": \\\"tripleo_nova_libvirt_guests enable VM shutdown on compute reboot/shutdown\\\", \\\"systemd\\\": {\\\"name\\\": \\\"tripleo_nova_libvirt_guests\\\", \\\"enabled\\\": true, \\\"daemon_reload\\\": true}}]}, {\\\"name\\\": \\\"ensure ceph configurations exist\\\", \\\"file\\\": {\\\"path\\\": {\\\"get_param\\\": \\\"CephConfigPath\\\"}, \\\"state\\\": \\\"directory\\\"}}, {\\\"name\\\": \\\"enable virt_sandbox_use_netlink for healthcheck\\\", \\\"seboolean\\\": {\\\"name\\\": \\\"virt_sandbox_use_netlink\\\", \\\"persistent\\\": true, \\\"state\\\": true}, \\\"when\\\": [\\\"ansible_facts.selinux is defined\\\", \\\"ansible_facts.selinux.status == \\\\\\\"enabled\\\\\\\"\\\"]}, {\\\"name\\\": \\\"Do we prepend nova startup with a delay\\\", \\\"set_fact\\\": {\\\"nova_compute_delay\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"nova_compute_startup_delay\\\"]}}}, {\\\"name\\\": \\\"install nova-compute delay wrapper script\\\", \\\"copy\\\": {\\\"content\\\": {\\\"get_file\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/scripts/delay-nova-compute\\\"}, \\\"dest\\\": \\\"/var/lib/nova/delay-nova-compute\\\", \\\"mode\\\": 493}, \\\"when\\\": \\\"nova_compute_delay|int > 0\\\"}, {\\\"name\\\": \\\"Is irqbalance enabled\\\", \\\"set_fact\\\": {\\\"compute_irqbalance_disabled\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"compute_disable_irqbalance\\\"]}}}, {\\\"name\\\": \\\"disable irqbalance service on compute\\\", \\\"when\\\": \\\"compute_irqbalance_disabled|bool\\\", \\\"service\\\": {\\\"name\\\": \\\"irqbalance.service\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}}], {\\\"get_attr\\\": [\\\"CinderNVMeOF\\\", \\\"cinder_nvmeof_host_prep_tasks\\\"]}]}, \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"install systemd-container for a greenfield\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"not check_nova_instances_result.stat.exists\\\"], \\\"package\\\": {\\\"name\\\": \\\"systemd-container\\\", \\\"state\\\": \\\"present\\\"}}, {\\\"name\\\": \\\"validate nova-compute container state\\\", \\\"containers.podman.podman_container_info\\\": {\\\"name\\\": \\\"nova_compute\\\"}, \\\"register\\\": \\\"nova_compute_infos\\\", \\\"failed_when\\\": [\\\"nova_compute_infos.containers.0.Healthcheck.Status is defined\\\", \\\"\'healthy\' not in nova_compute_infos.containers.0.Healthcheck.Status\\\"], \\\"retries\\\": 10, \\\"delay\\\": 30, \\\"tags\\\": [\\\"opendev-validation\\\", \\\"opendev-validation-nova\\\"], \\\"when\\\": [\\\"container_cli == \'podman\'\\\", \\\"not container_healthcheck_disabled\\\", \\\"step|int == 6\\\"]}, {\\\"name\\\": \\\"manage PMEM namespaces for vPMEM\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_nvdimm\\\"}, \\\"vars\\\": {\\\"tripleo_nvdimm_pmem_namespaces\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"nova_pmem_namespaces\\\"]}}, \\\"when\\\": [\\\"step|int == 1\\\", \\\"tripleo_nvdimm_pmem_namespaces != \'\'\\\"]}, {\\\"name\\\": \\\"manage OS version 9 specific sysctls\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"ansible_facts[\'os_family\'] == \'RedHat\'\\\", \\\"ansible_facts[\'distribution_major_version\'] is version(\'9\', \'==\')\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Enable post-copy by setting unprivileged_userfaultfd\\\", \\\"sysctl\\\": {\\\"name\\\": \\\"vm.unprivileged_userfaultfd\\\", \\\"value\\\": 1, \\\"sysctl_set\\\": true, \\\"sysctl_file\\\": \\\"/etc/sysctl.d/99-tripleo-postcopy.conf\\\", \\\"state\\\": \\\"present\\\", \\\"reload\\\": true}}]}, {\\\"name\\\": \\\"enable/disable ksm\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"is KSM enabled\\\", \\\"set_fact\\\": {\\\"compute_ksm_enabled\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"compute_enable_ksm\\\"]}}}, {\\\"name\\\": \\\"disable KSM on compute\\\", \\\"when\\\": \\\"not compute_ksm_enabled|bool\\\", \\\"block\\\": [{\\\"name\\\": \\\"Check for ksm\\\", \\\"shell\\\": \\\"systemctl is-active ksm.service || systemctl is-enabled ksm.service\\\", \\\"become\\\": true, \\\"failed_when\\\": false, \\\"register\\\": \\\"ksm_service_check\\\"}, {\\\"name\\\": \\\"disable KSM services\\\", \\\"service\\\": {\\\"name\\\": \\\"{{ item }}\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}, \\\"with_items\\\": [\\\"ksm.service\\\", \\\"ksmtuned.service\\\"], \\\"when\\\": [\\\"ksm_service_check.rc is defined\\\", \\\"ksm_service_check.rc == 0\\\"], \\\"register\\\": \\\"ksmdisabled\\\"}, {\\\"name\\\": \\\"delete PageKSM after disable ksm on compute\\\", \\\"command\\\": \\\"echo 2 >/sys/kernel/mm/ksm/run\\\", \\\"when\\\": [\\\"ksm_service_check.rc is defined\\\", \\\"ksm_service_check.rc == 0\\\", \\\"ksmdisabled is changed\\\"]}]}, {\\\"name\\\": \\\"enable KSM on compute\\\", \\\"when\\\": \\\"compute_ksm_enabled|bool\\\", \\\"block\\\": [{\\\"name\\\": \\\"make sure package providing ksmtuned is installed (RHEL8 or CentOS8)\\\", \\\"package\\\": {\\\"name\\\": \\\"qemu-kvm-common\\\", \\\"state\\\": \\\"present\\\"}, \\\"when\\\": [\\\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\\\"]}, {\\\"name\\\": \\\"make sure package providing ksmtuned is installed (RHEL9 or CentOS9)\\\", \\\"package\\\": {\\\"name\\\": \\\"ksmtuned\\\", \\\"state\\\": \\\"present\\\"}, \\\"when\\\": [\\\"ansible_facts[\'distribution_major_version\'] is version(\'9\', \'==\')\\\"]}, {\\\"name\\\": \\\"enable ksmtunded\\\", \\\"service\\\": {\\\"name\\\": \\\"{{ item }}\\\", \\\"state\\\": \\\"started\\\", \\\"enabled\\\": true}, \\\"with_items\\\": [\\\"ksm.service\\\", \\\"ksmtuned.service\\\"]}]}]}], \\\"external_post_deploy_tasks\\\": {\\\"get_attr\\\": [\\\"NovaComputeCommon\\\", \\\"nova_compute_common_deploy_steps_tasks\\\"]}, \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"Remove openstack-nova-compute and python-nova package during upgrade\\\", \\\"package\\\": {\\\"name\\\": [\\\"openstack-nova-compute\\\", \\\"python-nova\\\"], \\\"state\\\": \\\"removed\\\"}, \\\"failed_when\\\": false, \\\"when\\\": \\\"step|int == 2\\\"}, {\\\"name\\\": \\\"nova_compute pre system_upgrade tasks\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_run\\\", \\\"system_upgrade_nfsmounts\\\"], \\\"when\\\": [\\\"step|int == 3\\\", \\\"upgrade_leapp_enabled\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Unmount Nova NFS Share\\\", \\\"vars\\\": {\\\"nfs_backend_enable\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"nfs_backend_enable\\\"]}}, \\\"mount\\\": {\\\"name\\\": \\\"/var/lib/nova/instances\\\", \\\"state\\\": \\\"absent\\\", \\\"fstype\\\": \\\"nfs4\\\"}, \\\"when\\\": \\\"nfs_backend_enable|bool\\\"}]}, {\\\"name\\\": \\\"nova_compute post system_upgrade tasks\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_run\\\", \\\"system_upgrade_nfsmounts\\\"], \\\"when\\\": [\\\"step|int == 5\\\", \\\"upgrade_leapp_enabled\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Mount Nova NFS Share\\\", \\\"vars\\\": {\\\"nfs_backend_enable\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"nfs_backend_enable\\\"]}, \\\"nfs_share\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"nfs_share\\\"]}, \\\"nfs_options\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"nfs_options\\\"]}, \\\"nfs_vers\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"nfs_vers\\\"]}}, \\\"mount\\\": {\\\"name\\\": \\\"/var/lib/nova/instances\\\", \\\"state\\\": \\\"mounted\\\", \\\"fstype\\\": \\\"nfs4\\\", \\\"src\\\": \\\"{{nfs_share}}\\\", \\\"opts\\\": \\\"_netdev,bg,{{nfs_options}},nfsvers={{nfs_vers}}\\\"}, \\\"when\\\": \\\"nfs_backend_enable|bool\\\"}]}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"Remove openstack-nova-compute and python-nova package during upgrade\\\", \\\"package\\\": {\\\"name\\\": [\\\"openstack-nova-compute\\\", \\\"python-nova\\\"], \\\"state\\\": \\\"removed\\\"}, \\\"failed_when\\\": false, \\\"when\\\": \\\"step|int == 2\\\"}], \\\"post_update_tasks\\\": [{\\\"name\\\": \\\"Ensure instanceha directory is purged\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"become\\\": true, \\\"file\\\": {\\\"path\\\": \\\"/var/lib/nova/instanceha\\\", \\\"state\\\": \\\"absent\\\"}}], \\\"post_upgrade_tasks\\\": [{\\\"name\\\": \\\"Ensure instanceha directory is purged\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"become\\\": true, \\\"file\\\": {\\\"path\\\": \\\"/var/lib/nova/instanceha\\\", \\\"state\\\": \\\"absent\\\"}}], \\\"scale_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\", \\\"container_cli == \'podman\'\\\"], \\\"tags\\\": \\\"down\\\", \\\"become\\\": true, \\\"environment\\\": {\\\"OS_CLOUD\\\": {\\\"if\\\": [\\\"auth_cloud_name_set\\\", {\\\"get_param\\\": \\\"AuthCloudName\\\"}, {\\\"get_param\\\": \\\"RootStackName\\\"}]}}, \\\"block\\\": [{\\\"name\\\": \\\"Get nova-compute service ID\\\", \\\"command\\\": \\\"openstack compute service list --service nova-compute --column ID --column Host --format yaml\\\", \\\"register\\\": \\\"nova_compute_service_result\\\", \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"check_mode\\\": false, \\\"changed_when\\\": false}, {\\\"name\\\": \\\"is additional Cell?\\\", \\\"set_fact\\\": {\\\"is_additional_cell\\\": {\\\"get_param\\\": \\\"NovaAdditionalCell\\\"}}}, {\\\"name\\\": \\\"Set fact for nova_compute services\\\", \\\"set_fact\\\": {\\\"nova_compute_service\\\": \\\"{{ nova_compute_service_result.stdout | from_yaml | selectattr(\'Host\', \'match\', ansible_facts[\'fqdn\'] ~ \'.*\') | list }}\\\"}, \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"check_mode\\\": false}, {\\\"name\\\": \\\"Check search output\\\", \\\"fail\\\": {\\\"msg\\\": \\\"Found multiple `{{ ansible_facts[\'fqdn\'] }}`, which is unexpected. This means that the FQDN of the selected device to disable is either wrong or is sharing a name with another host, which is also wrong. Please correct this issue before continuing. Nova service list return data can be found here -> {{ nova_compute_service }}.\\\"}, \\\"when\\\": [\\\"(nova_compute_service | length) > 1\\\"]}, {\\\"name\\\": \\\"Disable nova services\\\", \\\"when\\\": [\\\"(nova_compute_service | length) == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Disable nova-compute service\\\", \\\"command\\\": \\\"openstack compute service set {{ nova_compute_service[0].Host }} nova-compute --disable\\\", \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"check_mode\\\": false, \\\"when\\\": [\\\"not is_additional_cell|bool\\\"]}, {\\\"name\\\": \\\"Stop nova-compute container\\\", \\\"service\\\": {\\\"name\\\": \\\"tripleo_nova_compute\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}, \\\"become\\\": true, \\\"register\\\": \\\"stop_nova_compute\\\", \\\"failed_when\\\": \\\"(\'msg\' in stop_nova_compute and \'Could not find the requested service tripleo_nova_compute\' not in stop_nova_compute.msg) or (\'rc\' in stop_nova_compute and stop_nova_compute.rc != 0)\\\"}, {\\\"name\\\": \\\"Delete nova-compute service\\\", \\\"command\\\": \\\"openstack compute service delete {{ nova_compute_service[0].ID }}\\\", \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"check_mode\\\": false}]}]}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Nova Conductor service\\\\n\\\", \\\"parameters\\\": {\\\"ContainerNovaConductorImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerNovaConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the nova config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaConductorLoggingSource\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {\\\"tag\\\": \\\"openstack.nova.conductor\\\", \\\"file\\\": \\\"/var/log/containers/nova/nova-conductor.log\\\"}}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"DeployIdentifier\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\\\n\\\"}, \\\"NovaWorkers\\\": {\\\"default\\\": 0, \\\"description\\\": \\\"Number of workers for Nova services.\\\", \\\"type\\\": \\\"number\\\"}, \\\"MonitoringSubscriptionNovaConductor\\\": {\\\"default\\\": \\\"overcloud-nova-conductor\\\", \\\"type\\\": \\\"string\\\"}, \\\"NovaPassword\\\": {\\\"description\\\": \\\"The password for the nova service and db account\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"NovaAdditionalCell\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether this is an cell additional to the default cell.\\\", \\\"type\\\": \\\"boolean\\\"}}, \\\"conditions\\\": {\\\"nova_workers_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"NovaWorkers\\\"}, 0]}}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"MySQLClient\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\\\"}, \\\"NovaLogging\\\": {\\\"type\\\": \\\"OS::TripleO::Services::Logging::NovaCommon\\\", \\\"properties\\\": {\\\"ContainerNovaImage\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaConductorImage\\\"]}, \\\"NovaServiceName\\\": \\\"conductor\\\"}}, \\\"NovaBase\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"NovaApiDBClient\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"NovaDBClient\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerNovaConductorImage\\\": \\\"ContainerNovaConductorImage\\\", \\\"ContainerNovaConfigImage\\\": \\\"ContainerNovaConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerNovaConductorImage\\\": {\\\"get_param\\\": \\\"ContainerNovaConductorImage\\\"}, \\\"ContainerNovaConfigImage\\\": {\\\"get_param\\\": \\\"ContainerNovaConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Nova Conductor service.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"nova_conductor\\\", \\\"monitoring_subscription\\\": {\\\"get_param\\\": \\\"MonitoringSubscriptionNovaConductor\\\"}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"NovaBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"get_attr\\\": [\\\"NovaApiDBClient\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"get_attr\\\": [\\\"NovaDBClient\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"get_attr\\\": [\\\"NovaLogging\\\", \\\"config_settings\\\"]}, {\\\"if\\\": [\\\"nova_workers_set\\\", {\\\"nova::conductor::workers\\\": {\\\"get_param\\\": \\\"NovaWorkers\\\"}}]}]}, \\\"service_config_settings\\\": {\\\"rabbitmq\\\": {\\\"get_attr\\\": [\\\"NovaBase\\\", \\\"role_data\\\", \\\"service_config_settings\\\"], \\\"rabbitmq\\\": null}, \\\"mysql\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"NovaApiDBClient\\\", \\\"role_data\\\", \\\"service_config_settings\\\", \\\"mysql\\\"]}, {\\\"get_attr\\\": [\\\"NovaDBClient\\\", \\\"role_data\\\", \\\"service_config_settings\\\", \\\"mysql\\\"]}]}, \\\"rsyslog\\\": {\\\"tripleo_logging_sources_nova_conductor\\\": [{\\\"get_param\\\": \\\"NovaConductorLoggingSource\\\"}]}}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"nova\\\", \\\"puppet_tags\\\": \\\"nova_config\\\", \\\"step_config\\\": {\\\"list_join\\\": [\\\"\\\\n\\\", [\\\"include tripleo::profile::base::nova::conductor\\\", {\\\"get_attr\\\": [\\\"MySQLClient\\\", \\\"role_data\\\", \\\"step_config\\\"]}]]}, \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/nova_conductor.json\\\": {\\\"command\\\": {\\\"list_join\\\": [\\\" \\\", [\\\"/usr/bin/nova-conductor\\\", {\\\"get_attr\\\": [\\\"NovaLogging\\\", \\\"cmd_extra_args\\\"]}]]}, \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/nova\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"recurse\\\": true}]}, \\\"/var/lib/kolla/config_files/nova_conductor_db_sync.json\\\": {\\\"command\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"/usr/bin/bootstrap_host_exec nova_conductor su nova -s /bin/bash -c \'/usr/bin/nova-manage db sync DB_SYNC_ARGS\'\\\", \\\"params\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"NovaAdditionalCell\\\"}, {\\\"DB_SYNC_ARGS\\\": \\\"--local_cell\\\"}, {\\\"DB_SYNC_ARGS\\\": \\\"\\\"}]}}}, \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/nova\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"recurse\\\": true}]}}, \\\"docker_config\\\": {\\\"step_2\\\": {\\\"get_attr\\\": [\\\"NovaLogging\\\", \\\"docker_config\\\", \\\"step_2\\\"]}, \\\"step_3\\\": {\\\"nova_db_sync\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaConductorImage\\\"]}, \\\"cap_add\\\": [\\\"AUDIT_WRITE\\\"], \\\"start_order\\\": 3, \\\"net\\\": \\\"host\\\", \\\"detach\\\": false, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"NovaLogging\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/nova_conductor_db_sync.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/nova:/var/lib/kolla/config_files/src:ro\\\"]]}, \\\"user\\\": \\\"root\\\", \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\", \\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}}}}, \\\"step_4\\\": {\\\"nova_conductor\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaConductorImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"healthcheck_rpc_port\\\"]}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"NovaLogging\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/nova_conductor.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/nova:/var/lib/kolla/config_files/src:ro\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"validate nova-conductor container state\\\", \\\"containers.podman.podman_container_info\\\": {\\\"name\\\": \\\"nova_conductor\\\"}, \\\"register\\\": \\\"nova_conductor_infos\\\", \\\"failed_when\\\": [\\\"nova_conductor_infos.containers.0.Healthcheck.Status is defined\\\", \\\"\'healthy\' not in nova_conductor_infos.containers.0.Healthcheck.Status\\\"], \\\"retries\\\": 10, \\\"delay\\\": 30, \\\"tags\\\": [\\\"opendev-validation\\\", \\\"opendev-validation-nova\\\"], \\\"when\\\": [\\\"container_cli == \'podman\'\\\", \\\"not container_healthcheck_disabled\\\", \\\"step|int == 5\\\"]}], \\\"host_prep_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"NovaLogging\\\", \\\"host_prep_tasks\\\"]}, [{\\\"name\\\": \\\"enable virt_sandbox_use_netlink for healthcheck\\\", \\\"seboolean\\\": {\\\"name\\\": \\\"virt_sandbox_use_netlink\\\", \\\"persistent\\\": true, \\\"state\\\": true}, \\\"when\\\": [\\\"ansible_facts.selinux is defined\\\", \\\"ansible_facts.selinux.status == \\\\\\\"enabled\\\\\\\"\\\"]}]]}, \\\"external_upgrade_tasks\\\": [{\\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Set facts for running online DB migrations\\\", \\\"set_fact\\\": {\\\"is_additional_cell\\\": {\\\"get_param\\\": \\\"NovaAdditionalCell\\\"}}, \\\"tags\\\": [\\\"online_upgrade\\\", \\\"online_upgrade_nova\\\"]}, {\\\"name\\\": \\\"Online data migration for Nova\\\", \\\"when\\\": \\\"not is_additional_cell|bool\\\", \\\"command\\\": \\\"{{ container_cli }} exec nova_conductor nova-manage db online_data_migrations\\\", \\\"delegate_to\\\": \\\"{{ (groups[\'nova_conductor\'] | difference(groups[\'excluded_overcloud\']))[0] }}\\\", \\\"become\\\": true, \\\"tags\\\": [\\\"online_upgrade\\\", \\\"online_upgrade_nova\\\"]}]}, {\\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade_transfer_data\\\", \\\"system_upgrade_stop_services\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Stop nova conductor container\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_stop\\\"}, \\\"vars\\\": {\\\"tripleo_containers_to_stop\\\": [\\\"nova_conductor\\\"], \\\"tripleo_delegate_to\\\": \\\"{{ groups[\'nova_conductor\'] | difference(groups[\'excluded_overcloud\']) }}\\\"}}]}], \\\"external_update_tasks\\\": [{\\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Set facts for running online DB migrations\\\", \\\"set_fact\\\": {\\\"is_additional_cell\\\": {\\\"get_param\\\": \\\"NovaAdditionalCell\\\"}}, \\\"tags\\\": [\\\"online_upgrade\\\", \\\"online_upgrade_nova\\\"]}, {\\\"name\\\": \\\"Online data migration for Nova\\\", \\\"when\\\": \\\"not is_additional_cell|bool\\\", \\\"command\\\": \\\"{{ container_cli }} exec nova_conductor nova-manage db online_data_migrations\\\", \\\"delegate_to\\\": \\\"{{ (groups[\'nova_conductor\'] | difference(groups[\'excluded_overcloud\']))[0] }}\\\", \\\"become\\\": true, \\\"tags\\\": [\\\"online_upgrade\\\", \\\"online_upgrade_nova\\\"]}]}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-common.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Contains a static list of common things necessary for containers\\\\n\\\", \\\"parameters\\\": {\\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry.  This mapping overrides those in ServiceNetMapDefaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"CephClientUserName\\\": {\\\"default\\\": \\\"openstack\\\", \\\"type\\\": \\\"string\\\"}, \\\"CephClusterName\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"ceph\\\", \\\"description\\\": \\\"The Ceph cluster name.\\\", \\\"constraints\\\": [{\\\"allowed_pattern\\\": \\\"[a-zA-Z0-9]+\\\", \\\"description\\\": \\\"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\\\n\\\"}]}, \\\"CinderRbdMultiConfig\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {}, \\\"description\\\": \\\"Dictionary of settings when configuring multiple RBD backends. The\\\\nhash key is the backend name, and the value is a dictionary of parameter\\\\nvalues unique to that backend. The following parameters are required,\\\\nand must match the corresponding value defined in CephExternalMultiConfig.\\\\n  CephClusterName (must match the CephExternalMultiConfig entry\'s \'cluster\')\\\\n  CephClusterFSID (must match the CephExternalMultiConfig entry\'s \'fsid\')\\\\nThe following parameters are optional, and override the corresponding\\\\nparameter\'s default value.\\\\n  CephClientUserName\\\\n  CinderRbdPoolName\\\\n  CinderRbdExtraPools\\\\n  CinderRbdAvailabilityZone\\\\n  CinderRbdFlattenVolumeFromSnapshot\\\\n\\\"}, \\\"CephConfigPath\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"/var/lib/tripleo-config/ceph\\\", \\\"description\\\": \\\"The path where the Ceph Cluster config files are stored on the host.\\\\n\\\"}, \\\"QemuMemoryBackingDir\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Directory used for memoryBacking source if configured as file. NOTE: big files will be stored here\\\\n\\\", \\\"default\\\": \\\"\\\", \\\"tags\\\": [\\\"role_specific\\\"]}}, \\\"conditions\\\": {\\\"memory_backing_dir_set\\\": {\\\"not\\\": {\\\"and\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"QemuMemoryBackingDir\\\"}, \\\"\\\"]}, {\\\"equals\\\": [{\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"QemuMemoryBackingDir\\\"]}, \\\"\\\"]}]}}}, \\\"resources\\\": {\\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"nova::compute::libvirt::qemu::memory_backing_dir\\\": \\\"QemuMemoryBackingDir\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"QemuMemoryBackingDir\\\": {\\\"get_param\\\": \\\"QemuMemoryBackingDir\\\"}}}]}}}}, \\\"outputs\\\": {\\\"kolla_config_files\\\": {\\\"description\\\": \\\"Common kolla config_files.\\\", \\\"value\\\": {\\\"list_concat\\\": [[{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-ceph/\\\", \\\"dest\\\": \\\"/etc/ceph/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]]}}, \\\"kolla_permissions\\\": {\\\"description\\\": \\\"Common kolla permissions.\\\", \\\"value\\\": {\\\"list_concat\\\": [[{\\\"path\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"/etc/ceph/CLUSTER.client.USER.keyring\\\", \\\"params\\\": {\\\"CLUSTER\\\": {\\\"get_param\\\": \\\"CephClusterName\\\"}, \\\"USER\\\": {\\\"get_param\\\": \\\"CephClientUserName\\\"}}}}, \\\"owner\\\": \\\"nova:nova\\\", \\\"perm\\\": \\\"0600\\\"}], {\\\"repeat\\\": {\\\"template\\\": {\\\"path\\\": \\\"/etc/ceph/<%keyring%>\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"perm\\\": \\\"0600\\\"}, \\\"for_each\\\": {\\\"<%keyring%>\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"let(u => $.data.default_user) -> $.data.multiconfig.values().select($.CephClusterName + \\\\\\\".client.\\\\\\\" + $.get(\\\\\\\"CephClientUserName\\\\\\\", $u) + \\\\\\\".keyring\\\\\\\")\\\", \\\"data\\\": {\\\"default_user\\\": {\\\"get_param\\\": \\\"CephClientUserName\\\"}, \\\"multiconfig\\\": {\\\"get_param\\\": \\\"CinderRbdMultiConfig\\\"}}}}}}}]}}, \\\"config_settings\\\": {\\\"description\\\": \\\"Extra hieradata for all modular virt daemons.\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\"]}}, \\\"volumes\\\": {\\\"description\\\": \\\"Common volumes for all modular virt daemons.\\\", \\\"value\\\": {\\\"list_concat\\\": [[\\\"/lib/modules:/lib/modules:ro\\\", \\\"/dev:/dev\\\", \\\"/run:/run\\\", \\\"/sys/fs/cgroup:/sys/fs/cgroup\\\", \\\"/sys/fs/selinux:/sys/fs/selinux\\\", \\\"/etc/selinux/config:/etc/selinux/config:ro\\\", \\\"/etc/libvirt:/etc/libvirt:shared\\\", \\\"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\\\", \\\"/run/libvirt:/run/libvirt:shared,z\\\", \\\"/var/lib/nova:/var/lib/nova:shared\\\", \\\"/var/lib/libvirt:/var/lib/libvirt:shared\\\", \\\"/var/cache/libvirt:/var/cache/libvirt:shared\\\", \\\"/var/lib/vhost_sockets:/var/lib/vhost_sockets\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", {\\\"list_join\\\": [\\\":\\\", [{\\\"get_param\\\": \\\"CephConfigPath\\\"}], [\\\"/var/lib/kolla/config_files/src-ceph\\\"], [\\\"z\\\"]]}], {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, [\\\"/etc/pki/CA/cacert.pem:/etc/pki/CA/cacert.pem:ro\\\", \\\"/etc/pki/libvirt:/etc/pki/libvirt:ro\\\", \\\"/etc/pki/qemu:/etc/pki/qemu:ro\\\"]]}, {\\\"if\\\": [\\\"memory_backing_dir_set\\\", [{\\\"str_replace\\\": {\\\"template\\\": \\\"MEMORY_BACKING_DIR:MEMORY_BACKING_DIR\\\", \\\"params\\\": {\\\"MEMORY_BACKING_DIR\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"nova::compute::libvirt::qemu::memory_backing_dir\\\"]}}}}]]}]}}, \\\"update_tasks\\\": {\\\"description\\\": \\\"Common update tasks for modular virt daemons\\\", \\\"value\\\": [{\\\"name\\\": \\\"check systemd-container package present or not\\\", \\\"package\\\": {\\\"name\\\": \\\"systemd-container\\\", \\\"state\\\": \\\"present\\\"}, \\\"check_mode\\\": true, \\\"register\\\": \\\"is_systemd_container_package\\\"}, {\\\"name\\\": \\\"download systemd-container package if not present\\\", \\\"yum\\\": {\\\"name\\\": \\\"systemd-container\\\", \\\"state\\\": \\\"present\\\", \\\"download_only\\\": true, \\\"download_dir\\\": \\\"/var/tmp/\\\"}, \\\"when\\\": \\\"is_systemd_container_package.changed\\\"}]}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/nova_libvirt_init_secret.sh\": \"#!/usr/bin/bash\\n\\nset -e\\n\\nCEPH_INFO=($*)\\n\\nif [ -z \\\"$CEPH_INFO\\\" ]; then\\n    echo \\\"error: At least one CLUSTER:CLIENT tuple must be specified\\\"\\n    exit 1\\nfi\\n\\necho \\\"------------------------------------------------\\\"\\necho \\\"Initializing virsh secrets for: ${CEPH_INFO[@]}\\\"\\n\\nfor INFO in ${CEPH_INFO[@]}; do\\n    IFS=: read CLUSTER CLIENT <<< $INFO\\n    if [ ! -f /etc/ceph/${CLUSTER}.conf ]; then\\n        echo \\\"Error: /etc/ceph/${CLUSTER}.conf was not found\\\"\\n        echo \\\"Path to nova_libvirt_init_secret was ${CEPH_INFO}\\\"\\n        exit 1\\n    fi\\n    FSID=$(awk \'$1 == \\\"fsid\\\" {print $3}\' /etc/ceph/${CLUSTER}.conf)\\n    if [ -z \\\"${FSID}\\\" ]; then\\n        echo \\\"Error: /etc/ceph/${CLUSTER}.conf contained an empty fsid definition\\\"\\n        echo \\\"Check your ceph configuration\\\"\\n        exit 1\\n    fi\\n\\n    echo \\\"--------\\\"\\n    echo \\\"Initializing the virsh secret for \'$CLUSTER\' cluster ($FSID) \'$CLIENT\' client\\\"\\n\\n    # Ensure the secret XML file exists. Puppet should have created a secret.xml\\n    # file for the first cluster\'s secret, so detect when to use that file.\\n    if grep -q $FSID /etc/nova/secret.xml; then\\n        SECRET_FILE=\\\"/etc/nova/secret.xml\\\"\\n        SECRET_NAME=\\\"client.${CLIENT} secret\\\"\\n    else\\n        SECRET_FILE=\\\"/etc/nova/${CLUSTER}-secret.xml\\\"\\n        SECRET_NAME=\\\"${CLUSTER}.client.${CLIENT} secret\\\"\\n    fi\\n\\n    if [ ! -f $SECRET_FILE ]; then\\n        echo \\\"Creating $SECRET_FILE\\\"\\n        cat <<EOF > $SECRET_FILE\\n<secret ephemeral=\'no\' private=\'no\'>\\n  <usage type=\'ceph\'>\\n    <name>${SECRET_NAME}</name>\\n  </usage>\\n  <uuid>${FSID}</uuid>\\n</secret>\\nEOF\\n    else\\n        echo \\\"The $SECRET_FILE file already exists\\\"\\n    fi\\n\\n    # Ensure the libvirt secret is defined\\n    if /usr/bin/virsh secret-list | grep -q $FSID; then\\n        echo \\\"The virsh secret for $FSID has already been defined\\\"\\n    else\\n        /usr/bin/virsh secret-define --file $SECRET_FILE\\n    fi\\n\\n    # Fetch the key from the keyring and ensure the secret is set\\n    KEY=$(awk \'$1 == \\\"key\\\" {print $3}\' /etc/ceph/${CLUSTER}.client.${CLIENT}.keyring)\\n    if /usr/bin/virsh secret-get-value $FSID 2>/dev/null | grep -q $KEY; then\\n        echo \\\"The virsh secret for $FSID has already been set\\\"\\n    else\\n        /usr/bin/virsh secret-set-value --secret $FSID --base64 $KEY\\n    fi\\ndone\\n\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack Modular Libvirt Service\\\\n\\\", \\\"parameters\\\": {\\\"ContainerNovaLibvirtImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerNovaLibvirtConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the nova_libvirt config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerNovaLibvirtUlimit\\\": {\\\"default\\\": [\\\"nofile=131072\\\", \\\"nproc=126960\\\"], \\\"description\\\": \\\"ulimit for Nova Libvirt Container\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"ContainerNovaLibvirtPidsLimit\\\": {\\\"default\\\": 65536, \\\"description\\\": \\\"Tune nova_libvirt container PID limit (set to 0 for unlimited) (defaults to 65536)\\\", \\\"type\\\": \\\"number\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"UseCustomGnuTlsQemuCryptoPolicy\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false, \\\"description\\\": \\\"If set to true, will use CustomGnuTlsQemuCryptoPolicy in crypto policy.\\\"}, \\\"CustomGnuTlsQemuCryptoPolicy\\\": {\\\"default\\\": \\\"QEMU=NONE:+ECDHE-RSA:+ECDHE-ECDSA:+RSA:+DHE-RSA:+GROUP-X25519:+GROUP-X448:+GROUP-SECP256R1:+GROUP-SECP384R1:+GROUP-SECP521R1:+GROUP-FFDHE2048:+GROUP-FFDHE3072:+GROUP-FFDHE4096:+GROUP-FFDHE6144:+GROUP-FFDHE8192:+CHACHA20-POLY1305:+AEAD:+SHA1:+SHA512:+SIGN-ECDSA-SHA256:+SIGN-ECDSA-SECP256R1-SHA256:+SIGN-ECDSA-SHA384:+SIGN-ECDSA-SECP384R1-SHA384:+SIGN-ECDSA-SHA512:+SIGN-ECDSA-SECP521R1-SHA512:+SIGN-EdDSA-Ed25519:+SIGN-EdDSA-Ed448:+SIGN-RSA-PSS-SHA256:+SIGN-RSA-PSS-SHA384:+SIGN-RSA-PSS-SHA512:+SIGN-RSA-PSS-RSAE-SHA256:+SIGN-RSA-PSS-RSAE-SHA384:+SIGN-RSA-PSS-RSAE-SHA512:+SIGN-RSA-SHA256:+SIGN-RSA-SHA384:+SIGN-RSA-SHA512:+VERS-TLS1.3:+VERS-TLS1.2:+VERS-DTLS1.2\\\", \\\"description\\\": \\\"Custom GnuTls Crypto Policy for QEMU\\\", \\\"type\\\": \\\"string\\\"}, \\\"UseTLSTransportForLiveMigration\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": true, \\\"description\\\": \\\"If set to true and if EnableInternalTLS is enabled, it will set the libvirt URI\'s transport to tls and configure the relevant keys for libvirt.\\\"}, \\\"NovaEnableRbdBackend\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to enable the Rbd backend for Nova ephemeral storage.\\\", \\\"type\\\": \\\"boolean\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"CinderEnableRbdBackend\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to enable or not the Rbd backend for Cinder\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"CephClientKey\\\": {\\\"description\\\": \\\"The Ceph client key. Can be created with ceph-authtool --gen-print-key.\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true, \\\"constraints\\\": [{\\\"allowed_pattern\\\": \\\"^[a-zA-Z0-9+/]{38}==$\\\"}]}, \\\"CephClusterFSID\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"The Ceph cluster FSID. Must be a UUID.\\\"}, \\\"CephClientUserName\\\": {\\\"default\\\": \\\"openstack\\\", \\\"type\\\": \\\"string\\\"}, \\\"CephClusterName\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"ceph\\\", \\\"description\\\": \\\"The Ceph cluster name.\\\", \\\"constraints\\\": [{\\\"allowed_pattern\\\": \\\"[a-zA-Z0-9]+\\\", \\\"description\\\": \\\"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\\\n\\\"}]}, \\\"CephConfigPath\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"/var/lib/tripleo-config/ceph\\\", \\\"description\\\": \\\"The path where the Ceph Cluster config files are stored on the host.\\\\n\\\"}, \\\"CinderRbdMultiConfig\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {}, \\\"description\\\": \\\"Dictionary of settings when configuring multiple RBD backends. The\\\\nhash key is the backend name, and the value is a dictionary of parameter\\\\nvalues unique to that backend. The following parameters are required,\\\\nand must match the corresponding value defined in CephExternalMultiConfig.\\\\n  CephClusterName (must match the CephExternalMultiConfig entry\'s \'cluster\')\\\\n  CephClusterFSID (must match the CephExternalMultiConfig entry\'s \'fsid\')\\\\nThe following parameters are optional, and override the corresponding\\\\nparameter\'s default value.\\\\n  CephClientUserName\\\\n  CinderRbdPoolName\\\\n  CinderRbdExtraPools\\\\n  CinderRbdAvailabilityZone\\\\n  CinderRbdFlattenVolumeFromSnapshot\\\\n\\\"}, \\\"UseTLSTransportForVnc\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": true, \\\"description\\\": \\\"If set to true and if EnableInternalTLS is enabled, it will enable TLS transaport for libvirt VNC and configure the relevant keys for libvirt.\\\"}, \\\"UseTLSTransportForNbd\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": true, \\\"description\\\": \\\"If set to true and if EnableInternalTLS is enabled, it will enable TLS transaport for libvirt NBD and configure the relevant keys for libvirt.\\\"}, \\\"InternalTLSCAFile\\\": {\\\"default\\\": \\\"/etc/ipa/ca.crt\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Specifies the default CA cert to use if TLS is used for services in the internal network.\\\"}, \\\"CertificateKeySize\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"2048\\\", \\\"description\\\": \\\"Specifies the private key size used when creating the certificate.\\\"}, \\\"LibvirtCertificateKeySize\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Override the private key size used when creating the certificate for this service\\\"}, \\\"QemuServerCertificateKeySize\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Override the private key size used when creating the certificate for this service\\\"}, \\\"QemuClientCertificateKeySize\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Override the private key size used when creating the certificate for this service\\\"}, \\\"LibvirtCACert\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"This specifies the CA certificate to use for TLS in libvirt. This file will be symlinked to the default CA path in libvirt, which is /etc/pki/CA/cacert.pem. Note that due to limitations GNU TLS, which is the TLS backend for libvirt, the file must be less than 65K (so we can\'t use the system\'s CA bundle). This parameter should be used if the default (which comes from the InternalTLSCAFile parameter) is not desired. The current default reflects TripleO\'s default CA, which is FreeIPA. It will only be used if internal TLS is enabled.\\\"}, \\\"QemuCACert\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"This specifies the CA certificate to use for qemu. This file will be symlinked to the default CA path, which is /etc/pki/qemu/ca-cert.pem. This parameter should be used if the default (which comes from the InternalTLSCAFile parameter) is not desired. The current default reflects TripleO\'s default CA, which is FreeIPA. It will only be used if internal TLS is enabled.\\\"}, \\\"VhostuserSocketGroup\\\": {\\\"default\\\": \\\"qemu\\\", \\\"description\\\": \\\"The vhost-user socket directory group name. Defaults to \'qemu\'. When vhostuser mode is \'dpdkvhostuserclient\' (which is the default mode), the vhost socket is created by qemu.\\\\n\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"QemuMemoryBackingDir\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Directory used for memoryBacking source if configured as file. NOTE: big files will be stored here\\\\n\\\", \\\"default\\\": \\\"\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaComputeLibvirtType\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"kvm\\\"}, \\\"LibvirtEnabledPerfEvents\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": [], \\\"description\\\": \\\"This is a performance event list which could be used as monitor. For example - ``enabled_perf_events = cmt, mbml, mbmt`` The supported events list can be found in https://libvirt.org/html/libvirt-libvirt-domain.html , which you may need to search key words ``VIR_PERF_PARAM_*``\\\"}, \\\"MonitoringSubscriptionNovaLibvirt\\\": {\\\"default\\\": \\\"overcloud-nova-libvirt\\\", \\\"type\\\": \\\"string\\\"}, \\\"MigrationSshKey\\\": {\\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"SSH key for migration. Expects a dictionary with keys \'public_key\' and \'private_key\'. Values should be identical to SSH public/private key files.\\\\n\\\", \\\"default\\\": {\\\"public_key\\\": \\\"\\\", \\\"private_key\\\": \\\"\\\"}}, \\\"MigrationSshPort\\\": {\\\"default\\\": 2022, \\\"description\\\": \\\"Target port for migration over ssh\\\", \\\"type\\\": \\\"number\\\"}, \\\"LibvirtTLSPassword\\\": {\\\"description\\\": \\\"The password for the libvirt service when TLS is enabled\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"QemuDefaultTLSVerify\\\": {\\\"description\\\": \\\"Whether to enable or disable TLS client certificate verification. Enabling this option will reject any client who does not have a certificate signed by the CA in /etc/pki/qemu/ca-cert.pem\\\\n\\\", \\\"default\\\": true, \\\"type\\\": \\\"boolean\\\"}, \\\"LibvirtLogFilters\\\": {\\\"description\\\": \\\"Defines a filter in libvirt daemon to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"1:libvirt 1:qemu 1:conf 1:security 3:event 3:json 3:file 3:object 1:util\\\"}, \\\"LibvirtVirtlogdLogFilters\\\": {\\\"description\\\": \\\"Defines a filter in virtlogd to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"1:logging 4:object 4:json 4:event 1:util\\\"}, \\\"LibvirtVirtsecretdLogFilters\\\": {\\\"description\\\": \\\"Defines a filter in virtsecretd to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\\\"}, \\\"LibvirtVirtnodedevdLogFilters\\\": {\\\"description\\\": \\\"Defines a filter in virtnodedevd to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\\\"}, \\\"LibvirtVirtstoragedLogFilters\\\": {\\\"description\\\": \\\"Defines a filter in virtstoraged to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\\\"}, \\\"LibvirtVirtqemudLogFilters\\\": {\\\"description\\\": \\\"Defines a filter in virtqemud to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\\\"}, \\\"LibvirtVirtproxydLogFilters\\\": {\\\"description\\\": \\\"Defines a filter in virtproxyd to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\\\"}, \\\"LibvirtTLSPriority\\\": {\\\"description\\\": \\\"Override the compile time default TLS priority string.\\\\n\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"NORMAL:-VERS-SSL3.0:-VERS-TLS-ALL:+VERS-TLS1.2\\\"}, \\\"NovaLibvirtOptVolumes\\\": {\\\"default\\\": [], \\\"description\\\": \\\"list of optional volumes to be mounted\\\", \\\"type\\\": \\\"comma_delimited_list\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaEnableVirtlogdContainerWrapper\\\": {\\\"description\\\": \\\"Generate a virtlogd wrapper script so that virtlogd launches in a separate container and won\'t get restarted e.g. on minor updates.\\\", \\\"type\\\": \\\"boolean\\\", \\\"default\\\": true}, \\\"VirtlogdWrapperDebug\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false, \\\"description\\\": \\\"Controls debugging for the wrapper scripts.\\\"}, \\\"DeployIdentifier\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\\\n\\\"}, \\\"RbdDiskCachemodes\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": [\\\"network=writeback\\\"], \\\"description\\\": \\\"Disk cachemodes for RBD backend.\\\\n\\\"}}, \\\"conditions\\\": {\\\"use_tls_for_live_migration\\\": {\\\"and\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, {\\\"get_param\\\": \\\"UseTLSTransportForLiveMigration\\\"}]}, \\\"libvirt_specific_ca_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"LibvirtCACert\\\"}, \\\"\\\"]}}, \\\"need_libvirt_secret\\\": {\\\"or\\\": [{\\\"equals\\\": [{\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"NovaEnableRbdBackend\\\"]}, true]}, {\\\"and\\\": [{\\\"equals\\\": [{\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"NovaEnableRbdBackend\\\"]}, \\\"\\\"]}, {\\\"equals\\\": [{\\\"get_param\\\": \\\"NovaEnableRbdBackend\\\"}, true]}]}, {\\\"get_param\\\": \\\"CinderEnableRbdBackend\\\"}]}, \\\"use_tls_for_vnc\\\": {\\\"and\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, {\\\"get_param\\\": \\\"UseTLSTransportForVnc\\\"}]}, \\\"libvirt_vnc_specific_ca_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"LibvirtVncCACert\\\"}, \\\"\\\"]}}, \\\"use_tls_for_nbd\\\": {\\\"and\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, {\\\"get_param\\\": \\\"UseTLSTransportForNbd\\\"}]}, \\\"qemu_specific_ca_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"QemuCACert\\\"}, \\\"\\\"]}}, \\\"key_size_libvirt_override_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"LibvirtCertificateKeySize\\\"}, \\\"\\\"]}}, \\\"key_size_qemu_client_override_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"QemuClientCertificateKeySize\\\"}, \\\"\\\"]}}, \\\"key_size_qemu_server_override_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"QemuServerCertificateKeySize\\\"}, \\\"\\\"]}}}, \\\"resources\\\": {\\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"vhostuser_socket_group\\\": \\\"VhostuserSocketGroup\\\", \\\"nova_libvirt_opt_volumes\\\": \\\"NovaLibvirtOptVolumes\\\", \\\"ContainerNovaLibvirtImage\\\": \\\"ContainerNovaLibvirtImage\\\", \\\"ContainerNovaLibvirtConfigImage\\\": \\\"ContainerNovaLibvirtConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"VhostuserSocketGroup\\\": {\\\"get_param\\\": \\\"VhostuserSocketGroup\\\"}, \\\"NovaLibvirtOptVolumes\\\": {\\\"get_param\\\": \\\"NovaLibvirtOptVolumes\\\"}, \\\"ContainerNovaLibvirtImage\\\": {\\\"get_param\\\": \\\"ContainerNovaLibvirtImage\\\"}, \\\"ContainerNovaLibvirtConfigImage\\\": {\\\"get_param\\\": \\\"ContainerNovaLibvirtConfigImage\\\"}}}]}}}, \\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"NovaLibvirtLogging\\\": {\\\"type\\\": \\\"OS::TripleO::Services::Logging::NovaLibvirt\\\"}, \\\"NovaBase\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"NovaLibvirtCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-common.yaml\\\"}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Libvirt service.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"nova_libvirt\\\", \\\"firewall_rules\\\": {\\\"200 nova_libvirt\\\": {\\\"dport\\\": [16514, \\\"61152-61215\\\", \\\"5900-6923\\\"]}}, \\\"ansible_group_vars\\\": {\\\"tripleo_nova_libvirt_virsh_container\\\": \\\"nova_virtproxyd\\\"}, \\\"monitoring_subscription\\\": {\\\"get_param\\\": \\\"MonitoringSubscriptionNovaLibvirt\\\"}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"NovaBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\"]}, {\\\"get_attr\\\": [\\\"NovaLibvirtLogging\\\", \\\"config_settings\\\"]}, {\\\"get_attr\\\": [\\\"NovaLibvirtCommon\\\", \\\"config_settings\\\"]}, {\\\"nova::compute::libvirt::manage_libvirt_services\\\": false, \\\"tripleo::profile::base::nova::virtlogd_wrapper::enable_wrapper\\\": {\\\"get_param\\\": \\\"NovaEnableVirtlogdContainerWrapper\\\"}, \\\"tripleo::profile::base::nova::virtlogd_wrapper::virtlogd_process_wrapper\\\": \\\"/var/lib/container-config-scripts/virtlogd_wrapper\\\", \\\"tripleo::profile::base::nova::virtlogd_wrapper::virtlogd_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaLibvirtImage\\\"]}, \\\"tripleo::profile::base::nova::virtlogd_wrapper::debug\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"VirtlogdWrapperDebug\\\"}, true, {\\\"get_attr\\\": [\\\"NovaBase\\\", \\\"role_data\\\", \\\"config_settings\\\", \\\"nova::logging::debug\\\"]}]}, \\\"nova::compute::libvirt::migration_support\\\": false, \\\"nova::compute::rbd::libvirt_images_rbd_ceph_conf\\\": {\\\"list_join\\\": [\\\"\\\", [\\\"/etc/ceph/\\\", {\\\"get_param\\\": \\\"CephClusterName\\\"}, \\\".conf\\\"]]}, \\\"nova::compute::rbd::libvirt_rbd_user\\\": {\\\"get_param\\\": \\\"CephClientUserName\\\"}, \\\"tripleo::profile::base::nova::compute_libvirt_shared::nova_rbd_ceph_conf_path\\\": {\\\"get_param\\\": \\\"CephConfigPath\\\"}, \\\"nova::compute::rbd::rbd_keyring\\\": {\\\"list_join\\\": [\\\".\\\", [\\\"client\\\", {\\\"get_param\\\": \\\"CephClientUserName\\\"}]]}, \\\"nova::compute::rbd::libvirt_rbd_secret_key\\\": {\\\"get_param\\\": \\\"CephClientKey\\\"}, \\\"nova::compute::rbd::libvirt_rbd_secret_uuid\\\": {\\\"get_param\\\": \\\"CephClusterFSID\\\"}, \\\"tripleo::profile::base::nova::migration::client::libvirt_enabled\\\": true, \\\"tripleo::profile::base::nova::migration::client::ssh_private_key\\\": {\\\"get_param\\\": [\\\"MigrationSshKey\\\", \\\"private_key\\\"]}, \\\"tripleo::profile::base::nova::migration::client::ssh_port\\\": {\\\"get_param\\\": \\\"MigrationSshPort\\\"}, \\\"nova::compute::libvirt::services::libvirt_virt_type\\\": {\\\"get_param\\\": \\\"NovaComputeLibvirtType\\\"}, \\\"nova::compute::libvirt::virt_type\\\": {\\\"get_param\\\": \\\"NovaComputeLibvirtType\\\"}, \\\"nova::compute::libvirt::enabled_perf_events\\\": {\\\"get_param\\\": \\\"LibvirtEnabledPerfEvents\\\"}, \\\"nova::compute::libvirt::qemu::configure_qemu\\\": true, \\\"nova::compute::libvirt::qemu::max_files\\\": 32768, \\\"nova::compute::libvirt::qemu::max_processes\\\": 131072, \\\"nova::migration::qemu::configure_qemu\\\": true, \\\"nova::migration::qemu::migration_port_min\\\": 61152, \\\"nova::migration::qemu::migration_port_max\\\": 61215, \\\"nova::compute::libvirt::vncserver_listen\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaLibvirtNetwork\\\"]}}}}, \\\"nova::compute::libvirt::log_filters\\\": {\\\"get_param\\\": \\\"LibvirtLogFilters\\\"}, \\\"nova::compute::libvirt::virtlogd::log_filters\\\": {\\\"get_param\\\": \\\"LibvirtVirtlogdLogFilters\\\"}, \\\"rbd_persistent_storage\\\": {\\\"get_param\\\": \\\"CinderEnableRbdBackend\\\"}, \\\"rbd_disk_cachemodes\\\": {\\\"get_param\\\": \\\"RbdDiskCachemodes\\\"}, \\\"nova::compute::libvirt::virtsecretd::log_filters\\\": {\\\"get_param\\\": \\\"LibvirtVirtsecretdLogFilters\\\"}, \\\"nova::compute::libvirt::virtnodedevd::log_filters\\\": {\\\"get_param\\\": \\\"LibvirtVirtnodedevdLogFilters\\\"}, \\\"nova::compute::libvirt::virtstoraged::log_filters\\\": {\\\"get_param\\\": \\\"LibvirtVirtstoragedLogFilters\\\"}, \\\"nova::compute::libvirt::virtqemud::log_filters\\\": {\\\"get_param\\\": \\\"LibvirtVirtqemudLogFilters\\\"}, \\\"nova::compute::libvirt::virtproxyd::log_filters\\\": {\\\"get_param\\\": \\\"LibvirtVirtproxydLogFilters\\\"}, \\\"tripleo::profile::base::nova::libvirt::modular_libvirt\\\": true, \\\"nova::compute::libvirt::services::modular_libvirt\\\": true, \\\"nova::compute::libvirt::modular_libvirt\\\": true, \\\"nova::migration::libvirt::modular_libvirt\\\": true}, {\\\"if\\\": [\\\"use_tls_for_live_migration\\\", {\\\"tripleo::profile::base::nova::migration::client::libvirt_tls\\\": true, \\\"tripleo::profile::base::nova::libvirt::tls_password\\\": {\\\"get_param\\\": [\\\"LibvirtTLSPassword\\\"]}, \\\"nova::compute::libvirt::qemu::default_tls_verify\\\": {\\\"get_param\\\": \\\"QemuDefaultTLSVerify\\\"}, \\\"nova::compute::libvirt::tls_priority\\\": {\\\"get_param\\\": \\\"LibvirtTLSPriority\\\"}, \\\"nova::migration::libvirt::listen_address\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaLibvirtNetwork\\\"]}}}}, \\\"nova::migration::libvirt::live_migration_inbound_addr\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'fqdn_$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaLibvirtNetwork\\\"]}}}}}, {\\\"nova::migration::libvirt::live_migration_inbound_addr\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'fqdn_$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaLibvirtNetwork\\\"]}}}}}]}, {\\\"if\\\": [\\\"use_tls_for_vnc\\\", {\\\"nova::compute::libvirt::qemu::vnc_tls\\\": true, \\\"nova::compute::libvirt::qemu::vnc_tls_verify\\\": true}]}, {\\\"if\\\": [\\\"use_tls_for_nbd\\\", {\\\"nova::compute::libvirt::qemu::nbd_tls\\\": true, \\\"nova::migration::libvirt::live_migration_with_native_tls\\\": true}]}]}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"nova_libvirt\\\", \\\"puppet_tags\\\": \\\"libvirtd_config,virtlogd_config,virtproxyd_config,virtqemud_config,virtnodedevd_config,virtsecretd_config,virtstoraged_config,nova_config,file,libvirt_tls_password\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::nova::libvirt\\\\n\\\", \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaLibvirtConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/nova_virtlogd.json\\\": {\\\"command\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"NovaEnableVirtlogdContainerWrapper\\\"}, \\\"/usr/local/bin/virtlogd_wrapper\\\", \\\"/usr/sbin/virtlogd --config /etc/libvirt/virtlogd.conf\\\"]}, \\\"config_files\\\": {\\\"get_attr\\\": [\\\"NovaLibvirtCommon\\\", \\\"kolla_config_files\\\"]}, \\\"permissions\\\": {\\\"get_attr\\\": [\\\"NovaLibvirtCommon\\\", \\\"kolla_permissions\\\"]}}, \\\"/var/lib/kolla/config_files/nova_virtsecretd.json\\\": {\\\"command\\\": \\\"/usr/sbin/virtsecretd --config /etc/libvirt/virtsecretd.conf\\\", \\\"config_files\\\": {\\\"get_attr\\\": [\\\"NovaLibvirtCommon\\\", \\\"kolla_config_files\\\"]}, \\\"permissions\\\": {\\\"get_attr\\\": [\\\"NovaLibvirtCommon\\\", \\\"kolla_permissions\\\"]}}, \\\"/var/lib/kolla/config_files/nova_virtnodedevd.json\\\": {\\\"command\\\": \\\"/usr/sbin/virtnodedevd --config /etc/libvirt/virtnodedevd.conf\\\", \\\"config_files\\\": {\\\"get_attr\\\": [\\\"NovaLibvirtCommon\\\", \\\"kolla_config_files\\\"]}, \\\"permissions\\\": {\\\"get_attr\\\": [\\\"NovaLibvirtCommon\\\", \\\"kolla_permissions\\\"]}}, \\\"/var/lib/kolla/config_files/nova_virtstoraged.json\\\": {\\\"command\\\": \\\"/usr/sbin/virtstoraged --config /etc/libvirt/virtstoraged.conf\\\", \\\"config_files\\\": {\\\"get_attr\\\": [\\\"NovaLibvirtCommon\\\", \\\"kolla_config_files\\\"]}, \\\"permissions\\\": {\\\"get_attr\\\": [\\\"NovaLibvirtCommon\\\", \\\"kolla_permissions\\\"]}}, \\\"/var/lib/kolla/config_files/nova_virtqemud.json\\\": {\\\"command\\\": \\\"/usr/sbin/virtqemud --config /etc/libvirt/virtqemud.conf\\\", \\\"config_files\\\": {\\\"get_attr\\\": [\\\"NovaLibvirtCommon\\\", \\\"kolla_config_files\\\"]}, \\\"permissions\\\": {\\\"get_attr\\\": [\\\"NovaLibvirtCommon\\\", \\\"kolla_permissions\\\"]}}, \\\"/var/lib/kolla/config_files/nova_virtproxyd.json\\\": {\\\"command\\\": \\\"/usr/sbin/virtproxyd --config /etc/libvirt/virtproxyd.conf\\\", \\\"config_files\\\": {\\\"get_attr\\\": [\\\"NovaLibvirtCommon\\\", \\\"kolla_config_files\\\"]}, \\\"permissions\\\": {\\\"get_attr\\\": [\\\"NovaLibvirtCommon\\\", \\\"kolla_permissions\\\"]}}}, \\\"container_config_scripts\\\": {\\\"nova_libvirt_init_secret.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": {\\\"get_file\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/nova_libvirt_init_secret.sh\\\"}}}, \\\"docker_config\\\": {\\\"step_2\\\": {\\\"nova_virtqemud_init_logs\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaLibvirtImage\\\"]}, \\\"net\\\": \\\"none\\\", \\\"privileged\\\": true, \\\"security_opt\\\": [\\\"label=level:s0\\\", \\\"label=type:spc_t\\\", \\\"label=filetype:container_file_t\\\"], \\\"user\\\": \\\"root\\\", \\\"volumes\\\": [\\\"/var/log/containers/libvirt/swtpm:/var/log/swtpm:shared,z\\\"], \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R tss:tss /var/log/swtpm\\\"], \\\"environment\\\": {\\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}}}, \\\"create_virtlogd_wrapper\\\": {\\\"start_order\\\": 1, \\\"detach\\\": false, \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"user\\\": \\\"root\\\", \\\"command\\\": {\\\"list_concat\\\": [[\\\"/container_puppet_apply.sh\\\", \\\"4\\\", \\\"file\\\", \\\"include ::tripleo::profile::base::nova::virtlogd_wrapper\\\"]]}, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaLibvirtImage\\\"]}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"container_puppet_apply_volumes\\\"]}, [\\\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:shared,z\\\"]]}, \\\"environment\\\": {\\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}}}}, \\\"step_3\\\": {\\\"map_merge\\\": [{\\\"if\\\": [{\\\"get_param\\\": \\\"NovaEnableVirtlogdContainerWrapper\\\"}, {\\\"nova_virtlogd_wrapper\\\": {\\\"start_order\\\": 0, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaLibvirtImage\\\"]}, \\\"ulimit\\\": {\\\"get_param\\\": \\\"ContainerNovaLibvirtUlimit\\\"}, \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"security_opt\\\": [\\\"label=level:s0\\\", \\\"label=type:spc_t\\\", \\\"label=filetype:container_file_t\\\"], \\\"restart\\\": \\\"always\\\", \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"NovaLibvirtLogging\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"NovaLibvirtCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/nova_virtlogd.json:/var/lib/kolla/config_files/config.json:ro\\\"], {\\\"if\\\": [{\\\"get_param\\\": \\\"NovaEnableVirtlogdContainerWrapper\\\"}, [\\\"/var/lib/container-config-scripts/virtlogd_wrapper:/usr/local/bin/virtlogd_wrapper:ro\\\"]]}]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}, {\\\"nova_virtlogd\\\": {\\\"start_order\\\": 0, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaLibvirtImage\\\"]}, \\\"ulimit\\\": {\\\"get_param\\\": \\\"ContainerNovaLibvirtUlimit\\\"}, \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"security_opt\\\": [\\\"label=level:s0\\\", \\\"label=type:spc_t\\\", \\\"label=filetype:container_file_t\\\"], \\\"restart\\\": \\\"always\\\", \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"NovaLibvirtLogging\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"NovaLibvirtCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/nova_virtlogd.json:/var/lib/kolla/config_files/config.json:ro\\\"], {\\\"if\\\": [{\\\"get_param\\\": \\\"NovaEnableVirtlogdContainerWrapper\\\"}, [\\\"/var/lib/container-config-scripts/virtlogd_wrapper:/usr/local/bin/virtlogd_wrapper:ro\\\"]]}]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}]}, {\\\"nova_virtsecretd\\\": {\\\"start_order\\\": 1, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaLibvirtImage\\\"]}, \\\"ulimit\\\": {\\\"get_param\\\": \\\"ContainerNovaLibvirtUlimit\\\"}, \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"pids_limit\\\": {\\\"get_param\\\": \\\"ContainerNovaLibvirtPidsLimit\\\"}, \\\"privileged\\\": true, \\\"security_opt\\\": [\\\"label=level:s0\\\", \\\"label=type:spc_t\\\", \\\"label=filetype:container_file_t\\\"], \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": [{\\\"if\\\": [{\\\"get_param\\\": \\\"NovaEnableVirtlogdContainerWrapper\\\"}, \\\"tripleo_nova_virtlogd_wrapper.service\\\", \\\"tripleo_nova_virtlogd.service\\\"]}], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"NovaLibvirtLogging\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"NovaLibvirtCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"nova_libvirt_opt_volumes\\\"]}, [\\\"/var/lib/kolla/config_files/nova_virtsecretd.json:/var/lib/kolla/config_files/config.json:ro\\\"]]}}}, {\\\"nova_virtnodedevd\\\": {\\\"start_order\\\": 2, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaLibvirtImage\\\"]}, \\\"ulimit\\\": {\\\"get_param\\\": \\\"ContainerNovaLibvirtUlimit\\\"}, \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"pids_limit\\\": {\\\"get_param\\\": \\\"ContainerNovaLibvirtPidsLimit\\\"}, \\\"privileged\\\": true, \\\"security_opt\\\": [\\\"label=level:s0\\\", \\\"label=type:spc_t\\\", \\\"label=filetype:container_file_t\\\"], \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": [{\\\"if\\\": [{\\\"get_param\\\": \\\"NovaEnableVirtlogdContainerWrapper\\\"}, \\\"tripleo_nova_virtlogd_wrapper.service\\\", \\\"tripleo_nova_virtlogd.service\\\"]}], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"NovaLibvirtLogging\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"NovaLibvirtCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"nova_libvirt_opt_volumes\\\"]}, [\\\"/var/lib/kolla/config_files/nova_virtnodedevd.json:/var/lib/kolla/config_files/config.json:ro\\\"]]}}}, {\\\"nova_virtstoraged\\\": {\\\"start_order\\\": 3, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaLibvirtImage\\\"]}, \\\"ulimit\\\": {\\\"get_param\\\": \\\"ContainerNovaLibvirtUlimit\\\"}, \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"pids_limit\\\": {\\\"get_param\\\": \\\"ContainerNovaLibvirtPidsLimit\\\"}, \\\"privileged\\\": true, \\\"security_opt\\\": [\\\"label=level:s0\\\", \\\"label=type:spc_t\\\", \\\"label=filetype:container_file_t\\\"], \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": [{\\\"if\\\": [{\\\"get_param\\\": \\\"NovaEnableVirtlogdContainerWrapper\\\"}, \\\"tripleo_nova_virtlogd_wrapper.service\\\", \\\"tripleo_nova_virtlogd.service\\\"]}], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"NovaLibvirtLogging\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"NovaLibvirtCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"nova_libvirt_opt_volumes\\\"]}, [\\\"/var/lib/kolla/config_files/nova_virtstoraged.json:/var/lib/kolla/config_files/config.json:ro\\\"]]}}}, {\\\"nova_virtqemud\\\": {\\\"start_order\\\": 4, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaLibvirtImage\\\"]}, \\\"ulimit\\\": {\\\"get_param\\\": \\\"ContainerNovaLibvirtUlimit\\\"}, \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"pids_limit\\\": {\\\"get_param\\\": \\\"ContainerNovaLibvirtPidsLimit\\\"}, \\\"privileged\\\": true, \\\"security_opt\\\": [\\\"label=level:s0\\\", \\\"label=type:spc_t\\\", \\\"label=filetype:container_file_t\\\"], \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": [{\\\"if\\\": [{\\\"get_param\\\": \\\"NovaEnableVirtlogdContainerWrapper\\\"}, \\\"tripleo_nova_virtlogd_wrapper.service\\\", \\\"tripleo_nova_virtlogd.service\\\"]}], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"NovaLibvirtLogging\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"NovaLibvirtCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"nova_libvirt_opt_volumes\\\"]}, [\\\"/var/lib/kolla/config_files/nova_virtqemud.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/log/containers/libvirt/swtpm:/var/log/swtpm:z\\\", {\\\"if\\\": [{\\\"get_param\\\": \\\"UseCustomGnuTlsQemuCryptoPolicy\\\"}, \\\"/etc/crypto-policies:/etc/crypto-policies:ro\\\"]}]]}}}, {\\\"nova_virtproxyd\\\": {\\\"start_order\\\": 5, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaLibvirtImage\\\"]}, \\\"ulimit\\\": {\\\"get_param\\\": \\\"ContainerNovaLibvirtUlimit\\\"}, \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"pids_limit\\\": {\\\"get_param\\\": \\\"ContainerNovaLibvirtPidsLimit\\\"}, \\\"privileged\\\": true, \\\"security_opt\\\": [\\\"label=level:s0\\\", \\\"label=type:spc_t\\\", \\\"label=filetype:container_file_t\\\"], \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": [{\\\"if\\\": [{\\\"get_param\\\": \\\"NovaEnableVirtlogdContainerWrapper\\\"}, \\\"tripleo_nova_virtlogd_wrapper.service\\\", \\\"tripleo_nova_virtlogd.service\\\"]}], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"NovaLibvirtLogging\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"NovaLibvirtCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"nova_libvirt_opt_volumes\\\"]}, [\\\"/var/lib/kolla/config_files/nova_virtproxyd.json:/var/lib/kolla/config_files/config.json:ro\\\"]]}}}]}, \\\"step_4\\\": {\\\"if\\\": [\\\"need_libvirt_secret\\\", {\\\"nova_libvirt_init_secret\\\": {\\\"detach\\\": false, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaLibvirtImage\\\"]}, \\\"security_opt\\\": [\\\"label=disable\\\"], \\\"privileged\\\": false, \\\"user\\\": \\\"root\\\", \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"environment\\\": {\\\"LIBVIRT_DEFAULT_URI\\\": \\\"qemu:///system\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/config-data/puppet-generated/nova_libvirt/etc/nova:/etc/nova\\\", \\\"/etc/libvirt:/etc/libvirt\\\", \\\"/run/libvirt:/run/libvirt:shared,z\\\", \\\"/var/lib/libvirt:/var/lib/libvirt:shared\\\", \\\"/var/lib/container-config-scripts/nova_libvirt_init_secret.sh:/nova_libvirt_init_secret.sh:ro\\\", {\\\"str_replace\\\": {\\\"template\\\": \\\"HOST_CEPH:/etc/ceph:ro\\\", \\\"params\\\": {\\\"HOST_CEPH\\\": {\\\"get_param\\\": \\\"CephConfigPath\\\"}}}}]]}, \\\"command\\\": {\\\"list_join\\\": [\\\" \\\", [{\\\"str_replace\\\": {\\\"template\\\": \\\"/nova_libvirt_init_secret.sh CLUSTER:USER\\\", \\\"params\\\": {\\\"CLUSTER\\\": {\\\"get_param\\\": \\\"CephClusterName\\\"}, \\\"USER\\\": {\\\"get_param\\\": \\\"CephClientUserName\\\"}}}}], {\\\"repeat\\\": {\\\"template\\\": \\\"<%ceph_info%>\\\", \\\"for_each\\\": {\\\"<%ceph_info%>\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"let(u => $.data.default_user) -> $.data.multiconfig.values().select($.CephClusterName + \\\\\\\":\\\\\\\" + $.get(\\\\\\\"CephClientUserName\\\\\\\", $u))\\\", \\\"data\\\": {\\\"default_user\\\": {\\\"get_param\\\": \\\"CephClientUserName\\\"}, \\\"multiconfig\\\": {\\\"get_param\\\": \\\"CinderRbdMultiConfig\\\"}}}}}}}]}}}]}}, \\\"deploy_steps_tasks\\\": {\\\"list_concat\\\": [[{\\\"name\\\": \\\"Ensure recovery of containerized virtqemud\\\", \\\"when\\\": \\\"step|int == 4\\\", \\\"become\\\": true, \\\"block\\\": [{\\\"name\\\": \\\"Create virtqemud recovery script\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/usr/libexec/recover_tripleo_nova_virtqemud.sh\\\", \\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/bin/bash\\\\npgrep -f /sbin/virtqemud\\\\n[ $? -eq 0 ] && exit 0\\\\nkill -9 $(cat /run/nova_virtqemud.pid)\\\\n\\\"}}, {\\\"name\\\": \\\"Create virtqemud recovery trigger service\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/tripleo_nova_virtqemud_recover.service\\\", \\\"mode\\\": \\\"0644\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Check and recover tripleo_nova_virtqemud\\\\nAfter=tripleo_nova_virtqemud.service\\\\nRequisite=tripleo_nova_virtqemud.service\\\\n[Service]\\\\nType=oneshot\\\\nExecStart=bash /usr/libexec/recover_tripleo_nova_virtqemud.sh\\\\nSyslogIdentifier=recover_tripleo_nova_virtqemud\\\\n[Install]\\\\nWantedBy=multi-user.target\\\\n\\\"}}, {\\\"name\\\": \\\"Create virtqemud recovery trigger timer\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/tripleo_nova_virtqemud_recover.timer\\\", \\\"mode\\\": \\\"0644\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Check and recover tripleo_nova_virtqemud every 10m\\\\nPartOf=tripleo_nova_virtqemud.service\\\\n[Timer]\\\\nOnCalendar=*:5/10\\\\nOnActiveSec=120\\\\nOnUnitActiveSec=60\\\\nRandomizedDelaySec=1m\\\\n[Install]\\\\nWantedBy=timers.target\\\\n\\\"}}, {\\\"name\\\": \\\"Enable virtqemud recovery trigger service\\\", \\\"systemd\\\": {\\\"name\\\": \\\"tripleo_nova_virtqemud_recover.service\\\", \\\"enabled\\\": true, \\\"daemon_reload\\\": true}}, {\\\"name\\\": \\\"Enable virtqemud recovery trigger timer\\\", \\\"systemd\\\": {\\\"name\\\": \\\"tripleo_nova_virtqemud_recover.timer\\\", \\\"enabled\\\": true, \\\"state\\\": \\\"restarted\\\", \\\"daemon_reload\\\": true}, \\\"register\\\": \\\"virtqemud_recover_timer_result\\\"}, {\\\"name\\\": \\\"Really enable virtqemud recovery trigger timer\\\", \\\"shell\\\": {\\\"cmd\\\": \\\"systemctl enable --now tripleo_nova_virtqemud_recover.timer\\\"}, \\\"when\\\": \\\"virtqemud_recover_timer_result.status.UnitFileState != \\\\\\\"enabled\\\\\\\"\\\"}]}], {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, [{\\\"name\\\": \\\"Certificate generation\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Create dirs for certificates and keys\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item }}\\\", \\\"state\\\": \\\"directory\\\", \\\"serole\\\": \\\"object_r\\\", \\\"setype\\\": \\\"cert_t\\\", \\\"seuser\\\": \\\"system_u\\\"}, \\\"with_items\\\": [\\\"/etc/pki/libvirt\\\", \\\"/etc/pki/libvirt/private\\\", \\\"/etc/pki/qemu\\\"]}, {\\\"include_role\\\": {\\\"name\\\": \\\"linux-system-roles.certificate\\\"}, \\\"vars\\\": {\\\"certificate_requests\\\": [{\\\"name\\\": \\\"libvirt-server-cert\\\", \\\"dns\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"{{fqdn_$NETWORK}}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaLibvirtNetwork\\\"]}}}}, \\\"principal\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"libvirt/{{fqdn_$NETWORK}}@{{idm_realm}}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaLibvirtNetwork\\\"]}}}}, \\\"run_after\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"# Copy cert and key to libvirt dirs\\\\ncp CACERT /etc/pki/CA/cacert.pem\\\\nchown root:root /etc/pki/CA/cacert.pem\\\\nchmod 644 /etc/pki/CA/cacert.pem\\\\ncp /etc/pki/tls/certs/libvirt-server-cert.crt /etc/pki/libvirt/servercert.pem\\\\ncp /etc/pki/tls/private/libvirt-server-cert.key /etc/pki/libvirt/private/serverkey.pem\\\\npodman exec nova_virtproxyd virt-admin server-update-tls virtproxyd || systemctl reload tripleo_nova_virtproxyd\\\\n\\\", \\\"params\\\": {\\\"CACERT\\\": {\\\"if\\\": [\\\"libvirt_specific_ca_set\\\", {\\\"get_param\\\": \\\"LibvirtCACert\\\"}, {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}]}}}}, \\\"key_size\\\": {\\\"if\\\": [\\\"key_size_libvirt_override_set\\\", {\\\"get_param\\\": \\\"LibvirtCertificateKeySize\\\"}, {\\\"get_param\\\": \\\"CertificateKeySize\\\"}]}, \\\"ca\\\": \\\"ipa\\\"}, {\\\"name\\\": \\\"libvirt-client-cert\\\", \\\"dns\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"{{fqdn_$NETWORK}}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaLibvirtNetwork\\\"]}}}}, \\\"principal\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"libvirt/{{fqdn_$NETWORK}}@{{idm_realm}}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaLibvirtNetwork\\\"]}}}}, \\\"run_after\\\": \\\"# Copy cert and key to libvirt dirs\\\\ncp /etc/pki/tls/certs/libvirt-client-cert.crt /etc/pki/libvirt/clientcert.pem\\\\ncp /etc/pki/tls/private/libvirt-client-cert.key /etc/pki/libvirt/private/clientkey.pem\\\\npodman exec nova_virtproxyd virt-admin server-update-tls virtproxyd || systemctl reload tripleo_nova_virtproxyd\\\\n\\\", \\\"key_size\\\": {\\\"if\\\": [\\\"key_size_libvirt_override_set\\\", {\\\"get_param\\\": \\\"LibvirtCertificateKeySize\\\"}, {\\\"get_param\\\": \\\"CertificateKeySize\\\"}]}, \\\"ca\\\": \\\"ipa\\\"}, {\\\"name\\\": \\\"qemu-server-cert\\\", \\\"owner\\\": \\\"root\\\", \\\"group\\\": \\\"qemu\\\", \\\"dns\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"{{fqdn_$NETWORK}}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaLibvirtNetwork\\\"]}}}}, \\\"principal\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"qemu/{{fqdn_$NETWORK}}@{{idm_realm}}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaLibvirtNetwork\\\"]}}}}, \\\"run_after\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"# Copy cert and key to qemu dir\\\\ncp CACERT /etc/pki/qemu/ca-cert.pem\\\\nchown root:root /etc/pki/qemu/ca-cert.pem\\\\nchmod 644 /etc/pki/qemu/ca-cert.pem\\\\ncp -a /etc/pki/tls/certs/qemu-server-cert.crt /etc/pki/qemu/server-cert.pem\\\\ncp -a /etc/pki/tls/private/qemu-server-cert.key /etc/pki/qemu/server-key.pem\\\\nchgrp qemu /etc/pki/qemu/server-*\\\\nchmod 0640 /etc/pki/qemu/server-cert.pem\\\\nchmod 0640 /etc/pki/qemu/server-key.pem\\\\n\\\", \\\"params\\\": {\\\"CACERT\\\": {\\\"if\\\": [\\\"qemu_specific_ca_set\\\", {\\\"get_param\\\": \\\"QemuCACert\\\"}, {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}]}}}}, \\\"key_size\\\": {\\\"if\\\": [\\\"key_size_qemu_server_override_set\\\", {\\\"get_param\\\": \\\"QemuServerCertificateKeySize\\\"}, {\\\"get_param\\\": \\\"CertificateKeySize\\\"}]}, \\\"ca\\\": \\\"ipa\\\"}, {\\\"name\\\": \\\"qemu-client-cert\\\", \\\"owner\\\": \\\"root\\\", \\\"group\\\": \\\"qemu\\\", \\\"dns\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"{{fqdn_$NETWORK}}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaLibvirtNetwork\\\"]}}}}, \\\"principal\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"qemu/{{fqdn_$NETWORK}}@{{idm_realm}}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaLibvirtNetwork\\\"]}}}}, \\\"run_after\\\": \\\"# Copy cert and key to qemu dir\\\\ncp -a /etc/pki/tls/certs/qemu-client-cert.crt /etc/pki/qemu/client-cert.pem\\\\ncp -a /etc/pki/tls/private/qemu-client-cert.key /etc/pki/qemu/client-key.pem\\\\nchgrp qemu /etc/pki/qemu/client-*\\\\nchmod 0640 /etc/pki/qemu/client-cert.pem\\\\nchmod 0640 /etc/pki/qemu/client-key.pem\\\\n\\\", \\\"key_size\\\": {\\\"if\\\": [\\\"key_size_qemu_client_override_set\\\", {\\\"get_param\\\": \\\"QemuClientCertificateKeySize\\\"}, {\\\"get_param\\\": \\\"CertificateKeySize\\\"}]}, \\\"ca\\\": \\\"ipa\\\"}]}}]}]]}, [{\\\"name\\\": \\\"Set up systemd target for libvirt services\\\", \\\"when\\\": \\\"step|int == 4\\\", \\\"block\\\": [{\\\"name\\\": \\\"Create systemd file\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/tripleo_nova_libvirt.target\\\", \\\"mode\\\": \\\"0644\\\", \\\"owner\\\": \\\"root\\\", \\\"group\\\": \\\"root\\\", \\\"content\\\": \\\"[Unit]\\\\nWants=tripleo_nova_virtsecretd.service\\\\nWants=tripleo_nova_virtnodedevd.service\\\\nWants=tripleo_nova_virtstoraged.service\\\\nWants=tripleo_nova_virtproxyd.service\\\\nWants=tripleo_nova_virtqemud.service\\\\nAfter=tripleo_nova_virtsecretd.service\\\\nAfter=tripleo_nova_virtnodedevd.service\\\\nAfter=tripleo_nova_virtstoraged.service\\\\nAfter=tripleo_nova_virtproxyd.service\\\\nAfter=tripleo_nova_virtqemud.service\\\\n\\\"}, \\\"become\\\": true, \\\"register\\\": \\\"libvirt_target_result\\\"}, {\\\"name\\\": \\\"Reload systemd\\\", \\\"systemd\\\": {\\\"name\\\": \\\"tripleo_nova_libvirt.target\\\", \\\"enabled\\\": true, \\\"state\\\": \\\"restarted\\\", \\\"daemon_reload\\\": true}, \\\"become\\\": true, \\\"when\\\": \\\"libvirt_target_result.changed\\\"}]}]]}, \\\"host_prep_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"NovaLibvirtLogging\\\", \\\"host_prep_tasks\\\"]}, [{\\\"name\\\": \\\"create libvirt persistent data directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype | default(omit) }}\\\", \\\"mode\\\": \\\"{{ item.mode | default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/etc/libvirt\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/etc/libvirt/secrets\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/etc/libvirt/qemu\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/lib/libvirt\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/cache/libvirt\\\"}, {\\\"path\\\": \\\"/var/lib/nova\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/run/libvirt\\\"}, {\\\"path\\\": \\\"/var/log/containers/libvirt/swtpm\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0770\\\"}]}, {\\\"name\\\": \\\"ensure qemu group is present on the host\\\", \\\"group\\\": {\\\"name\\\": \\\"qemu\\\", \\\"gid\\\": 107, \\\"state\\\": \\\"present\\\"}}, {\\\"name\\\": \\\"ensure qemu user is present on the host\\\", \\\"user\\\": {\\\"name\\\": \\\"qemu\\\", \\\"uid\\\": 107, \\\"group\\\": \\\"qemu\\\", \\\"state\\\": \\\"present\\\", \\\"shell\\\": \\\"/sbin/nologin\\\", \\\"comment\\\": \\\"qemu user\\\"}}, {\\\"name\\\": \\\"create directory for vhost-user sockets with qemu ownership\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/vhost_sockets\\\", \\\"state\\\": \\\"directory\\\", \\\"owner\\\": \\\"qemu\\\", \\\"group\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"vhostuser_socket_group\\\"]}, \\\"setype\\\": \\\"virt_cache_t\\\", \\\"seuser\\\": \\\"system_u\\\"}}, {\\\"name\\\": \\\"ensure ceph configurations exist\\\", \\\"file\\\": {\\\"path\\\": {\\\"get_param\\\": \\\"CephConfigPath\\\"}, \\\"state\\\": \\\"directory\\\"}}, {\\\"name\\\": \\\"check if libvirt is installed\\\", \\\"command\\\": \\\"/usr/bin/rpm -q libvirt-daemon\\\", \\\"failed_when\\\": false, \\\"register\\\": \\\"libvirt_installed\\\", \\\"check_mode\\\": false}, {\\\"name\\\": \\\"make sure libvirt services are disabled and masked\\\", \\\"service\\\": {\\\"name\\\": \\\"{{ item }}\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false, \\\"masked\\\": true, \\\"daemon_reload\\\": true}, \\\"with_items\\\": [\\\"libvirtd.service\\\", \\\"virtlogd.socket\\\"], \\\"when\\\": \\\"libvirt_installed.rc == 0\\\"}, {\\\"name\\\": \\\"ensure /run/libvirt is present upon reboot\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/tmpfiles.d/run-libvirt.conf\\\", \\\"content\\\": \\\"d /run/libvirt 0755 root root - -\\\\n\\\"}}, {\\\"name\\\": \\\"Enable os_enable_vtpm SELinux boolean for vTPM\\\", \\\"seboolean\\\": {\\\"name\\\": \\\"os_enable_vtpm\\\", \\\"persistent\\\": true, \\\"state\\\": true}, \\\"when\\\": [\\\"ansible_facts.selinux is defined\\\", \\\"ansible_facts.selinux.status == \\\\\\\"enabled\\\\\\\"\\\"]}, {\\\"if\\\": [{\\\"get_param\\\": \\\"UseCustomGnuTlsQemuCryptoPolicy\\\"}, [{\\\"name\\\": \\\"set gnutls_qemu_config_crypto_policy fact\\\", \\\"set_fact\\\": {\\\"gnutls_qemu_config_crypto_policy\\\": {\\\"get_param\\\": \\\"CustomGnuTlsQemuCryptoPolicy\\\"}}}, {\\\"name\\\": \\\"create gnutls-qemu.config\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/crypto-policies/local.d/gnutls-qemu.config\\\", \\\"mode\\\": \\\"0644\\\", \\\"owner\\\": \\\"root\\\", \\\"group\\\": \\\"root\\\", \\\"content\\\": \\\"{{ gnutls_qemu_config_crypto_policy }}\\\\n\\\"}, \\\"register\\\": \\\"update_gnutls_config\\\"}], [{\\\"name\\\": \\\"remove gnutls-qemu.config\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/crypto-policies/local.d/gnutls-qemu.config\\\", \\\"state\\\": \\\"absent\\\"}, \\\"register\\\": \\\"update_gnutls_config\\\"}]]}, {\\\"name\\\": \\\"update crypto policies\\\", \\\"command\\\": \\\"update-crypto-policies\\\", \\\"when\\\": \\\"update_gnutls_config.changed\\\"}]]}, \\\"metadata_settings\\\": {\\\"list_concat\\\": [{\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, [{\\\"service\\\": \\\"libvirt\\\", \\\"network\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaLibvirtNetwork\\\"]}, \\\"type\\\": \\\"node\\\"}, {\\\"service\\\": \\\"qemu\\\", \\\"network\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaLibvirtNetwork\\\"]}, \\\"type\\\": \\\"node\\\"}, {\\\"service\\\": \\\"libvirt-vnc\\\", \\\"network\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaLibvirtNetwork\\\"]}, \\\"type\\\": \\\"node\\\"}]]}]}, \\\"upgrade_tasks\\\": {\\\"list_concat\\\": [[{\\\"name\\\": \\\"Fail if we are on RHEL8 as this is monolithic libvirt deployment\\\", \\\"when\\\": [\\\"step|int == 0\\\", \\\"\'system_upgrade\' not in ansible_run_tags\\\", \\\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\\\"], \\\"fail\\\": {\\\"msg\\\": \\\"Use of the Modular Libvirt deployment on RHEL8 results in loss of workloads. Use NovaLibvirtLegacy in roles data.\\\"}}, {\\\"name\\\": \\\"nova_libvirt_container_tmpfile_cleanup\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Remove old tmpfiles.d config\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/tmpfiles.d/var-run-libvirt.conf\\\", \\\"state\\\": \\\"absent\\\"}}]}, {\\\"name\\\": \\\"Get container virtlogd image\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": \\\"always\\\", \\\"set_fact\\\": {\\\"virtlogd_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaLibvirtImage\\\"]}}}, {\\\"name\\\": \\\"Force pull image novalibvirt\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"containers.podman.podman_image\\\": {\\\"name\\\": \\\"{{ virtlogd_image }}\\\", \\\"force\\\": true}}, {\\\"name\\\": \\\"Diff OS release in container image and baremetal\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"shell\\\": \\\"diff /etc/redhat-release <(podman run {{ virtlogd_image }} cat /etc/redhat-release)\\\\n\\\", \\\"args\\\": {\\\"executable\\\": \\\"/bin/bash\\\"}, \\\"failed_when\\\": false, \\\"register\\\": \\\"libvirt_ubi_diff\\\"}, {\\\"name\\\": \\\"Fail if UBI of the container does not match RHEL of running host\\\", \\\"when\\\": [\\\"\'system_upgrade\' not in ansible_run_tags\\\", \\\"step|int == 1\\\", \\\"libvirt_ubi_diff.rc == 1\\\"], \\\"fail\\\": {\\\"msg\\\": \\\"The host operating system versus container UBI does not match.\\\\n{{ libvirt_ubi_diff.stdout }}\\\\nMost likely container passed to NovaLibvirt was EL8 one.\\\\nYou have to pass the correct container for container-image-prepare.\\\\nIf you would continue all running workloads would get destroyed.\\\\n\\\"}}], {\\\"if\\\": [{\\\"get_param\\\": \\\"NovaEnableVirtlogdContainerWrapper\\\"}, [{\\\"name\\\": \\\"Switch virtlogd image before system upgrade\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Get running image version\\\", \\\"shell\\\": \\\"podman ps --filter name=^nova_virtlogd$ --format \\\\\\\"{% raw %}{{ .Image }}{% endraw %}\\\\\\\"\\\\n\\\", \\\"register\\\": \\\"old_virtlogd_image\\\"}, {\\\"name\\\": \\\"Switch running image to new image in wrapper script\\\", \\\"shell\\\": \\\"set -o pipefail\\\\nsed -i -e \'s|{{ old_virtlogd_image.stdout }}|{{ virtlogd_image }}|\' /var/lib/container-config-scripts/virtlogd_wrapper\\\\n\\\", \\\"when\\\": [\\\"old_virtlogd_image.stdout != virtlogd_image\\\", \\\"old_virtlogd_image.stdout != \'\'\\\"]}]}]]}]}, \\\"update_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"NovaLibvirtCommon\\\", \\\"update_tasks\\\"]}, [{\\\"name\\\": \\\"nova_libvirt_container_tmpfile_cleanup\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Remove old tmpfiles.d config\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/tmpfiles.d/var-run-libvirt.conf\\\", \\\"state\\\": \\\"absent\\\"}}]}]]}}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack Libvirt Service\\\\n\\\", \\\"parameters\\\": {\\\"ContainerNovaLibvirtImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerNovaLibvirtConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the nova_libvirt config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerNovaLibvirtUlimit\\\": {\\\"default\\\": [\\\"nofile=131072\\\", \\\"nproc=126960\\\"], \\\"description\\\": \\\"ulimit for Nova Libvirt Container\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"ContainerNovaLibvirtPidsLimit\\\": {\\\"default\\\": 65536, \\\"description\\\": \\\"Tune nova_libvirt container PID limit (set to 0 for unlimited) (defaults to 65536)\\\", \\\"type\\\": \\\"number\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"UseTLSTransportForLiveMigration\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": true, \\\"description\\\": \\\"If set to true and if EnableInternalTLS is enabled, it will set the libvirt URI\'s transport to tls and configure the relevant keys for libvirt.\\\"}, \\\"NovaEnableRbdBackend\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to enable the Rbd backend for Nova ephemeral storage.\\\", \\\"type\\\": \\\"boolean\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"CinderEnableRbdBackend\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to enable or not the Rbd backend for Cinder\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"CephClientKey\\\": {\\\"description\\\": \\\"The Ceph client key. Can be created with ceph-authtool --gen-print-key.\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true, \\\"constraints\\\": [{\\\"allowed_pattern\\\": \\\"^[a-zA-Z0-9+/]{38}==$\\\"}]}, \\\"CephClusterFSID\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"The Ceph cluster FSID. Must be a UUID.\\\"}, \\\"CephClientUserName\\\": {\\\"default\\\": \\\"openstack\\\", \\\"type\\\": \\\"string\\\"}, \\\"CephClusterName\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"ceph\\\", \\\"description\\\": \\\"The Ceph cluster name.\\\", \\\"constraints\\\": [{\\\"allowed_pattern\\\": \\\"[a-zA-Z0-9]+\\\", \\\"description\\\": \\\"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\\\n\\\"}]}, \\\"CinderRbdMultiConfig\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {}, \\\"description\\\": \\\"Dictionary of settings when configuring multiple RBD backends. The\\\\nhash key is the backend name, and the value is a dictionary of parameter\\\\nvalues unique to that backend. The following parameters are required,\\\\nand must match the corresponding value defined in CephExternalMultiConfig.\\\\n  CephClusterName (must match the CephExternalMultiConfig entry\'s \'cluster\')\\\\n  CephClusterFSID (must match the CephExternalMultiConfig entry\'s \'fsid\')\\\\nThe following parameters are optional, and override the corresponding\\\\nparameter\'s default value.\\\\n  CephClientUserName\\\\n  CinderRbdPoolName\\\\n  CinderRbdExtraPools\\\\n  CinderRbdAvailabilityZone\\\\n  CinderRbdFlattenVolumeFromSnapshot\\\\n\\\"}, \\\"UseTLSTransportForVnc\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": true, \\\"description\\\": \\\"If set to true and if EnableInternalTLS is enabled, it will enable TLS transaport for libvirt VNC and configure the relevant keys for libvirt.\\\"}, \\\"UseTLSTransportForNbd\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": true, \\\"description\\\": \\\"If set to true and if EnableInternalTLS is enabled, it will enable TLS transaport for libvirt NBD and configure the relevant keys for libvirt.\\\"}, \\\"InternalTLSCAFile\\\": {\\\"default\\\": \\\"/etc/ipa/ca.crt\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Specifies the default CA cert to use if TLS is used for services in the internal network.\\\"}, \\\"CertificateKeySize\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"2048\\\", \\\"description\\\": \\\"Specifies the private key size used when creating the certificate.\\\"}, \\\"LibvirtCertificateKeySize\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Override the private key size used when creating the certificate for this service\\\"}, \\\"QemuServerCertificateKeySize\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Override the private key size used when creating the certificate for this service\\\"}, \\\"QemuClientCertificateKeySize\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Override the private key size used when creating the certificate for this service\\\"}, \\\"LibvirtCACert\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"This specifies the CA certificate to use for TLS in libvirt. This file will be symlinked to the default CA path in libvirt, which is /etc/pki/CA/cacert.pem. Note that due to limitations GNU TLS, which is the TLS backend for libvirt, the file must be less than 65K (so we can\'t use the system\'s CA bundle). This parameter should be used if the default (which comes from the InternalTLSCAFile parameter) is not desired. The current default reflects TripleO\'s default CA, which is FreeIPA. It will only be used if internal TLS is enabled.\\\"}, \\\"QemuCACert\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"This specifies the CA certificate to use for qemu. This file will be symlinked to the default CA path, which is /etc/pki/qemu/ca-cert.pem. This parameter should be used if the default (which comes from the InternalTLSCAFile parameter) is not desired. The current default reflects TripleO\'s default CA, which is FreeIPA. It will only be used if internal TLS is enabled.\\\"}, \\\"VhostuserSocketGroup\\\": {\\\"default\\\": \\\"qemu\\\", \\\"description\\\": \\\"The vhost-user socket directory group name. Defaults to \'qemu\'. When vhostuser mode is \'dpdkvhostuserclient\' (which is the default mode), the vhost socket is created by qemu.\\\\n\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"QemuMemoryBackingDir\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Directory used for memoryBacking source if configured as file. NOTE: big files will be stored here\\\\n\\\", \\\"default\\\": \\\"\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaComputeLibvirtType\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"kvm\\\"}, \\\"LibvirtEnabledPerfEvents\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": [], \\\"description\\\": \\\"This is a performance event list which could be used as monitor. For example - ``enabled_perf_events = cmt, mbml, mbmt`` The supported events list can be found in https://libvirt.org/html/libvirt-libvirt-domain.html , which you may need to search key words ``VIR_PERF_PARAM_*``\\\"}, \\\"MonitoringSubscriptionNovaLibvirt\\\": {\\\"default\\\": \\\"overcloud-nova-libvirt\\\", \\\"type\\\": \\\"string\\\"}, \\\"MigrationSshKey\\\": {\\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"SSH key for migration. Expects a dictionary with keys \'public_key\' and \'private_key\'. Values should be identical to SSH public/private key files.\\\\n\\\", \\\"default\\\": {\\\"public_key\\\": \\\"\\\", \\\"private_key\\\": \\\"\\\"}}, \\\"MigrationSshPort\\\": {\\\"default\\\": 2022, \\\"description\\\": \\\"Target port for migration over ssh\\\", \\\"type\\\": \\\"number\\\"}, \\\"LibvirtTLSPassword\\\": {\\\"description\\\": \\\"The password for the libvirt service when TLS is enabled\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"QemuDefaultTLSVerify\\\": {\\\"description\\\": \\\"Whether to enable or disable TLS client certificate verification. Enabling this option will reject any client who does not have a certificate signed by the CA in /etc/pki/qemu/ca-cert.pem\\\\n\\\", \\\"default\\\": true, \\\"type\\\": \\\"boolean\\\"}, \\\"LibvirtLogFilters\\\": {\\\"description\\\": \\\"Defines a filter in libvirt daemon to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"1:libvirt 1:qemu 1:conf 1:security 3:event 3:json 3:file 3:object 1:util\\\"}, \\\"LibvirtVirtlogdLogFilters\\\": {\\\"description\\\": \\\"Defines a filter in virtlogd to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"1:logging 4:object 4:json 4:event 1:util\\\"}, \\\"LibvirtTLSPriority\\\": {\\\"description\\\": \\\"Override the compile time default TLS priority string.\\\\n\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"NORMAL:-VERS-SSL3.0:-VERS-TLS-ALL:+VERS-TLS1.2\\\"}, \\\"NovaLibvirtOptVolumes\\\": {\\\"default\\\": [], \\\"description\\\": \\\"list of optional volumes to be mounted\\\", \\\"type\\\": \\\"comma_delimited_list\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"CephConfigPath\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"/var/lib/tripleo-config/ceph\\\", \\\"description\\\": \\\"The path where the Ceph Cluster config files are stored on the host.\\\\n\\\"}, \\\"NovaEnableVirtlogdContainerWrapper\\\": {\\\"description\\\": \\\"Generate a virtlogd wrapper script so that virtlogd launches in a separate container and won\'t get restarted e.g. on minor updates.\\\", \\\"type\\\": \\\"boolean\\\", \\\"default\\\": true}, \\\"VirtlogdWrapperDebug\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false, \\\"description\\\": \\\"Controls debugging for the wrapper scripts.\\\"}, \\\"DeployIdentifier\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\\\n\\\"}, \\\"RbdDiskCachemodes\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": [\\\"network=writeback\\\"], \\\"description\\\": \\\"Disk cachemodes for RBD backend.\\\\n\\\"}}, \\\"conditions\\\": {\\\"use_tls_for_live_migration\\\": {\\\"and\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, {\\\"get_param\\\": \\\"UseTLSTransportForLiveMigration\\\"}]}, \\\"libvirt_specific_ca_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"LibvirtCACert\\\"}, \\\"\\\"]}}, \\\"need_libvirt_secret\\\": {\\\"or\\\": [{\\\"equals\\\": [{\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"NovaEnableRbdBackend\\\"]}, true]}, {\\\"and\\\": [{\\\"equals\\\": [{\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"NovaEnableRbdBackend\\\"]}, \\\"\\\"]}, {\\\"get_param\\\": \\\"NovaEnableRbdBackend\\\"}]}, {\\\"get_param\\\": \\\"CinderEnableRbdBackend\\\"}]}, \\\"use_tls_for_vnc\\\": {\\\"and\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, {\\\"get_param\\\": \\\"UseTLSTransportForVnc\\\"}]}, \\\"libvirt_vnc_specific_ca_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"LibvirtVncCACert\\\"}, \\\"\\\"]}}, \\\"memory_backing_dir_set\\\": {\\\"not\\\": {\\\"and\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"QemuMemoryBackingDir\\\"}, \\\"\\\"]}, {\\\"equals\\\": [{\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"QemuMemoryBackingDir\\\"]}, \\\"\\\"]}]}}, \\\"use_tls_for_nbd\\\": {\\\"and\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, {\\\"get_param\\\": \\\"UseTLSTransportForNbd\\\"}]}, \\\"qemu_specific_ca_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"QemuCACert\\\"}, \\\"\\\"]}}, \\\"key_size_libvirt_override_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"LibvirtCertificateKeySize\\\"}, \\\"\\\"]}}, \\\"key_size_qemu_client_override_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"QemuClientCertificateKeySize\\\"}, \\\"\\\"]}}, \\\"key_size_qemu_server_override_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"QemuServerCertificateKeySize\\\"}, \\\"\\\"]}}}, \\\"resources\\\": {\\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"vhostuser_socket_group\\\": \\\"VhostuserSocketGroup\\\", \\\"nova::compute::libvirt::qemu::memory_backing_dir\\\": \\\"QemuMemoryBackingDir\\\", \\\"nova_libvirt_opt_volumes\\\": \\\"NovaLibvirtOptVolumes\\\", \\\"ContainerNovaLibvirtImage\\\": \\\"ContainerNovaLibvirtImage\\\", \\\"ContainerNovaLibvirtConfigImage\\\": \\\"ContainerNovaLibvirtConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"VhostuserSocketGroup\\\": {\\\"get_param\\\": \\\"VhostuserSocketGroup\\\"}, \\\"QemuMemoryBackingDir\\\": {\\\"get_param\\\": \\\"QemuMemoryBackingDir\\\"}, \\\"NovaLibvirtOptVolumes\\\": {\\\"get_param\\\": \\\"NovaLibvirtOptVolumes\\\"}, \\\"ContainerNovaLibvirtImage\\\": {\\\"get_param\\\": \\\"ContainerNovaLibvirtImage\\\"}, \\\"ContainerNovaLibvirtConfigImage\\\": {\\\"get_param\\\": \\\"ContainerNovaLibvirtConfigImage\\\"}}}]}}}, \\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"NovaLibvirtLogging\\\": {\\\"type\\\": \\\"OS::TripleO::Services::Logging::NovaLibvirt\\\"}, \\\"NovaBase\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"NovaLibvirtCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-common.yaml\\\"}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Libvirt service.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"nova_libvirt\\\", \\\"firewall_rules\\\": {\\\"200 nova_libvirt\\\": {\\\"dport\\\": [16514, \\\"61152-61215\\\", \\\"5900-6923\\\"]}}, \\\"ansible_group_vars\\\": {\\\"tripleo_nova_libvirt_virsh_container\\\": \\\"nova_libvirt\\\"}, \\\"monitoring_subscription\\\": {\\\"get_param\\\": \\\"MonitoringSubscriptionNovaLibvirt\\\"}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"NovaBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\"]}, {\\\"get_attr\\\": [\\\"NovaLibvirtLogging\\\", \\\"config_settings\\\"]}, {\\\"nova::compute::libvirt::manage_libvirt_services\\\": false, \\\"tripleo::profile::base::nova::virtlogd_wrapper::enable_wrapper\\\": {\\\"get_param\\\": \\\"NovaEnableVirtlogdContainerWrapper\\\"}, \\\"tripleo::profile::base::nova::virtlogd_wrapper::virtlogd_process_wrapper\\\": \\\"/var/lib/container-config-scripts/virtlogd_wrapper\\\", \\\"tripleo::profile::base::nova::virtlogd_wrapper::virtlogd_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaLibvirtImage\\\"]}, \\\"tripleo::profile::base::nova::virtlogd_wrapper::debug\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"VirtlogdWrapperDebug\\\"}, true, {\\\"get_attr\\\": [\\\"NovaBase\\\", \\\"role_data\\\", \\\"config_settings\\\", \\\"nova::logging::debug\\\"]}]}, \\\"nova::compute::libvirt::migration_support\\\": false, \\\"nova::compute::rbd::libvirt_images_rbd_ceph_conf\\\": {\\\"list_join\\\": [\\\"\\\", [\\\"/etc/ceph/\\\", {\\\"get_param\\\": \\\"CephClusterName\\\"}, \\\".conf\\\"]]}, \\\"nova::compute::rbd::libvirt_rbd_user\\\": {\\\"get_param\\\": \\\"CephClientUserName\\\"}, \\\"tripleo::profile::base::nova::compute_libvirt_shared::nova_rbd_ceph_conf_path\\\": {\\\"get_param\\\": \\\"CephConfigPath\\\"}, \\\"nova::compute::rbd::rbd_keyring\\\": {\\\"list_join\\\": [\\\".\\\", [\\\"client\\\", {\\\"get_param\\\": \\\"CephClientUserName\\\"}]]}, \\\"nova::compute::rbd::libvirt_rbd_secret_key\\\": {\\\"get_param\\\": \\\"CephClientKey\\\"}, \\\"nova::compute::rbd::libvirt_rbd_secret_uuid\\\": {\\\"get_param\\\": \\\"CephClusterFSID\\\"}, \\\"tripleo::profile::base::nova::migration::client::libvirt_enabled\\\": true, \\\"tripleo::profile::base::nova::migration::client::ssh_private_key\\\": {\\\"get_param\\\": [\\\"MigrationSshKey\\\", \\\"private_key\\\"]}, \\\"tripleo::profile::base::nova::migration::client::ssh_port\\\": {\\\"get_param\\\": \\\"MigrationSshPort\\\"}, \\\"nova::compute::libvirt::services::libvirt_virt_type\\\": {\\\"get_param\\\": \\\"NovaComputeLibvirtType\\\"}, \\\"nova::compute::libvirt::virt_type\\\": {\\\"get_param\\\": \\\"NovaComputeLibvirtType\\\"}, \\\"nova::compute::libvirt::enabled_perf_events\\\": {\\\"get_param\\\": \\\"LibvirtEnabledPerfEvents\\\"}, \\\"nova::compute::libvirt::qemu::configure_qemu\\\": true, \\\"nova::compute::libvirt::qemu::max_files\\\": 32768, \\\"nova::compute::libvirt::qemu::max_processes\\\": 131072, \\\"nova::migration::qemu::configure_qemu\\\": true, \\\"nova::migration::qemu::migration_port_min\\\": 61152, \\\"nova::migration::qemu::migration_port_max\\\": 61215, \\\"nova::compute::libvirt::vncserver_listen\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaLibvirtNetwork\\\"]}}}}, \\\"nova::compute::libvirt::log_filters\\\": {\\\"get_param\\\": \\\"LibvirtLogFilters\\\"}, \\\"nova::compute::libvirt::virtlogd::log_filters\\\": {\\\"get_param\\\": \\\"LibvirtVirtlogdLogFilters\\\"}, \\\"rbd_persistent_storage\\\": {\\\"get_param\\\": \\\"CinderEnableRbdBackend\\\"}, \\\"rbd_disk_cachemodes\\\": {\\\"get_param\\\": \\\"RbdDiskCachemodes\\\"}, \\\"tripleo::profile::base::nova::libvirt::modular_libvirt\\\": false, \\\"nova::compute::libvirt::services::modular_libvirt\\\": false, \\\"nova::compute::libvirt::modular_libvirt\\\": false, \\\"nova::migration::libvirt::modular_libvirt\\\": false}, {\\\"if\\\": [\\\"use_tls_for_live_migration\\\", {\\\"tripleo::profile::base::nova::migration::client::libvirt_tls\\\": true, \\\"tripleo::profile::base::nova::libvirt::tls_password\\\": {\\\"get_param\\\": [\\\"LibvirtTLSPassword\\\"]}, \\\"nova::compute::libvirt::qemu::default_tls_verify\\\": {\\\"get_param\\\": \\\"QemuDefaultTLSVerify\\\"}, \\\"nova::compute::libvirt::tls_priority\\\": {\\\"get_param\\\": \\\"LibvirtTLSPriority\\\"}, \\\"nova::migration::libvirt::listen_address\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaLibvirtNetwork\\\"]}}}}, \\\"nova::migration::libvirt::live_migration_inbound_addr\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'fqdn_$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaLibvirtNetwork\\\"]}}}}}, {\\\"nova::migration::libvirt::live_migration_inbound_addr\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'fqdn_$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaLibvirtNetwork\\\"]}}}}}]}, {\\\"if\\\": [\\\"use_tls_for_vnc\\\", {\\\"nova::compute::libvirt::qemu::vnc_tls\\\": true, \\\"nova::compute::libvirt::qemu::vnc_tls_verify\\\": true}]}, {\\\"if\\\": [\\\"use_tls_for_nbd\\\", {\\\"nova::compute::libvirt::qemu::nbd_tls\\\": true, \\\"nova::migration::libvirt::live_migration_with_native_tls\\\": true}]}]}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"nova_libvirt\\\", \\\"puppet_tags\\\": \\\"libvirtd_config,virtlogd_config,nova_config,file,libvirt_tls_password\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::nova::libvirt\\\\n\\\", \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaLibvirtConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/nova_libvirt.json\\\": {\\\"command\\\": \\\"/nova_libvirt_launcher.sh\\\", \\\"config_files\\\": {\\\"list_concat\\\": [[{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-ceph/\\\", \\\"dest\\\": \\\"/etc/ceph/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]]}, \\\"permissions\\\": {\\\"list_concat\\\": [[{\\\"path\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"/etc/ceph/CLUSTER.client.USER.keyring\\\", \\\"params\\\": {\\\"CLUSTER\\\": {\\\"get_param\\\": \\\"CephClusterName\\\"}, \\\"USER\\\": {\\\"get_param\\\": \\\"CephClientUserName\\\"}}}}, \\\"owner\\\": \\\"nova:nova\\\", \\\"perm\\\": \\\"0600\\\"}], {\\\"repeat\\\": {\\\"template\\\": {\\\"path\\\": \\\"/etc/ceph/<%keyring%>\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"perm\\\": \\\"0600\\\"}, \\\"for_each\\\": {\\\"<%keyring%>\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"let(u => $.data.default_user) -> $.data.multiconfig.values().select($.CephClusterName + \\\\\\\".client.\\\\\\\" +  $.get(\\\\\\\"CephClientUserName\\\\\\\", $u) + \\\\\\\".keyring\\\\\\\")\\\", \\\"data\\\": {\\\"default_user\\\": {\\\"get_param\\\": \\\"CephClientUserName\\\"}, \\\"multiconfig\\\": {\\\"get_param\\\": \\\"CinderRbdMultiConfig\\\"}}}}}}}]}}, \\\"/var/lib/kolla/config_files/nova_virtlogd.json\\\": {\\\"command\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"NovaEnableVirtlogdContainerWrapper\\\"}, \\\"/usr/local/bin/virtlogd_wrapper\\\", \\\"/usr/sbin/virtlogd --config /etc/libvirt/virtlogd.conf\\\"]}, \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}}, \\\"container_config_scripts\\\": {\\\"nova_libvirt_launcher.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"#!/bin/bash\\\\nset -xe\\\\nif [[ -f /usr/lib/systemd/kvm-setup ]]; then\\\\n  /usr/lib/systemd/kvm-setup\\\\nfi\\\\nexec systemd-run --scope --slice=system --property=Delegate=\\\\\\\"cpu cpuacct memory blkio devices\\\\\\\" /usr/sbin/libvirtd LIBVIRTD_ARGS\\\\n\\\", \\\"params\\\": {\\\"LIBVIRTD_ARGS\\\": {\\\"if\\\": [\\\"use_tls_for_live_migration\\\", \\\"--listen\\\", \\\"\\\"]}}}}}, \\\"nova_libvirt_init_secret.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": {\\\"get_file\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/nova_libvirt_init_secret.sh\\\"}}}, \\\"docker_config\\\": {\\\"step_2\\\": {\\\"create_virtlogd_wrapper\\\": {\\\"start_order\\\": 1, \\\"detach\\\": false, \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"user\\\": \\\"root\\\", \\\"command\\\": {\\\"list_concat\\\": [[\\\"/container_puppet_apply.sh\\\", \\\"4\\\", \\\"file\\\", \\\"include ::tripleo::profile::base::nova::virtlogd_wrapper\\\"]]}, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaLibvirtImage\\\"]}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"container_puppet_apply_volumes\\\"]}, [\\\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:shared,z\\\"]]}, \\\"environment\\\": {\\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}}}}, \\\"step_3\\\": {\\\"map_merge\\\": [{\\\"if\\\": [{\\\"get_param\\\": \\\"NovaEnableVirtlogdContainerWrapper\\\"}, {\\\"nova_virtlogd_wrapper\\\": {\\\"start_order\\\": 0, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaLibvirtImage\\\"]}, \\\"ulimit\\\": {\\\"get_param\\\": \\\"ContainerNovaLibvirtUlimit\\\"}, \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"security_opt\\\": [\\\"label=level:s0\\\", \\\"label=type:spc_t\\\", \\\"label=filetype:container_file_t\\\"], \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck virtlogd\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"NovaLibvirtLogging\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/nova_virtlogd.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/dev:/dev\\\", \\\"/run:/run\\\", \\\"/sys/fs/cgroup:/sys/fs/cgroup\\\", \\\"/run/libvirt:/run/libvirt:shared,z\\\", \\\"/var/lib/libvirt:/var/lib/libvirt\\\", \\\"/etc/libvirt/qemu:/etc/libvirt/qemu:ro\\\", \\\"/var/lib/nova:/var/lib/nova:shared\\\"], {\\\"if\\\": [{\\\"get_param\\\": \\\"NovaEnableVirtlogdContainerWrapper\\\"}, [\\\"/var/lib/container-config-scripts/virtlogd_wrapper:/usr/local/bin/virtlogd_wrapper:ro\\\"]]}]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}, {\\\"nova_virtlogd\\\": {\\\"start_order\\\": 0, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaLibvirtImage\\\"]}, \\\"ulimit\\\": {\\\"get_param\\\": \\\"ContainerNovaLibvirtUlimit\\\"}, \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"security_opt\\\": [\\\"label=level:s0\\\", \\\"label=type:spc_t\\\", \\\"label=filetype:container_file_t\\\"], \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck virtlogd\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"NovaLibvirtLogging\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/nova_virtlogd.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/dev:/dev\\\", \\\"/run:/run\\\", \\\"/sys/fs/cgroup:/sys/fs/cgroup\\\", \\\"/run/libvirt:/run/libvirt:shared,z\\\", \\\"/var/lib/libvirt:/var/lib/libvirt\\\", \\\"/etc/libvirt/qemu:/etc/libvirt/qemu:ro\\\", \\\"/var/lib/nova:/var/lib/nova:shared\\\"], {\\\"if\\\": [{\\\"get_param\\\": \\\"NovaEnableVirtlogdContainerWrapper\\\"}, [\\\"/var/lib/container-config-scripts/virtlogd_wrapper:/usr/local/bin/virtlogd_wrapper:ro\\\"]]}]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}]}, {\\\"nova_libvirt\\\": {\\\"start_order\\\": 1, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaLibvirtImage\\\"]}, \\\"ulimit\\\": {\\\"get_param\\\": \\\"ContainerNovaLibvirtUlimit\\\"}, \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"pids_limit\\\": {\\\"get_param\\\": \\\"ContainerNovaLibvirtPidsLimit\\\"}, \\\"privileged\\\": true, \\\"security_opt\\\": [\\\"label=level:s0\\\", \\\"label=type:spc_t\\\", \\\"label=filetype:container_file_t\\\"], \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": [{\\\"if\\\": [{\\\"get_param\\\": \\\"NovaEnableVirtlogdContainerWrapper\\\"}, \\\"tripleo_nova_virtlogd_wrapper.service\\\", \\\"tripleo_nova_virtlogd.service\\\"]}], \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck libvirtd\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"NovaLibvirtLogging\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"nova_libvirt_opt_volumes\\\"]}, [\\\"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\\\", \\\"/var/lib/kolla/config_files/nova_libvirt.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/container-config-scripts/nova_libvirt_launcher.sh:/nova_libvirt_launcher.sh:ro\\\", {\\\"list_join\\\": [\\\":\\\", [{\\\"get_param\\\": \\\"CephConfigPath\\\"}], [\\\"/var/lib/kolla/config_files/src-ceph\\\"], [\\\"ro\\\"]]}, \\\"/lib/modules:/lib/modules:ro\\\", \\\"/dev:/dev\\\", \\\"/run:/run\\\", \\\"/sys/fs/cgroup:/sys/fs/cgroup\\\", \\\"/etc/libvirt:/etc/libvirt\\\", \\\"/run/libvirt:/run/libvirt:shared,z\\\", \\\"/var/lib/libvirt:/var/lib/libvirt:shared\\\", \\\"/var/cache/libvirt:/var/cache/libvirt:shared\\\", \\\"/var/lib/vhost_sockets:/var/lib/vhost_sockets\\\", \\\"/var/lib/nova:/var/lib/nova:shared\\\", \\\"/sys/fs/selinux:/sys/fs/selinux\\\", \\\"/etc/selinux/config:/etc/selinux/config:ro\\\"], {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, [\\\"/etc/pki/CA/cacert.pem:/etc/pki/CA/cacert.pem:ro\\\", \\\"/etc/pki/libvirt:/etc/pki/libvirt:ro\\\", \\\"/etc/pki/qemu:/etc/pki/qemu:ro\\\"]]}, {\\\"if\\\": [\\\"memory_backing_dir_set\\\", [{\\\"str_replace\\\": {\\\"template\\\": \\\"MEMORY_BACKING_DIR:MEMORY_BACKING_DIR\\\", \\\"params\\\": {\\\"MEMORY_BACKING_DIR\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"memory_backing_dir\\\"]}}}}]]}]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}]}, \\\"step_4\\\": {\\\"if\\\": [\\\"need_libvirt_secret\\\", {\\\"nova_libvirt_init_secret\\\": {\\\"detach\\\": false, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaLibvirtImage\\\"]}, \\\"security_opt\\\": [\\\"label=disable\\\"], \\\"privileged\\\": false, \\\"user\\\": \\\"root\\\", \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/config-data/puppet-generated/nova_libvirt/etc/nova:/etc/nova\\\", \\\"/etc/libvirt:/etc/libvirt\\\", \\\"/run/libvirt:/run/libvirt:shared,z\\\", \\\"/var/lib/libvirt:/var/lib/libvirt:shared\\\", \\\"/var/lib/container-config-scripts/nova_libvirt_init_secret.sh:/nova_libvirt_init_secret.sh:ro\\\", {\\\"str_replace\\\": {\\\"template\\\": \\\"HOST_CEPH:/etc/ceph:ro\\\", \\\"params\\\": {\\\"HOST_CEPH\\\": {\\\"get_param\\\": \\\"CephConfigPath\\\"}}}}]]}, \\\"command\\\": {\\\"list_join\\\": [\\\" \\\", [{\\\"str_replace\\\": {\\\"template\\\": \\\"/nova_libvirt_init_secret.sh CLUSTER:USER\\\", \\\"params\\\": {\\\"CLUSTER\\\": {\\\"get_param\\\": \\\"CephClusterName\\\"}, \\\"USER\\\": {\\\"get_param\\\": \\\"CephClientUserName\\\"}}}}], {\\\"repeat\\\": {\\\"template\\\": \\\"<%ceph_info%>\\\", \\\"for_each\\\": {\\\"<%ceph_info%>\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"let(u => $.data.default_user) -> $.data.multiconfig.values().select($.CephClusterName + \\\\\\\":\\\\\\\" + $.get(\\\\\\\"CephClientUserName\\\\\\\", $u))\\\", \\\"data\\\": {\\\"default_user\\\": {\\\"get_param\\\": \\\"CephClientUserName\\\"}, \\\"multiconfig\\\": {\\\"get_param\\\": \\\"CinderRbdMultiConfig\\\"}}}}}}}]}}}]}}, \\\"deploy_steps_tasks\\\": {\\\"list_concat\\\": [[{\\\"name\\\": \\\"validate nova-libvirt container state\\\", \\\"containers.podman.podman_container_info\\\": {\\\"name\\\": \\\"nova_libvirt\\\"}, \\\"register\\\": \\\"nova_libvirt_infos\\\", \\\"failed_when\\\": [\\\"nova_libvirt_infos.containers.0.Healthcheck.Status is defined\\\", \\\"\'healthy\' not in nova_libvirt_infos.containers.0.Healthcheck.Status\\\"], \\\"retries\\\": 10, \\\"delay\\\": 30, \\\"tags\\\": [\\\"opendev-validation\\\", \\\"opendev-validation-nova\\\"], \\\"when\\\": [\\\"container_cli == \'podman\'\\\", \\\"not container_healthcheck_disabled\\\", \\\"step|int == 4\\\"]}, {\\\"name\\\": \\\"Set up systemd target for libvirt services\\\", \\\"when\\\": \\\"step|int == 4\\\", \\\"block\\\": [{\\\"name\\\": \\\"Create systemd file\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/tripleo_nova_libvirt.target\\\", \\\"mode\\\": \\\"0644\\\", \\\"owner\\\": \\\"root\\\", \\\"group\\\": \\\"root\\\", \\\"content\\\": \\\"[Unit]\\\\nWants=tripleo_nova_libvirt.service\\\\nAfter=tripleo_nova_libvirt.service\\\\n\\\"}, \\\"become\\\": true, \\\"register\\\": \\\"libvirt_target_result\\\"}, {\\\"name\\\": \\\"Reload systemd\\\", \\\"systemd\\\": {\\\"name\\\": \\\"tripleo_nova_libvirt.target\\\", \\\"enabled\\\": true, \\\"state\\\": \\\"restarted\\\", \\\"daemon_reload\\\": true}, \\\"become\\\": true, \\\"when\\\": \\\"libvirt_target_result.changed\\\"}]}], {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, [{\\\"name\\\": \\\"Certificate generation\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Create dirs for certificates and keys\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item }}\\\", \\\"state\\\": \\\"directory\\\", \\\"serole\\\": \\\"object_r\\\", \\\"setype\\\": \\\"cert_t\\\", \\\"seuser\\\": \\\"system_u\\\"}, \\\"with_items\\\": [\\\"/etc/pki/libvirt\\\", \\\"/etc/pki/libvirt/private\\\", \\\"/etc/pki/qemu\\\"]}, {\\\"include_role\\\": {\\\"name\\\": \\\"linux-system-roles.certificate\\\"}, \\\"vars\\\": {\\\"certificate_requests\\\": [{\\\"name\\\": \\\"libvirt-server-cert\\\", \\\"dns\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"{{fqdn_$NETWORK}}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaLibvirtNetwork\\\"]}}}}, \\\"principal\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"libvirt/{{fqdn_$NETWORK}}@{{idm_realm}}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaLibvirtNetwork\\\"]}}}}, \\\"run_after\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"# Copy cert and key to libvirt dirs\\\\ncp CACERT /etc/pki/CA/cacert.pem\\\\nchown root:root /etc/pki/CA/cacert.pem\\\\nchmod 644 /etc/pki/CA/cacert.pem\\\\ncp /etc/pki/tls/certs/libvirt-server-cert.crt /etc/pki/libvirt/servercert.pem\\\\ncp /etc/pki/tls/private/libvirt-server-cert.key /etc/pki/libvirt/private/serverkey.pem\\\\nsystemctl reload tripleo_nova_libvirt\\\\n\\\", \\\"params\\\": {\\\"CACERT\\\": {\\\"if\\\": [\\\"libvirt_specific_ca_set\\\", {\\\"get_param\\\": \\\"LibvirtCACert\\\"}, {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}]}}}}, \\\"key_size\\\": {\\\"if\\\": [\\\"key_size_libvirt_override_set\\\", {\\\"get_param\\\": \\\"LibvirtCertificateKeySize\\\"}, {\\\"get_param\\\": \\\"CertificateKeySize\\\"}]}, \\\"ca\\\": \\\"ipa\\\"}, {\\\"name\\\": \\\"libvirt-client-cert\\\", \\\"dns\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"{{fqdn_$NETWORK}}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaLibvirtNetwork\\\"]}}}}, \\\"principal\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"libvirt/{{fqdn_$NETWORK}}@{{idm_realm}}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaLibvirtNetwork\\\"]}}}}, \\\"run_after\\\": \\\"# Copy cert and key to libvirt dirs\\\\ncp /etc/pki/tls/certs/libvirt-client-cert.crt /etc/pki/libvirt/clientcert.pem\\\\ncp /etc/pki/tls/private/libvirt-client-cert.key /etc/pki/libvirt/private/clientkey.pem\\\\nsystemctl reload tripleo_nova_libvirt\\\\n\\\", \\\"key_size\\\": {\\\"if\\\": [\\\"key_size_libvirt_override_set\\\", {\\\"get_param\\\": \\\"LibvirtCertificateKeySize\\\"}, {\\\"get_param\\\": \\\"CertificateKeySize\\\"}]}, \\\"ca\\\": \\\"ipa\\\"}, {\\\"name\\\": \\\"qemu-server-cert\\\", \\\"owner\\\": \\\"root\\\", \\\"group\\\": \\\"qemu\\\", \\\"dns\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"{{fqdn_$NETWORK}}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaLibvirtNetwork\\\"]}}}}, \\\"principal\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"qemu/{{fqdn_$NETWORK}}@{{idm_realm}}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaLibvirtNetwork\\\"]}}}}, \\\"run_after\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"# Copy cert and key to qemu dir\\\\ncp CACERT /etc/pki/qemu/ca-cert.pem\\\\nchown root:root /etc/pki/qemu/ca-cert.pem\\\\nchmod 644 /etc/pki/qemu/ca-cert.pem\\\\ncp -a /etc/pki/tls/certs/qemu-server-cert.crt /etc/pki/qemu/server-cert.pem\\\\ncp -a /etc/pki/tls/private/qemu-server-cert.key /etc/pki/qemu/server-key.pem\\\\nchgrp qemu /etc/pki/qemu/server-*\\\\nchmod 0640 /etc/pki/qemu/server-cert.pem\\\\nchmod 0640 /etc/pki/qemu/server-key.pem\\\\nsystemctl reload tripleo_nova_libvirt\\\\n\\\", \\\"params\\\": {\\\"CACERT\\\": {\\\"if\\\": [\\\"qemu_specific_ca_set\\\", {\\\"get_param\\\": \\\"QemuCACert\\\"}, {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}]}}}}, \\\"key_size\\\": {\\\"if\\\": [\\\"key_size_qemu_server_override_set\\\", {\\\"get_param\\\": \\\"QemuServerCertificateKeySize\\\"}, {\\\"get_param\\\": \\\"CertificateKeySize\\\"}]}, \\\"ca\\\": \\\"ipa\\\"}, {\\\"name\\\": \\\"qemu-client-cert\\\", \\\"owner\\\": \\\"root\\\", \\\"group\\\": \\\"qemu\\\", \\\"dns\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"{{fqdn_$NETWORK}}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaLibvirtNetwork\\\"]}}}}, \\\"principal\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"qemu/{{fqdn_$NETWORK}}@{{idm_realm}}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaLibvirtNetwork\\\"]}}}}, \\\"run_after\\\": \\\"# Copy cert and key to qemu dir\\\\ncp -a /etc/pki/tls/certs/qemu-client-cert.crt /etc/pki/qemu/client-cert.pem\\\\ncp -a /etc/pki/tls/private/qemu-client-cert.key /etc/pki/qemu/client-key.pem\\\\nchgrp qemu /etc/pki/qemu/client-*\\\\nchmod 0640 /etc/pki/qemu/client-cert.pem\\\\nchmod 0640 /etc/pki/qemu/client-key.pem\\\\nsystemctl reload tripleo_nova_libvirt\\\\n\\\", \\\"key_size\\\": {\\\"if\\\": [\\\"key_size_qemu_client_override_set\\\", {\\\"get_param\\\": \\\"QemuClientCertificateKeySize\\\"}, {\\\"get_param\\\": \\\"CertificateKeySize\\\"}]}, \\\"ca\\\": \\\"ipa\\\"}]}}]}]]}]}, \\\"host_prep_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"NovaLibvirtLogging\\\", \\\"host_prep_tasks\\\"]}, [{\\\"name\\\": \\\"create libvirt persistent data directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype | default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/etc/libvirt\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/etc/libvirt/secrets\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/etc/libvirt/qemu\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/lib/libvirt\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/cache/libvirt\\\"}, {\\\"path\\\": \\\"/var/lib/nova\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/run/libvirt\\\"}]}, {\\\"name\\\": \\\"ensure qemu group is present on the host\\\", \\\"group\\\": {\\\"name\\\": \\\"qemu\\\", \\\"gid\\\": 107, \\\"state\\\": \\\"present\\\"}}, {\\\"name\\\": \\\"ensure qemu user is present on the host\\\", \\\"user\\\": {\\\"name\\\": \\\"qemu\\\", \\\"uid\\\": 107, \\\"group\\\": \\\"qemu\\\", \\\"state\\\": \\\"present\\\", \\\"shell\\\": \\\"/sbin/nologin\\\", \\\"comment\\\": \\\"qemu user\\\"}}, {\\\"name\\\": \\\"create directory for vhost-user sockets with qemu ownership\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/vhost_sockets\\\", \\\"state\\\": \\\"directory\\\", \\\"owner\\\": \\\"qemu\\\", \\\"group\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"vhostuser_socket_group\\\"]}, \\\"setype\\\": \\\"virt_cache_t\\\", \\\"seuser\\\": \\\"system_u\\\"}}, {\\\"name\\\": \\\"ensure ceph configurations exist\\\", \\\"file\\\": {\\\"path\\\": {\\\"get_param\\\": \\\"CephConfigPath\\\"}, \\\"state\\\": \\\"directory\\\"}}, {\\\"name\\\": \\\"check if libvirt is installed\\\", \\\"command\\\": \\\"/usr/bin/rpm -q libvirt-daemon\\\", \\\"failed_when\\\": false, \\\"register\\\": \\\"libvirt_installed\\\", \\\"check_mode\\\": false}, {\\\"name\\\": \\\"make sure libvirt services are disabled and masked\\\", \\\"service\\\": {\\\"name\\\": \\\"{{ item }}\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false, \\\"masked\\\": true, \\\"daemon_reload\\\": true}, \\\"with_items\\\": [\\\"libvirtd.service\\\", \\\"virtlogd.socket\\\"], \\\"when\\\": \\\"libvirt_installed.rc == 0\\\"}, {\\\"name\\\": \\\"ensure /run/libvirt is present upon reboot\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/tmpfiles.d/run-libvirt.conf\\\", \\\"content\\\": \\\"d /run/libvirt 0755 root root - -\\\\n\\\"}}, {\\\"name\\\": \\\"Enable os_enable_vtpm SELinux boolean for vTPM\\\", \\\"seboolean\\\": {\\\"name\\\": \\\"os_enable_vtpm\\\", \\\"persistent\\\": true, \\\"state\\\": true}, \\\"when\\\": [\\\"ansible_facts.selinux is defined\\\", \\\"ansible_facts.selinux.status == \\\\\\\"enabled\\\\\\\"\\\"]}]]}, \\\"metadata_settings\\\": {\\\"list_concat\\\": [{\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, [{\\\"service\\\": \\\"libvirt\\\", \\\"network\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaLibvirtNetwork\\\"]}, \\\"type\\\": \\\"node\\\"}, {\\\"service\\\": \\\"qemu\\\", \\\"network\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaLibvirtNetwork\\\"]}, \\\"type\\\": \\\"node\\\"}, {\\\"service\\\": \\\"libvirt-vnc\\\", \\\"network\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaLibvirtNetwork\\\"]}, \\\"type\\\": \\\"node\\\"}]]}]}, \\\"upgrade_tasks\\\": {\\\"list_concat\\\": [[{\\\"name\\\": \\\"Fail if we are on RHEL9 as this is monolithic libvirt deployment\\\", \\\"when\\\": [\\\"step|int == 0\\\", \\\"\'system_upgrade\' not in ansible_run_tags\\\", \\\"ansible_facts[\'distribution_major_version\'] is version(\'9\', \'==\')\\\"], \\\"fail\\\": {\\\"msg\\\": \\\"On RHEL9 use Modular Libvirt deployment. Use NovaLibvirt in roles data.\\\"}}, {\\\"name\\\": \\\"nova_libvirt_container_tmpfile_cleanup\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Remove old tmpfiles.d config\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/tmpfiles.d/var-run-libvirt.conf\\\", \\\"state\\\": \\\"absent\\\"}}]}, {\\\"name\\\": \\\"Get container virtlogd image\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": \\\"always\\\", \\\"set_fact\\\": {\\\"virtlogd_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaLibvirtImage\\\"]}}}, {\\\"name\\\": \\\"Force pull image novalibvirt\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"containers.podman.podman_image\\\": {\\\"name\\\": \\\"{{ virtlogd_image }}\\\", \\\"force\\\": true}}, {\\\"name\\\": \\\"Diff OS release in container image and baremetal\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"shell\\\": \\\"diff /etc/redhat-release <(podman run {{ virtlogd_image }} cat /etc/redhat-release)\\\\n\\\", \\\"args\\\": {\\\"executable\\\": \\\"/bin/bash\\\"}, \\\"failed_when\\\": false, \\\"register\\\": \\\"libvirt_ubi_diff\\\"}, {\\\"name\\\": \\\"Fail if UBI of the container does not match RHEL of running host\\\", \\\"when\\\": [\\\"\'system_upgrade\' not in ansible_run_tags\\\", \\\"step|int == 1\\\", \\\"libvirt_ubi_diff.rc == 1\\\"], \\\"fail\\\": {\\\"msg\\\": \\\"The host operating system versus container UBI does not match.\\\\n{{ libvirt_ubi_diff.stdout }}\\\\nMost likely container passed to NovaLibvirtLegacy was EL9 one.\\\\nYou have to pass the correct container for container-image-prepare.\\\\nIf you would continue all running workloads would get destroyed.\\\\n\\\"}}], {\\\"if\\\": [{\\\"get_param\\\": \\\"NovaEnableVirtlogdContainerWrapper\\\"}, [{\\\"name\\\": \\\"Switch virtlogd image before system upgrade\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Get running image version\\\", \\\"shell\\\": \\\"podman ps --filter name=^nova_virtlogd$ --format \\\\\\\"{% raw %}{{ .Image }}{% endraw %}\\\\\\\"\\\\n\\\", \\\"register\\\": \\\"old_virtlogd_image\\\"}, {\\\"name\\\": \\\"Switch running image to new image in wrapper script\\\", \\\"shell\\\": \\\"set -o pipefail\\\\nsed -i -e \'s|{{ old_virtlogd_image.stdout }}|{{ virtlogd_image }}|\' /var/lib/container-config-scripts/virtlogd_wrapper\\\\n\\\", \\\"when\\\": [\\\"old_virtlogd_image.stdout != virtlogd_image\\\", \\\"old_virtlogd_image.stdout != \'\'\\\"]}]}]]}]}, \\\"update_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"NovaLibvirtCommon\\\", \\\"update_tasks\\\"]}, [{\\\"name\\\": \\\"nova_libvirt_container_tmpfile_cleanup\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Remove old tmpfiles.d config\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/tmpfiles.d/var-run-libvirt.conf\\\", \\\"state\\\": \\\"absent\\\"}}]}]]}}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Configure libvirt-guests\\\\n\\\", \\\"parameters\\\": {\\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"ContainerNovaLibvirtConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the nova_libvirt config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaResumeGuestsStateOnHostBoot\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to start running instance on compute host reboot\\\", \\\"type\\\": \\\"boolean\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaResumeGuestsShutdownTimeout\\\": {\\\"default\\\": 300, \\\"description\\\": \\\"Number of seconds we\'re willing to wait for a guest to shut down. If this is 0, then there is no time out (use with caution, as guests might not respond to a shutdown request). The default value is 300 seconds (5 minutes).\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}}, \\\"resources\\\": {\\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"tripleo::profile::base::nova::compute::libvirt_guests::enabled\\\": \\\"NovaResumeGuestsStateOnHostBoot\\\", \\\"nova::compute::libvirt_guests::shutdown_timeout\\\": \\\"NovaResumeGuestsShutdownTimeout\\\", \\\"ContainerNovaLibvirtConfigImage\\\": \\\"ContainerNovaLibvirtConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"NovaResumeGuestsStateOnHostBoot\\\": {\\\"get_param\\\": \\\"NovaResumeGuestsStateOnHostBoot\\\"}, \\\"NovaResumeGuestsShutdownTimeout\\\": {\\\"get_param\\\": \\\"NovaResumeGuestsShutdownTimeout\\\"}, \\\"ContainerNovaLibvirtConfigImage\\\": {\\\"get_param\\\": \\\"ContainerNovaLibvirtConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for libvirt-guests\\\", \\\"value\\\": {\\\"service_name\\\": \\\"nova_libvirt_guests\\\", \\\"config_settings\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\"]}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"nova_libvirt\\\", \\\"puppet_tags\\\": \\\"libvirtd_config,nova_config,file,libvirt_tls_password\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::nova::compute::libvirt_guests\\\\n\\\", \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaLibvirtConfigImage\\\"]}}}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Template for nova\'s logging to files\\\\n\\\", \\\"parameters\\\": {\\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"ContainerNovaImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaServiceName\\\": {\\\"description\\\": \\\"service name\\\", \\\"type\\\": \\\"string\\\"}, \\\"DeployIdentifier\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\\\n\\\"}}, \\\"resources\\\": {\\\"InitLogContainerName\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"string\\\", \\\"value\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"nova_SERVICE_init_log\\\", \\\"params\\\": {\\\"SERVICE\\\": {\\\"get_param\\\": \\\"NovaServiceName\\\"}}}}}}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerNovaImage\\\": \\\"ContainerNovaImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerNovaImage\\\": {\\\"get_param\\\": \\\"ContainerNovaImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"cmd_extra_args\\\": {\\\"description\\\": \\\"Extra command line arguments for running the service in the container.\\\", \\\"value\\\": \\\"\\\"}, \\\"config_settings\\\": {\\\"description\\\": \\\"Extra hieradata needed to log to files in the host.\\\", \\\"value\\\": null}, \\\"volumes\\\": {\\\"description\\\": \\\"The volumes needed to log to files in the host.\\\", \\\"value\\\": [\\\"/var/log/containers/nova:/var/log/nova\\\"]}, \\\"docker_config\\\": {\\\"description\\\": \\\"Extra containers needed for logging to files in the host.\\\", \\\"value\\\": {\\\"step_2\\\": {\\\"map_replace\\\": [{\\\"CONTAINERNAME\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaImage\\\"]}, \\\"net\\\": \\\"none\\\", \\\"privileged\\\": false, \\\"user\\\": \\\"root\\\", \\\"volumes\\\": [\\\"/var/log/containers/nova:/var/log/nova:z\\\"], \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R nova:nova /var/log/nova\\\"], \\\"environment\\\": {\\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}}}}, {\\\"keys\\\": {\\\"CONTAINERNAME\\\": {\\\"get_attr\\\": [\\\"InitLogContainerName\\\", \\\"value\\\"]}}}]}}}, \\\"host_prep_tasks\\\": {\\\"description\\\": \\\"Extra ansible tasks needed for logging to files in the host.\\\", \\\"value\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"state\\\": \\\"directory\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/nova\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}]}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized nova-manage runner service\\\\n\\\", \\\"parameters\\\": {\\\"ContainerNovaConductorImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}}, \\\"resources\\\": {\\\"NovaLogging\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\\\", \\\"properties\\\": {\\\"ContainerNovaImage\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaConductorImage\\\"]}, \\\"NovaServiceName\\\": \\\"manager\\\"}}, \\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"NovaConductorBase\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}, \\\"NovaAdditionalCell\\\": false}}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerNovaConductorImage\\\": \\\"ContainerNovaConductorImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerNovaConductorImage\\\": {\\\"get_param\\\": \\\"ContainerNovaConductorImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the nova-manage runner service.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"nova_manager\\\", \\\"config_settings\\\": {\\\"get_attr\\\": [\\\"NovaConductorBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, \\\"service_config_settings\\\": {\\\"mysql\\\": {\\\"get_attr\\\": [\\\"NovaConductorBase\\\", \\\"role_data\\\", \\\"service_config_settings\\\", \\\"mysql\\\"]}}, \\\"puppet_config\\\": {\\\"get_attr\\\": [\\\"NovaConductorBase\\\", \\\"role_data\\\", \\\"puppet_config\\\"]}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/nova_manager.json\\\": {\\\"command\\\": \\\"/bin/sleep infinity\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/nova\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"recurse\\\": true}]}}, \\\"docker_config\\\": {\\\"step_2\\\": {\\\"get_attr\\\": [\\\"NovaLogging\\\", \\\"docker_config\\\", \\\"step_2\\\"]}, \\\"step_4\\\": {\\\"nova_manager\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaConductorImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"restart\\\": \\\"always\\\", \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"NovaLogging\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/nova_manager.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/nova:/var/lib/kolla/config_files/src:ro\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"host_prep_tasks\\\": {\\\"get_attr\\\": [\\\"NovaLogging\\\", \\\"host_prep_tasks\\\"]}}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Nova Metadata service\\\\n\\\", \\\"parameters\\\": {\\\"ContainerNovaMetadataImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerNovaMetadataConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the nova config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaMetadataLoggingSource\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {\\\"tag\\\": \\\"openstack.nova.api.metadata\\\", \\\"file\\\": \\\"/var/log/containers/nova/nova-metadata-api.log\\\"}}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"NovaWorkers\\\": {\\\"default\\\": 0, \\\"description\\\": \\\"Number of workers for Nova services.\\\", \\\"type\\\": \\\"number\\\"}, \\\"NovaPassword\\\": {\\\"description\\\": \\\"The password for the nova service and db account\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"KeystoneRegion\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"regionOne\\\", \\\"description\\\": \\\"Keystone region for endpoint\\\"}, \\\"NeutronMetadataProxySharedSecret\\\": {\\\"description\\\": \\\"Shared secret to prevent spoofing\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"MonitoringSubscriptionNovaMetadata\\\": {\\\"default\\\": \\\"overcloud-nova-metadata\\\", \\\"type\\\": \\\"string\\\"}, \\\"NovaLocalMetadataPerCell\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Indicates that the nova-metadata API service has been deployed per-cell, so that we can have better performance and data isolation in a multi-cell deployment. Users should consider the use of this configuration depending on how neutron is setup. If networks span cells, you might need to run nova-metadata API service globally. If your networks are segmented along cell boundaries, then you can run nova-metadata API service per cell. When running nova-metadata API service per cell, you should also configure each Neutron metadata-agent to point to the corresponding nova-metadata API service.\\\\n\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"MemcacheUseAdvancedPool\\\": {\\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"Use the advanced (eventlet safe) memcached client pool.\\\\n\\\", \\\"default\\\": true}}, \\\"conditions\\\": {\\\"nova_workers_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"NovaWorkers\\\"}, 0]}}, \\\"is_neutron_shared_metadata_notempty\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"NeutronMetadataProxySharedSecret\\\"}, \\\"\\\"]}}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"MySQLClient\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\\\"}, \\\"NovaMetadataLogging\\\": {\\\"type\\\": \\\"OS::TripleO::Services::Logging::NovaMetadata\\\"}, \\\"ApacheServiceBase\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}, \\\"EnableInternalTLS\\\": {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}}}, \\\"NovaBase\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"NovaApiDBClient\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"NovaDBClient\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerNovaMetadataImage\\\": \\\"ContainerNovaMetadataImage\\\", \\\"ContainerNovaMetadataConfigImage\\\": \\\"ContainerNovaMetadataConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerNovaMetadataImage\\\": {\\\"get_param\\\": \\\"ContainerNovaMetadataImage\\\"}, \\\"ContainerNovaMetadataConfigImage\\\": {\\\"get_param\\\": \\\"ContainerNovaMetadataConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Nova Metadata service.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"nova_metadata\\\", \\\"firewall_rules\\\": {\\\"139 nova_metadata\\\": {\\\"dport\\\": [8775]}}, \\\"firewall_frontend_rules\\\": {\\\"100 nova_metadatahaproxy_frontend\\\": {\\\"dport\\\": [8775]}}, \\\"firewall_ssl_frontend_rules\\\": {\\\"100 nova_metadatahaproxy_frontend_ssl\\\": {\\\"dport\\\": [13775]}}, \\\"monitoring_subscription\\\": {\\\"get_param\\\": \\\"MonitoringSubscriptionNovaMetadata\\\"}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"NovaBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"if\\\": [{\\\"not\\\": {\\\"get_param\\\": \\\"NovaLocalMetadataPerCell\\\"}}, {\\\"get_attr\\\": [\\\"NovaApiDBClient\\\", \\\"role_data\\\", \\\"config_settings\\\"]}]}, {\\\"get_attr\\\": [\\\"NovaDBClient\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"get_attr\\\": [\\\"ApacheServiceBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"get_attr\\\": [\\\"NovaMetadataLogging\\\", \\\"config_settings\\\"]}, {\\\"apache::default_vhost\\\": false}, {\\\"nova::keystone::authtoken::project_name\\\": \\\"service\\\", \\\"nova::keystone::authtoken::password\\\": {\\\"get_param\\\": \\\"NovaPassword\\\"}, \\\"nova::keystone::authtoken::www_authenticate_uri\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystonePublic\\\", \\\"uri_no_suffix\\\"]}, \\\"nova::keystone::authtoken::auth_url\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"uri_no_suffix\\\"]}, \\\"nova::keystone::authtoken::region_name\\\": {\\\"get_param\\\": \\\"KeystoneRegion\\\"}, \\\"nova::keystone::authtoken::interface\\\": \\\"internal\\\", \\\"nova::keystone::authtoken::memcache_use_advanced_pool\\\": {\\\"get_param\\\": \\\"MemcacheUseAdvancedPool\\\"}, \\\"nova::wsgi::apache_metadata::api_port\\\": \\\"8775\\\", \\\"nova::wsgi::apache_metadata::ssl\\\": {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, \\\"nova::metadata::local_metadata_per_cell\\\": {\\\"get_param\\\": \\\"NovaLocalMetadataPerCell\\\"}, \\\"nova::wsgi::apache_metadata::bind_host\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaMetadataNetwork\\\"]}}}}, \\\"nova::wsgi::apache_metadata::servername\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'fqdn_$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaMetadataNetwork\\\"]}}}}, \\\"nova::wsgi::apache_metadata::workers\\\": {\\\"if\\\": [\\\"nova_workers_set\\\", {\\\"get_param\\\": \\\"NovaWorkers\\\"}]}, \\\"nova::metadata::neutron_metadata_proxy_shared_secret\\\": {\\\"if\\\": [\\\"is_neutron_shared_metadata_notempty\\\", {\\\"get_param\\\": \\\"NeutronMetadataProxySharedSecret\\\"}]}}]}, \\\"service_config_settings\\\": {\\\"rabbitmq\\\": {\\\"get_attr\\\": [\\\"NovaBase\\\", \\\"role_data\\\", \\\"service_config_settings\\\"], \\\"rabbitmq\\\": null}, \\\"mysql\\\": {\\\"map_merge\\\": [{\\\"if\\\": [{\\\"not\\\": {\\\"get_param\\\": \\\"NovaLocalMetadataPerCell\\\"}}, {\\\"get_attr\\\": [\\\"NovaApiDBClient\\\", \\\"role_data\\\", \\\"service_config_settings\\\", \\\"mysql\\\"]}]}, {\\\"get_attr\\\": [\\\"NovaDBClient\\\", \\\"role_data\\\", \\\"service_config_settings\\\", \\\"mysql\\\"]}]}, \\\"rsyslog\\\": {\\\"tripleo_logging_sources_nova_metadata\\\": [{\\\"get_param\\\": \\\"NovaMetadataLoggingSource\\\"}]}}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"nova_metadata\\\", \\\"puppet_tags\\\": \\\"nova_config,nova_api_paste_ini\\\", \\\"step_config\\\": {\\\"list_join\\\": [\\\"\\\\n\\\", [\\\"include tripleo::profile::base::nova::metadata\\\", {\\\"get_attr\\\": [\\\"MySQLClient\\\", \\\"role_data\\\", \\\"step_config\\\"]}]]}, \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaMetadataConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/nova_metadata.json\\\": {\\\"command\\\": \\\"/usr/sbin/httpd -DFOREGROUND\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/etc/httpd/conf.d\\\", \\\"dest\\\": \\\"/etc/httpd/conf.d\\\", \\\"merge\\\": false, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\\\", \\\"dest\\\": \\\"/etc/httpd/conf.modules.d\\\", \\\"merge\\\": false, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/nova\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"recurse\\\": true}]}}, \\\"docker_config\\\": {\\\"step_2\\\": {\\\"get_attr\\\": [\\\"NovaMetadataLogging\\\", \\\"docker_config\\\", \\\"step_2\\\"]}, \\\"step_4\\\": {\\\"nova_metadata\\\": {\\\"start_order\\\": 2, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaMetadataImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"user\\\": \\\"root\\\", \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"NovaMetadataLogging\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/nova_metadata.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/nova_metadata:/var/lib/kolla/config_files/src:ro\\\"], {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, [\\\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\\\", \\\"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\\\"]]}]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"deploy_steps_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ApacheServiceBase\\\", \\\"role_data\\\", \\\"deploy_steps_tasks\\\"]}, [{\\\"name\\\": \\\"validate nova-metadata container state\\\", \\\"containers.podman.podman_container_info\\\": {\\\"name\\\": \\\"nova_metadata\\\"}, \\\"register\\\": \\\"nova_metadata_infos\\\", \\\"failed_when\\\": [\\\"nova_metadata_infos.containers.0.Healthcheck.Status is defined\\\", \\\"\'healthy\' not in nova_metadata_infos.containers.0.Healthcheck.Status\\\"], \\\"retries\\\": 10, \\\"delay\\\": 30, \\\"tags\\\": [\\\"opendev-validation\\\", \\\"opendev-validation-nova\\\"], \\\"when\\\": [\\\"container_cli == \'podman\'\\\", \\\"not container_healthcheck_disabled\\\", \\\"step|int == 5\\\"]}]]}, \\\"host_prep_tasks\\\": {\\\"get_attr\\\": [\\\"NovaMetadataLogging\\\", \\\"host_prep_tasks\\\"]}, \\\"metadata_settings\\\": {\\\"get_attr\\\": [\\\"ApacheServiceBase\\\", \\\"role_data\\\", \\\"metadata_settings\\\"]}, \\\"external_upgrade_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade_transfer_data\\\", \\\"system_upgrade_stop_services\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Stop nova metadata container\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_stop\\\"}, \\\"vars\\\": {\\\"tripleo_containers_to_stop\\\": [\\\"nova_metadata\\\"], \\\"tripleo_delegate_to\\\": \\\"{{ groups[\'nova_metadata\'] | difference(groups[\'excluded_overcloud\']) }}\\\"}}]}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Configure sshd_config\\\\n\\\", \\\"parameters\\\": {\\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"BannerText\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Configures Banner text in sshd_config\\\", \\\"type\\\": \\\"string\\\"}, \\\"MessageOfTheDay\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Configures /etc/motd text\\\", \\\"type\\\": \\\"string\\\"}, \\\"SshServerOptions\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of sshd_config values\\\", \\\"type\\\": \\\"json\\\"}, \\\"SshServerOptionsOverrides\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of sshd_config values to override definitions in SshServerOptions\\\", \\\"type\\\": \\\"json\\\"}, \\\"PasswordAuthentication\\\": {\\\"default\\\": \\\"no\\\", \\\"description\\\": \\\"Whether or not disable password authentication\\\", \\\"type\\\": \\\"string\\\"}, \\\"SshFirewallAllowAll\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Set this to true to open up ssh access from all sources.\\\", \\\"type\\\": \\\"boolean\\\"}}, \\\"conditions\\\": {\\\"ssh_firewall_allow_all\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"SshFirewallAllowAll\\\"}, true]}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the ssh\\\", \\\"value\\\": {\\\"service_name\\\": \\\"sshd\\\", \\\"firewall_rules\\\": {\\\"003 accept ssh from all\\\": {\\\"proto\\\": \\\"tcp\\\", \\\"dport\\\": 22, \\\"extras\\\": {\\\"ensure\\\": {\\\"if\\\": [\\\"ssh_firewall_allow_all\\\", \\\"present\\\", \\\"absent\\\"]}}}}, \\\"config_settings\\\": {\\\"tripleo::profile::base::sshd::bannertext\\\": {\\\"get_param\\\": \\\"BannerText\\\"}, \\\"tripleo::profile::base::sshd::motd\\\": {\\\"get_param\\\": \\\"MessageOfTheDay\\\"}, \\\"tripleo::profile::base::sshd::options\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"SshServerOptions\\\"}, {\\\"get_param\\\": \\\"SshServerOptionsOverrides\\\"}]}, \\\"tripleo::profile::base::sshd::password_authentication\\\": {\\\"get_param\\\": \\\"PasswordAuthentication\\\"}}, \\\"step_config\\\": \\\"include tripleo::profile::base::sshd\\\"}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Nova Migration Target service\\\\n\\\", \\\"parameters\\\": {\\\"ContainerNovaComputeImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerNovaLibvirtConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the nova_libvirt config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"DockerNovaMigrationSshdPort\\\": {\\\"default\\\": 2022, \\\"description\\\": \\\"Port that dockerized nova migration target sshd service binds to.\\\", \\\"type\\\": \\\"number\\\"}, \\\"MigrationSshKey\\\": {\\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"SSH key for migration. Expects a dictionary with keys \'public_key\' and \'private_key\'. Values should be identical to SSH public/private key files.\\\\n\\\", \\\"default\\\": {\\\"public_key\\\": \\\"\\\", \\\"private_key\\\": \\\"\\\"}}, \\\"MigrationSshPort\\\": {\\\"default\\\": 2022, \\\"description\\\": \\\"Target port for migration over ssh\\\", \\\"type\\\": \\\"number\\\"}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"SshdBase\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-puppet.yaml\\\", \\\"properties\\\": {\\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerNovaComputeImage\\\": \\\"ContainerNovaComputeImage\\\", \\\"ContainerNovaLibvirtConfigImage\\\": \\\"ContainerNovaLibvirtConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerNovaComputeImage\\\": {\\\"get_param\\\": \\\"ContainerNovaComputeImage\\\"}, \\\"ContainerNovaLibvirtConfigImage\\\": {\\\"get_param\\\": \\\"ContainerNovaLibvirtConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Nova Migration Target service.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"nova_migration_target\\\", \\\"firewall_rules\\\": {\\\"map_merge\\\": [{\\\"map_merge\\\": {\\\"repeat\\\": {\\\"for_each\\\": {\\\"<%net_cidr%>\\\": {\\\"get_param\\\": [\\\"ServiceData\\\", \\\"net_cidr_map\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaLibvirtNetwork\\\"]}]}}, \\\"template\\\": {\\\"113 nova_migration_target accept libvirt subnet <%net_cidr%>\\\": {\\\"source\\\": \\\"<%net_cidr%>\\\", \\\"proto\\\": \\\"tcp\\\", \\\"dport\\\": {\\\"get_param\\\": \\\"MigrationSshPort\\\"}}}}}}, {\\\"map_merge\\\": {\\\"repeat\\\": {\\\"for_each\\\": {\\\"<%net_cidr%>\\\": {\\\"get_param\\\": [\\\"ServiceData\\\", \\\"net_cidr_map\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaApiNetwork\\\"]}]}}, \\\"template\\\": {\\\"113 nova_migration_target accept api subnet <%net_cidr%>\\\": {\\\"source\\\": \\\"<%net_cidr%>\\\", \\\"proto\\\": \\\"tcp\\\", \\\"dport\\\": {\\\"get_param\\\": \\\"MigrationSshPort\\\"}}}}}}]}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"SshdBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"tripleo::profile::base::nova::migration::target::ssh_authorized_keys\\\": [{\\\"get_param\\\": [\\\"MigrationSshKey\\\", \\\"public_key\\\"]}], \\\"tripleo::profile::base::nova::migration::target::ssh_localaddrs\\\": [\\\"%{hiera(\'cold_migration_ssh_inbound_addr\')}\\\", \\\"%{hiera(\'live_migration_ssh_inbound_addr\')}\\\"], \\\"live_migration_ssh_inbound_addr\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaLibvirtNetwork\\\"]}}}}, \\\"cold_migration_ssh_inbound_addr\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaApiNetwork\\\"]}}}}, \\\"tripleo::profile::base::sshd::port\\\": [22]}]}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"nova_libvirt\\\", \\\"step_config\\\": {\\\"list_join\\\": [\\\"\\\\n\\\", [{\\\"get_attr\\\": [\\\"SshdBase\\\", \\\"role_data\\\", \\\"step_config\\\"]}, \\\"include tripleo::profile::base::nova::migration::target\\\"]]}, \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaLibvirtConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/nova-migration-target.json\\\": {\\\"command\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"dumb-init --single-child -- /usr/sbin/sshd -D -p SSHDPORT\\\", \\\"params\\\": {\\\"SSHDPORT\\\": {\\\"get_param\\\": \\\"DockerNovaMigrationSshdPort\\\"}}}}, \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/host-ssh/ssh_host_*_key\\\", \\\"dest\\\": \\\"/etc/ssh/\\\", \\\"owner\\\": \\\"root\\\", \\\"perm\\\": \\\"0600\\\"}]}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"Create libvirt persistent data directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\"}, \\\"loop\\\": [{\\\"path\\\": \\\"/run/libvirt\\\", \\\"setype\\\": \\\"virt_var_run_t\\\"}]}, {\\\"name\\\": \\\"ensure /run/libvirt is present upon reboot\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/tmpfiles.d/run-libvirt.conf\\\", \\\"content\\\": \\\"d /run/libvirt 0755 root root - -\\\\n\\\"}}], \\\"docker_config\\\": {\\\"step_4\\\": {\\\"nova_migration_target\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaComputeImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"user\\\": \\\"root\\\", \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/nova-migration-target.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/etc/ssh:/host-ssh:ro\\\", \\\"/run/libvirt:/run/libvirt:shared,z\\\", \\\"/var/lib/nova:/var/lib/nova:shared\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"validate nova-migration-target container state\\\", \\\"containers.podman.podman_container_info\\\": {\\\"name\\\": \\\"nova_migration_target\\\"}, \\\"register\\\": \\\"nova_migration_target_infos\\\", \\\"failed_when\\\": [\\\"nova_migration_target_infos.containers.0.Healthcheck.Status is defined\\\", \\\"\'healthy\' not in nova_migration_target_infos.containers.0.Healthcheck.Status\\\"], \\\"retries\\\": 10, \\\"delay\\\": 30, \\\"tags\\\": [\\\"opendev-validation\\\", \\\"opendev-validation-nova\\\"], \\\"when\\\": [\\\"container_cli == \'podman\'\\\", \\\"not container_healthcheck_disabled\\\", \\\"step|int == 5\\\"]}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"nova_migration_target_tmpfile_cleanup\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Remove old tmpfiles.d config\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/tmpfiles.d/var-run-libvirt.conf\\\", \\\"state\\\": \\\"absent\\\"}}]}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"nova_migration_target_tmpfile_cleanup\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Remove old tmpfiles.d config\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/tmpfiles.d/var-run-libvirt.conf\\\", \\\"state\\\": \\\"absent\\\"}}]}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/placement_wait_for_service.py\": \"#!/usr/bin/python3\\n#\\n# Copyright 2018 Red Hat Inc.\\n#\\n# Licensed under the Apache License, Version 2.0 (the \\\"License\\\"); you may\\n# not use this file except in compliance with the License. You may obtain\\n# a copy of the License at\\n#\\n#      http://www.apache.org/licenses/LICENSE-2.0\\n#\\n# Unless required by applicable law or agreed to in writing, software\\n# distributed under the License is distributed on an \\\"AS IS\\\" BASIS, WITHOUT\\n# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the\\n# License for the specific language governing permissions and limitations\\n# under the License.\\n\\n# shell script to check if placement API is up after X attempts.\\n# Default max is 60 iterations with 10s (default) timeout in between.\\n\\nimport logging\\nimport os\\nimport re\\nimport six\\nimport sys\\nimport time\\n\\nfrom keystoneauth1.identity import v3\\nfrom keystoneauth1 import session\\nfrom keystoneclient.v3 import client\\nimport requests\\n\\n# In python3 SafeConfigParser was renamed to ConfigParser and the default\\n# for duplicate options default to true. In case of nova it is valid to\\n# have duplicate option lines, e.g. passthrough_whitelist which leads to\\n# issues reading the nova.conf\\n# https://bugs.launchpad.net/tripleo/+bug/1827775\\nif six.PY3:\\n    from six.moves.configparser import ConfigParser\\n    config = ConfigParser(strict=False)\\nelse:\\n    from six.moves.configparser import SafeConfigParser\\n    config = SafeConfigParser()\\n\\n\\ndebug = os.getenv(\'__OS_DEBUG\', \'false\')\\n\\nif debug.lower() == \'true\':\\n    loglevel = logging.DEBUG\\nelse:\\n    loglevel = logging.INFO\\n\\nlogging.basicConfig(stream=sys.stdout, level=loglevel)\\nLOG = logging.getLogger(\'placement_wait_for_service\')\\n\\niterations = 60\\ntimeout = 10\\nplacement_cfg = \'/etc/placement/placement.conf\'\\n\\nif __name__ == \'__main__\':\\n    if os.path.isfile(placement_cfg):\\n        try:\\n            config.read(placement_cfg)\\n        except Exception:\\n            LOG.exception(\'Error while reading placement.conf:\')\\n    else:\\n        LOG.error(\'Placement configuration file %s does not exist\',\\n                  placement_cfg)\\n        sys.exit(1)\\n\\n    # get keystone client with details from [keystone_authtoken] section\\n    auth = v3.Password(\\n        user_domain_name=config.get(\'keystone_authtoken\', \'user_domain_name\'),\\n        username=config.get(\'keystone_authtoken\', \'username\'),\\n        password=config.get(\'keystone_authtoken\', \'password\'),\\n        project_name=config.get(\'keystone_authtoken\', \'project_name\'),\\n        project_domain_name=config.get(\'keystone_authtoken\',\\n                                       \'project_domain_name\'),\\n        auth_url=config.get(\'keystone_authtoken\', \'auth_url\') + \'/v3\')\\n    sess = session.Session(auth=auth, verify=False)\\n    keystone = client.Client(session=sess, interface=\'internal\')\\n\\n    iterations_endpoint = iterations\\n    placement_endpoint_url = None\\n    while iterations_endpoint > 1:\\n        iterations_endpoint -= 1\\n        try:\\n            # get placement service id\\n            placement_service_id = keystone.services.list(\\n                name=\'placement\')[0].id\\n\\n            # get placement endpoint\\n            # Note: puppet-placement does not support setting the interface\\n            #       until we have https://review.opendev.org/688862.\\n            #       Lets hard code \'internal\' for now.\\n            placement_endpoint_url = keystone.endpoints.list(\\n                service=placement_service_id,\\n                region=config.get(\'keystone_authtoken\', \'region_name\'),\\n                interface=\'internal\')[0].url\\n            if not placement_endpoint_url:\\n                LOG.error(\'Failed to get placement service endpoint!\')\\n            else:\\n                break\\n        except Exception:\\n            LOG.exception(\'Retry - Failed to get placement service endpoint:\')\\n        time.sleep(timeout)\\n\\n    if not placement_endpoint_url:\\n        LOG.error(\'Failed to get placement service endpoint!\')\\n        sys.exit(1)\\n\\n    # we should have CURRENT in the request response from placement:\\n    # {\\\"versions\\\": [{\\\"status\\\": \\\"CURRENT\\\", \\\"min_version\\\": \\\"1.0\\\", \\\"max_version\\\":\\n    # \\\"1.29\\\", \\\"id\\\": \\\"v1.0\\\", \\\"links\\\": [{\\\"href\\\": \\\"\\\", \\\"rel\\\": \\\"self\\\"}]}]}\\n    response_reg = re.compile(\'.*CURRENT,*\')\\n\\n    while iterations > 1:\\n        iterations -= 1\\n        try:\\n            r = requests.get(placement_endpoint_url + \'/\', verify=False)\\n            if r.status_code == 200 and response_reg.match(r.text):\\n                LOG.info(\'Placement service up! - %s\', r.text)\\n                sys.exit(0)\\n                break\\n            else:\\n                LOG.info(\'response - %r\', r)\\n                LOG.info(\'Placement service not up - %s, %s\',\\n                         r.status_code,\\n                         r.text)\\n        except Exception:\\n            LOG.exception(\'Error query the placement endpoint:\')\\n        time.sleep(timeout)\\n\\n    sys.exit(1)\\n\\n# vim: set et ts=4 sw=4 :\\n\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Placement API service\\\\n\\\", \\\"parameters\\\": {\\\"ContainerPlacementImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerPlacementConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the placement config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"EnableSQLAlchemyCollectd\\\": {\\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"Set to true to enable the SQLAlchemy-collectd server plugin\\\\n\\\", \\\"default\\\": false}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"DeployIdentifier\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\\\n\\\"}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"PlacementWorkers\\\": {\\\"default\\\": 0, \\\"description\\\": \\\"Number of workers for Placement services.\\\", \\\"type\\\": \\\"number\\\"}, \\\"PlacementPassword\\\": {\\\"description\\\": \\\"The password for the Placement service and db account\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"PlacementAPIInterface\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Endpoint interface to be used for the placement API.\\\\n\\\", \\\"default\\\": \\\"internal\\\"}, \\\"EnforceSecureRbac\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false, \\\"description\\\": \\\"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\\\"}, \\\"KeystoneRegion\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"regionOne\\\", \\\"description\\\": \\\"Keystone region for endpoint\\\"}, \\\"MonitoringSubscriptionPlacement\\\": {\\\"default\\\": \\\"overcloud-placement\\\", \\\"type\\\": \\\"string\\\"}, \\\"PlacementLoggingSource\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {\\\"tag\\\": \\\"openstack.placement\\\", \\\"file\\\": \\\"/var/log/containers/placement/placement.log\\\"}}, \\\"NovaPassword\\\": {\\\"description\\\": \\\"The password for the nova service and db account\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"Debug\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false, \\\"description\\\": \\\"Set to True to enable debugging on all services.\\\"}, \\\"MemcacheUseAdvancedPool\\\": {\\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"Use the advanced (eventlet safe) memcached client pool.\\\\n\\\", \\\"default\\\": true}, \\\"PlacementDebug\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Set to True to enable debugging Placement services.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"PlacementPolicies\\\": {\\\"description\\\": \\\"A hash of policies to configure for Placement API.\\\\ne.g. { nova-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\\\n\\\", \\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}}, \\\"conditions\\\": {\\\"placement_workers_zero\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"PlacementWorkers\\\"}, 0]}, \\\"internal_tls_enabled\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, true]}, \\\"enable_sqlalchemy_collectd\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"EnableSQLAlchemyCollectd\\\"}, true]}}, \\\"resources\\\": {\\\"ApacheServiceBase\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}, \\\"EnableInternalTLS\\\": {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}}}, \\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"MySQLClient\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\\\"}, \\\"PlacementLogging\\\": {\\\"type\\\": \\\"OS::TripleO::Services::Logging::PlacementApi\\\"}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerPlacementImage\\\": \\\"ContainerPlacementImage\\\", \\\"ContainerPlacementConfigImage\\\": \\\"ContainerPlacementConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerPlacementImage\\\": {\\\"get_param\\\": \\\"ContainerPlacementImage\\\"}, \\\"ContainerPlacementConfigImage\\\": {\\\"get_param\\\": \\\"ContainerPlacementConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Placement API role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"placement\\\", \\\"firewall_rules\\\": {\\\"138 placement\\\": {\\\"dport\\\": [8778]}}, \\\"firewall_frontend_rules\\\": {\\\"100 placement_haproxy_frontend\\\": {\\\"dport\\\": [8778]}}, \\\"firewall_ssl_frontend_rules\\\": {\\\"100 placement_haproxy_frontend_ssl\\\": {\\\"dport\\\": [13778]}}, \\\"keystone_resources\\\": {\\\"placement\\\": {\\\"endpoints\\\": {\\\"public\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"PlacementPublic\\\", \\\"uri\\\"]}, \\\"internal\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"PlacementInternal\\\", \\\"uri\\\"]}, \\\"admin\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"PlacementAdmin\\\", \\\"uri\\\"]}}, \\\"users\\\": {\\\"placement\\\": {\\\"password\\\": {\\\"get_param\\\": \\\"PlacementPassword\\\"}}}, \\\"region\\\": {\\\"get_param\\\": \\\"KeystoneRegion\\\"}, \\\"service\\\": \\\"placement\\\"}}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"PlacementLogging\\\", \\\"config_settings\\\"]}, {\\\"apache::default_vhost\\\": false}, {\\\"placement::keystone::authtoken::project_name\\\": \\\"service\\\", \\\"placement::keystone::authtoken::password\\\": {\\\"get_param\\\": \\\"PlacementPassword\\\"}, \\\"placement::keystone::authtoken::www_authenticate_uri\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystonePublic\\\", \\\"uri_no_suffix\\\"]}, \\\"placement::keystone::authtoken::auth_url\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"uri_no_suffix\\\"]}, \\\"placement::keystone::authtoken::region_name\\\": {\\\"get_param\\\": \\\"KeystoneRegion\\\"}, \\\"placement::keystone::authtoken::interface\\\": \\\"internal\\\", \\\"placement::keystone::authtoken::memcache_use_advanced_pool\\\": {\\\"get_param\\\": \\\"MemcacheUseAdvancedPool\\\"}, \\\"placement::logging::debug\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"PlacementDebug\\\"}, true, {\\\"get_param\\\": \\\"Debug\\\"}]}, \\\"placement::policy::enforce_new_defaults\\\": {\\\"get_param\\\": \\\"EnforceSecureRbac\\\"}, \\\"placement::policy::enforce_scope\\\": {\\\"get_param\\\": \\\"EnforceSecureRbac\\\"}, \\\"placement::policy::policies\\\": {\\\"get_param\\\": \\\"PlacementPolicies\\\"}, \\\"placement::wsgi::apache::api_port\\\": \\\"8778\\\", \\\"placement::wsgi::apache::ssl\\\": {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, \\\"placement::wsgi::apache::bind_host\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PlacementNetwork\\\"]}}}}, \\\"placement::wsgi::apache::servername\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'fqdn_$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PlacementNetwork\\\"]}}}}, \\\"placement::db::database_connection\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"MysqlInternal\\\", \\\"protocol\\\"]}, \\\"username\\\": \\\"placement\\\", \\\"password\\\": {\\\"get_param\\\": \\\"PlacementPassword\\\"}, \\\"host\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"MysqlInternal\\\", \\\"host\\\"]}, \\\"path\\\": \\\"/placement\\\", \\\"query\\\": {\\\"if\\\": [\\\"enable_sqlalchemy_collectd\\\", {\\\"read_default_file\\\": \\\"/etc/my.cnf.d/tripleo.cnf\\\", \\\"read_default_group\\\": \\\"tripleo\\\", \\\"plugin\\\": \\\"collectd\\\", \\\"collectd_program_name\\\": \\\"placement_api\\\", \\\"collectd_host\\\": \\\"localhost\\\"}, {\\\"read_default_file\\\": \\\"/etc/my.cnf.d/tripleo.cnf\\\", \\\"read_default_group\\\": \\\"tripleo\\\"}]}}}}, {\\\"if\\\": [\\\"placement_workers_zero\\\", {}, {\\\"placement::wsgi::apache::workers\\\": {\\\"get_param\\\": \\\"PlacementWorkers\\\"}}]}]}, \\\"service_config_settings\\\": {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_placement\\\": [{\\\"get_param\\\": \\\"PlacementLoggingSource\\\"}]}, \\\"mysql\\\": {\\\"placement::db::mysql::password\\\": {\\\"get_param\\\": \\\"PlacementPassword\\\"}, \\\"placement::db::mysql::user\\\": \\\"placement\\\", \\\"placement::db::mysql::host\\\": \\\"%\\\", \\\"placement::db::mysql::dbname\\\": \\\"placement\\\"}}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"placement\\\", \\\"puppet_tags\\\": \\\"placement_config\\\", \\\"step_config\\\": {\\\"list_join\\\": [\\\"\\\\n\\\", [{\\\"get_attr\\\": [\\\"MySQLClient\\\", \\\"role_data\\\", \\\"step_config\\\"]}, \\\"include tripleo::profile::base::placement::api\\\"]]}, \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerPlacementConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/placement_api.json\\\": {\\\"command\\\": \\\"/usr/sbin/httpd -DFOREGROUND\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/etc/httpd/conf.d\\\", \\\"dest\\\": \\\"/etc/httpd/conf.d\\\", \\\"merge\\\": false, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\\\", \\\"dest\\\": \\\"/etc/httpd/conf.modules.d\\\", \\\"merge\\\": false, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/placement\\\", \\\"owner\\\": \\\"placement:placement\\\", \\\"recurse\\\": true}]}, \\\"/var/lib/kolla/config_files/placement_api_db_sync.json\\\": {\\\"command\\\": \\\"/usr/bin/bootstrap_host_exec placement su placement -s /bin/bash -c \'/usr/bin/placement-manage db sync\'\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/etc/httpd/conf.d\\\", \\\"dest\\\": \\\"/etc/httpd/conf.d\\\", \\\"merge\\\": false, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\\\", \\\"dest\\\": \\\"/etc/httpd/conf.modules.d\\\", \\\"merge\\\": false, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/placement\\\", \\\"owner\\\": \\\"placement:placement\\\", \\\"recurse\\\": true}]}, \\\"/var/lib/kolla/config_files/placement_api_wait_for_service.json\\\": {\\\"command\\\": \\\"/usr/bin/bootstrap_host_exec placement su placement -s /bin/bash -c \'/container-config-scripts/pyshim.sh /container-config-scripts/placement_wait_for_service.py\'\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/etc/httpd/conf.d\\\", \\\"dest\\\": \\\"/etc/httpd/conf.d\\\", \\\"merge\\\": false, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\\\", \\\"dest\\\": \\\"/etc/httpd/conf.modules.d\\\", \\\"merge\\\": false, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/placement\\\", \\\"owner\\\": \\\"placement:placement\\\", \\\"recurse\\\": true}]}}, \\\"container_config_scripts\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"container_config_scripts\\\"]}, {\\\"placement_wait_for_service.py\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": {\\\"get_file\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/container_config_scripts/placement_wait_for_service.py\\\"}}}]}, \\\"docker_config\\\": {\\\"step_2\\\": {\\\"get_attr\\\": [\\\"PlacementLogging\\\", \\\"docker_config\\\", \\\"step_2\\\"]}, \\\"step_3\\\": {\\\"placement_api_db_sync\\\": {\\\"start_order\\\": 1, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerPlacementImage\\\"]}, \\\"cap_add\\\": [\\\"AUDIT_WRITE\\\"], \\\"net\\\": \\\"host\\\", \\\"detach\\\": false, \\\"user\\\": \\\"root\\\", \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"PlacementLogging\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/placement_api_db_sync.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/placement:/var/lib/kolla/config_files/src:ro\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\", \\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}}}}, \\\"step_4\\\": {\\\"placement_api\\\": {\\\"start_order\\\": 1, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerPlacementImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"user\\\": \\\"root\\\", \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"PlacementLogging\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/placement_api.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/placement:/var/lib/kolla/config_files/src:ro\\\"], {\\\"if\\\": [\\\"internal_tls_enabled\\\", [\\\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\\\"], []]}, {\\\"if\\\": [\\\"internal_tls_enabled\\\", [\\\"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\\\"], []]}]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}, \\\"placement_wait_for_service\\\": {\\\"start_order\\\": 2, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerPlacementImage\\\"]}, \\\"user\\\": \\\"root\\\", \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"detach\\\": false, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"PlacementLogging\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/placement_api_wait_for_service.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/placement:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/container-config-scripts:/container-config-scripts:z\\\"]]}, \\\"environment\\\": {\\\"__OS_DEBUG\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"str($.data.debug)\\\", \\\"data\\\": {\\\"debug\\\": {\\\"get_param\\\": \\\"Debug\\\"}}}}, \\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"host_prep_tasks\\\": {\\\"get_attr\\\": [\\\"PlacementLogging\\\", \\\"host_prep_tasks\\\"]}, \\\"deploy_steps_tasks\\\": {\\\"get_attr\\\": [\\\"ApacheServiceBase\\\", \\\"role_data\\\", \\\"deploy_steps_tasks\\\"]}, \\\"upgrade_tasks\\\": []}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Nova Scheduler service\\\\n\\\", \\\"parameters\\\": {\\\"ContainerNovaSchedulerImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerNovaConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the nova config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaSchedulerLoggingSource\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {\\\"tag\\\": \\\"openstack.nova.scheduler\\\", \\\"file\\\": \\\"/var/log/containers/nova/nova-scheduler.log\\\"}}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"NovaSchedulerAvailableFilters\\\": {\\\"default\\\": [], \\\"description\\\": \\\"List of scheduler available filters\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"NovaSchedulerEnabledFilters\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": [], \\\"description\\\": \\\"An array of filters used by Nova to filter a node. These filters will be applied in the order they are listed, so place your most restrictive filters first to make the filtering process more efficient.\\\\n\\\"}, \\\"NovaSchedulerMaxAttempts\\\": {\\\"type\\\": \\\"number\\\", \\\"default\\\": 3, \\\"description\\\": \\\"Maximum number of attempts the scheduler will make when deploying the instance. You should keep it greater or equal to the number of bare metal nodes you expect to deploy at once to work around potential race conditions when scheduling.\\\\n\\\"}, \\\"MonitoringSubscriptionNovaScheduler\\\": {\\\"default\\\": \\\"overcloud-nova-scheduler\\\", \\\"type\\\": \\\"string\\\"}, \\\"NovaSchedulerDiscoverHostsInCellsInterval\\\": {\\\"type\\\": \\\"number\\\", \\\"default\\\": -1, \\\"description\\\": \\\"This value controls how often (in seconds) the scheduler should attempt to discover new hosts that have been added to cells. The default value of -1 disables the periodic task completely. It is recommended to set this parameter for deployments using Ironic.\\\\n\\\"}, \\\"NovaSchedulerWorkers\\\": {\\\"default\\\": 0, \\\"description\\\": \\\"Number of workers for Nova Scheduler services.\\\", \\\"type\\\": \\\"number\\\"}, \\\"NovaSchedulerQueryImageType\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": true, \\\"description\\\": \\\"This setting causes the scheduler to ask placement only for compute hosts that support the disk_format of the image used in the request.\\\\n\\\"}, \\\"NovaSchedulerLimitTenantsToPlacementAggregate\\\": {\\\"default\\\": false, \\\"description\\\": \\\"This value allows to have tenant isolation with placement. It ensures hosts in tenant-isolated host aggregate and availability zones will only be available to specific set of tenants.\\\\n\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"NovaSchedulerPlacementAggregateRequiredForTenants\\\": {\\\"default\\\": false, \\\"description\\\": \\\"This setting, when `NovaSchedulerLimitTenantsToPlacementAggregate` is true, controls whether or not a tenant with no aggregate affinity will be allowed to schedule to any available node. If aggregates are used to limit some tenants but not all, then this should be False. If all tenants should be confined via aggregate, then this should be True.\\\\n\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"NovaSchedulerEnableIsolatedAggregateFiltering\\\": {\\\"default\\\": false, \\\"description\\\": \\\"This setting allows the scheduler to restrict hosts in aggregates based on matching required traits in the aggregate metadata and the instance flavor/image. If an aggregate is configured with a property with key trait:$TRAIT_NAME and value required, the instance flavor extra_specs and/or image metadata must also contain trait:$TRAIT_NAME=required to be eligible to be scheduled to hosts in that aggregate.\\\\n\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"NovaSchedulerQueryPlacementForAvailabilityZone\\\": {\\\"default\\\": false, \\\"description\\\": \\\"This setting allows the scheduler to look up a host aggregate with metadata key of availability zone set to the value provided by incoming request, and request result from placement be limited to that aggregate.\\\\n\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"NovaSchedulerQueryPlacementForRoutedNetworkAggregates\\\": {\\\"default\\\": false, \\\"description\\\": \\\"This setting allows the scheduler to verify if the requested networks or port are related to neutron routed network. This requires that the related aggregates to be reported in placement, so only hosts within the asked aggregates would be accepted.\\\\n\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"NovaSchedulerHostSubsetSize\\\": {\\\"default\\\": 1, \\\"description\\\": \\\"Size of subset of best hosts selected by scheduler.\\\\n\\\", \\\"type\\\": \\\"number\\\"}, \\\"NovaSchedulerShuffleBestSameWeighedHosts\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Enable spreading the instances between hosts with the same best weight.\\\\n\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"NovaSchedulerDefaultFilters\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": [], \\\"description\\\": \\\"(DEPRECATED) An array of filters used by Nova to filter a node. These filters will be applied in the order they are listed, so place your most restrictive filters first to make the filtering process more efficient.\\\\n\\\"}}, \\\"conditions\\\": {\\\"nova_scheduler_workers_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"NovaSchedulerWorkers\\\"}, 0]}}, \\\"scheduler_default_filters\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"NovaSchedulerDefaultFilters\\\"}, []]}}, \\\"disabled_scheduler_enabled_filters\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"NovaSchedulerEnabledFilters\\\"}, []]}}, \\\"parameter_groups\\\": [{\\\"label\\\": \\\"deprecated\\\", \\\"description\\\": \\\"The following parameters are deprecated and will be removed. They should not\\\\nbe relied on for new deployments. If you have concerns regarding deprecated\\\\nparameters, please contact the TripleO development team on IRC or the\\\\nOpenstack mailing list.\\\\n\\\", \\\"parameters\\\": [\\\"NovaSchedulerDefaultFilters\\\"]}], \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"MySQLClient\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\\\"}, \\\"NovaLogging\\\": {\\\"type\\\": \\\"OS::TripleO::Services::Logging::NovaCommon\\\", \\\"properties\\\": {\\\"ContainerNovaImage\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaSchedulerImage\\\"]}, \\\"NovaServiceName\\\": \\\"scheduler\\\"}}, \\\"NovaBase\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"NovaApiDBClient\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"NovaDBClient\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerNovaSchedulerImage\\\": \\\"ContainerNovaSchedulerImage\\\", \\\"ContainerNovaConfigImage\\\": \\\"ContainerNovaConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerNovaSchedulerImage\\\": {\\\"get_param\\\": \\\"ContainerNovaSchedulerImage\\\"}, \\\"ContainerNovaConfigImage\\\": {\\\"get_param\\\": \\\"ContainerNovaConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Nova Scheduler service.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"nova_scheduler\\\", \\\"monitoring_subscription\\\": {\\\"get_param\\\": \\\"MonitoringSubscriptionNovaScheduler\\\"}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"NovaBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"get_attr\\\": [\\\"NovaApiDBClient\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"get_attr\\\": [\\\"NovaDBClient\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"get_attr\\\": [\\\"NovaLogging\\\", \\\"config_settings\\\"]}, {\\\"nova::scheduler::filter::scheduler_available_filters\\\": {\\\"get_param\\\": \\\"NovaSchedulerAvailableFilters\\\"}, \\\"nova::scheduler::filter::scheduler_enabled_filters\\\": {\\\"if\\\": [{\\\"and\\\": [\\\"scheduler_default_filters\\\", \\\"disabled_scheduler_enabled_filters\\\"]}, {\\\"get_param\\\": \\\"NovaSchedulerDefaultFilters\\\"}, {\\\"get_param\\\": \\\"NovaSchedulerEnabledFilters\\\"}]}, \\\"nova::scheduler::filter::scheduler_max_attempts\\\": {\\\"get_param\\\": \\\"NovaSchedulerMaxAttempts\\\"}, \\\"nova::scheduler::filter::scheduler_host_subset_size\\\": {\\\"get_param\\\": \\\"NovaSchedulerHostSubsetSize\\\"}, \\\"nova::scheduler::filter::shuffle_best_same_weighed_hosts\\\": {\\\"get_param\\\": \\\"NovaSchedulerShuffleBestSameWeighedHosts\\\"}, \\\"nova::scheduler::discover_hosts_in_cells_interval\\\": {\\\"get_param\\\": \\\"NovaSchedulerDiscoverHostsInCellsInterval\\\"}, \\\"nova::scheduler::query_placement_for_image_type_support\\\": {\\\"get_param\\\": \\\"NovaSchedulerQueryImageType\\\"}, \\\"nova::scheduler::limit_tenants_to_placement_aggregate\\\": {\\\"get_param\\\": \\\"NovaSchedulerLimitTenantsToPlacementAggregate\\\"}, \\\"nova::scheduler::placement_aggregate_required_for_tenants\\\": {\\\"get_param\\\": \\\"NovaSchedulerPlacementAggregateRequiredForTenants\\\"}, \\\"nova::scheduler::enable_isolated_aggregate_filtering\\\": {\\\"get_param\\\": \\\"NovaSchedulerEnableIsolatedAggregateFiltering\\\"}, \\\"nova::scheduler::query_placement_for_availability_zone\\\": {\\\"get_param\\\": \\\"NovaSchedulerQueryPlacementForAvailabilityZone\\\"}, \\\"nova::scheduler::query_placement_for_routed_network_aggregates\\\": {\\\"get_param\\\": \\\"NovaSchedulerQueryPlacementForRoutedNetworkAggregates\\\"}, \\\"nova::scheduler::workers\\\": {\\\"if\\\": [\\\"nova_scheduler_workers_set\\\", {\\\"get_param\\\": \\\"NovaSchedulerWorkers\\\"}]}}]}, \\\"service_config_settings\\\": {\\\"rabbitmq\\\": {\\\"get_attr\\\": [\\\"NovaBase\\\", \\\"role_data\\\", \\\"service_config_settings\\\"], \\\"rabbitmq\\\": null}, \\\"mysql\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"NovaApiDBClient\\\", \\\"role_data\\\", \\\"service_config_settings\\\", \\\"mysql\\\"]}, {\\\"get_attr\\\": [\\\"NovaDBClient\\\", \\\"role_data\\\", \\\"service_config_settings\\\", \\\"mysql\\\"]}]}, \\\"rsyslog\\\": {\\\"tripleo_logging_sources_nova_scheduler\\\": [{\\\"get_param\\\": \\\"NovaSchedulerLoggingSource\\\"}]}}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"nova\\\", \\\"puppet_tags\\\": \\\"nova_config\\\", \\\"step_config\\\": {\\\"list_join\\\": [\\\"\\\\n\\\", [\\\"include tripleo::profile::base::nova::scheduler\\\", {\\\"get_attr\\\": [\\\"MySQLClient\\\", \\\"role_data\\\", \\\"step_config\\\"]}]]}, \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/nova_scheduler.json\\\": {\\\"command\\\": {\\\"list_join\\\": [\\\" \\\", [\\\"/usr/bin/nova-scheduler\\\", {\\\"get_attr\\\": [\\\"NovaLogging\\\", \\\"cmd_extra_args\\\"]}]]}, \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/nova\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"recurse\\\": true}]}}, \\\"docker_config\\\": {\\\"step_4\\\": {\\\"nova_scheduler\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaSchedulerImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"healthcheck_rpc_port\\\"]}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"NovaLogging\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/nova_scheduler.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/nova:/var/lib/kolla/config_files/src:ro\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"validate nova-scheduler container state\\\", \\\"containers.podman.podman_container_info\\\": {\\\"name\\\": \\\"nova_scheduler\\\"}, \\\"register\\\": \\\"nova_scheduler_infos\\\", \\\"failed_when\\\": [\\\"nova_scheduler_infos.containers.0.Healthcheck.Status is defined\\\", \\\"\'healthy\' not in nova_scheduler_infos.containers.0.Healthcheck.Status\\\"], \\\"retries\\\": 10, \\\"delay\\\": 30, \\\"tags\\\": [\\\"opendev-validation\\\", \\\"opendev-validation-nova\\\"], \\\"when\\\": [\\\"container_cli == \'podman\'\\\", \\\"not container_healthcheck_disabled\\\", \\\"step|int == 5\\\"]}], \\\"host_prep_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"NovaLogging\\\", \\\"host_prep_tasks\\\"]}, [{\\\"name\\\": \\\"enable virt_sandbox_use_netlink for healthcheck\\\", \\\"seboolean\\\": {\\\"name\\\": \\\"virt_sandbox_use_netlink\\\", \\\"persistent\\\": true, \\\"state\\\": true}, \\\"when\\\": [\\\"ansible_facts.selinux is defined\\\", \\\"ansible_facts.selinux.status == \\\\\\\"enabled\\\\\\\"\\\"]}]]}, \\\"external_upgrade_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade_transfer_data\\\", \\\"system_upgrade_stop_services\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Stop nova scheduler container\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_stop\\\"}, \\\"vars\\\": {\\\"tripleo_containers_to_stop\\\": [\\\"nova_scheduler\\\"], \\\"tripleo_delegate_to\\\": \\\"{{ groups[\'nova_scheduler\'] | difference(groups[\'excluded_overcloud\']) }}\\\"}}]}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Nova Vncproxy service\\\\n\\\", \\\"parameters\\\": {\\\"ContainerNovaVncProxyImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerNovaConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the nova config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NovaVncproxyLoggingSource\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {\\\"tag\\\": \\\"openstack.nova.vncproxy\\\", \\\"file\\\": \\\"/var/log/containers/nova/nova-novncproxy.log\\\"}}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"UseTLSTransportForVnc\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": true, \\\"description\\\": \\\"If set to true and if EnableInternalTLS is enabled, it will enable TLS transaport for libvirt VNC and configure the relevant keys for libvirt.\\\"}, \\\"InternalTLSVncProxyCAFile\\\": {\\\"default\\\": \\\"/etc/ipa/ca.crt\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Specifies the CA cert to use for VNC TLS.\\\"}, \\\"CertificateKeySize\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"2048\\\", \\\"description\\\": \\\"Specifies the private key size used when creating the certificate.\\\"}, \\\"NovaVNCCertificateKeySize\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Override the private key size used when creating the certificate for this service\\\"}, \\\"LibvirtVNCClientCertificateKeySize\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Override the private key size used when creating the certificate for this service\\\"}, \\\"LibvirtVncCACert\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"This specifies the CA certificate to use for VNC TLS. This file will be symlinked to the default CA path, which is /etc/pki/CA/certs/vnc.crt. This parameter should be used if the default (which comes from the InternalTLSVncProxyCAFile parameter) is not desired. The current default reflects TripleO\'s default CA, which is FreeIPA. It will only be used if internal TLS is enabled.\\\"}, \\\"NovaVNCProxySSLCiphers\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"OpenSSL cipher preference string that specifies what ciphers to allow for TLS connections from clients.  See the man page for the OpenSSL \'ciphers\' command for details of the cipher preference string format and allowed values.\\\"}, \\\"NovaVNCProxySSLMinimumVersion\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"default\\\", \\\"description\\\": \\\"Minimum allowed SSL/TLS protocol version.  Valid values are \'default\', \'tlsv1_1\', \'tlsv1_2\', and \'tlsv1_3\'.  A value of \'default\' will use the underlying system OpenSSL defaults.\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"default\\\", \\\"tlsv1_1\\\", \\\"tlsv1_2\\\", \\\"tlsv1_3\\\"]}]}, \\\"RootStackName\\\": {\\\"description\\\": \\\"The name of the stack/plan.\\\", \\\"type\\\": \\\"string\\\"}, \\\"AuthCloudName\\\": {\\\"description\\\": \\\"Entry in clouds.yaml to use for authentication\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\"}}, \\\"conditions\\\": {\\\"auth_cloud_name_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"AuthCloudName\\\"}, \\\"\\\"]}}, \\\"use_tls_for_vnc\\\": {\\\"and\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, {\\\"get_param\\\": \\\"UseTLSTransportForVnc\\\"}]}, \\\"libvirt_vnc_specific_ca_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"LibvirtVncCACert\\\"}, \\\"\\\"]}}, \\\"proxy_ssl_ciphers_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"NovaVNCProxySSLCiphers\\\"}, \\\"\\\"]}}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"MySQLClient\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\\\"}, \\\"NovaLogging\\\": {\\\"type\\\": \\\"OS::TripleO::Services::Logging::NovaCommon\\\", \\\"properties\\\": {\\\"ContainerNovaImage\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaVncProxyImage\\\"]}, \\\"NovaServiceName\\\": \\\"vncproxy\\\"}}, \\\"NovaBase\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"NovaDBClient\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerNovaVncProxyImage\\\": \\\"ContainerNovaVncProxyImage\\\", \\\"ContainerNovaConfigImage\\\": \\\"ContainerNovaConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerNovaVncProxyImage\\\": {\\\"get_param\\\": \\\"ContainerNovaVncProxyImage\\\"}, \\\"ContainerNovaConfigImage\\\": {\\\"get_param\\\": \\\"ContainerNovaConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Nova Vncproxy service.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"nova_vnc_proxy\\\", \\\"firewall_rules\\\": {\\\"137 nova_vnc_proxy\\\": {\\\"dport\\\": [6080]}}, \\\"firewall_frontend_rules\\\": {\\\"100 nova_vncproxy_haproxy_frontend\\\": {\\\"dport\\\": [6080]}}, \\\"firewall_ssl_frontend_rules\\\": {\\\"100 nova_vncproxy_haproxy_frontend_ssl\\\": {\\\"dport\\\": [13080]}}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"NovaBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"get_attr\\\": [\\\"NovaDBClient\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"get_attr\\\": [\\\"NovaLogging\\\", \\\"config_settings\\\"]}, {\\\"nova::vncproxy::enabled\\\": true, \\\"nova::vncproxy::common::vncproxy_protocol\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaVNCProxyCellPublic\\\", \\\"protocol\\\"]}, \\\"nova::vncproxy::common::vncproxy_host\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaVNCProxyCellPublic\\\", \\\"host_nobrackets\\\"]}, \\\"nova::vncproxy::common::vncproxy_port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"NovaVNCProxyCellPublic\\\", \\\"port\\\"]}, \\\"nova::vncproxy::host\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaLibvirtNetwork\\\"]}}}}}, {\\\"if\\\": [\\\"use_tls_for_vnc\\\", {\\\"nova::vncproxy::allow_vencrypt\\\": true, \\\"nova::vncproxy::vencrypt_key\\\": \\\"/etc/pki/tls/private/libvirt-vnc-client-cert.key\\\", \\\"nova::vncproxy::vencrypt_cert\\\": \\\"/etc/pki/tls/certs/libvirt-vnc-client-cert.crt\\\", \\\"nova::vncproxy::vencrypt_ca\\\": \\\"/etc/pki/CA/certs/vnc.crt\\\", \\\"nova::ssl_only\\\": true, \\\"nova::console_ssl_ciphers\\\": {\\\"if\\\": [\\\"proxy_ssl_ciphers_set\\\", {\\\"get_param\\\": \\\"NovaVNCProxySSLCiphers\\\"}]}, \\\"nova::console_ssl_minimum_version\\\": {\\\"get_param\\\": \\\"NovaVNCProxySSLMinimumVersion\\\"}, \\\"nova::cert\\\": \\\"/etc/pki/tls/certs/novnc-proxy.crt\\\", \\\"nova::key\\\": \\\"/etc/pki/tls/private/novnc-proxy.key\\\"}]}]}, \\\"service_config_settings\\\": {\\\"rabbitmq\\\": {\\\"get_attr\\\": [\\\"NovaBase\\\", \\\"role_data\\\", \\\"service_config_settings\\\"], \\\"rabbitmq\\\": null}, \\\"mysql\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"NovaDBClient\\\", \\\"role_data\\\", \\\"service_config_settings\\\", \\\"mysql\\\"]}]}, \\\"rsyslog\\\": {\\\"tripleo_logging_sources_nova_vnc_proxy\\\": [{\\\"get_param\\\": \\\"NovaVncproxyLoggingSource\\\"}]}}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"nova\\\", \\\"puppet_tags\\\": \\\"nova_config\\\", \\\"step_config\\\": {\\\"list_join\\\": [\\\"\\\\n\\\", [\\\"include tripleo::profile::base::nova::vncproxy\\\", {\\\"get_attr\\\": [\\\"MySQLClient\\\", \\\"role_data\\\", \\\"step_config\\\"]}]]}, \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/nova_vnc_proxy.json\\\": {\\\"command\\\": {\\\"list_join\\\": [\\\" \\\", [\\\"/usr/bin/nova-novncproxy --web /usr/share/novnc/\\\", {\\\"get_attr\\\": [\\\"NovaLogging\\\", \\\"cmd_extra_args\\\"]}]]}, \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-tls/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true, \\\"optional\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/nova\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/certs/novnc-proxy.crt\\\", \\\"owner\\\": \\\"root:root\\\", \\\"perm\\\": \\\"0644\\\"}, {\\\"path\\\": \\\"/etc/pki/tls/private/novnc-proxy.key\\\", \\\"owner\\\": \\\"root:qemu\\\", \\\"perm\\\": \\\"0640\\\"}, {\\\"path\\\": \\\"/etc/pki/tls/certs/libvirt-vnc-client-cert.crt\\\", \\\"owner\\\": \\\"root:root\\\", \\\"perm\\\": \\\"0644\\\"}, {\\\"path\\\": \\\"/etc/pki/tls/private/libvirt-vnc-client-cert.key\\\", \\\"owner\\\": \\\"root:qemu\\\", \\\"perm\\\": \\\"0640\\\"}]}}, \\\"docker_config\\\": {\\\"step_4\\\": {\\\"nova_vnc_proxy\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaVncProxyImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"NovaLogging\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/nova_vnc_proxy.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/nova:/var/lib/kolla/config_files/src:ro\\\"], {\\\"if\\\": [\\\"use_tls_for_vnc\\\", [{\\\"str_replace\\\": {\\\"template\\\": \\\"CACERT:/etc/pki/CA/certs/vnc.crt:ro\\\", \\\"params\\\": {\\\"CACERT\\\": {\\\"if\\\": [\\\"libvirt_vnc_specific_ca_set\\\", {\\\"get_param\\\": \\\"LibvirtVncCACert\\\"}, {\\\"get_param\\\": \\\"InternalTLSVncProxyCAFile\\\"}]}}}}, \\\"/etc/pki/tls/certs/libvirt-vnc-client-cert.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/libvirt-vnc-client-cert.crt:ro\\\", \\\"/etc/pki/tls/private/libvirt-vnc-client-cert.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/libvirt-vnc-client-cert.key:ro\\\", \\\"/etc/pki/tls/certs/novnc-proxy.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/novnc-proxy.crt:ro\\\", \\\"/etc/pki/tls/private/novnc-proxy.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/novnc-proxy.key:ro\\\"]]}]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"metadata_settings\\\": {\\\"if\\\": [\\\"use_tls_for_vnc\\\", [{\\\"service\\\": \\\"libvirt-vnc\\\", \\\"network\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaLibvirtNetwork\\\"]}, \\\"type\\\": \\\"node\\\"}, {\\\"service\\\": \\\"novnc-proxy\\\", \\\"network\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaLibvirtNetwork\\\"]}, \\\"type\\\": \\\"node\\\"}]]}, \\\"deploy_steps_tasks\\\": {\\\"list_concat\\\": [[{\\\"name\\\": \\\"validate nova-vnc-proxy container state\\\", \\\"containers.podman.podman_container_info\\\": {\\\"name\\\": \\\"nova_vnc_proxy\\\"}, \\\"register\\\": \\\"nova_vnc_proxy_infos\\\", \\\"failed_when\\\": [\\\"nova_vnc_proxy_infos.containers.0.Healthcheck.Status is defined\\\", \\\"\'healthy\' not in nova_vnc_proxy_infos.containers.0.Healthcheck.Status\\\"], \\\"retries\\\": 10, \\\"delay\\\": 30, \\\"tags\\\": [\\\"opendev-validation\\\", \\\"opendev-validation-nova\\\"], \\\"when\\\": [\\\"container_cli == \'podman\'\\\", \\\"not container_healthcheck_disabled\\\", \\\"step|int == 5\\\"]}], {\\\"if\\\": [\\\"use_tls_for_vnc\\\", [{\\\"name\\\": \\\"Certificate generation\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"vars\\\": {\\\"cert_key_size\\\": {\\\"get_param\\\": \\\"CertificateKeySize\\\"}, \\\"nova_vnc_key_size\\\": {\\\"get_param\\\": \\\"NovaVNCCertificateKeySize\\\"}, \\\"libvirt_vnc_key_size\\\": {\\\"get_param\\\": \\\"LibvirtVNCClientCertificateKeySize\\\"}, \\\"libvirt_network\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"{{ fqdn_NETWORK }}\\\", \\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"NovaLibvirtNetwork\\\"]}}}}}, \\\"block\\\": [{\\\"name\\\": \\\"Execute system role for Nova/Libvirt VNC certs\\\", \\\"loop\\\": [{\\\"name\\\": \\\"libvirt-vnc-client-cert\\\", \\\"key_size\\\": \\\"{{ libvirt_vnc_key_size | default(cert_key_size, true) }}\\\", \\\"principal\\\": \\\"libvirt-vnc/{{ libvirt_network }}@{{ idm_realm }}\\\"}, {\\\"name\\\": \\\"novnc-proxy\\\", \\\"key_size\\\": \\\"{{ nova_vnc_key_size | default(cert_key_size, true) }}\\\", \\\"principal\\\": \\\"novnc-proxy/{{ libvirt_network }}@{{ idm_realm }}\\\"}], \\\"loop_control\\\": {\\\"loop_var\\\": \\\"cert\\\"}, \\\"include_role\\\": {\\\"name\\\": \\\"linux-system-roles.certificate\\\"}, \\\"vars\\\": {\\\"certificate_requests\\\": [{\\\"name\\\": \\\"{{ cert.name }}\\\", \\\"dns\\\": \\\"{{ libvirt_network }}\\\", \\\"principal\\\": \\\"{{ cert.principal }}\\\", \\\"key_size\\\": \\\"{{ cert.key_size }}\\\", \\\"run_after\\\": \\\"container_name=$({{container_cli}} ps --format=\\\\\\\\{\\\\\\\\{.Names\\\\\\\\}\\\\\\\\} | grep nova_vnc_proxy)\\\\nservice_crt=\\\\\\\"/etc/pki/tls/certs/{{ cert.name }}.crt\\\\\\\"\\\\nservice_key=\\\\\\\"/etc/pki/tls/private/{{ cert.name }}.key\\\\\\\"\\\\n# Copy the new cert from the mount-point to the real path\\\\n{{container_cli}} exec -u root \\\\\\\"$container_name\\\\\\\" cp \\\\\\\"/var/lib/kolla/config_files/src-tls$service_crt\\\\\\\" \\\\\\\"$service_crt\\\\\\\"\\\\n# Copy the new key from the mount-point to the real path\\\\n{{container_cli}} exec -u root \\\\\\\"$container_name\\\\\\\" cp \\\\\\\"/var/lib/kolla/config_files/src-tls$service_key\\\\\\\" \\\\\\\"$service_key\\\\\\\"\\\\n\\\\n# Set permissions\\\\n{{container_cli}} exec -u root \\\\\\\"$container_name\\\\\\\" chmod 0644 $service_crt\\\\n{{container_cli}} exec -u root \\\\\\\"$container_name\\\\\\\" chmod 0640 $service_key\\\\n{{container_cli}} exec -u root \\\\\\\"$container_name\\\\\\\" chgrp qemu $service_key\\\\n\\\\n# No need to trigger a reload for novnc proxy since the cert is not cached\\\\n\\\", \\\"ca\\\": \\\"ipa\\\"}]}}]}]]}]}, \\\"host_prep_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"NovaLogging\\\", \\\"host_prep_tasks\\\"]}, [{\\\"name\\\": \\\"ensure qemu group is present on the host\\\", \\\"group\\\": {\\\"name\\\": \\\"qemu\\\", \\\"gid\\\": 107, \\\"state\\\": \\\"present\\\"}}, {\\\"name\\\": \\\"ensure qemu user is present on the host\\\", \\\"user\\\": {\\\"name\\\": \\\"qemu\\\", \\\"uid\\\": 107, \\\"group\\\": \\\"qemu\\\", \\\"state\\\": \\\"present\\\", \\\"shell\\\": \\\"/sbin/nologin\\\", \\\"comment\\\": \\\"qemu user\\\"}}]]}, \\\"post_upgrade_tasks\\\": [{\\\"when\\\": [\\\"step|int == 3\\\"], \\\"become\\\": true, \\\"environment\\\": {\\\"OS_CLOUD\\\": {\\\"if\\\": [\\\"auth_cloud_name_set\\\", {\\\"get_param\\\": \\\"AuthCloudName\\\"}, {\\\"get_param\\\": \\\"RootStackName\\\"}]}}, \\\"block\\\": [{\\\"name\\\": \\\"Get nova-consoleauth service ID\\\", \\\"command\\\": \\\"openstack compute service list --service nova-consoleauth --column ID  --column Host --format yaml\\\", \\\"register\\\": \\\"nova_compute_service_result\\\", \\\"check_mode\\\": false, \\\"run_once\\\": true, \\\"changed_when\\\": false, \\\"failed_when\\\": false, \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\"}, {\\\"name\\\": \\\"Deleting nova-consoleauth\\\", \\\"command\\\": \\\"openstack compute service delete {{ item.ID }}\\\", \\\"loop\\\": \\\"{{ nova_compute_service_result.stdout | from_yaml | default([]) }}\\\", \\\"run_once\\\": true, \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"failed_when\\\": false}]}], \\\"external_upgrade_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade_transfer_data\\\", \\\"system_upgrade_stop_services\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Stop nova vnc proxy container\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_stop\\\"}, \\\"vars\\\": {\\\"tripleo_containers_to_stop\\\": [\\\"nova_vnc_proxy\\\"], \\\"tripleo_delegate_to\\\": \\\"{{ groups[\'nova_vnc_proxy\'] | difference(groups[\'excluded_overcloud\']) }}\\\"}}]}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Containerized logrotate with crond for containerized service logs rotation\\\\n\\\", \\\"parameters\\\": {\\\"ContainerCrondImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerCrondConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the crond config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"LogrotateMaxsize\\\": {\\\"description\\\": \\\"Configures the maxsize param for containerized logrotate.\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"10M\\\"}, \\\"LogrotateRotationInterval\\\": {\\\"description\\\": \\\"Configures rotation interval for containerized logrotate.\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"daily\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"hourly\\\", \\\"daily\\\", \\\"weekly\\\", \\\"monthly\\\"]}]}, \\\"LogrotateRotate\\\": {\\\"description\\\": \\\"Configures the rotate param for containerized logrotate.\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"14\\\"}, \\\"LogrotatePurgeAfterDays\\\": {\\\"description\\\": \\\"Enforces life time (days) of rotated and compressed files.\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"14\\\"}, \\\"LogrotateDateExt\\\": {\\\"description\\\": \\\"Enable/disable dateext parameter.\\\", \\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"LogrotateDateFormat\\\": {\\\"description\\\": \\\"Configures dateformat strings for containerized logrotate. This is valid when LogrotateDateExt is true. The allowed specifiers are only %Y %m %d %H %M %S %V and %s.\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"-%Y%m%d\\\", \\\"constraints\\\": [{\\\"allowed_pattern\\\": \\\"-(%[YmdHMSVs])+$\\\"}]}, \\\"LogrotateDateYesterday\\\": {\\\"description\\\": \\\"Configures dateyesterday paramter for containerized logrotate. This is valid when LogrotateDateExt is true.\\\", \\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerCrondImage\\\": \\\"ContainerCrondImage\\\", \\\"ContainerCrondConfigImage\\\": \\\"ContainerCrondConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerCrondImage\\\": {\\\"get_param\\\": \\\"ContainerCrondImage\\\"}, \\\"ContainerCrondConfigImage\\\": {\\\"get_param\\\": \\\"ContainerCrondConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the crond role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"logrotate_crond\\\", \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"tripleo::profile::base::logging::logrotate::maxsize\\\": {\\\"get_param\\\": \\\"LogrotateMaxsize\\\"}, \\\"tripleo::profile::base::logging::logrotate::rotation\\\": {\\\"get_param\\\": \\\"LogrotateRotationInterval\\\"}, \\\"tripleo::profile::base::logging::logrotate::rotate\\\": {\\\"get_param\\\": \\\"LogrotateRotate\\\"}, \\\"tripleo::profile::base::logging::logrotate::purge_after_days\\\": {\\\"get_param\\\": \\\"LogrotatePurgeAfterDays\\\"}, \\\"tripleo::profile::base::logging::logrotate::dateext\\\": {\\\"get_param\\\": \\\"LogrotateDateExt\\\"}}, {\\\"if\\\": [{\\\"get_param\\\": \\\"LogrotateDateExt\\\"}, {\\\"tripleo::profile::base::logging::logrotate::dateformat\\\": {\\\"get_param\\\": \\\"LogrotateDateFormat\\\"}, \\\"tripleo::profile::base::logging::logrotate::dateyesterday\\\": {\\\"get_param\\\": \\\"LogrotateDateYesterday\\\"}}]}]}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"allow logrotate to read inside containers\\\", \\\"seboolean\\\": {\\\"name\\\": \\\"logrotate_read_inside_containers\\\", \\\"persistent\\\": true, \\\"state\\\": true}, \\\"when\\\": [\\\"ansible_facts.selinux is defined\\\", \\\"ansible_facts.selinux.status == \\\\\\\"enabled\\\\\\\"\\\"]}], \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"configure tmpwatch on the host\\\", \\\"when\\\": \\\"step|int == 2\\\", \\\"block\\\": [{\\\"name\\\": \\\"Push script\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/usr/local/sbin/containers-tmpwatch\\\", \\\"owner\\\": \\\"root\\\", \\\"group\\\": \\\"root\\\", \\\"mode\\\": 493, \\\"content\\\": \\\"#!/bin/sh\\\\ntmpwatch --nodirs \\\\\\\\\\\\n  -X \\\\\\\"/var/log/containers/*/*log\\\\\\\" \\\\\\\\\\\\n  -X \\\\\\\"/var/log/containers/*/*/*log\\\\\\\" \\\\\\\\\\\\n  -X \\\\\\\"/var/log/containers/*/*err\\\\\\\" \\\\\\\\\\\\n  {{ LogrotatePurgeAfterDays|int +1 }}d \\\\\\\\\\\\n  /var/log/containers/ 2>&1 | logger -t container-tmpwatch\\\\n\\\"}, \\\"vars\\\": {\\\"LogrotatePurgeAfterDays\\\": {\\\"get_param\\\": \\\"LogrotatePurgeAfterDays\\\"}}}, {\\\"name\\\": \\\"Insert cronjob in root crontab\\\", \\\"cron\\\": {\\\"name\\\": \\\"Remove old logs\\\", \\\"special_time\\\": \\\"daily\\\", \\\"user\\\": \\\"root\\\", \\\"job\\\": \\\"/usr/local/sbin/containers-tmpwatch\\\"}}]}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"Ensure old cron.daily is absent\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/cron.daily/containers-tmpwatch\\\", \\\"state\\\": \\\"absent\\\"}}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"Ensure old cron.daily is absent\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/cron.daily/containers-tmpwatch\\\", \\\"state\\\": \\\"absent\\\"}}], \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"crond\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::logging::logrotate\\\", \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCrondConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/logrotate-crond.json\\\": {\\\"command\\\": \\\"/usr/sbin/crond -s -n\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}}, \\\"docker_config\\\": {\\\"step_4\\\": {\\\"logrotate_crond\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCrondImage\\\"]}, \\\"net\\\": \\\"none\\\", \\\"pid\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"user\\\": \\\"root\\\", \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/usr/share/openstack-tripleo-common/healthcheck/cron\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/logrotate-crond.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/crond:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/log/containers:/var/log/containers:z\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"external_upgrade_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade_transfer_data\\\", \\\"system_upgrade_stop_services\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Stop logrotate container\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_stop\\\"}, \\\"vars\\\": {\\\"tripleo_containers_to_stop\\\": [\\\"logrotate_crond\\\"], \\\"tripleo_delegate_to\\\": \\\"{{ groups[\'logrotate_crond\'] | difference(groups[\'excluded_overcloud\']) }}\\\"}}]}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-base.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack Swift Proxy service configured with Puppet\\\\n\\\", \\\"parameters\\\": {\\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"SwiftHashSuffix\\\": {\\\"description\\\": \\\"A random string to be used as a salt when hashing to determine mappings in the ring.\\\", \\\"hidden\\\": true, \\\"type\\\": \\\"string\\\"}, \\\"SwiftHashPrefix\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"A random string to be used as an extra salt when hashing to determine mappings in the ring.\\\", \\\"hidden\\\": true, \\\"type\\\": \\\"string\\\"}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Swift common swift settings.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"swift_base\\\", \\\"config_settings\\\": {\\\"swift::swift_hash_path_suffix\\\": {\\\"get_param\\\": \\\"SwiftHashSuffix\\\"}, \\\"swift::swift_hash_path_prefix\\\": {\\\"get_param\\\": \\\"SwiftHashPrefix\\\"}}}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized swift proxy service\\\\n\\\", \\\"parameters\\\": {\\\"ContainerSwiftProxyImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerSwiftConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the swift config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"SwiftEncryptionEnabled\\\": {\\\"description\\\": \\\"Set to True to enable data-at-rest encryption in Swift\\\", \\\"default\\\": false, \\\"type\\\": \\\"boolean\\\"}, \\\"DeployIdentifier\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\\\n\\\"}, \\\"SwiftPassword\\\": {\\\"description\\\": \\\"The password for the swift service account\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"SwiftProxyNodeTimeout\\\": {\\\"default\\\": 60, \\\"description\\\": \\\"Timeout for requests going from swift-proxy to swift a/c/o services.\\\", \\\"type\\\": \\\"number\\\"}, \\\"SwiftProxyRecoverableNodeTimeout\\\": {\\\"default\\\": 30, \\\"description\\\": \\\"Timeout for GET/HEAD requests going from swift-proxy to swift a/c/o services.\\\", \\\"type\\\": \\\"number\\\"}, \\\"SwiftWorkers\\\": {\\\"default\\\": 0, \\\"description\\\": \\\"Number of workers for Swift service.\\\", \\\"type\\\": \\\"string\\\"}, \\\"KeystoneRegion\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"regionOne\\\", \\\"description\\\": \\\"Keystone region for endpoint\\\"}, \\\"MonitoringSubscriptionSwiftProxy\\\": {\\\"default\\\": \\\"overcloud-swift-proxy\\\", \\\"type\\\": \\\"string\\\"}, \\\"SwiftCeilometerPipelineEnabled\\\": {\\\"description\\\": \\\"Set to False to disable the swift proxy ceilometer pipeline.\\\", \\\"default\\\": false, \\\"type\\\": \\\"boolean\\\"}, \\\"SwiftCeilometerIgnoreProjects\\\": {\\\"default\\\": [\\\"service\\\"], \\\"description\\\": \\\"Comma-seperated list of project names to ignore.\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"MemcachedTLS\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"SwiftCorsAllowedOrigin\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Indicate whether this resource may be shared with the domain received in the request \\\\\\\"origin\\\\\\\" header.\\\"}, \\\"EnforceSecureRbac\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false, \\\"description\\\": \\\"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\\\"}}, \\\"conditions\\\": {\\\"internal_tls_enabled\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, true]}, \\\"swift_encryption_enabled\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"SwiftEncryptionEnabled\\\"}, true]}, \\\"ceilometer_pipeline_enabled\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"SwiftCeilometerPipelineEnabled\\\"}, true]}, \\\"use_tls_proxy\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, true]}, \\\"cors_allowed_origin_unset\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"SwiftCorsAllowedOrigin\\\"}, \\\"\\\"]}, \\\"swift_workers_zero\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"SwiftWorkers\\\"}, \\\"0\\\"]}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"SwiftBase\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-base.yaml\\\", \\\"properties\\\": {\\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"TLSProxyBase\\\": {\\\"type\\\": \\\"OS::TripleO::Services::TLSProxyBase\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}, \\\"EnableInternalTLS\\\": {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}}}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerSwiftProxyImage\\\": \\\"ContainerSwiftProxyImage\\\", \\\"ContainerSwiftConfigImage\\\": \\\"ContainerSwiftConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerSwiftProxyImage\\\": {\\\"get_param\\\": \\\"ContainerSwiftProxyImage\\\"}, \\\"ContainerSwiftConfigImage\\\": {\\\"get_param\\\": \\\"ContainerSwiftConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the swift proxy.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"swift_proxy\\\", \\\"firewall_rules\\\": {\\\"122 swift proxy\\\": {\\\"dport\\\": [8080]}}, \\\"firewall_frontend_rules\\\": {\\\"100 swift_proxy_server_haproxy_frontend\\\": {\\\"dport\\\": [8080]}}, \\\"firewall_ssl_frontend_rules\\\": {\\\"100 swift_proxy_server_haproxy_frontend_ssl\\\": {\\\"dport\\\": [13808]}}, \\\"keystone_resources\\\": {\\\"swift\\\": {\\\"endpoints\\\": {\\\"public\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftPublic\\\", \\\"uri\\\"]}, \\\"internal\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftInternal\\\", \\\"uri\\\"]}, \\\"admin\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftAdmin\\\", \\\"uri\\\"]}}, \\\"users\\\": {\\\"swift\\\": {\\\"password\\\": {\\\"get_param\\\": \\\"SwiftPassword\\\"}}}, \\\"region\\\": {\\\"get_param\\\": \\\"KeystoneRegion\\\"}, \\\"service\\\": \\\"object-store\\\", \\\"roles\\\": [\\\"swiftoperator\\\", \\\"ResellerAdmin\\\"]}}, \\\"monitoring_subscription\\\": {\\\"get_param\\\": \\\"MonitoringSubscriptionSwiftProxy\\\"}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"SwiftBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"get_attr\\\": [\\\"TLSProxyBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"if\\\": [\\\"cors_allowed_origin_unset\\\", {}, {\\\"swift::proxy::cors_allow_origin\\\": {\\\"get_param\\\": \\\"SwiftCorsAllowedOrigin\\\"}}]}, {\\\"swift::proxy::authtoken::www_authenticate_uri\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystonePublic\\\", \\\"uri_no_suffix\\\"]}, \\\"swift::proxy::authtoken::auth_url\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"uri_no_suffix\\\"]}, \\\"swift::proxy::authtoken::password\\\": {\\\"get_param\\\": \\\"SwiftPassword\\\"}, \\\"swift::proxy::authtoken::project_name\\\": \\\"service\\\", \\\"swift::proxy::authtoken::region_name\\\": {\\\"get_param\\\": \\\"KeystoneRegion\\\"}, \\\"swift::proxy::authtoken::interface\\\": \\\"internal\\\", \\\"swift::proxy::s3token::auth_uri\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneV3Internal\\\", \\\"uri\\\"]}, \\\"swift::proxy::node_timeout\\\": {\\\"get_param\\\": \\\"SwiftProxyNodeTimeout\\\"}, \\\"swift::proxy::recoverable_node_timeout\\\": {\\\"get_param\\\": \\\"SwiftProxyRecoverableNodeTimeout\\\"}}, {\\\"if\\\": [\\\"swift_workers_zero\\\", {}, {\\\"swift::proxy::workers\\\": {\\\"get_param\\\": \\\"SwiftWorkers\\\"}}]}, {\\\"if\\\": [\\\"ceilometer_pipeline_enabled\\\", {\\\"swift::proxy::ceilometer::auth_url\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"uri_no_suffix\\\"]}, \\\"swift::proxy::ceilometer::password\\\": {\\\"get_param\\\": \\\"SwiftPassword\\\"}, \\\"swift::proxy::ceilometer::project_name\\\": \\\"service\\\", \\\"swift::proxy::ceilometer::region_name\\\": {\\\"get_param\\\": \\\"KeystoneRegion\\\"}, \\\"swift::proxy::ceilometer::ignore_projects\\\": {\\\"get_param\\\": \\\"SwiftCeilometerIgnoreProjects\\\"}, \\\"swift::proxy::ceilometer::nonblocking_notify\\\": true, \\\"swift::proxy::ceilometer::rabbit_heartbeat_in_pthread\\\": false}, {}]}, {\\\"swift::proxy::staticweb::url_base\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftPublic\\\", \\\"uri_no_suffix\\\"]}, \\\"tripleo::profile::base::swift::proxy::ceilometer_enabled\\\": {\\\"get_param\\\": \\\"SwiftCeilometerPipelineEnabled\\\"}, \\\"swift::proxy::keystone::operator_roles\\\": [\\\"admin\\\", \\\"swiftoperator\\\", \\\"ResellerAdmin\\\"], \\\"swift::proxy::versioned_writes::allow_versioned_writes\\\": true}, {\\\"if\\\": [{\\\"get_param\\\": \\\"EnforceSecureRbac\\\"}, {\\\"swift::proxy::keystone::project_reader_roles\\\": [\\\"SwiftProjectReader\\\"]}, {\\\"swift::proxy::keystone::system_reader_roles\\\": [\\\"SwiftSystemReader\\\"]}]}, {\\\"if\\\": [\\\"swift_encryption_enabled\\\", {\\\"swift::keymaster::key_id\\\": \\\"test_id\\\", \\\"swift::keymaster::username\\\": \\\"swift\\\", \\\"swift::keymaster::password\\\": {\\\"get_param\\\": \\\"SwiftPassword\\\"}, \\\"swift::keymaster::project_name\\\": \\\"service\\\", \\\"swift::keymaster::project_domain_id\\\": \\\"default\\\", \\\"swift::keymaster::user_domain_id\\\": \\\"default\\\", \\\"swift::keymaster::auth_endpoint\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"uri\\\"]}}, {}]}, {\\\"swift::proxy::pipeline\\\": {\\\"list_concat\\\": [[\\\"catch_errors\\\", \\\"gatekeeper\\\", \\\"healthcheck\\\", \\\"proxy-logging\\\", \\\"cache\\\", \\\"listing_formats\\\", \\\"ratelimit\\\", \\\"bulk\\\", \\\"tempurl\\\", \\\"formpost\\\", \\\"authtoken\\\", \\\"s3api\\\", \\\"s3token\\\", \\\"keystone\\\", \\\"staticweb\\\", \\\"copy\\\", \\\"container_quotas\\\", \\\"account_quotas\\\", \\\"slo\\\", \\\"dlo\\\", \\\"versioned_writes\\\"], {\\\"if\\\": [\\\"ceilometer_pipeline_enabled\\\", [\\\"ceilometer\\\"], []]}, {\\\"if\\\": [\\\"swift_encryption_enabled\\\", [\\\"kms_keymaster\\\", \\\"encryption\\\"], []]}, [\\\"proxy-logging\\\", \\\"proxy-server\\\"]]}, \\\"swift::proxy::account_autocreate\\\": true, \\\"tripleo::profile::base::swift::proxy::tls_proxy_bind_ip\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"SwiftProxyNetwork\\\"]}}}}, \\\"tripleo::profile::base::swift::proxy::tls_proxy_fqdn\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'fqdn_$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"SwiftProxyNetwork\\\"]}}}}, \\\"tripleo::profile::base::swift::proxy::tls_proxy_port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftInternal\\\", \\\"port\\\"]}, \\\"swift::proxy::port\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"SwiftInternal\\\", \\\"port\\\"]}, \\\"swift::proxy::proxy_local_net_ip\\\": {\\\"if\\\": [\\\"use_tls_proxy\\\", \\\"%{hiera(\'localhost_address\')}\\\", {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"SwiftProxyNetwork\\\"]}}}}]}, \\\"swift::proxy::cache::tls_enabled\\\": {\\\"get_param\\\": \\\"MemcachedTLS\\\"}}]}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"swift\\\", \\\"puppet_tags\\\": \\\"swift_config,swift_proxy_config,swift_keymaster_config\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::swift::proxy\\\\n\\\", \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerSwiftConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/swift_proxy.json\\\": {\\\"command\\\": \\\"/usr/bin/swift-proxy-server /etc/swift/proxy-server.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}, \\\"/var/lib/kolla/config_files/swift_proxy_tls_proxy.json\\\": {\\\"command\\\": \\\"/usr/sbin/httpd -DFOREGROUND\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/etc/httpd/conf.d\\\", \\\"dest\\\": \\\"/etc/httpd/conf.d\\\", \\\"merge\\\": false, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\\\", \\\"dest\\\": \\\"/etc/httpd/conf.modules.d\\\", \\\"merge\\\": false, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}}, \\\"container_config_scripts\\\": {\\\"create_swift_secret.sh\\\": {\\\"mode\\\": \\\"0700\\\", \\\"content\\\": \\\"#!/bin/bash\\\\nexport OS_PROJECT_DOMAIN_ID=$(crudini --get /etc/swift/keymaster.conf kms_keymaster project_domain_id)\\\\nexport OS_USER_DOMAIN_ID=$(crudini --get /etc/swift/keymaster.conf kms_keymaster user_domain_id)\\\\nexport OS_PROJECT_NAME=$(crudini --get /etc/swift/keymaster.conf kms_keymaster project_name)\\\\nexport OS_USERNAME=$(crudini --get /etc/swift/keymaster.conf kms_keymaster username)\\\\nexport OS_PASSWORD=$(crudini --get /etc/swift/keymaster.conf kms_keymaster password)\\\\nexport OS_AUTH_URL=$(crudini --get /etc/swift/keymaster.conf kms_keymaster auth_endpoint)\\\\nexport OS_AUTH_TYPE=password\\\\nexport OS_IDENTITY_API_VERSION=3\\\\n\\\\necho \\\\\\\"Check if secret already exists\\\\\\\"\\\\nsecret_href=$(openstack secret list --name swift_root_secret_uuid)\\\\nrc=$?\\\\nif [[ $rc != 0 ]]; then\\\\n  echo \\\\\\\"Failed to check secrets, check if Barbican in enabled and responding properly\\\\\\\"\\\\n  exit $rc;\\\\nfi\\\\nif [ -z \\\\\\\"$secret_href\\\\\\\" ]; then\\\\n  echo \\\\\\\"Create new secret\\\\\\\"\\\\n  order_href=$(openstack secret order create --name swift_root_secret_uuid --payload-content-type=\\\\\\\"application/octet-stream\\\\\\\" --algorithm aes --bit-length 256 --mode ctr key -f value -c \\\\\\\"Order href\\\\\\\")\\\\nfi\\\\n\\\"}, \\\"set_swift_keymaster_key_id.sh\\\": {\\\"mode\\\": \\\"0700\\\", \\\"content\\\": \\\"#!/bin/bash\\\\nexport OS_PROJECT_DOMAIN_ID=$(crudini --get /etc/swift/keymaster.conf kms_keymaster project_domain_id)\\\\nexport OS_USER_DOMAIN_ID=$(crudini --get /etc/swift/keymaster.conf kms_keymaster user_domain_id)\\\\nexport OS_PROJECT_NAME=$(crudini --get /etc/swift/keymaster.conf kms_keymaster project_name)\\\\nexport OS_USERNAME=$(crudini --get /etc/swift/keymaster.conf kms_keymaster username)\\\\nexport OS_PASSWORD=$(crudini --get /etc/swift/keymaster.conf kms_keymaster password)\\\\nexport OS_AUTH_URL=$(crudini --get /etc/swift/keymaster.conf kms_keymaster auth_endpoint)\\\\nexport OS_AUTH_TYPE=password\\\\nexport OS_IDENTITY_API_VERSION=3\\\\necho \\\\\\\"retrieve key_id\\\\\\\"\\\\nloop_wait=2\\\\nfor i in {0..5}; do\\\\n  #TODO update uuid from mistral here too\\\\n  secret_href=$(openstack secret list --name swift_root_secret_uuid)\\\\n  if [ \\\\\\\"$secret_href\\\\\\\" ]; then\\\\n    echo \\\\\\\"set key_id in keymaster.conf\\\\\\\"\\\\n    secret_href=$(openstack secret list --name swift_root_secret_uuid -f value -c \\\\\\\"Secret href\\\\\\\")\\\\n    crudini --set /etc/swift/keymaster.conf kms_keymaster key_id ${secret_href##*/}\\\\n    exit 0\\\\n  else\\\\n    echo \\\\\\\"no key, wait for $loop_wait and check again\\\\\\\"\\\\n    sleep $loop_wait\\\\n    ((loop_wait++))\\\\n  fi\\\\ndone\\\\necho \\\\\\\"Failed to set secret in keymaster.conf, check if Barbican is enabled and responding properly\\\\\\\"\\\\nexit 1\\\\n\\\"}}, \\\"docker_config\\\": {\\\"step_4\\\": {\\\"map_merge\\\": [{\\\"if\\\": [\\\"swift_encryption_enabled\\\", {\\\"create_swift_secret\\\": {\\\"start_order\\\": 0, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerSwiftProxyImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"detach\\\": false, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/config-data/puppet-generated/swift/etc/swift:/etc/swift:ro\\\", \\\"/var/lib/container-config-scripts/create_swift_secret.sh:/create_swift_secret.sh:ro\\\"]]}, \\\"user\\\": \\\"root\\\", \\\"command\\\": \\\"/usr/bin/bootstrap_host_exec swift_proxy /create_swift_secret.sh\\\"}}, {}]}, {\\\"if\\\": [\\\"swift_encryption_enabled\\\", {\\\"set_swift_secret\\\": {\\\"start_order\\\": 1, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerSwiftProxyImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"detach\\\": false, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/config-data/puppet-generated/swift/etc/swift:/etc/swift:rw,z\\\", \\\"/var/lib/container-config-scripts/set_swift_keymaster_key_id.sh:/set_swift_keymaster_key_id.sh:ro\\\"]]}, \\\"user\\\": \\\"root\\\", \\\"command\\\": \\\"/set_swift_keymaster_key_id.sh\\\", \\\"environment\\\": {\\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}}}}, {}]}, {\\\"swift_proxy\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerSwiftProxyImage\\\"]}, \\\"start_order\\\": 2, \\\"net\\\": \\\"host\\\", \\\"user\\\": \\\"swift\\\", \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/swift_proxy.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/swift:/var/lib/kolla/config_files/src:ro\\\", \\\"/srv/node:/srv/node\\\", \\\"/dev:/dev\\\", \\\"/var/log/containers/swift:/var/log/swift:z\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}, {\\\"if\\\": [\\\"internal_tls_enabled\\\", {\\\"swift_proxy_tls_proxy\\\": {\\\"start_order\\\": 3, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerSwiftProxyImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"user\\\": \\\"root\\\", \\\"restart\\\": \\\"always\\\", \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/swift_proxy_tls_proxy.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/swift:/var/lib/kolla/config_files/src:ro\\\", \\\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\\\", \\\"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}, {}]}]}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode|default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/srv/node\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/log/swift\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/log/containers/swift\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}], \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Configure rsyslog for swift\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Check if rsyslog exists\\\", \\\"shell\\\": \\\"systemctl is-active rsyslog\\\", \\\"register\\\": \\\"swift_rsyslog_config\\\"}, {\\\"name\\\": \\\"Forward logging to swift.log file\\\", \\\"copy\\\": {\\\"content\\\": \\\"# Fix for https://bugs.launchpad.net/tripleo/+bug/1776180\\\\nlocal2.*                 /var/log/containers/swift/swift.log\\\\n&                        stop\\\\n\\\", \\\"dest\\\": \\\"/etc/rsyslog.d/openstack-swift.conf\\\"}, \\\"register\\\": \\\"swift_logconfig\\\", \\\"when\\\": [\\\"swift_rsyslog_config is defined\\\", \\\"swift_rsyslog_config.rc == 0\\\"]}, {\\\"name\\\": \\\"Restart rsyslogd service after logging conf change\\\", \\\"service\\\": {\\\"name\\\": \\\"rsyslog\\\", \\\"state\\\": \\\"restarted\\\"}, \\\"when\\\": [\\\"swift_logconfig is defined\\\", \\\"swift_logconfig is changed\\\"]}]}, {\\\"name\\\": \\\"Run kolla_set_configs to copy ring files\\\", \\\"when\\\": \\\"step|int == 5\\\", \\\"shell\\\": \\\"{{ container_cli }} exec -u root {{ item }} /usr/local/bin/kolla_set_configs \\\", \\\"become\\\": true, \\\"register\\\": \\\"kolla_set_configs_result\\\", \\\"failed_when\\\": [\\\"kolla_set_configs_result.rc is defined\\\", \\\"kolla_set_configs_result.rc not in [0, 125]\\\"], \\\"with_items\\\": [\\\"swift_proxy\\\"]}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"Check swift containers log folder/symlink exists\\\", \\\"stat\\\": {\\\"path\\\": \\\"/var/log/containers/swift\\\"}, \\\"register\\\": \\\"swift_log_link\\\"}, {\\\"name\\\": \\\"Delete if symlink\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/log/containers/swift\\\", \\\"state\\\": \\\"absent\\\"}, \\\"when\\\": \\\"swift_log_link.stat.islnk is defined and swift_log_link.stat.islnk\\\"}], \\\"metadata_settings\\\": {\\\"get_attr\\\": [\\\"TLSProxyBase\\\", \\\"role_data\\\", \\\"metadata_settings\\\"]}}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Swift Storage services.\\\\n\\\", \\\"parameters\\\": {\\\"ContainerSwiftProxyImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerSwiftAccountImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerSwiftContainerImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerSwiftObjectImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerSwiftConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the swift config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"SwiftRawDisks\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"A hash of additional raw devices to use as Swift backend (eg. {sdb: {}})\\\", \\\"type\\\": \\\"json\\\"}, \\\"SwiftReplicas\\\": {\\\"type\\\": \\\"number\\\", \\\"default\\\": 3, \\\"description\\\": \\\"How many replicas to use in the swift rings.\\\"}, \\\"SwiftUseLocalDir\\\": {\\\"default\\\": true, \\\"description\\\": \\\"Use a local directory for Swift storage services when building rings\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"SwiftContainerSharderEnabled\\\": {\\\"description\\\": \\\"Set to True to enable Swift container sharder service\\\", \\\"default\\\": false, \\\"type\\\": \\\"boolean\\\"}, \\\"SwiftMountCheck\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Value of mount_check in Swift account/container/object -server.conf\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"SwiftUseNodeDataLookup\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Use NodeDataLookup for disk devices in order to use persistent naming\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"SwiftAccountWorkers\\\": {\\\"default\\\": 0, \\\"description\\\": \\\"Number of workers for Swift account service.\\\", \\\"type\\\": \\\"string\\\"}, \\\"SwiftContainerWorkers\\\": {\\\"default\\\": 0, \\\"description\\\": \\\"Number of workers for Swift account service.\\\", \\\"type\\\": \\\"string\\\"}, \\\"SwiftObjectWorkers\\\": {\\\"default\\\": 0, \\\"description\\\": \\\"Number of workers for Swift account service.\\\", \\\"type\\\": \\\"string\\\"}, \\\"DeployIdentifier\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\\\n\\\"}, \\\"MemcachedTLS\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"ControllerEnableSwiftStorage\\\": {\\\"default\\\": true, \\\"description\\\": \\\"Whether to enable Swift Storage on the Controller\\\", \\\"type\\\": \\\"boolean\\\"}}, \\\"parameter_groups\\\": [{\\\"label\\\": \\\"deprecated\\\", \\\"description\\\": \\\"Do not use deprecated params, they will be removed.\\\", \\\"parameters\\\": [\\\"ControllerEnableSwiftStorage\\\"]}], \\\"conditions\\\": {\\\"single_replica_mode\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"SwiftReplicas\\\"}, 1]}, \\\"swift_container_sharder_enabled\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"SwiftContainerSharderEnabled\\\"}, true]}, \\\"swift_mount_check\\\": {\\\"or\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"SwiftMountCheck\\\"}, true]}, {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"SwiftRawDisks\\\"}, {}]}}]}, \\\"account_workers_zero\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"SwiftAccountWorkers\\\"}, \\\"0\\\"]}, \\\"container_workers_zero\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"SwiftContainerWorkers\\\"}, \\\"0\\\"]}, \\\"object_workers_zero\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"SwiftObjectWorkers\\\"}, \\\"0\\\"]}, \\\"use_node_data_lookup\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"SwiftUseNodeDataLookup\\\"}, true]}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"SwiftBase\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-base.yaml\\\", \\\"properties\\\": {\\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerSwiftProxyImage\\\": \\\"ContainerSwiftProxyImage\\\", \\\"ContainerSwiftAccountImage\\\": \\\"ContainerSwiftAccountImage\\\", \\\"ContainerSwiftContainerImage\\\": \\\"ContainerSwiftContainerImage\\\", \\\"ContainerSwiftObjectImage\\\": \\\"ContainerSwiftObjectImage\\\", \\\"ContainerSwiftConfigImage\\\": \\\"ContainerSwiftConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerSwiftProxyImage\\\": {\\\"get_param\\\": \\\"ContainerSwiftProxyImage\\\"}, \\\"ContainerSwiftAccountImage\\\": {\\\"get_param\\\": \\\"ContainerSwiftAccountImage\\\"}, \\\"ContainerSwiftContainerImage\\\": {\\\"get_param\\\": \\\"ContainerSwiftContainerImage\\\"}, \\\"ContainerSwiftObjectImage\\\": {\\\"get_param\\\": \\\"ContainerSwiftObjectImage\\\"}, \\\"ContainerSwiftConfigImage\\\": {\\\"get_param\\\": \\\"ContainerSwiftConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the swift storage services.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"swift_storage\\\", \\\"firewall_rules\\\": {\\\"123 swift storage\\\": {\\\"dport\\\": [873, 6000, 6001, 6002]}}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"SwiftBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"swift::storage::all::mount_check\\\": false, \\\"tripleo::profile::base::swift::storage::use_local_dir\\\": {\\\"get_param\\\": \\\"SwiftUseLocalDir\\\"}, \\\"swift::storage::all::incoming_chmod\\\": \\\"Du=rwx,g=rx,o=rx,Fu=rw,g=r,o=r\\\", \\\"swift::storage::all::outgoing_chmod\\\": \\\"Du=rwx,g=rx,o=rx,Fu=rw,g=r,o=r\\\", \\\"swift::storage::all::account_port\\\": 6002, \\\"swift::storage::all::container_port\\\": 6001, \\\"swift::storage::all::object_port\\\": 6000, \\\"swift::storage::all::object_pipeline\\\": [\\\"healthcheck\\\", \\\"recon\\\", \\\"object-server\\\"], \\\"swift::storage::all::container_pipeline\\\": [\\\"healthcheck\\\", \\\"recon\\\", \\\"container-server\\\"], \\\"swift::storage::all::account_pipeline\\\": [\\\"healthcheck\\\", \\\"recon\\\", \\\"account-server\\\"]}, {\\\"if\\\": [\\\"use_node_data_lookup\\\", {}, {\\\"swift::storage::disks::args\\\": {\\\"get_param\\\": \\\"SwiftRawDisks\\\"}}]}, {\\\"swift::storage::all::storage_local_net_ip\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"SwiftStorageNetwork\\\"]}}}}, \\\"rsync::server::pid_file\\\": \\\"UNSET\\\", \\\"swift::objectexpirer::cache_tls_enabled\\\": {\\\"get_param\\\": \\\"MemcachedTLS\\\"}}, {\\\"if\\\": [\\\"account_workers_zero\\\", {}, {\\\"swift::storage::all::account_server_workers\\\": {\\\"get_param\\\": \\\"SwiftAccountWorkers\\\"}}]}, {\\\"if\\\": [\\\"container_workers_zero\\\", {}, {\\\"swift::storage::all::container_server_workers\\\": {\\\"get_param\\\": \\\"SwiftContainerWorkers\\\"}}]}, {\\\"if\\\": [\\\"object_workers_zero\\\", {}, {\\\"swift::storage::all::object_server_workers\\\": {\\\"get_param\\\": \\\"SwiftObjectWorkers\\\"}}]}]}, \\\"service_config_settings\\\": {}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"swift\\\", \\\"puppet_tags\\\": \\\"swift_config,swift_container_config,swift_container_sync_realms_config,swift_account_config,swift_object_config,swift_object_expirer_config,rsync::server\\\", \\\"step_config\\\": {\\\"list_join\\\": [\\\"\\\\n\\\", [\\\"class xinetd() {}\\\", \\\"define xinetd::service($bind=\'\',$port=\'\',$server=\'\',$server_args=\'\') {}\\\", \\\"noop_resource(\'service\')\\\", \\\"include tripleo::profile::base::swift::storage\\\"]]}, \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerSwiftConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/swift_account_auditor.json\\\": {\\\"command\\\": \\\"/usr/bin/swift-account-auditor /etc/swift/account-server.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}, \\\"/var/lib/kolla/config_files/swift_account_reaper.json\\\": {\\\"command\\\": \\\"/usr/bin/swift-account-reaper /etc/swift/account-server.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}, \\\"/var/lib/kolla/config_files/swift_account_replicator.json\\\": {\\\"command\\\": \\\"/usr/bin/swift-account-replicator /etc/swift/account-server.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}, \\\"/var/lib/kolla/config_files/swift_account_server.json\\\": {\\\"command\\\": \\\"/usr/bin/swift-account-server /etc/swift/account-server.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}, \\\"/var/lib/kolla/config_files/swift_container_auditor.json\\\": {\\\"command\\\": \\\"/usr/bin/swift-container-auditor /etc/swift/container-server.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}, \\\"/var/lib/kolla/config_files/swift_container_replicator.json\\\": {\\\"command\\\": \\\"/usr/bin/swift-container-replicator /etc/swift/container-server.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}, \\\"/var/lib/kolla/config_files/swift_container_updater.json\\\": {\\\"command\\\": \\\"/usr/bin/swift-container-updater /etc/swift/container-server.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}, \\\"/var/lib/kolla/config_files/swift_container_server.json\\\": {\\\"command\\\": \\\"/usr/bin/swift-container-server /etc/swift/container-server.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}, \\\"/var/lib/kolla/config_files/swift_container_sharder.json\\\": {\\\"command\\\": \\\"/usr/bin/swift-container-sharder /etc/swift/container-server.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}, \\\"/var/lib/kolla/config_files/swift_object_auditor.json\\\": {\\\"command\\\": \\\"/usr/bin/swift-object-auditor /etc/swift/object-server.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}, \\\"/var/lib/kolla/config_files/swift_object_expirer.json\\\": {\\\"command\\\": \\\"/usr/bin/swift-object-expirer /etc/swift/object-expirer.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}, \\\"/var/lib/kolla/config_files/swift_object_replicator.json\\\": {\\\"command\\\": \\\"/usr/bin/swift-object-replicator /etc/swift/object-server.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}, \\\"/var/lib/kolla/config_files/swift_object_updater.json\\\": {\\\"command\\\": \\\"/usr/bin/swift-object-updater /etc/swift/object-server.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}, \\\"/var/lib/kolla/config_files/swift_object_server.json\\\": {\\\"command\\\": \\\"/usr/bin/swift-object-server /etc/swift/object-server.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/cache/swift\\\", \\\"owner\\\": \\\"swift:swift\\\", \\\"recurse\\\": true}]}, \\\"/var/lib/kolla/config_files/swift_rsync.json\\\": {\\\"command\\\": \\\"/usr/bin/rsync --daemon --no-detach --config=/etc/rsyncd.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}}, \\\"docker_config\\\": {\\\"step_3\\\": {\\\"swift_setup_srv\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerSwiftAccountImage\\\"]}, \\\"net\\\": \\\"none\\\", \\\"user\\\": \\\"root\\\", \\\"command\\\": [\\\"find\\\", \\\"/srv/node\\\", \\\"-maxdepth\\\", \\\"1\\\", \\\"-type\\\", \\\"d\\\", \\\"-exec\\\", \\\"chown\\\", \\\"swift:\\\", \\\"{}\\\", \\\";\\\"], \\\"volumes\\\": [\\\"/srv/node:/srv/node:z\\\"], \\\"environment\\\": {\\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}}}}, \\\"step_4\\\": {\\\"map_merge\\\": [{\\\"if\\\": [\\\"single_replica_mode\\\", {}, {\\\"swift_account_auditor\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerSwiftAccountImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"user\\\": \\\"swift\\\", \\\"restart\\\": \\\"always\\\", \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/swift_account_auditor.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/swift:/var/lib/kolla/config_files/src:ro\\\", \\\"/srv/node:/srv/node\\\", \\\"/dev:/dev\\\", \\\"/var/cache/swift:/var/cache/swift:z\\\", \\\"/var/log/containers/swift:/var/log/swift:z\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}, \\\"swift_account_replicator\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerSwiftAccountImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"user\\\": \\\"swift\\\", \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/swift_account_replicator.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/swift:/var/lib/kolla/config_files/src:ro\\\", \\\"/srv/node:/srv/node\\\", \\\"/dev:/dev\\\", \\\"/var/cache/swift:/var/cache/swift\\\", \\\"/var/log/containers/swift:/var/log/swift:z\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}, \\\"swift_container_auditor\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerSwiftContainerImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"user\\\": \\\"swift\\\", \\\"restart\\\": \\\"always\\\", \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/swift_container_auditor.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/swift:/var/lib/kolla/config_files/src:ro\\\", \\\"/srv/node:/srv/node\\\", \\\"/dev:/dev\\\", \\\"/var/cache/swift:/var/cache/swift\\\", \\\"/var/log/containers/swift:/var/log/swift:z\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}, \\\"swift_container_replicator\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerSwiftContainerImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"user\\\": \\\"swift\\\", \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/swift_container_replicator.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/swift:/var/lib/kolla/config_files/src:ro\\\", \\\"/srv/node:/srv/node\\\", \\\"/dev:/dev\\\", \\\"/var/cache/swift:/var/cache/swift\\\", \\\"/var/log/containers/swift:/var/log/swift:z\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}, \\\"swift_object_auditor\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerSwiftObjectImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"user\\\": \\\"swift\\\", \\\"restart\\\": \\\"always\\\", \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/swift_object_auditor.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/swift:/var/lib/kolla/config_files/src:ro\\\", \\\"/srv/node:/srv/node\\\", \\\"/dev:/dev\\\", \\\"/var/cache/swift:/var/cache/swift\\\", \\\"/var/log/containers/swift:/var/log/swift:z\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}, \\\"swift_object_replicator\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerSwiftObjectImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"user\\\": \\\"swift\\\", \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/swift_object_replicator.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/swift:/var/lib/kolla/config_files/src:ro\\\", \\\"/srv/node:/srv/node\\\", \\\"/dev:/dev\\\", \\\"/var/cache/swift:/var/cache/swift\\\", \\\"/var/log/containers/swift:/var/log/swift:z\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}, \\\"swift_rsync\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerSwiftObjectImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"user\\\": \\\"root\\\", \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"privileged\\\": false, \\\"cap_add\\\": [\\\"NET_BIND_SERVICE\\\"], \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/swift_rsync.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/swift:/var/lib/kolla/config_files/src:ro\\\", \\\"/srv/node:/srv/node\\\", \\\"/dev:/dev\\\", \\\"/var/log/containers/swift:/var/log/swift:z\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}]}, {\\\"swift_account_reaper\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerSwiftAccountImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"user\\\": \\\"swift\\\", \\\"restart\\\": \\\"always\\\", \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/swift_account_reaper.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/swift:/var/lib/kolla/config_files/src:ro\\\", \\\"/srv/node:/srv/node\\\", \\\"/dev:/dev\\\", \\\"/var/cache/swift:/var/cache/swift:z\\\", \\\"/var/log/containers/swift:/var/log/swift:z\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}, \\\"swift_account_server\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerSwiftAccountImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"user\\\": \\\"swift\\\", \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/swift_account_server.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/swift:/var/lib/kolla/config_files/src:ro\\\", \\\"/srv/node:/srv/node\\\", \\\"/dev:/dev\\\", \\\"/var/cache/swift:/var/cache/swift\\\", \\\"/var/log/containers/swift:/var/log/swift:z\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}, \\\"swift_container_updater\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerSwiftContainerImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"user\\\": \\\"swift\\\", \\\"restart\\\": \\\"always\\\", \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/swift_container_updater.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/swift:/var/lib/kolla/config_files/src:ro\\\", \\\"/srv/node:/srv/node\\\", \\\"/dev:/dev\\\", \\\"/var/cache/swift:/var/cache/swift\\\", \\\"/var/log/containers/swift:/var/log/swift:z\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}, \\\"swift_container_server\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerSwiftContainerImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"user\\\": \\\"swift\\\", \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/swift_container_server.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/swift:/var/lib/kolla/config_files/src:ro\\\", \\\"/srv/node:/srv/node\\\", \\\"/dev:/dev\\\", \\\"/var/cache/swift:/var/cache/swift\\\", \\\"/var/log/containers/swift:/var/log/swift:z\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}, \\\"swift_object_expirer\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerSwiftProxyImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"user\\\": \\\"swift\\\", \\\"restart\\\": \\\"always\\\", \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/swift_object_expirer.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/swift:/var/lib/kolla/config_files/src:ro\\\", \\\"/srv/node:/srv/node\\\", \\\"/dev:/dev\\\", \\\"/var/cache/swift:/var/cache/swift\\\", \\\"/var/log/containers/swift:/var/log/swift:z\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}, \\\"swift_object_updater\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerSwiftObjectImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"user\\\": \\\"swift\\\", \\\"restart\\\": \\\"always\\\", \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/swift_object_updater.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/swift:/var/lib/kolla/config_files/src:ro\\\", \\\"/srv/node:/srv/node\\\", \\\"/dev:/dev\\\", \\\"/var/cache/swift:/var/cache/swift\\\", \\\"/var/log/containers/swift:/var/log/swift:z\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}, \\\"swift_object_server\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerSwiftObjectImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"user\\\": \\\"swift\\\", \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/swift_object_server.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/swift:/var/lib/kolla/config_files/src:ro\\\", \\\"/srv/node:/srv/node\\\", \\\"/dev:/dev\\\", \\\"/var/cache/swift:/var/cache/swift\\\", \\\"/var/log/containers/swift:/var/log/swift:z\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}, {\\\"if\\\": [\\\"swift_container_sharder_enabled\\\", {\\\"swift_container_sharder\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerSwiftContainerImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"user\\\": \\\"swift\\\", \\\"restart\\\": \\\"always\\\", \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/swift_container_sharder.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/swift:/var/lib/kolla/config_files/src:ro\\\", \\\"/srv/node:/srv/node\\\", \\\"/dev:/dev\\\", \\\"/var/cache/swift:/var/cache/swift\\\", \\\"/var/log/containers/swift:/var/log/swift:z\\\"]]}}}, {}]}]}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode|default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/srv/node\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/cache/swift\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/log/containers/swift\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}, {\\\"name\\\": \\\"Set swift_use_local_disks fact\\\", \\\"set_fact\\\": {\\\"swift_use_local_disks\\\": {\\\"get_param\\\": \\\"SwiftUseLocalDir\\\"}}}, {\\\"name\\\": \\\"Set use_node_data_lookup fact\\\", \\\"set_fact\\\": {\\\"use_node_data_lookup\\\": {\\\"get_param\\\": \\\"SwiftUseNodeDataLookup\\\"}}}, {\\\"name\\\": \\\"Create Swift d1 directory if needed\\\", \\\"file\\\": {\\\"path\\\": \\\"/srv/node/d1\\\", \\\"state\\\": \\\"directory\\\"}, \\\"when\\\": \\\"swift_use_local_disks\\\"}, {\\\"name\\\": \\\"Set fact for SwiftRawDisks\\\", \\\"set_fact\\\": {\\\"swift_raw_disks\\\": {\\\"get_param\\\": \\\"SwiftRawDisks\\\"}}, \\\"when\\\": \\\"not use_node_data_lookup|bool\\\"}, {\\\"name\\\": \\\"Get hiera swift::storage::disks::args\\\", \\\"shell\\\": \\\"hiera -c /etc/puppet/hiera.yaml swift::storage::disks::args | sed =e \'s/=>/:/g\'\\\", \\\"register\\\": \\\"hiera_output\\\", \\\"when\\\": \\\"use_node_data_lookup|bool\\\"}, {\\\"name\\\": \\\"Set fact for swift_raw_disks\\\", \\\"set_fact\\\": {\\\"swift_raw_disks\\\": \\\"{{ hiera_output.stdout | from_json }}\\\"}, \\\"when\\\": \\\"use_node_data_lookup|bool\\\"}, {\\\"name\\\": \\\"Format SwiftRawDisks\\\", \\\"community.general.filesystem\\\": {\\\"fstype\\\": \\\"xfs\\\", \\\"dev\\\": \\\"{{ swift_raw_disks[item][\'base_dir\']|default(\'/dev\') }}/{{ item }}\\\", \\\"opts\\\": \\\"-f -i size=1024\\\"}, \\\"with_items\\\": \\\"{{ swift_raw_disks }}\\\", \\\"when\\\": \\\"swift_raw_disks|length > 0\\\"}, {\\\"name\\\": \\\"Refresh facts if SwiftRawDisks is set to get uuids if newly created partitions\\\", \\\"setup\\\": {\\\"gather_subset\\\": [\\\"!all\\\", \\\"!min\\\", \\\"hardware\\\"], \\\"filter\\\": \\\"ansible_device_links\\\"}, \\\"when\\\": \\\"swift_raw_disks|length > 0\\\"}, {\\\"name\\\": \\\"Mount devices defined in SwiftRawDisks\\\", \\\"mount\\\": {\\\"name\\\": \\\"/srv/node/{{ item }}\\\", \\\"src\\\": \\\"{% if lsblk.results[\'uuids\'][item] is defined %}UUID={{ ansible_facts[\'device_links\'][\'uuids\'][item][0] }}{% else %}{{ swift_raw_disks[item][\'base_dir\']|default(\'/dev\') }}/{{ item }}{% endif %}\\\", \\\"fstype\\\": \\\"xfs\\\", \\\"opts\\\": \\\"noatime\\\", \\\"state\\\": \\\"mounted\\\"}, \\\"with_items\\\": \\\"{{ swift_raw_disks }}\\\", \\\"when\\\": \\\"swift_raw_disks|length > 0\\\"}], \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Configure rsyslog for swift\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Check if rsyslog exists\\\", \\\"shell\\\": \\\"systemctl is-active rsyslog\\\", \\\"register\\\": \\\"swift_rsyslog_config\\\"}, {\\\"name\\\": \\\"Forward logging to swift.log file\\\", \\\"copy\\\": {\\\"content\\\": \\\"# Fix for https://bugs.launchpad.net/tripleo/+bug/1776180\\\\nlocal2.*                 /var/log/containers/swift/swift.log\\\\n&                        stop\\\\n\\\", \\\"dest\\\": \\\"/etc/rsyslog.d/openstack-swift.conf\\\"}, \\\"register\\\": \\\"swift_logconfig\\\", \\\"when\\\": [\\\"swift_rsyslog_config is defined\\\", \\\"swift_rsyslog_config.rc == 0\\\"]}, {\\\"name\\\": \\\"Restart rsyslogd service after logging conf change\\\", \\\"service\\\": {\\\"name\\\": \\\"rsyslog\\\", \\\"state\\\": \\\"restarted\\\"}, \\\"when\\\": [\\\"swift_logconfig is defined\\\", \\\"swift_logconfig is changed\\\"]}]}, {\\\"name\\\": \\\"Run kolla_set_configs to copy ring files\\\", \\\"when\\\": \\\"step|int == 5\\\", \\\"shell\\\": \\\"{{ container_cli }} exec -u root {{ item }} /usr/local/bin/kolla_set_configs\\\", \\\"become\\\": true, \\\"register\\\": \\\"kolla_set_configs_result\\\", \\\"failed_when\\\": [\\\"kolla_set_configs_result.rc is defined\\\", \\\"kolla_set_configs_result.rc not in [0, 125]\\\"], \\\"with_items\\\": [\\\"swift_account_auditor\\\", \\\"swift_account_reaper\\\", \\\"swift_account_replicator\\\", \\\"swift_account_server\\\", \\\"swift_container_auditor\\\", \\\"swift_container_replicator\\\", \\\"swift_container_server\\\", \\\"swift_container_updater\\\", \\\"swift_object_auditor\\\", \\\"swift_object_expirer\\\", \\\"swift_object_replicator\\\", \\\"swift_object_server\\\", \\\"swift_object_updater\\\"]}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"Check swift containers log folder/symlink exists\\\", \\\"stat\\\": {\\\"path\\\": \\\"/var/log/containers/swift\\\"}, \\\"register\\\": \\\"swift_log_link\\\"}, {\\\"name\\\": \\\"Delete if symlink\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/log/containers/swift\\\", \\\"state\\\": \\\"absent\\\"}, \\\"when\\\": \\\"swift_log_link.stat.islnk is defined and swift_log_link.stat.islnk\\\"}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack Swift Ringbuilder\\\\n\\\", \\\"parameters\\\": {\\\"ContainerSwiftConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the swift config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"SwiftMinPartHours\\\": {\\\"type\\\": \\\"number\\\", \\\"default\\\": 1, \\\"description\\\": \\\"The minimum time (in hours) before a partition in a ring can be moved following a rebalance.\\\"}, \\\"SwiftPartPower\\\": {\\\"default\\\": 10, \\\"description\\\": \\\"Partition Power to use when building Swift rings\\\", \\\"type\\\": \\\"number\\\"}, \\\"SwiftRingBuild\\\": {\\\"default\\\": true, \\\"description\\\": \\\"Whether to manage Swift rings or not\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"SwiftReplicas\\\": {\\\"type\\\": \\\"number\\\", \\\"default\\\": 3, \\\"description\\\": \\\"How many replicas to use in the swift rings.\\\"}, \\\"SwiftRawDisks\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"A hash of additional raw devices to use as Swift backend (eg. {sdb: {}})\\\", \\\"type\\\": \\\"json\\\"}, \\\"SwiftUseLocalDir\\\": {\\\"default\\\": true, \\\"description\\\": \\\"Use a local directory for Swift storage services when building rings\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"SwiftUseNodeDataLookup\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Use NodeDataLookup for disk devices in order to use persistent naming\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"SwiftRingGetTempurl\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"A temporary Swift URL to download rings from.\\\", \\\"type\\\": \\\"string\\\"}, \\\"SwiftRingPutTempurl\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"A temporary Swift URL to upload rings to.\\\", \\\"type\\\": \\\"string\\\"}, \\\"DeployIdentifier\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\\\n\\\"}}, \\\"conditions\\\": {\\\"swift_use_local_dir\\\": {\\\"and\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"SwiftUseLocalDir\\\"}, true]}, {\\\"equals\\\": [{\\\"get_param\\\": \\\"SwiftRawDisks\\\"}, {}]}]}}, \\\"resources\\\": {\\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerSwiftConfigImage\\\": \\\"ContainerSwiftConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerSwiftConfigImage\\\": {\\\"get_param\\\": \\\"ContainerSwiftConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for Swift Ringbuilder configuration in containers.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"swift_ringbuilder\\\", \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"tripleo::profile::base::swift::ringbuilder::skip_consistency_check\\\": true, \\\"tripleo::profile::base::swift::ringbuilder::swift_ring_get_tempurl\\\": {\\\"get_param\\\": \\\"SwiftRingGetTempurl\\\"}, \\\"tripleo::profile::base::swift::ringbuilder::swift_ring_put_tempurl\\\": {\\\"get_param\\\": \\\"SwiftRingPutTempurl\\\"}, \\\"tripleo::profile::base::swift::ringbuilder::build_ring\\\": {\\\"get_param\\\": \\\"SwiftRingBuild\\\"}, \\\"tripleo::profile::base::swift::ringbuilder::replicas\\\": {\\\"get_param\\\": \\\"SwiftReplicas\\\"}, \\\"tripleo::profile::base::swift::ringbuilder::part_power\\\": {\\\"get_param\\\": \\\"SwiftPartPower\\\"}, \\\"tripleo::profile::base::swift::ringbuilder::min_part_hours\\\": {\\\"get_param\\\": \\\"SwiftMinPartHours\\\"}, \\\"tripleo::profile::base::swift::ringbuilder::raw_disk_prefix\\\": \\\"r1z1-\\\"}, {\\\"if\\\": [{\\\"get_param\\\": \\\"SwiftUseNodeDataLookup\\\"}, {}, {\\\"tripleo::profile::base::swift::ringbuilder::raw_disks\\\": {\\\"list_concat\\\": [{\\\"if\\\": [\\\"swift_use_local_dir\\\", [\\\":%PORT%/d1\\\"]]}, {\\\"repeat\\\": {\\\"template\\\": \\\":%PORT%/DEVICE\\\", \\\"for_each\\\": {\\\"DEVICE\\\": {\\\"get_param\\\": \\\"SwiftRawDisks\\\"}}}}]}}]}]}, \\\"service_config_settings\\\": {}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"swift_ringbuilder\\\", \\\"puppet_tags\\\": \\\"swift_config,exec,fetch_swift_ring_tarball,extract_swift_ring_tarball,ring_object_device,swift::ringbuilder::create,tripleo::profile::base::swift::add_devices,swift::ringbuilder::rebalance,create_swift_ring_tarball,upload_swift_ring_tarball\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::swift::ringbuilder\\\\n\\\", \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerSwiftConfigImage\\\"]}}, \\\"kolla_config\\\": {}, \\\"docker_config\\\": {\\\"step_3\\\": {\\\"swift_copy_rings\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerSwiftConfigImage\\\"]}, \\\"net\\\": \\\"none\\\", \\\"user\\\": \\\"root\\\", \\\"detach\\\": false, \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"cp -v -dR --preserve -t /etc/swift /swift_ringbuilder/etc/swift/*.gz /swift_ringbuilder/etc/swift/*.builder /swift_ringbuilder/etc/swift/backups\\\"], \\\"volumes\\\": [\\\"/var/lib/config-data/puppet-generated/swift/etc/swift:/etc/swift:rw,z\\\", \\\"/var/lib/config-data/puppet-generated/swift_ringbuilder:/swift_ringbuilder:ro\\\"], \\\"environment\\\": {\\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}}}}}}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"SNMP client configured with Puppet, to facilitate Ceilometer Hardware monitoring in the undercloud. This service is required to enable hardware monitoring.\\\\n\\\", \\\"parameters\\\": {\\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"SnmpdReadonlyUserName\\\": {\\\"default\\\": \\\"ro_snmp_user\\\", \\\"description\\\": \\\"The user name for SNMPd with readonly rights running on all Overcloud nodes\\\", \\\"type\\\": \\\"string\\\"}, \\\"SnmpdReadonlyUserPassword\\\": {\\\"description\\\": \\\"The user password for SNMPd with readonly rights running on all Overcloud nodes\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"SnmpdBindHost\\\": {\\\"description\\\": \\\"An array of bind host addresses on which SNMP daemon will listen.\\\", \\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": [\\\"udp:161\\\", \\\"udp6:[::1]:161\\\"]}, \\\"SnmpdOptions\\\": {\\\"description\\\": \\\"A string containing the commandline options passed to snmpd\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"-LS0-5d\\\"}, \\\"SnmpdIpSubnet\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"IP address/subnet on the snmpd network. If empty (default), SnmpdNetwork will be taken.\\\", \\\"type\\\": \\\"string\\\"}}, \\\"conditions\\\": {\\\"snmpd_network_unset\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"SnmpdIpSubnet\\\"}, \\\"\\\"]}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the SNMP services\\\", \\\"value\\\": {\\\"service_name\\\": \\\"snmp\\\", \\\"firewall_rules\\\": {\\\"if\\\": [\\\"snmpd_network_unset\\\", {\\\"map_merge\\\": {\\\"repeat\\\": {\\\"for_each\\\": {\\\"<%net_cidr%>\\\": {\\\"get_param\\\": [\\\"ServiceData\\\", \\\"net_cidr_map\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"SnmpdNetwork\\\"]}]}}, \\\"template\\\": {\\\"124 snmp <%net_cidr%>\\\": {\\\"dport\\\": 161, \\\"proto\\\": \\\"udp\\\", \\\"source\\\": \\\"<%net_cidr%>\\\"}}}}}, {\\\"124 snmp\\\": {\\\"dport\\\": 161, \\\"proto\\\": \\\"udp\\\", \\\"source\\\": {\\\"get_param\\\": \\\"SnmpdIpSubnet\\\"}}}]}, \\\"config_settings\\\": {\\\"tripleo::profile::base::snmp::snmpd_user\\\": {\\\"get_param\\\": \\\"SnmpdReadonlyUserName\\\"}, \\\"tripleo::profile::base::snmp::snmpd_password\\\": {\\\"get_param\\\": \\\"SnmpdReadonlyUserPassword\\\"}, \\\"snmp::agentaddress\\\": {\\\"get_param\\\": \\\"SnmpdBindHost\\\"}, \\\"snmp::snmpd_options\\\": {\\\"get_param\\\": \\\"SnmpdOptions\\\"}}, \\\"step_config\\\": \\\"include tripleo::profile::base::snmp\\\\n\\\", \\\"upgrade_tasks\\\": [{\\\"when\\\": \\\"step|int == 0\\\", \\\"block\\\": [{\\\"name\\\": \\\"Check if snmpd is enabled\\\", \\\"command\\\": \\\"systemctl is-enabled --quiet snmpd\\\", \\\"failed_when\\\": false, \\\"register\\\": \\\"snmpd_enabled_result\\\"}, {\\\"name\\\": \\\"Set fact snmpd_enabled\\\", \\\"set_fact\\\": {\\\"snmpd_enabled\\\": \\\"{{ snmpd_enabled_result.rc == 0 }}\\\"}}]}, {\\\"name\\\": \\\"Stop snmp service\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"snmpd_enabled|bool\\\"], \\\"service\\\": \\\"name=snmpd state=stopped\\\"}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Composable Timezone service\\\\n\\\", \\\"parameters\\\": {\\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"TimeZone\\\": {\\\"default\\\": \\\"UTC\\\", \\\"description\\\": \\\"The timezone to be set on the overcloud.\\\", \\\"type\\\": \\\"string\\\"}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Timezone role using composable services.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"timezone\\\", \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"Run timezone role\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_timezone\\\"}, \\\"vars\\\": {\\\"tripleo_timezone\\\": {\\\"get_param\\\": \\\"TimeZone\\\"}}}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Horizon service\\\\n\\\", \\\"parameters\\\": {\\\"ContainerHorizonImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerHorizonConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the horizon config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"Debug\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Set to True to enable debugging on all services.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"HorizonDebug\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Set to True to enable debugging Horizon service.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"HorizonAllowedHosts\\\": {\\\"default\\\": \\\"*\\\", \\\"description\\\": \\\"A list of IP/Hostname for the server Horizon is running on. Used for header checks.\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"HorizonPasswordValidator\\\": {\\\"description\\\": \\\"Regex for password validation\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\"}, \\\"HorizonPasswordValidatorHelp\\\": {\\\"description\\\": \\\"Help text for password validation\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\"}, \\\"HorizonSecret\\\": {\\\"description\\\": \\\"Secret key for Django\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true, \\\"default\\\": \\\"\\\"}, \\\"HorizonSecureCookies\\\": {\\\"description\\\": \\\"Set CSRF_COOKIE_SECURE / SESSION_COOKIE_SECURE in Horizon\\\", \\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"HorizonSessionTimeout\\\": {\\\"description\\\": \\\"Set session timeout for horizon in seconds\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 1800}, \\\"MemcachedIPv6\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Enable IPv6 features in Memcached.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"MonitoringSubscriptionHorizon\\\": {\\\"default\\\": \\\"overcloud-horizon\\\", \\\"type\\\": \\\"string\\\"}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"InternalTLSCAFile\\\": {\\\"default\\\": \\\"/etc/ipa/ca.crt\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Specifies the default CA cert to use if TLS is used for services in the internal network.\\\"}, \\\"HorizonVhostExtraParams\\\": {\\\"default\\\": {\\\"add_listen\\\": true, \\\"priority\\\": 10, \\\"access_log_format\\\": \\\"%a %l %u %t \\\\\\\\\\\\\\\"%r\\\\\\\\\\\\\\\" %>s %b \\\\\\\\\\\\\\\"%%{}{Referer}i\\\\\\\\\\\\\\\" \\\\\\\\\\\\\\\"%%{}{User-Agent}i\\\\\\\\\\\\\\\"\\\", \\\"options\\\": [\\\"FollowSymLinks\\\", \\\"MultiViews\\\"]}, \\\"description\\\": \\\"Extra parameters for Horizon vhost configuration\\\", \\\"type\\\": \\\"json\\\"}, \\\"HorizonCustomizationModule\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Horizon has a global overrides mechanism available to perform customizations\\\", \\\"type\\\": \\\"string\\\"}, \\\"HorizonHelpURL\\\": {\\\"default\\\": \\\"http://docs.openstack.org\\\", \\\"description\\\": \\\"On top of dashboard there is a Help button. This button could be used to re-direct user to vendor documentation or dedicated help portal.\\\", \\\"type\\\": \\\"string\\\"}, \\\"TimeZone\\\": {\\\"default\\\": \\\"UTC\\\", \\\"description\\\": \\\"The timezone to be set on the overcloud.\\\", \\\"type\\\": \\\"string\\\"}, \\\"WebSSOEnable\\\": {\\\"default\\\": false, \\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"Enable support for Web Single Sign-On\\\"}, \\\"WebSSOInitialChoice\\\": {\\\"default\\\": \\\"OIDC\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"The initial authentication choice to select by default\\\"}, \\\"WebSSOChoicesHideKeystone\\\": {\\\"default\\\": false, \\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"Hide Keystone crednetials login when WebSSO is enabled.\\\"}, \\\"WebSSOChoices\\\": {\\\"default\\\": [[\\\"OIDC\\\", \\\"OpenID Connect\\\"]], \\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"Specifies the list of SSO authentication choices to present. Each item is a list of an SSO choice identifier and a display message.\\\"}, \\\"WebSSOIDPMapping\\\": {\\\"default\\\": {\\\"OIDC\\\": [\\\"myidp\\\", \\\"openid\\\"]}, \\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"Specifies a mapping from SSO authentication choice to identity provider and protocol.  The identity provider and protocol names must match the resources defined in keystone.\\\"}, \\\"HorizonDomainChoices\\\": {\\\"default\\\": [], \\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"Specifies available domains to choose from. We expect an array of hashes, and the hashes should have two items each (name, display) containing Keystone domain name and a human-readable description of the domain respectively.\\\"}, \\\"HorizonLoggingSource\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {\\\"tag\\\": \\\"openstack.horizon\\\", \\\"file\\\": \\\"/var/log/containers/horizon/horizon.log\\\"}}, \\\"HorizonHstsHeaderValue\\\": {\\\"default\\\": [], \\\"description\\\": \\\"Enables HTTP Strict-Transport-Security header in response.\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}}, \\\"parameter_groups\\\": [{\\\"label\\\": \\\"deprecated\\\", \\\"description\\\": \\\"The following parameters are deprecated and will be removed. They should not\\\\nbe relied on for new deployments. If you have concerns regarding deprecated\\\\nparameters, please contact the TripleO development team on IRC or the\\\\nOpenStack mailing list.\\\\n\\\", \\\"parameters\\\": [\\\"MemcachedIPv6\\\"]}], \\\"conditions\\\": {\\\"horizon_domain_choices_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"HorizonDomainChoices\\\"}, []]}}, \\\"is_ipv6\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"ServiceData\\\", \\\"net_ip_version_map\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HorizonNetwork\\\"]}]}, 6]}, \\\"horizon_logger_debug\\\": {\\\"or\\\": [{\\\"get_param\\\": \\\"Debug\\\"}, {\\\"get_param\\\": \\\"HorizonDebug\\\"}]}, \\\"horizon_hsts_header_value_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"HorizonHstsHeaderValue\\\"}, []]}}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerHorizonImage\\\": \\\"ContainerHorizonImage\\\", \\\"ContainerHorizonConfigImage\\\": \\\"ContainerHorizonConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerHorizonImage\\\": {\\\"get_param\\\": \\\"ContainerHorizonImage\\\"}, \\\"ContainerHorizonConfigImage\\\": {\\\"get_param\\\": \\\"ContainerHorizonConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Horizon API role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"horizon\\\", \\\"firewall_rules\\\": {\\\"126 horizon\\\": {\\\"dport\\\": [{\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, 443, 80]}]}}, \\\"firewall_frontend_rules\\\": {\\\"100 horizon_haproxy_frontend\\\": {\\\"dport\\\": [80]}}, \\\"firewall_ssl_frontend_rules\\\": {\\\"100 horizon_haproxy_frontend_ssl\\\": {\\\"dport\\\": [443]}}, \\\"monitoring_subscription\\\": {\\\"get_param\\\": \\\"MonitoringSubscriptionHorizon\\\"}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"horizon::allowed_hosts\\\": {\\\"get_param\\\": \\\"HorizonAllowedHosts\\\"}, \\\"horizon::enable_secure_proxy_ssl_header\\\": true, \\\"horizon::secure_proxy_addr_header\\\": \\\"HTTP_X_FORWARDED_FOR\\\", \\\"horizon::disable_password_reveal\\\": true, \\\"horizon::enforce_password_check\\\": true, \\\"horizon::disallow_iframe_embed\\\": true, \\\"horizon::cache_backend\\\": \\\"django.core.cache.backends.memcached.MemcachedCache\\\", \\\"horizon::django_session_engine\\\": \\\"django.contrib.sessions.backends.cache\\\", \\\"horizon::vhost_extra_params\\\": {\\\"get_param\\\": \\\"HorizonVhostExtraParams\\\"}, \\\"horizon::bind_address\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HorizonNetwork\\\"]}}}}, \\\"horizon::keystone_url\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneV3Public\\\", \\\"uri\\\"]}, \\\"horizon::password_validator\\\": {\\\"get_param\\\": [\\\"HorizonPasswordValidator\\\"]}, \\\"horizon::password_validator_help\\\": {\\\"get_param\\\": [\\\"HorizonPasswordValidatorHelp\\\"]}, \\\"horizon::secret_key\\\": {\\\"get_param\\\": \\\"HorizonSecret\\\"}, \\\"horizon::secure_cookies\\\": {\\\"get_param\\\": [\\\"HorizonSecureCookies\\\"]}, \\\"horizon::session_timeout\\\": {\\\"get_param\\\": \\\"HorizonSessionTimeout\\\"}, \\\"memcached_ipv6\\\": {\\\"if\\\": [\\\"is_ipv6\\\", true, false]}, \\\"horizon::servername\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'fqdn_$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HorizonNetwork\\\"]}}}}, \\\"horizon::listen_ssl\\\": {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, \\\"horizon::customization_module\\\": {\\\"get_param\\\": \\\"HorizonCustomizationModule\\\"}, \\\"horizon::timezone\\\": {\\\"get_param\\\": \\\"TimeZone\\\"}, \\\"horizon::file_upload_temp_dir\\\": \\\"/var/tmp\\\", \\\"horizon::help_url\\\": {\\\"get_param\\\": \\\"HorizonHelpURL\\\"}, \\\"horizon::enable_user_pass\\\": \\\"UNSET\\\"}, {\\\"if\\\": [{\\\"get_param\\\": \\\"WebSSOEnable\\\"}, {\\\"horizon::websso_enabled\\\": {\\\"get_param\\\": \\\"WebSSOEnable\\\"}, \\\"horizon::websso_initial_choice\\\": {\\\"get_param\\\": \\\"WebSSOInitialChoice\\\"}, \\\"horizon::websso_choices\\\": {\\\"get_param\\\": \\\"WebSSOChoices\\\"}, \\\"horizon::websso_idp_mapping\\\": {\\\"get_param\\\": \\\"WebSSOIDPMapping\\\"}, \\\"horizon::websso_choices_hide_keystone\\\": {\\\"get_param\\\": \\\"WebSSOChoicesHideKeystone\\\"}}]}, {\\\"if\\\": [{\\\"get_param\\\": \\\"HorizonDebug\\\"}, {\\\"horizon::django_debug\\\": true}, {\\\"horizon::django_debug\\\": {\\\"get_param\\\": \\\"Debug\\\"}}]}, {\\\"if\\\": [\\\"horizon_logger_debug\\\", {\\\"horizon::log_level\\\": \\\"DEBUG\\\"}]}, {\\\"if\\\": [\\\"horizon_domain_choices_set\\\", {\\\"horizon::keystone_domain_choices\\\": {\\\"get_param\\\": \\\"HorizonDomainChoices\\\"}}]}]}, \\\"ansible_group_vars\\\": {\\\"keystone_enable_member\\\": true}, \\\"service_config_settings\\\": {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_horizon\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"$.data.sources.flatten()\\\", \\\"data\\\": {\\\"sources\\\": [{\\\"get_param\\\": \\\"HorizonLoggingSource\\\"}]}}}}, \\\"haproxy\\\": {\\\"if\\\": [\\\"horizon_hsts_header_value_set\\\", {\\\"tripleo::profile::base::horizon::hsts_header_value\\\": {\\\"get_param\\\": \\\"HorizonHstsHeaderValue\\\"}}]}}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"horizon\\\", \\\"puppet_tags\\\": \\\"horizon_config\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::horizon\\\\n\\\", \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHorizonConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/horizon.json\\\": {\\\"command\\\": \\\"/usr/sbin/httpd -DFOREGROUND\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/etc/httpd/conf.d\\\", \\\"dest\\\": \\\"/etc/httpd/conf.d\\\", \\\"merge\\\": false, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\\\", \\\"dest\\\": \\\"/etc/httpd/conf.modules.d\\\", \\\"merge\\\": false, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/horizon/\\\", \\\"owner\\\": \\\"apache:apache\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/etc/openstack-dashboard/\\\", \\\"owner\\\": \\\"apache:apache\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/usr/share/openstack-dashboard/openstack_dashboard/local/\\\", \\\"owner\\\": \\\"apache:apache\\\", \\\"recurse\\\": false}, {\\\"path\\\": \\\"/usr/share/openstack-dashboard/openstack_dashboard/local/local_settings.d/\\\", \\\"owner\\\": \\\"apache:apache\\\", \\\"recurse\\\": false}]}}, \\\"docker_config\\\": {\\\"step_2\\\": {\\\"horizon_fix_perms\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHorizonImage\\\"]}, \\\"net\\\": \\\"none\\\", \\\"user\\\": \\\"root\\\", \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"touch /var/log/horizon/horizon.log ; chown -R apache:apache /var/log/horizon && chmod -R a+rx /etc/openstack-dashboard\\\"], \\\"volumes\\\": [\\\"/var/log/containers/horizon:/var/log/horizon:z\\\", \\\"/var/log/containers/httpd/horizon:/var/log/httpd:z\\\", \\\"/var/lib/config-data/puppet-generated/horizon/etc/openstack-dashboard:/etc/openstack-dashboard\\\"]}}, \\\"step_3\\\": {\\\"horizon\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHorizonImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/horizon.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/horizon:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/log/containers/horizon:/var/log/horizon:z\\\", \\\"/var/log/containers/httpd/horizon:/var/log/httpd:z\\\", \\\"/var/tmp/horizon:/var/tmp:z\\\", \\\"/var/www:/var/www:ro\\\"], {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, [\\\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\\\", \\\"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\\\"]]}]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\", \\\"ENABLE_DESIGNATE\\\": \\\"yes\\\", \\\"ENABLE_HEAT\\\": \\\"yes\\\", \\\"ENABLE_IRONIC\\\": \\\"yes\\\", \\\"ENABLE_MANILA\\\": \\\"yes\\\", \\\"ENABLE_OCTAVIA\\\": \\\"yes\\\"}}}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode|default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/horizon\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/log/containers/httpd/horizon\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/www\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/tmp/horizon\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"01777\\\"}]}, {\\\"name\\\": \\\"ensure /var/tmp/horizon exists on boot\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/tmpfiles.d/var-tmp-horizon.conf\\\", \\\"content\\\": \\\"d /var/tmp/horizon 01777 root root - -\\\\n\\\"}}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"Anchor for upgrade and update tasks\\\", \\\"when\\\": \\\"step|int == 0\\\", \\\"block\\\": [{\\\"name\\\": \\\"Reset selinux label on /var/tmp\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/tmp\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"tmp_t\\\", \\\"mode\\\": 1023}}]}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"Anchor for upgrade and update tasks\\\", \\\"when\\\": \\\"step|int == 0\\\", \\\"block\\\": [{\\\"name\\\": \\\"Reset selinux label on /var/tmp\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/tmp\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"tmp_t\\\", \\\"mode\\\": 1023}}]}], \\\"external_upgrade_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade_transfer_data\\\", \\\"system_upgrade_stop_services\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Stop horizon container\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_stop\\\"}, \\\"vars\\\": {\\\"tripleo_containers_to_stop\\\": [\\\"horizon\\\"], \\\"tripleo_delegate_to\\\": \\\"{{ groups[\'horizon\'] | difference(groups[\'excluded_overcloud\']) }}\\\"}}]}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Chrony time service deployment using ansible, this YAML file creates the interface between the HOT template and the ansible role that actually installs and configure chronyd.\\\\n\\\", \\\"parameters\\\": {\\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"NtpServer\\\": {\\\"default\\\": [\\\"0.pool.ntp.org\\\", \\\"1.pool.ntp.org\\\", \\\"2.pool.ntp.org\\\", \\\"3.pool.ntp.org\\\"], \\\"description\\\": \\\"NTP servers list. Defaulted to a set of pool.ntp.org servers in order to have a sane default for Pacemaker deployments when not configuring this parameter by default.\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"NtpPool\\\": {\\\"default\\\": [], \\\"description\\\": \\\"NTP pool list.  Defaults to [], so only NtpServer is used by default.\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"ChronyGlobalServerOptions\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Default server options for the configured NTP servers in chrony.conf. If this is specified, NtpIburstEnable, MaxPoll, and MinPoll are ignored.\\\", \\\"type\\\": \\\"string\\\"}, \\\"ChronyGlobalPoolOptions\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Default pool options for the configured NTP pools in chrony.conf. If this is specified, NtpIburstEnable, MaxPoll, and MinPoll are ignored.\\\", \\\"type\\\": \\\"string\\\"}, \\\"NtpIburstEnable\\\": {\\\"default\\\": true, \\\"description\\\": \\\"Specifies whether to enable the iburst option for every NTP peer. If iburst is enabled, when the ntp server is unreachable ntp will send a burst of eight packages instead of one. This is designed to speed up the initial syncrhonization.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"MaxPoll\\\": {\\\"description\\\": \\\"Specify maximum poll interval of upstream servers for NTP messages, in seconds to the power of two. The maximum poll interval defaults to 10 (1,024 s). Allowed values are 4 to 17.\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 10, \\\"constraints\\\": [{\\\"range\\\": {\\\"min\\\": 4, \\\"max\\\": 17}}]}, \\\"MinPoll\\\": {\\\"description\\\": \\\"Specify minimum poll interval of upstream servers for NTP messages, in seconds to the power of two. The minimum poll interval defaults to 6 (64 s). Allowed values are 4 to 17.\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 6, \\\"constraints\\\": [{\\\"range\\\": {\\\"min\\\": 4, \\\"max\\\": 17}}]}, \\\"EnablePackageInstall\\\": {\\\"default\\\": \\\"false\\\", \\\"description\\\": \\\"Set to true to enable package installation at deploy time\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"ChronyAclRules\\\": {\\\"default\\\": [\\\"deny all\\\"], \\\"description\\\": \\\"Access Control List of NTP clients.  By default no clients are permitted.\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}}, \\\"conditions\\\": {\\\"chrony_global_server_settings_is_empty\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"ChronyGlobalServerOptions\\\"}, \\\"\\\"]}, \\\"chrony_global_pool_settings_is_empty\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"ChronyGlobalPoolOptions\\\"}, \\\"\\\"]}, \\\"ntp_iburst\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"NtpIburstEnable\\\"}, true]}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role chrony using composable timesync services.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"chrony\\\", \\\"firewall_rules\\\": {\\\"105 ntp\\\": {\\\"dport\\\": 123, \\\"proto\\\": \\\"udp\\\"}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"Check for NTP service\\\", \\\"shell\\\": \\\"systemctl is-active ntpd.service || systemctl is-enabled ntpd.service\\\", \\\"failed_when\\\": false, \\\"become\\\": true, \\\"register\\\": \\\"ntp_service_check\\\"}, {\\\"name\\\": \\\"Disable NTP before configuring Chrony\\\", \\\"service\\\": {\\\"name\\\": \\\"ntpd\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}, \\\"when\\\": [\\\"ntp_service_check.rc is defined\\\", \\\"ntp_service_check.rc == 0\\\"]}, {\\\"name\\\": \\\"Install, Configure and Run Chrony\\\", \\\"include_role\\\": {\\\"name\\\": \\\"chrony\\\"}}, {\\\"name\\\": \\\"Force NTP sync\\\", \\\"command\\\": \\\"chronyc makestep\\\"}, {\\\"name\\\": \\\"Ensure system is NTP time synced\\\", \\\"command\\\": \\\"chronyc waitsync 30\\\"}], \\\"ansible_group_vars\\\": {\\\"chrony_role_action\\\": \\\"all\\\", \\\"chrony_ntp_servers\\\": {\\\"get_param\\\": \\\"NtpServer\\\"}, \\\"chrony_ntp_pools\\\": {\\\"get_param\\\": \\\"NtpPool\\\"}, \\\"chrony_global_server_settings\\\": {\\\"if\\\": [\\\"chrony_global_server_settings_is_empty\\\", {\\\"str_replace\\\": {\\\"template\\\": \\\"IBURST minpoll MINPOLL maxpoll MAXPOLL\\\", \\\"params\\\": {\\\"IBURST\\\": {\\\"if\\\": [\\\"ntp_iburst\\\", \\\"iburst\\\", \\\"\\\"]}, \\\"MINPOLL\\\": {\\\"get_param\\\": \\\"MinPoll\\\"}, \\\"MAXPOLL\\\": {\\\"get_param\\\": \\\"MaxPoll\\\"}}}}, {\\\"get_param\\\": \\\"ChronyGlobalServerOptions\\\"}]}, \\\"chrony_global_pool_settings\\\": {\\\"if\\\": [\\\"chrony_global_pool_settings_is_empty\\\", {\\\"str_replace\\\": {\\\"template\\\": \\\"IBURST minpoll MINPOLL maxpoll MAXPOLL\\\", \\\"params\\\": {\\\"IBURST\\\": {\\\"if\\\": [\\\"ntp_iburst\\\", \\\"iburst\\\", \\\"\\\"]}, \\\"MINPOLL\\\": {\\\"get_param\\\": \\\"MinPoll\\\"}, \\\"MAXPOLL\\\": {\\\"get_param\\\": \\\"MaxPoll\\\"}}}}, {\\\"get_param\\\": \\\"ChronyGlobalPoolOptions\\\"}]}, \\\"chrony_manage_package\\\": {\\\"get_param\\\": \\\"EnablePackageInstall\\\"}, \\\"chrony_acl_rules\\\": {\\\"get_param\\\": \\\"ChronyAclRules\\\"}}}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Time services such as timemaster with deployment using ansible, this YAML file creates the interface between the HOT template and the ansible roles that actually installs and configure chronyd and timemaster.\\\\n\\\", \\\"parameters\\\": {\\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"DefaultPasswords\\\": {\\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"NtpServer\\\": {\\\"default\\\": [\\\"0.pool.ntp.org\\\", \\\"1.pool.ntp.org\\\", \\\"2.pool.ntp.org\\\", \\\"3.pool.ntp.org\\\"], \\\"description\\\": \\\"NTP servers list. Defaulted to a set of pool.ntp.org servers in order to have a sane default for Pacemaker deployments when not configuring this parameter by default.\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"NtpPool\\\": {\\\"default\\\": [], \\\"description\\\": \\\"NTP pool list.  Defaults to [], so only NtpServer is used by default.\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"ChronyGlobalServerOptions\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Default server options for the configured NTP servers in chrony.conf. If this is specified, NtpIburstEnable, MaxPoll, and MinPoll are ignored.\\\", \\\"type\\\": \\\"string\\\"}, \\\"ChronyGlobalPoolOptions\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Default pool options for the configured NTP pools in chrony.conf. If this is specified, NtpIburstEnable, MaxPoll, and MinPoll are ignored.\\\", \\\"type\\\": \\\"string\\\"}, \\\"NtpIburstEnable\\\": {\\\"default\\\": true, \\\"description\\\": \\\"Specifies whether to enable the iburst option for every NTP peer. If iburst is enabled, when the ntp server is unreachable ntp will send a burst of eight packages instead of one. This is designed to speed up the initial syncrhonization.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"MaxPoll\\\": {\\\"description\\\": \\\"Specify maximum poll interval of upstream servers for NTP messages, in seconds to the power of two. The maximum poll interval defaults to 10 (1,024 s). Allowed values are 4 to 17.\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 10, \\\"constraints\\\": [{\\\"range\\\": {\\\"min\\\": 4, \\\"max\\\": 17}}]}, \\\"MinPoll\\\": {\\\"description\\\": \\\"Specify minimum poll interval of upstream servers for NTP messages, in seconds to the power of two. The minimum poll interval defaults to 6 (64 s). Allowed values are 4 to 17.\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 6, \\\"constraints\\\": [{\\\"range\\\": {\\\"min\\\": 4, \\\"max\\\": 17}}]}, \\\"EnablePackageInstall\\\": {\\\"default\\\": \\\"false\\\", \\\"description\\\": \\\"Set to true to enable package installation at deploy time\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"ChronyAclRules\\\": {\\\"default\\\": [\\\"deny all\\\"], \\\"description\\\": \\\"Access Control List of NTP clients.  By default no clients are permitted.\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"PTPInterfaces\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Interfaces to be added to PTP domain\\\", \\\"type\\\": \\\"comma_delimited_list\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"PTPMessageTransport\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"PTP transport mechanism, possible values UDPv4,L2\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}}, \\\"resources\\\": {\\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"tripleo_ptp_interfaces\\\": \\\"PTPInterfaces\\\", \\\"tripleo_ptp_transport\\\": \\\"PTPMessageTransport\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"PTPInterfaces\\\": {\\\"get_param\\\": \\\"PTPInterfaces\\\"}, \\\"PTPMessageTransport\\\": {\\\"get_param\\\": \\\"PTPMessageTransport\\\"}}}]}}}}, \\\"conditions\\\": {\\\"chrony_global_server_settings_is_empty\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"ChronyGlobalServerOptions\\\"}, \\\"\\\"]}, \\\"chrony_global_pool_settings_is_empty\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"ChronyGlobalPoolOptions\\\"}, \\\"\\\"]}, \\\"ntp_iburst\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"NtpIburstEnable\\\"}, true]}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Configure and starts timemaster service.\\\", \\\"value\\\": {\\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"Configure and Run Timemaster\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_timemaster\\\"}}], \\\"ansible_group_vars\\\": {\\\"chrony_role_action\\\": \\\"all\\\", \\\"chrony_ntp_servers\\\": {\\\"get_param\\\": \\\"NtpServer\\\"}, \\\"chrony_ntp_pools\\\": {\\\"get_param\\\": \\\"NtpPool\\\"}, \\\"tripleo_timemaster_role_action\\\": \\\"all\\\", \\\"chrony_global_server_settings\\\": {\\\"if\\\": [\\\"chrony_global_server_settings_is_empty\\\", {\\\"str_replace\\\": {\\\"template\\\": \\\"IBURST minpoll MINPOLL maxpoll MAXPOLL\\\", \\\"params\\\": {\\\"IBURST\\\": {\\\"if\\\": [\\\"ntp_iburst\\\", \\\"iburst\\\", \\\"\\\"]}, \\\"MINPOLL\\\": {\\\"get_param\\\": \\\"MinPoll\\\"}, \\\"MAXPOLL\\\": {\\\"get_param\\\": \\\"MaxPoll\\\"}}}}, {\\\"get_param\\\": \\\"ChronyGlobalServerOptions\\\"}]}, \\\"chrony_global_pool_settings\\\": {\\\"if\\\": [\\\"chrony_global_pool_settings_is_empty\\\", {\\\"str_replace\\\": {\\\"template\\\": \\\"IBURST minpoll MINPOLL maxpoll MAXPOLL\\\", \\\"params\\\": {\\\"IBURST\\\": {\\\"if\\\": [\\\"ntp_iburst\\\", \\\"iburst\\\", \\\"\\\"]}, \\\"MINPOLL\\\": {\\\"get_param\\\": \\\"MinPoll\\\"}, \\\"MAXPOLL\\\": {\\\"get_param\\\": \\\"MaxPoll\\\"}}}}, {\\\"get_param\\\": \\\"ChronyGlobalPoolOptions\\\"}]}, \\\"chrony_manage_package\\\": {\\\"get_param\\\": \\\"EnablePackageInstall\\\"}, \\\"chrony_acl_rules\\\": {\\\"get_param\\\": \\\"ChronyAclRules\\\"}, \\\"ptp_interfaces\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"tripleo_ptp_interfaces\\\"]}, \\\"ptp_transport\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"tripleo_ptp_transport\\\"]}}}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"TripleO Firewall settings\\\\n\\\", \\\"parameters\\\": {\\\"Debug\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false, \\\"description\\\": \\\"Set to True to enable debugging on all services.\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ExtraFirewallRules\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of firewall rules.\\\", \\\"type\\\": \\\"json\\\", \\\"tags\\\": [\\\"role_specific\\\"]}}, \\\"resources\\\": {\\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"extra_firewall_rules\\\": \\\"ExtraFirewallRules\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ExtraFirewallRules\\\": {\\\"get_param\\\": \\\"ExtraFirewallRules\\\"}}}]}}}}, \\\"conditions\\\": {\\\"no_ctlplane\\\": {\\\"equals\\\": [{\\\"get_params\\\": [\\\"ServiceData\\\", \\\"net_cidr_map\\\", \\\"ctlplane\\\"]}, null]}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the TripleO firewall settings\\\", \\\"value\\\": {\\\"service_name\\\": \\\"tripleo_firewall\\\", \\\"config_settings\\\": {\\\"tripleo::firewall::manage_firewall\\\": false, \\\"tripleo::firewall::purge_firewall_rules\\\": false}, \\\"ansible_group_vars\\\": {\\\"tripleo_nftables_debug\\\": {\\\"get_param\\\": \\\"Debug\\\"}}, \\\"firewall_rules\\\": {\\\"map_merge\\\": [{\\\"map_merge\\\": {\\\"repeat\\\": {\\\"for_each\\\": {\\\"<%net_cidr%>\\\": {\\\"get_param\\\": [\\\"ServiceData\\\", \\\"net_cidr_map\\\", \\\"ctlplane\\\"]}}, \\\"template\\\": {\\\"003 accept ssh from ctlplane subnet <%net_cidr%>\\\": {\\\"source\\\": \\\"<%net_cidr%>\\\", \\\"proto\\\": \\\"tcp\\\", \\\"dport\\\": 22}}}}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"extra_firewall_rules\\\"]}]}, \\\"host_prep_tasks\\\": [{\\\"if\\\": [\\\"no_ctlplane\\\", {\\\"name\\\": \\\"Failure - ctlplane subnet is unset\\\", \\\"fail\\\": {\\\"msg\\\": \\\"No CIDRs found in the ctlplane network tags.\\\\nPlease refer to the documentation in order to\\\\nset the correct network tags in DeployedServerPortMap.\\\\n\\\"}}, {\\\"name\\\": \\\"Notice - ctlplane subnet is set\\\", \\\"debug\\\": {\\\"msg\\\": \\\"CIDRs found in the ctlplane network tags.\\\\n\\\"}}]}], \\\"host_firewall_tasks\\\": [{\\\"name\\\": \\\"Run firewall role\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_firewall\\\"}}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"Cleanup tripleo-iptables services\\\", \\\"when\\\": [\\\"(step | int) == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Disable tripleo-iptables.service\\\", \\\"systemd\\\": {\\\"name\\\": \\\"tripleo-iptables.service\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}, \\\"register\\\": \\\"systemd_tripleo_iptables\\\", \\\"failed_when\\\": false}, {\\\"name\\\": \\\"Cleanup tripleo-iptables.services\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/systemd/system/tripleo-iptables.service\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"Disable tripleo-ip6tables.service\\\", \\\"systemd\\\": {\\\"name\\\": \\\"tripleo-ip6tables.service\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}, \\\"register\\\": \\\"systemd_tripleo_ip6tables\\\", \\\"failed_when\\\": false}, {\\\"name\\\": \\\"Cleanup tripleo-ip6tables.services\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/systemd/system/tripleo-ip6tables.service\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"Reload systemd\\\", \\\"systemd\\\": {\\\"daemon_reload\\\": true}, \\\"when\\\": [\\\"(systemd_tripleo_iptables is changed or systemd_tripleo_ip6tables is changed)\\\"]}]}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"Cleanup tripleo-iptables services\\\", \\\"when\\\": [\\\"(step | int) == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Disable tripleo-iptables.service\\\", \\\"systemd\\\": {\\\"name\\\": \\\"tripleo-iptables.service\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}, \\\"register\\\": \\\"systemd_tripleo_iptables\\\", \\\"failed_when\\\": false}, {\\\"name\\\": \\\"Cleanup tripleo-iptables.services\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/systemd/system/tripleo-iptables.service\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"Disable tripleo-ip6tables.service\\\", \\\"systemd\\\": {\\\"name\\\": \\\"tripleo-ip6tables.service\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}, \\\"register\\\": \\\"systemd_tripleo_ip6tables\\\", \\\"failed_when\\\": false}, {\\\"name\\\": \\\"Cleanup tripleo-ip6tables.services\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/systemd/system/tripleo-ip6tables.service\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"Reload systemd\\\", \\\"systemd\\\": {\\\"daemon_reload\\\": true}, \\\"when\\\": [\\\"(systemd_tripleo_iptables is changed or systemd_tripleo_ip6tables is changed)\\\"]}]}, {\\\"when\\\": [\\\"(step | int) == 3\\\"], \\\"block\\\": [{\\\"name\\\": \\\"blank ipv6 rule before activating ipv6 firewall.\\\", \\\"shell\\\": \\\"cat /etc/sysconfig/ip6tables > /etc/sysconfig/ip6tables.n-o-upgrade; cat</dev/null>/etc/sysconfig/ip6tables\\\", \\\"args\\\": {\\\"creates\\\": \\\"/etc/sysconfig/ip6tables.n-o-upgrade\\\"}}, {\\\"name\\\": \\\"cleanup unmanaged rules pushed by iptables-services\\\", \\\"shell\\\": \\\"iptables -C INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  iptables -D INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT\\\\niptables -C INPUT -p icmp -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  iptables -D INPUT -p icmp -j ACCEPT\\\\niptables -C INPUT -i lo -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  iptables -D INPUT -i lo -j ACCEPT\\\\niptables -C INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  iptables -D INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT\\\\niptables -C INPUT -j REJECT --reject-with icmp-host-prohibited &>/dev/null && \\\\\\\\\\\\n  iptables -D INPUT -j REJECT --reject-with icmp-host-prohibited\\\\niptables -C FORWARD -j REJECT --reject-with icmp-host-prohibited &>/dev/null && \\\\\\\\\\\\n  iptables -D FORWARD -j REJECT --reject-with icmp-host-prohibited\\\\n\\\\nsed -i \'/^-A INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT$/d\' /etc/sysconfig/iptables\\\\nsed -i \'/^-A INPUT -p icmp -j ACCEPT$/d\' /etc/sysconfig/iptables\\\\nsed -i \'/^-A INPUT -i lo -j ACCEPT$/d\' /etc/sysconfig/iptables\\\\nsed -i \'/^-A INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT$/d\' /etc/sysconfig/iptables\\\\nsed -i \'/^-A INPUT -j REJECT --reject-with icmp-host-prohibited$/d\' /etc/sysconfig/iptables\\\\nsed -i \'/^-A FORWARD -j REJECT --reject-with icmp-host-prohibited$/d\' /etc/sysconfig/iptables\\\\n\\\\nip6tables -C INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  ip6tables -D INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT\\\\nip6tables -C INPUT -p ipv6-icmp -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  ip6tables -D INPUT -p ipv6-icmp -j ACCEPT\\\\nip6tables -C INPUT -i lo -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  ip6tables -D INPUT -i lo -j ACCEPT\\\\nip6tables -C INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  ip6tables -D INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT\\\\nip6tables -C INPUT -d fe80::/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  ip6tables -D INPUT -d fe80::/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT\\\\nip6tables -C INPUT -j REJECT --reject-with icmp6-adm-prohibited &>/dev/null && \\\\\\\\\\\\n  ip6tables -D INPUT -j REJECT --reject-with icmp6-adm-prohibited\\\\nip6tables -C FORWARD -j REJECT --reject-with icmp6-adm-prohibited &>/dev/null && \\\\\\\\\\\\n  ip6tables -D FORWARD -j REJECT --reject-with icmp6-adm-prohibited\\\\n\\\\nsed -i \'/^-A INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\\\nsed -i \'/^-A INPUT -p ipv6-icmp -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\\\nsed -i \'/^-A INPUT -i lo -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\\\nsed -i \'/^-A INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\\\nsed -i \'/^-A INPUT -d fe80::\\\\\\\\/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\\\nsed -i \'/^-A INPUT -j REJECT --reject-with icmp6-adm-prohibited$/d\' /etc/sysconfig/ip6tables\\\\nsed -i \'/^-A FORWARD -j REJECT --reject-with icmp6-adm-prohibited$/d\' /etc/sysconfig/ip6tables\\\"}]}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Configures podman on the host\\\\n\\\", \\\"parameters\\\": {\\\"DockerInsecureRegistryAddress\\\": {\\\"description\\\": \\\"Optional. The IP Address and Port of an insecure docker namespace that will be configured in /etc/sysconfig/docker. The value can be multiple addresses separated by commas.\\\", \\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": []}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"ContainerImageRegistryLogin\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false, \\\"description\\\": \\\"Flag to enable container registry login actions during the deployment. Setting this to true will cause login calls to be performed during the deployment.\\\"}, \\\"ContainerImageRegistryCredentials\\\": {\\\"type\\\": \\\"json\\\", \\\"hidden\\\": true, \\\"default\\\": {}, \\\"description\\\": \\\"Mapping of image registry hosts to login credentials. Must be in the following example format\\\\n\\\\n  docker.io:\\\\n    username: pa55word\\\\n  \'192.0.2.1:8787\':\\\\n    registry_username: password\\\\n\\\"}, \\\"ContainerDefaultPidsLimit\\\": {\\\"type\\\": \\\"number\\\", \\\"default\\\": 4096, \\\"description\\\": \\\"Setting to configure the default pids_limit in /etc/container/container.conf. This is supported starting with podman 2.0.x\\\"}, \\\"ContainerDefaultEventsLogger\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"journald\\\", \\\"description\\\": \\\"Setting to configure where podman logs its events. Uses journald by default as that will rotate data stored in tmpfs.\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"journald\\\", \\\"file\\\", \\\"none\\\"]}]}, \\\"SystemdDropInDependencies\\\": {\\\"default\\\": true, \\\"description\\\": \\\"tell the tripleo_container_manage to inject additional ordering dependencies for the systemd scopes associated to podman containers.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"deployment_source_hosts\\\": {\\\"default\\\": \\\"Undercloud\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Host or hostgroup that runs the deployment\\\"}}, \\\"conditions\\\": {\\\"insecure_registry_is_empty\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"DockerInsecureRegistryAddress\\\"}, []]}, \\\"systemd_drop_in_dependencies_enabled\\\": {\\\"get_param\\\": \\\"SystemdDropInDependencies\\\"}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the podman service\\\", \\\"value\\\": {\\\"service_name\\\": \\\"podman\\\", \\\"config_settings\\\": {}, \\\"step_config\\\": \\\"\\\", \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"Install and configure Podman\\\", \\\"block\\\": [{\\\"name\\\": \\\"Set login facts\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_insecure_registries\\\": {\\\"if\\\": [\\\"insecure_registry_is_empty\\\", [], {\\\"get_param\\\": \\\"DockerInsecureRegistryAddress\\\"}]}, \\\"container_registry_login\\\": {\\\"get_param\\\": \\\"ContainerImageRegistryLogin\\\"}, \\\"container_registry_logins\\\": {}, \\\"container_registry_logins_json\\\": {\\\"get_param\\\": \\\"ContainerImageRegistryCredentials\\\"}, \\\"container_default_pids_limit\\\": {\\\"get_param\\\": \\\"ContainerDefaultPidsLimit\\\"}, \\\"container_events_logger_mechanism\\\": {\\\"get_param\\\": \\\"ContainerDefaultEventsLogger\\\"}}}, {\\\"name\\\": \\\"Convert logins json to dict\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_logins\\\": \\\"{{ container_registry_logins_json | from_json }}\\\"}, \\\"when\\\": [\\\"container_registry_logins_json is string\\\", \\\"container_registry_login | bool\\\", \\\"(container_registry_logins_json | length) > 0\\\"]}, {\\\"name\\\": \\\"Set registry logins\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_logins\\\": \\\"{{ container_registry_logins_json }}\\\"}, \\\"when\\\": [\\\"container_registry_logins_json is mapping\\\", \\\"container_registry_login | bool\\\", \\\"(container_registry_logins_json | length) > 0\\\"]}, {\\\"name\\\": \\\"Run podman install\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_install.yml\\\"}, \\\"vars\\\": {\\\"tripleo_container_registry_insecure_registries\\\": \\\"{{ container_registry_insecure_registries }}\\\", \\\"tripleo_container_default_pids_limit\\\": \\\"{{ container_default_pids_limit }}\\\", \\\"tripleo_container_events_logger_mechanism\\\": \\\"{{ container_events_logger_mechanism }}\\\"}}, {\\\"name\\\": \\\"Run podman login\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_login.yml\\\"}, \\\"vars\\\": {\\\"tripleo_container_registry_logins\\\": \\\"{{ container_registry_logins }}\\\", \\\"tripleo_container_registry_login\\\": \\\"{{ container_registry_login | bool }}\\\"}}]}, {\\\"if\\\": [\\\"systemd_drop_in_dependencies_enabled\\\", [{\\\"name\\\": \\\"Configure tripleo_container_manage to generate systemd drop-in dependencies\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/sysconfig/podman_drop_in\\\", \\\"content\\\": \\\"This file makes tripleo_container_manage generate additional systemd\\\\ndependencies for containers that have special\\\\nstart/stop ordering constraints. It ensures that\\\\nthose constraints are enforced on reboot/shutdown.\\\\n\\\"}}], [{\\\"name\\\": \\\"Configure tripleo_container_manage to not generate drop-in dependencies\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/sysconfig/podman_drop_in\\\", \\\"state\\\": \\\"absent\\\"}}]]}], \\\"deploy_steps_tasks\\\": [{\\\"when\\\": [\\\"(step|int) == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Pre-fetch all the containers\\\", \\\"become\\\": true, \\\"containers.podman.podman_image\\\": {\\\"name\\\": \\\"{{ prefetch_image }}\\\", \\\"validate_certs\\\": false, \\\"force\\\": true}, \\\"register\\\": \\\"result\\\", \\\"until\\\": \\\"result is succeeded\\\", \\\"retries\\\": 5, \\\"delay\\\": 5, \\\"loop_control\\\": {\\\"loop_var\\\": \\\"prefetch_image\\\"}, \\\"loop\\\": \\\"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\\\"}]}], \\\"service_config_settings\\\": {}, \\\"workaround_upgrade_tasks\\\": [{\\\"name\\\": \\\"Configure Podman registry\\\", \\\"when\\\": [\\\"step|int == 0\\\"], \\\"tags\\\": [\\\"setup_packages\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Make sure the Undercloud hostname is included in /etc/hosts\\\", \\\"when\\\": [\\\"undercloud_hosts_entries is defined\\\"], \\\"lineinfile\\\": {\\\"dest\\\": \\\"/etc/hosts\\\", \\\"line\\\": \\\"{{ undercloud_hosts_entries | join(\'\') }}\\\", \\\"state\\\": \\\"present\\\"}}]}, {\\\"name\\\": \\\"Run podman install\\\", \\\"tags\\\": [\\\"system_upgrade\\\", \\\"system_upgrade_run\\\", \\\"setup_packages\\\"], \\\"when\\\": [\\\"step|int == 0\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Set login facts\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_insecure_registries\\\": {\\\"if\\\": [\\\"insecure_registry_is_empty\\\", [], {\\\"get_param\\\": \\\"DockerInsecureRegistryAddress\\\"}]}, \\\"container_registry_login\\\": {\\\"get_param\\\": \\\"ContainerImageRegistryLogin\\\"}, \\\"container_registry_logins\\\": {}, \\\"container_registry_logins_json\\\": {\\\"get_param\\\": \\\"ContainerImageRegistryCredentials\\\"}, \\\"container_default_pids_limit\\\": {\\\"get_param\\\": \\\"ContainerDefaultPidsLimit\\\"}, \\\"container_events_logger_mechanism\\\": {\\\"get_param\\\": \\\"ContainerDefaultEventsLogger\\\"}}}, {\\\"name\\\": \\\"Convert logins json to dict\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_logins\\\": \\\"{{ container_registry_logins_json | from_json }}\\\"}, \\\"when\\\": [\\\"container_registry_logins_json is string\\\", \\\"container_registry_login | bool\\\", \\\"(container_registry_logins_json | length) > 0\\\"]}, {\\\"name\\\": \\\"Set registry logins\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_logins\\\": \\\"{{ container_registry_logins_json }}\\\"}, \\\"when\\\": [\\\"container_registry_logins_json is mapping\\\", \\\"container_registry_login | bool\\\", \\\"(container_registry_logins_json | length) > 0\\\"]}, {\\\"name\\\": \\\"Run podman install\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_install.yml\\\"}, \\\"vars\\\": {\\\"tripleo_container_registry_insecure_registries\\\": \\\"{{ container_registry_insecure_registries }}\\\", \\\"tripleo_container_default_pids_limit\\\": \\\"{{ container_default_pids_limit }}\\\", \\\"tripleo_container_events_logger_mechanism\\\": \\\"{{ container_events_logger_mechanism }}\\\"}}, {\\\"name\\\": \\\"Run podman login\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_login.yml\\\"}, \\\"vars\\\": {\\\"tripleo_container_registry_logins\\\": \\\"{{ container_registry_logins }}\\\", \\\"tripleo_container_registry_login\\\": \\\"{{ container_registry_login | bool }}\\\"}}]}, {\\\"name\\\": \\\"Comment infra_image in container.conf\\\", \\\"lineinfile\\\": {\\\"dest\\\": \\\"/usr/share/containers/containers.conf\\\", \\\"regexp\\\": \\\"(?i)^(infra_image.*)\\\", \\\"line\\\": \\\"#\\\\\\\\1\\\", \\\"backrefs\\\": true, \\\"state\\\": \\\"present\\\"}, \\\"tags\\\": [\\\"setup_packages\\\"], \\\"when\\\": [\\\"step|int == 0\\\"]}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"Configure Podman registry\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Make sure the Undercloud hostname is included in /etc/hosts\\\", \\\"when\\\": [\\\"undercloud_hosts_entries is defined\\\"], \\\"lineinfile\\\": {\\\"dest\\\": \\\"/etc/hosts\\\", \\\"line\\\": \\\"{{ undercloud_hosts_entries | join(\'\') }}\\\", \\\"state\\\": \\\"present\\\"}}]}, {\\\"name\\\": \\\"Run podman install\\\", \\\"tags\\\": [\\\"system_upgrade\\\", \\\"system_upgrade_run\\\"], \\\"when\\\": [\\\"step|int == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Set login facts\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_insecure_registries\\\": {\\\"if\\\": [\\\"insecure_registry_is_empty\\\", [], {\\\"get_param\\\": \\\"DockerInsecureRegistryAddress\\\"}]}, \\\"container_registry_login\\\": {\\\"get_param\\\": \\\"ContainerImageRegistryLogin\\\"}, \\\"container_registry_logins\\\": {}, \\\"container_registry_logins_json\\\": {\\\"get_param\\\": \\\"ContainerImageRegistryCredentials\\\"}, \\\"container_default_pids_limit\\\": {\\\"get_param\\\": \\\"ContainerDefaultPidsLimit\\\"}, \\\"container_events_logger_mechanism\\\": {\\\"get_param\\\": \\\"ContainerDefaultEventsLogger\\\"}}}, {\\\"name\\\": \\\"Convert logins json to dict\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_logins\\\": \\\"{{ container_registry_logins_json | from_json }}\\\"}, \\\"when\\\": [\\\"container_registry_logins_json is string\\\", \\\"container_registry_login | bool\\\", \\\"(container_registry_logins_json | length) > 0\\\"]}, {\\\"name\\\": \\\"Set registry logins\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_logins\\\": \\\"{{ container_registry_logins_json }}\\\"}, \\\"when\\\": [\\\"container_registry_logins_json is mapping\\\", \\\"container_registry_login | bool\\\", \\\"(container_registry_logins_json | length) > 0\\\"]}, {\\\"name\\\": \\\"Run podman install\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_install.yml\\\"}, \\\"vars\\\": {\\\"tripleo_container_registry_insecure_registries\\\": \\\"{{ container_registry_insecure_registries }}\\\", \\\"tripleo_container_default_pids_limit\\\": \\\"{{ container_default_pids_limit }}\\\", \\\"tripleo_container_events_logger_mechanism\\\": \\\"{{ container_events_logger_mechanism }}\\\"}}, {\\\"name\\\": \\\"Run podman login\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_login.yml\\\"}, \\\"vars\\\": {\\\"tripleo_container_registry_logins\\\": \\\"{{ container_registry_logins }}\\\", \\\"tripleo_container_registry_login\\\": \\\"{{ container_registry_login | bool }}\\\"}}]}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"Force pre-fetch of container images\\\", \\\"when\\\": [\\\"(step|int) == 5\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Pre-fetch all the containers\\\", \\\"become\\\": true, \\\"containers.podman.podman_image\\\": {\\\"name\\\": \\\"{{ prefetch_image }}\\\", \\\"validate_certs\\\": false, \\\"force\\\": true}, \\\"register\\\": \\\"result\\\", \\\"until\\\": \\\"result is succeeded\\\", \\\"retries\\\": 5, \\\"delay\\\": 5, \\\"loop_control\\\": {\\\"loop_var\\\": \\\"prefetch_image\\\"}, \\\"loop\\\": \\\"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\\\"}]}], \\\"post_upgrade_tasks\\\": [{\\\"name\\\": \\\"Purge Podman\\\", \\\"when\\\": [\\\"(step | int) == 3\\\", \\\"container_cli == \'podman\'\\\", \\\"deployment_source_hosts not in group_names\\\"], \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_purge.yml\\\"}, \\\"vars\\\": {\\\"deployment_source_hosts\\\": {\\\"get_param\\\": \\\"deployment_source_hosts\\\"}}}], \\\"post_update_tasks\\\": [{\\\"name\\\": \\\"Purge Podman\\\", \\\"when\\\": [\\\"(step | int) == 3\\\", \\\"container_cli == \'podman\'\\\", \\\"deployment_source_hosts not in group_names\\\"], \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_purge.yml\\\"}, \\\"vars\\\": {\\\"deployment_source_hosts\\\": {\\\"get_param\\\": \\\"deployment_source_hosts\\\"}}}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"TripleO Package installation settings\\\\n\\\", \\\"parameters\\\": {\\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"EnablePackageInstall\\\": {\\\"default\\\": \\\"false\\\", \\\"description\\\": \\\"Set to true to enable package installation at deploy time\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"UpgradeLeappEnabled\\\": {\\\"description\\\": \\\"Use Leapp for operating system upgrade\\\", \\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"UpgradeLeappDebug\\\": {\\\"description\\\": \\\"Print debugging output when running Leapp\\\", \\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"UpgradeLeappDevelSkip\\\": {\\\"description\\\": \\\"Skip Leapp checks by setting env variables when running Leapp in\\\\ndevelopment/testing. For example, LEAPP_DEVEL_SKIP_RHSM=1.\\\\n\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"UpgradeLeappCommandOptions\\\": {\\\"description\\\": \\\"In case or using UpgradeLeappDevelSkip with LEAPP_NO_RHSM=1 user\\\\ncan specify --enablerepo <repo1> --enablerepo <repo2> options for\\\\nleapp to use these repositories for the upgrade process.\\\\n\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"UpgradeLeappRebootTimeout\\\": {\\\"description\\\": \\\"Timeout (seconds) for the OS upgrade phase via Leapp\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 3600}, \\\"UpgradeLeappPostRebootDelay\\\": {\\\"description\\\": \\\"Maximum (seconds) to wait for machine to reboot and respond to a test\\\\ncommand.\\\\n\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 120}, \\\"UpgradeLeappToRemove\\\": {\\\"default\\\": [], \\\"description\\\": \\\"List of packages to remove during Leapp upgrade.\\\", \\\"type\\\": \\\"comma_delimited_list\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"UpgradeLeappToInstall\\\": {\\\"default\\\": [], \\\"description\\\": \\\"List of packages to install after Leapp upgrade.\\\", \\\"type\\\": \\\"comma_delimited_list\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"LeappUnloadKernelDrivers\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": [], \\\"description\\\": \\\"List of modules to unload from the system due to being incompatible\\\\nwith the next RHEL version. If not being unloaded Leapp will\\\\ninhibit the upgrade.\\\\n\\\"}, \\\"LeappActorsToRemove\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": [], \\\"description\\\": \\\"List of actors to remove from the leapp process to prevent them\\\\nfrom inhibiting the upgrade.\\\\n\\\"}, \\\"LeappRepoInitCommand\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Command or script snippet to run on all overcloud nodes to\\\\ninitialize the Leapp process. E.g. a repository switch.\\\\n\\\", \\\"default\\\": \\\"\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"LeappInitCommand\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Command or script snippet to run on all overcloud nodes to\\\\napply any necessary workarounds to get Leapp working.\\\\n\\\", \\\"default\\\": \\\"\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NICsPrefixesToUdev\\\": {\\\"default\\\": [], \\\"description\\\": \\\"List of NIC prefixes to hardcode into udev in order to prevent\\\\nrenaming.\\\\n\\\", \\\"type\\\": \\\"comma_delimited_list\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"LeappPreRebootCommand\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Command or script snippet to run on all overcloud nodes to\\\\napply any necessary workarounds before rebooting into Leapp.\\\\n\\\", \\\"default\\\": \\\"\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"LeappPostRebootCommand\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Command or script snippet to run on all overcloud nodes to\\\\napply any necessary workarounds after rebooting from Leapp.\\\\n\\\", \\\"default\\\": \\\"\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"UpgradeInitCommand\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Command or script snippet to run on all overcloud nodes to\\\\ninitialize the upgrade process. E.g. a repository switch.\\\\n\\\", \\\"default\\\": \\\"\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"UpgradeInitCommonCommand\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Common commands required by the upgrades process. This should not\\\\nnormally be modified by the operator and is set and unset in the\\\\nmajor-upgrade-composable-steps.yaml and major-upgrade-converge.yaml\\\\nenvironment files.\\\\n\\\", \\\"default\\\": \\\"\\\"}, \\\"SkipPackageUpdate\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Set to true to skip the update all packages\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"SkipRhelEnforcement\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to avoid or not RHEL/OSP policies enforcement on Red Hat. Mainly for CI purpose.  It shouldn\'t matter on other distributions where it\'s disabled in the role. Set to true to skip the enforcement.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"DnfStreams\\\": {\\\"default\\\": [], \\\"description\\\": \\\"List of streams to be configured before updating packages. Each list element contains a dictionary with the following values defined module[mandatory], stream[mandatory], distribution_version[mandatory] and profile[optional]. If the profile is not specified \'common\' will be used instead.\\\", \\\"type\\\": \\\"json\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"BaseTripleoPackages\\\": {\\\"default\\\": [], \\\"description\\\": \\\"List of packages to install.\\\", \\\"type\\\": \\\"comma_delimited_list\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerImageRegistryLogin\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false, \\\"description\\\": \\\"Flag to enable container registry login actions during the deployment. Setting this to true will cause login calls to be performed during the deployment.\\\"}}, \\\"resources\\\": {\\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"dnf_module_list\\\": \\\"DnfStreams\\\", \\\"upgrade_leapp_devel_skip\\\": \\\"UpgradeLeappDevelSkip\\\", \\\"upgrade_leapp_command_options\\\": \\\"UpgradeLeappCommandOptions\\\", \\\"upgrade_leapp_to_remove\\\": \\\"UpgradeLeappToRemove\\\", \\\"upgrade_leapp_to_install\\\": \\\"UpgradeLeappToInstall\\\", \\\"leapp_repo_init_command\\\": \\\"LeappRepoInitCommand\\\", \\\"leapp_init_command\\\": \\\"LeappInitCommand\\\", \\\"nics_prefixes_to_keep\\\": \\\"NICsPrefixesToUdev\\\", \\\"upgrade_leapp_modules_to_unload\\\": \\\"LeappUnloadKernelDrivers\\\", \\\"upgrade_leapp_actors_to_remove\\\": \\\"LeappActorsToRemove\\\", \\\"upgrade_init_command\\\": \\\"UpgradeInitCommand\\\", \\\"base_tripleo_packages\\\": \\\"BaseTripleoPackages\\\", \\\"leapp_pre_reboot_command\\\": \\\"LeappPreRebootCommand\\\", \\\"leapp_post_reboot_command\\\": \\\"LeappPostRebootCommand\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"DnfStreams\\\": {\\\"get_param\\\": \\\"DnfStreams\\\"}, \\\"UpgradeLeappDevelSkip\\\": {\\\"get_param\\\": \\\"UpgradeLeappDevelSkip\\\"}, \\\"UpgradeLeappCommandOptions\\\": {\\\"get_param\\\": \\\"UpgradeLeappCommandOptions\\\"}, \\\"UpgradeLeappToRemove\\\": {\\\"get_param\\\": \\\"UpgradeLeappToRemove\\\"}, \\\"UpgradeLeappToInstall\\\": {\\\"get_param\\\": \\\"UpgradeLeappToInstall\\\"}, \\\"LeappUnloadKernelDrivers\\\": {\\\"get_param\\\": \\\"LeappUnloadKernelDrivers\\\"}, \\\"LeappPreRebootCommand\\\": {\\\"get_param\\\": \\\"LeappPreRebootCommand\\\"}, \\\"LeappPostRebootCommand\\\": {\\\"get_param\\\": \\\"LeappPostRebootCommand\\\"}, \\\"LeappActorsToRemove\\\": {\\\"get_param\\\": \\\"LeappActorsToRemove\\\"}, \\\"UpgradeInitCommand\\\": {\\\"get_param\\\": \\\"UpgradeInitCommand\\\"}, \\\"LeappRepoInitCommand\\\": {\\\"get_param\\\": \\\"LeappRepoInitCommand\\\"}, \\\"LeappInitCommand\\\": {\\\"get_param\\\": \\\"LeappInitCommand\\\"}, \\\"NICsPrefixesToUdev\\\": {\\\"get_param\\\": \\\"NICsPrefixesToUdev\\\"}, \\\"BaseTripleoPackages\\\": {\\\"get_param\\\": \\\"BaseTripleoPackages\\\"}}}]}}}, \\\"Podman\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}}, \\\"conditions\\\": {\\\"podman_requires_login\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"ContainerImageRegistryLogin\\\"}, true]}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the TripleO package settings\\\", \\\"value\\\": {\\\"service_name\\\": \\\"tripleo_packages\\\", \\\"config_settings\\\": {\\\"tripleo::packages::enable_install\\\": {\\\"get_param\\\": \\\"EnablePackageInstall\\\"}}, \\\"step_config\\\": \\\"include ::tripleo::packages\\\\n\\\", \\\"upgrade_tasks\\\": {\\\"list_concat\\\": [[{\\\"name\\\": \\\"Gather missing facts\\\", \\\"setup\\\": {\\\"gather_subset\\\": [\\\"!all\\\", \\\"!min\\\", \\\"distribution\\\"]}, \\\"tags\\\": [\\\"always\\\"]}, {\\\"name\\\": \\\"Set leapp facts\\\", \\\"set_fact\\\": {\\\"upgrade_leapp_enabled\\\": \\\"{{ _upgradeLeappEnabled | bool and\\\\n   ansible_facts[\'distribution\'] == \'RedHat\' and\\\\n   ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\') }}\\\", \\\"upgrade_leapp_debug\\\": {\\\"get_param\\\": \\\"UpgradeLeappDebug\\\"}, \\\"upgrade_leapp_devel_skip\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"upgrade_leapp_devel_skip\\\"]}, \\\"upgrade_leapp_command_options\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"upgrade_leapp_command_options\\\"]}, \\\"upgrade_leapp_reboot_timeout\\\": {\\\"get_param\\\": \\\"UpgradeLeappRebootTimeout\\\"}, \\\"upgrade_leapp_post_reboot_delay\\\": {\\\"get_param\\\": \\\"UpgradeLeappPostRebootDelay\\\"}}, \\\"vars\\\": {\\\"_upgradeLeappEnabled\\\": {\\\"get_param\\\": \\\"UpgradeLeappEnabled\\\"}}, \\\"tags\\\": [\\\"always\\\"]}, {\\\"name\\\": \\\"system_upgrade_prepare step 3\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_prepare\\\"], \\\"when\\\": [\\\"step|int == 3\\\", \\\"upgrade_leapp_enabled\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Run LeappRepoInitCommand\\\", \\\"shell\\\": {\\\"list_join\\\": [\\\"\\\", [\\\"#!/bin/bash\\\\n\\\\n\\\", {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"leapp_repo_init_command\\\"]}]]}}, {\\\"name\\\": \\\"Remove firewalld bindings\\\", \\\"package\\\": {\\\"name\\\": \\\"python3-firewall\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"install leapp\\\", \\\"package\\\": {\\\"name\\\": \\\"leapp-repository-openstack\\\", \\\"state\\\": \\\"latest\\\"}}, {\\\"name\\\": \\\"Run LeappInitCommand\\\", \\\"shell\\\": {\\\"list_join\\\": [\\\"\\\", [\\\"#!/bin/bash\\\\n\\\\n\\\", {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"leapp_init_command\\\"]}]]}}, {\\\"name\\\": \\\"Remove vdo\\\", \\\"package\\\": {\\\"name\\\": \\\"vdo\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"add packages into Leapp\'s to_remove file\\\", \\\"vars\\\": {\\\"pkg_to_remove\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"upgrade_leapp_to_remove\\\"]}}, \\\"lineinfile\\\": {\\\"path\\\": \\\"/etc/leapp/transaction/to_remove\\\", \\\"line\\\": \\\"{{ item }}\\\"}, \\\"loop\\\": \\\"{{ pkg_to_remove }}\\\"}, {\\\"name\\\": \\\"add packages into Leapp\'s to_install file\\\", \\\"vars\\\": {\\\"pkg_to_install\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"upgrade_leapp_to_install\\\"]}}, \\\"lineinfile\\\": {\\\"path\\\": \\\"/etc/leapp/transaction/to_install\\\", \\\"line\\\": \\\"{{ item }}\\\"}, \\\"loop\\\": \\\"{{ pkg_to_install }}\\\"}, {\\\"name\\\": \\\"check sshd_config file\\\", \\\"stat\\\": {\\\"path\\\": \\\"/etc/ssh/sshd_config\\\"}, \\\"register\\\": \\\"sshd_config_result\\\"}, {\\\"name\\\": \\\"add PermitRootLogin option for leapp\\\", \\\"lineinfile\\\": {\\\"path\\\": \\\"/etc/ssh/sshd_config\\\", \\\"regexp\\\": \\\"^(# *)?PermitRootLogin\\\", \\\"line\\\": \\\"PermitRootLogin without-password\\\"}}, {\\\"name\\\": \\\"Remove paunch-services\\\", \\\"package\\\": {\\\"name\\\": \\\"paunch-services\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"tripleo_container_manage reconfiguration\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_manage\\\", \\\"tasks_from\\\": \\\"shutdown.yml\\\"}}]}, {\\\"name\\\": \\\"system_upgrade_prepare step 4\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_prepare\\\"], \\\"when\\\": [\\\"step|int == 4\\\", \\\"upgrade_leapp_enabled\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Delete the kernel modules in Leapp database (device_driver_deprecation_data.json)\\\", \\\"vars\\\": {\\\"modules_to_unload\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"upgrade_leapp_modules_to_unload\\\"]}}, \\\"shell\\\": \\\"set -o pipefail && jq \'. | del(.data[] | select(.driver_name == \\\\\\\"{{ item }}\\\\\\\"))\' /etc/leapp/files/device_driver_deprecation_data.json > /etc/leapp/files/device_driver_deprecation_data.json_modified && mv /etc/leapp/files/device_driver_deprecation_data.json_modified /etc/leapp/files/device_driver_deprecation_data.json\\\\n\\\", \\\"loop\\\": \\\"{{ modules_to_unload }}\\\"}, {\\\"name\\\": \\\"Remove leapp actors to prevent them inhibiting the upgrade\\\", \\\"vars\\\": {\\\"actors_to_remove\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"upgrade_leapp_actors_to_remove\\\"]}}, \\\"command\\\": {\\\"cmd\\\": \\\"find /usr/share/leapp-repository/repositories/ -name {{ item }} -type d -print -exec rm -rf \\\\\\\"{}\\\\\\\" +\\\"}, \\\"loop\\\": \\\"{{ actors_to_remove }}\\\"}, {\\\"name\\\": \\\"set leapp required answers\\\", \\\"shell\\\": \\\"leapp answer --add --section check_vdo.confirm=True\\\\n\\\"}, {\\\"name\\\": \\\"Replace EFI grub.cfg with redirect to /boot/grub2/grub.cfg\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_kernel\\\", \\\"tasks_from\\\": \\\"efigrub.yml\\\"}}, {\\\"name\\\": \\\"Keep nics with prefix in NICsPrefixesToUdev from renaming\\\", \\\"vars\\\": {\\\"nics_prefixes_to_keep\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"nics_prefixes_to_keep\\\"]}}, \\\"shell\\\": \\\"ip -j link show | \\\\\\\\ jq -r --arg prefix \\\\\\\"{{ item }}\\\\\\\" \'.[] |\\\\n  select((.ifname | startswith($prefix)) and\\\\n  (.ifname | test(\\\\\\\"^.*v[0-9]*$\\\\\\\") | not) and\\\\n  (.ifname | test(\\\\\\\"^.*_[0-9]*$\\\\\\\") | not) and\\\\n  (.ifname | test(\\\\\\\"^.*\\\\\\\\\\\\\\\\..*$\\\\\\\") | not)) |\\\\n  if .permaddr? then .address=.permaddr else . end |\\\\n  \\\\\\\"SUBSYSTEM==\\\\\\\\\\\\\\\"net\\\\\\\\\\\\\\\",ACTION==\\\\\\\\\\\\\\\"add\\\\\\\\\\\\\\\",DRIVERS==\\\\\\\\\\\\\\\"?*\\\\\\\\\\\\\\\",\\\\\\\" + \\\\\\\"NAME=\\\\\\\\\\\\\\\"\\\\\\\" + .ifname +\\\\\\\"\\\\\\\\\\\\\\\" ,ATTR{address}==\\\\\\\\\\\\\\\"\\\\\\\" + .address + \\\\\\\"\\\\\\\\\\\\\\\"\\\\\\\"\' >> /etc/udev/rules.d/70-rhosp-persistent-net.rules\\\\n\\\", \\\"loop\\\": \\\"{{ nics_prefixes_to_keep|list }}\\\"}, {\\\"name\\\": \\\"run leapp upgrade (download packages)\\\", \\\"shell\\\": \\\"{% if upgrade_leapp_devel_skip|default(false) %}{{ upgrade_leapp_devel_skip }}{% endif %} leapp upgrade {% if upgrade_leapp_debug|default(true) %}--debug{% endif %} {% if upgrade_leapp_command_options|default(false) %}{{ upgrade_leapp_command_options }}{% endif %}\\\\n\\\", \\\"when\\\": \\\"upgrade_leapp_enabled\\\"}]}, {\\\"name\\\": \\\"system_upgrade_run step 4\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_run\\\", \\\"system_upgrade_reboot\\\"], \\\"when\\\": [\\\"step|int == 4\\\", \\\"upgrade_leapp_enabled\\\", \\\"\'Undercloud\' not in group_names\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Run LeappPreRebootCommand\\\", \\\"shell\\\": {\\\"list_join\\\": [\\\"\\\", [\\\"#!/bin/bash\\\\n\\\\n\\\", {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"leapp_pre_reboot_command\\\"]}]]}}, {\\\"name\\\": \\\"Check that nova_libvirt is running\\\", \\\"shell\\\": \\\"podman ps --filter name=^nova_virtlogd$ --format \\\\\\\"{% raw %}{{ .Image }}{% endraw %}\\\\\\\"\\\\n\\\", \\\"register\\\": \\\"is_virtlogd_image_running\\\"}, {\\\"name\\\": \\\"Remove systemd files to disable them\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/systemd/system/{{ item }}\\\", \\\"state\\\": \\\"absent\\\"}, \\\"with_items\\\": [\\\"tripleo_nova_libvirt.service\\\", \\\"tripleo_nova_virtlogd_wrapper.service\\\", \\\"tripleo_nova_libvirt.target\\\"], \\\"when\\\": \\\"is_virtlogd_image_running.stdout != \'\'\\\"}, {\\\"name\\\": \\\"reboot to perform the upgrade\\\", \\\"reboot\\\": {\\\"reboot_timeout\\\": \\\"{{upgrade_leapp_reboot_timeout}}\\\", \\\"test_command\\\": \\\"source /etc/os-release; [ \\\\\\\"${VERSION_ID%.*}\\\\\\\" -ge \\\\\\\"8\\\\\\\" ] && systemctl is-system-running | grep -qE \\\\\\\"running|degraded\\\\\\\" || exit 1\\\", \\\"post_reboot_delay\\\": \\\"{{ upgrade_leapp_post_reboot_delay }}\\\"}}, {\\\"name\\\": \\\"Set selinux back to enforcing after leapp reboot\\\", \\\"selinux\\\": {\\\"policy\\\": \\\"targeted\\\", \\\"state\\\": \\\"enforcing\\\"}}, {\\\"name\\\": \\\"Run LeappPostRebootCommand\\\", \\\"shell\\\": {\\\"list_join\\\": [\\\"\\\", [\\\"#!/bin/bash\\\\n\\\\n\\\", {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"leapp_post_reboot_command\\\"]}]]}}]}, {\\\"name\\\": \\\"Host packages setup step0\\\", \\\"tags\\\": \\\"setup_packages\\\", \\\"when\\\": \\\"step|int == 0\\\", \\\"block\\\": [{\\\"name\\\": \\\"Package and repo update tasks\\\", \\\"block\\\": [{\\\"name\\\": \\\"Run UpgradeInitCommand\\\", \\\"shell\\\": {\\\"list_join\\\": [\\\"\\\", [\\\"#!/bin/bash\\\\n\\\\n\\\", \\\"if [[ -f /etc/resolv.conf.save ]] ; then rm /etc/resolv.conf.save; fi\\\\n\\\\n\\\", {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"upgrade_init_command\\\"]}]]}}, {\\\"name\\\": \\\"Run UpgradeInitCommonCommand\\\", \\\"shell\\\": {\\\"list_join\\\": [\\\"\\\", [\\\"#!/bin/bash\\\\n\\\\n\\\", {\\\"get_param\\\": \\\"UpgradeInitCommonCommand\\\"}]]}}, {\\\"name\\\": \\\"Ensure DNF modules have the right stream\\\", \\\"vars\\\": {\\\"dnf_module_list\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"dnf_module_list\\\"]}}, \\\"dnf\\\": {\\\"name\\\": \\\"@{{ item.module }}:{{ item.stream }}/{{ item.profile|default(\'common\') }}\\\", \\\"state\\\": \\\"present\\\"}, \\\"loop\\\": \\\"{{ dnf_module_list|list }}\\\", \\\"when\\\": [\\\"dnf_module_list|length > 0\\\", \\\"item.distribution_version is defined\\\", \\\"ansible_facts[\'distribution_major_version\'] is version(item.distribution_version, \'==\')\\\"]}, {\\\"name\\\": \\\"Ensure TripleO prerequisite packages are installed\\\", \\\"package\\\": {\\\"name\\\": [\\\"jq\\\", \\\"lvm2\\\", \\\"openstack-selinux\\\", \\\"os-net-config\\\", \\\"puppet-tripleo\\\", \\\"python3-heat-agent*\\\", \\\"rsync\\\"], \\\"state\\\": \\\"present\\\"}, \\\"when\\\": \\\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\\\"}, {\\\"name\\\": \\\"Ensure TripleO prerequisite packages are installed and use role based heat variable to provide specific list of packages\\\", \\\"vars\\\": {\\\"base_tripleo_packages\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"base_tripleo_packages\\\"]}}, \\\"package\\\": {\\\"name\\\": \\\"{{ base_tripleo_packages }}\\\", \\\"state\\\": \\\"present\\\"}, \\\"when\\\": [\\\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\\\", \\\"base_tripleo_packages|length > 0\\\"]}, {\\\"name\\\": \\\"WA for 2240185 - If the image is schema 1 and lacks signatures than add empty signatures\\\", \\\"shell\\\": \\\"for manifest_file in `find /var/lib/containers/storage/overlay-images/ -name \'manifest\'`\\\\ndo\\\\n    cat <<< $( jq  \'if .schemaVersion == 1 then if has(\\\\\\\"signatures\\\\\\\") then . else .signatures=[] end else . end\' $manifest_file ) > $manifest_file\\\\ndone\\\\n\\\", \\\"when\\\": \\\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\\\"}]}, {\\\"name\\\": \\\"check if libvirt is installed\\\", \\\"command\\\": \\\"/usr/bin/rpm -q libvirt-daemon\\\", \\\"failed_when\\\": false, \\\"register\\\": \\\"libvirt_installed\\\", \\\"check_mode\\\": false}, {\\\"name\\\": \\\"make sure libvirt services are disabled and masked\\\", \\\"service\\\": {\\\"name\\\": \\\"{{ item }}\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false, \\\"masked\\\": true, \\\"daemon_reload\\\": true}, \\\"loop\\\": [\\\"libvirtd.service\\\", \\\"virtlogd.socket\\\"], \\\"when\\\": [\\\"libvirt_installed.rc == 0\\\"]}]}, {\\\"name\\\": \\\"Host packages setup step2\\\", \\\"tags\\\": \\\"setup_packages\\\", \\\"when\\\": \\\"step|int == 2\\\", \\\"block\\\": [{\\\"name\\\": \\\"Special treatment for OpenvSwitch\\\", \\\"tripleo_ovs_upgrade\\\": null, \\\"register\\\": \\\"ovs_upgrade\\\"}, {\\\"name\\\": \\\"Always ensure the openvswitch service is enabled and running after upgrades\\\", \\\"service\\\": {\\\"name\\\": \\\"openvswitch\\\", \\\"enabled\\\": true, \\\"state\\\": \\\"started\\\"}, \\\"when\\\": [\\\"ovs_upgrade.changed|bool\\\"]}]}, {\\\"name\\\": \\\"Host packages setup step3\\\", \\\"tags\\\": \\\"setup_packages\\\", \\\"when\\\": \\\"step|int == 3\\\", \\\"block\\\": [{\\\"name\\\": \\\"Check for os-net-config upgrade\\\", \\\"shell\\\": \\\"yum check-upgrade | awk \'/os-net-config/{print}\'\\\", \\\"register\\\": \\\"os_net_config_need_upgrade\\\"}, {\\\"name\\\": \\\"Check that os-net-config has legacy configuration\\\", \\\"stat\\\": {\\\"path\\\": \\\"/etc/os-net-config/config.json\\\", \\\"get_attributes\\\": false, \\\"get_checksum\\\": false, \\\"get_mime\\\": false}, \\\"register\\\": \\\"stat_config_json\\\"}, {\\\"name\\\": \\\"Check that os-net-config has new configuration\\\", \\\"stat\\\": {\\\"path\\\": \\\"/etc/os-net-config/config.yaml\\\", \\\"get_attributes\\\": false, \\\"get_checksum\\\": false, \\\"get_mime\\\": false}, \\\"register\\\": \\\"stat_config_yaml\\\"}, {\\\"name\\\": \\\"Slurp the os-net-config config.json\\\", \\\"slurp\\\": {\\\"src\\\": \\\"/etc/os-net-config/config.json\\\"}, \\\"register\\\": \\\"os_config_json\\\", \\\"when\\\": [\\\"stat_config_json.stat.exists\\\", \\\"not stat_config_yaml.stat.exists\\\"]}, {\\\"name\\\": \\\"Write updated /etc/os-net-config/config.yaml\\\", \\\"copy\\\": {\\\"content\\\": \\\"{{ os_config_json.content | b64decode | from_json | to_yaml }}\\\", \\\"dest\\\": \\\"/etc/os-net-config/config.yaml\\\"}, \\\"when\\\": [\\\"stat_config_json.stat.exists\\\", \\\"not stat_config_yaml.stat.exists\\\"]}, {\\\"name\\\": \\\"Remove legacy os-net-config configuration\\\", \\\"command\\\": \\\"mv /etc/os-net-config/config.json /etc/os-net-config/deprecated_config.json\\\", \\\"when\\\": [\\\"stat_config_json.stat.exists\\\"]}, {\\\"block\\\": [{\\\"name\\\": \\\"Upgrade os-net-config\\\", \\\"package\\\": \\\"name=os-net-config state=latest\\\"}, {\\\"name\\\": \\\"take new os-net-config parameters into account now\\\", \\\"command\\\": \\\"os-net-config --no-activate -c /etc/os-net-config/config.yaml -v --detailed-exit-codes\\\", \\\"register\\\": \\\"os_net_config_upgrade\\\", \\\"failed_when\\\": \\\"os_net_config_upgrade.rc not in [0,2]\\\", \\\"changed_when\\\": \\\"os_net_config_upgrade.rc == 2\\\"}], \\\"when\\\": [\\\"os_net_config_need_upgrade.stdout\\\", \\\"stat_config_yaml.stat.exists or stat_config_json.stat.exists\\\"]}, {\\\"name\\\": \\\"Update all packages\\\", \\\"when\\\": [\\\"not skip_package_update|bool\\\"], \\\"yum\\\": {\\\"name\\\": \\\"*\\\", \\\"state\\\": \\\"latest\\\", \\\"exclude\\\": \\\"ansible-core\\\"}, \\\"vars\\\": {\\\"skip_package_update\\\": {\\\"get_param\\\": \\\"SkipPackageUpdate\\\"}}}, {\\\"name\\\": \\\"Check whether openvswitch exits\\\", \\\"command\\\": \\\"systemctl status openvswitch.service\\\", \\\"register\\\": \\\"ovs_service\\\", \\\"ignore_errors\\\": true}, {\\\"name\\\": \\\"Always ensure the openvswitch service is enabled and running after upgrades rhbz#2329821\\\", \\\"service\\\": {\\\"name\\\": \\\"openvswitch\\\", \\\"enabled\\\": true, \\\"state\\\": \\\"started\\\"}, \\\"when\\\": [\\\"ovs_service.stderr != \\\\\\\"Unit openvswitch.service could not be found.\\\\\\\"\\\"]}]}], {\\\"if\\\": [\\\"podman_requires_login\\\", {\\\"get_attr\\\": [\\\"Podman\\\", \\\"role_data\\\", \\\"workaround_upgrade_tasks\\\"]}, []]}]}, \\\"external_upgrade_tasks\\\": [{\\\"name\\\": \\\"Clean up upgrade artifacts\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade_cleanup\\\"], \\\"block\\\": [{\\\"name\\\": \\\"cleanup tripleo_persist\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_persist\\\", \\\"tasks_from\\\": \\\"cleanup.yml\\\"}}]}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"Enforce RHOSP rules regarding subscription.\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_redhat_enforce\\\"}, \\\"vars\\\": {\\\"skip_rhel_enforcement\\\": {\\\"get_param\\\": \\\"SkipRhelEnforcement\\\"}}, \\\"when\\\": [\\\"step|int == 0\\\", \\\"ansible_facts[\'distribution\'] == \'RedHat\'\\\", \\\"not (skip_rhel_enforcement | bool)\\\"]}, {\\\"name\\\": \\\"Ensure DNF modules have the right stream enabled\\\", \\\"vars\\\": {\\\"dnf_module_list\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"dnf_module_list\\\"]}}, \\\"tripleo_dnf_stream\\\": {\\\"name\\\": \\\"{{ item.module }}:{{ item.stream }}\\\", \\\"state\\\": \\\"enabled\\\"}, \\\"loop\\\": \\\"{{ dnf_module_list|list }}\\\", \\\"when\\\": [\\\"step|int == 0\\\", \\\"dnf_module_list|length > 0\\\", \\\"item.distribution_version is defined\\\", \\\"ansible_facts[\'distribution_major_version\'] is version(item.distribution_version, \'==\')\\\"]}, {\\\"name\\\": \\\"Check for existing yum.pid\\\", \\\"stat\\\": \\\"path=/run/yum.pid\\\", \\\"register\\\": \\\"yum_pid_file\\\", \\\"when\\\": \\\"step|int == 0 or step|int == 3\\\"}, {\\\"name\\\": \\\"Exit if existing yum process\\\", \\\"fail\\\": \\\"msg=\\\\\\\"ERROR existing yum.pid detected - can\'t continue! Please ensure there is no other package update process for the duration of the minor update worfklow. Exiting.\\\\\\\"\\\", \\\"when\\\": \\\"(step|int == 0 or step|int == 3) and yum_pid_file.stat.exists\\\"}, {\\\"name\\\": \\\"Special treatment for OpenvSwitch\\\", \\\"tripleo_ovs_upgrade\\\": null, \\\"when\\\": [\\\"step|int == 2\\\"], \\\"register\\\": \\\"ovs_upgrade\\\"}, {\\\"name\\\": \\\"Always ensure the openvswitch service is enabled and running after upgrades\\\", \\\"service\\\": {\\\"name\\\": \\\"openvswitch\\\", \\\"enabled\\\": true, \\\"state\\\": \\\"started\\\"}, \\\"when\\\": [\\\"step|int == 2\\\", \\\"ovs_upgrade.changed|bool\\\"]}, {\\\"name\\\": \\\"Update packages and EFI grub.cfg\\\", \\\"when\\\": [\\\"step|int == 3\\\", \\\"not skip_package_update|bool\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Update all packages\\\", \\\"yum\\\": {\\\"name\\\": \\\"*\\\", \\\"state\\\": \\\"latest\\\", \\\"exclude\\\": \\\"ansible-core\\\"}}, {\\\"name\\\": \\\"Replace EFI grub.cfg with redirect to /boot/grub2/grub.cfg\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_kernel\\\", \\\"tasks_from\\\": \\\"efigrub.yml\\\"}}], \\\"vars\\\": {\\\"skip_package_update\\\": {\\\"get_param\\\": \\\"SkipPackageUpdate\\\"}}}, {\\\"name\\\": \\\"Ensure openvswitch is running after update\\\", \\\"when\\\": \\\"step|int == 3\\\", \\\"service\\\": {\\\"name\\\": \\\"openvswitch\\\", \\\"enabled\\\": true, \\\"state\\\": \\\"started\\\"}, \\\"ignore_errors\\\": true}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Prepare container images\\\\n\\\", \\\"parameters\\\": {\\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"ContainerImagePrepare\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Used to run \\\\\\\"openstack tripleo container image prepare\\\\\\\". This is run after the registry is installed to populate the registry with images.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ContainerImagePrepareLogFile\\\": {\\\"default\\\": \\\"/var/log/tripleo-container-image-prepare.log\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Used to store outputs of \\\\\\\"openstack tripleo container image prepare\\\\\\\".\\\"}, \\\"DockerInsecureRegistryAddress\\\": {\\\"description\\\": \\\"Optional. The IP Address and Port of an insecure docker namespace that will be configured in /etc/sysconfig/docker. The value can be multiple addresses separated by commas.\\\", \\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": []}, \\\"NeutronMechanismDrivers\\\": {\\\"default\\\": \\\"ovn\\\", \\\"description\\\": \\\"The mechanism drivers for the Neutron tenant network.\\\\n\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"DockerRegistryMirror\\\": {\\\"description\\\": \\\"Optional. Mirror to use for registry docker.io\\\", \\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"Debug\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Set to True to enable debugging on all services.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"ContainerImagePrepareDebug\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether or not we want to activate --debug in tripleo container image prepare.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"ContainerImageRegistryCredentials\\\": {\\\"type\\\": \\\"json\\\", \\\"hidden\\\": true, \\\"default\\\": {}, \\\"description\\\": \\\"Mapping of image registry hosts to login credentials. Must be in the following example format\\\\n\\\\n  docker.io:\\\\n    username: pa55word\\\\n  \'192.0.2.1:8787\':\\\\n    registry_username: password\\\\n\\\"}, \\\"AdditionalArchitectures\\\": {\\\"default\\\": [], \\\"description\\\": \\\"List of additional architectures to enable.\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"ControllerContainerImagePrepare\\\": {\\\"description\\\": \\\"Used to run \\\\\\\"openstack tripleo container image prepare\\\\\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\\\", \\\"type\\\": \\\"json\\\", \\\"default\\\": {}}, \\\"ControllerServices\\\": {\\\"description\\\": \\\"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Controller role.\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"ControllerCount\\\": {\\\"description\\\": \\\"Number of Controller nodes to deploy\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 1}, \\\"CellControllerContainerImagePrepare\\\": {\\\"description\\\": \\\"Used to run \\\\\\\"openstack tripleo container image prepare\\\\\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\\\", \\\"type\\\": \\\"json\\\", \\\"default\\\": {}}, \\\"CellControllerServices\\\": {\\\"description\\\": \\\"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CellController role.\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"CellControllerCount\\\": {\\\"description\\\": \\\"Number of CellController nodes to deploy\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 1}, \\\"CellControllerComputeContainerImagePrepare\\\": {\\\"description\\\": \\\"Used to run \\\\\\\"openstack tripleo container image prepare\\\\\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\\\", \\\"type\\\": \\\"json\\\", \\\"default\\\": {}}, \\\"CellControllerComputeServices\\\": {\\\"description\\\": \\\"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CellControllerCompute role.\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"CellControllerComputeCount\\\": {\\\"description\\\": \\\"Number of CellControllerCompute nodes to deploy\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 1}, \\\"ComputeContainerImagePrepare\\\": {\\\"description\\\": \\\"Used to run \\\\\\\"openstack tripleo container image prepare\\\\\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\\\", \\\"type\\\": \\\"json\\\", \\\"default\\\": {}}, \\\"ComputeServices\\\": {\\\"description\\\": \\\"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Compute role.\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"ComputeCount\\\": {\\\"description\\\": \\\"Number of Compute nodes to deploy\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 1}, \\\"BlockStorageContainerImagePrepare\\\": {\\\"description\\\": \\\"Used to run \\\\\\\"openstack tripleo container image prepare\\\\\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\\\", \\\"type\\\": \\\"json\\\", \\\"default\\\": {}}, \\\"BlockStorageServices\\\": {\\\"description\\\": \\\"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the BlockStorage role.\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"BlockStorageCount\\\": {\\\"description\\\": \\\"Number of BlockStorage nodes to deploy\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 0}, \\\"ObjectStorageContainerImagePrepare\\\": {\\\"description\\\": \\\"Used to run \\\\\\\"openstack tripleo container image prepare\\\\\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\\\", \\\"type\\\": \\\"json\\\", \\\"default\\\": {}}, \\\"ObjectStorageServices\\\": {\\\"description\\\": \\\"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the ObjectStorage role.\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"ObjectStorageCount\\\": {\\\"description\\\": \\\"Number of ObjectStorage nodes to deploy\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 0}, \\\"CephStorageContainerImagePrepare\\\": {\\\"description\\\": \\\"Used to run \\\\\\\"openstack tripleo container image prepare\\\\\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\\\", \\\"type\\\": \\\"json\\\", \\\"default\\\": {}}, \\\"CephStorageServices\\\": {\\\"description\\\": \\\"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CephStorage role.\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"CephStorageCount\\\": {\\\"description\\\": \\\"Number of CephStorage nodes to deploy\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 0}, \\\"NetworkerContainerImagePrepare\\\": {\\\"description\\\": \\\"Used to run \\\\\\\"openstack tripleo container image prepare\\\\\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\\\", \\\"type\\\": \\\"json\\\", \\\"default\\\": {}}, \\\"NetworkerServices\\\": {\\\"description\\\": \\\"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Networker role.\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"NetworkerCount\\\": {\\\"description\\\": \\\"Number of Networker nodes to deploy\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 0}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for container image prepare\\\", \\\"value\\\": {\\\"service_name\\\": \\\"container_image_prepare\\\", \\\"external_deploy_tasks\\\": [{\\\"name\\\": \\\"Run tripleo-container-image-prepare role\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_image_prepare\\\"}, \\\"vars\\\": {\\\"tripleo_container_image_prepare_log_file\\\": {\\\"get_param\\\": \\\"ContainerImagePrepareLogFile\\\"}, \\\"tripleo_container_image_prepare_debug\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ContainerImagePrepareDebug\\\"}, true, {\\\"get_param\\\": \\\"Debug\\\"}]}, \\\"tripleo_container_image_prepare_roles\\\": [{\\\"name\\\": \\\"Controller\\\", \\\"description\\\": \\\"Controller role that has all the controler services loaded and handles\\\\\\\\nDatabase, Messaging and Network functions.\\\\\\\\n\\\", \\\"CountDefault\\\": 1, \\\"tags\\\": [\\\"primary\\\", \\\"controller\\\", \\\"external_bridge\\\"], \\\"networks\\\": {\\\"InternalApi\\\": {\\\"subnet\\\": \\\"internal_api_subnet\\\"}, \\\"Storage\\\": {\\\"subnet\\\": \\\"storage_subnet\\\"}, \\\"StorageMgmt\\\": {\\\"subnet\\\": \\\"storage_mgmt_subnet\\\"}, \\\"Tenant\\\": {\\\"subnet\\\": \\\"tenant_subnet\\\"}}, \\\"default_route_networks\\\": [\\\"ControlPlane\\\"], \\\"HostnameFormatDefault\\\": \\\"%stackname%-controller-%index%\\\", \\\"RoleParametersDefault\\\": {\\\"OVNCMSOptions\\\": \\\"enable-chassis-as-gw\\\"}, \\\"uses_deprecated_params\\\": true, \\\"deprecated_param_extraconfig\\\": \\\"controllerExtraConfig\\\", \\\"deprecated_param_flavor\\\": \\\"OvercloudControlFlavor\\\", \\\"deprecated_param_image\\\": \\\"controllerImage\\\", \\\"deprecated_nic_config_name\\\": \\\"controller.yaml\\\", \\\"update_serial\\\": 1, \\\"ServicesDefault\\\": [\\\"OS::TripleO::Services::Aide\\\", \\\"OS::TripleO::Services::AodhApi\\\", \\\"OS::TripleO::Services::AodhEvaluator\\\", \\\"OS::TripleO::Services::AodhListener\\\", \\\"OS::TripleO::Services::AodhNotifier\\\", \\\"OS::TripleO::Services::AuditD\\\", \\\"OS::TripleO::Services::BarbicanApi\\\", \\\"OS::TripleO::Services::BarbicanBackendSimpleCrypto\\\", \\\"OS::TripleO::Services::BarbicanBackendDogtag\\\", \\\"OS::TripleO::Services::BarbicanBackendKmip\\\", \\\"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\\\", \\\"OS::TripleO::Services::BootParams\\\", \\\"OS::TripleO::Services::CACerts\\\", \\\"OS::TripleO::Services::CeilometerAgentCentral\\\", \\\"OS::TripleO::Services::CeilometerAgentNotification\\\", \\\"OS::TripleO::Services::CephClient\\\", \\\"OS::TripleO::Services::CephExternal\\\", \\\"OS::TripleO::Services::CephGrafana\\\", \\\"OS::TripleO::Services::CephMds\\\", \\\"OS::TripleO::Services::CephMgr\\\", \\\"OS::TripleO::Services::CephMon\\\", \\\"OS::TripleO::Services::CephNfs\\\", \\\"OS::TripleO::Services::CephRbdMirror\\\", \\\"OS::TripleO::Services::CephRgw\\\", \\\"OS::TripleO::Services::CinderApi\\\", \\\"OS::TripleO::Services::CinderBackendDellSc\\\", \\\"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\\\", \\\"OS::TripleO::Services::CinderBackendDellEMCPowermax\\\", \\\"OS::TripleO::Services::CinderBackendDellEMCPowerStore\\\", \\\"OS::TripleO::Services::CinderBackendDellEMCSc\\\", \\\"OS::TripleO::Services::CinderBackendDellEMCUnity\\\", \\\"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\\\", \\\"OS::TripleO::Services::CinderBackendDellEMCVNX\\\", \\\"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\\\", \\\"OS::TripleO::Services::CinderBackendDellEMCXtremio\\\", \\\"OS::TripleO::Services::CinderBackendNetApp\\\", \\\"OS::TripleO::Services::CinderBackendPure\\\", \\\"OS::TripleO::Services::CinderBackendScaleIO\\\", \\\"OS::TripleO::Services::CinderBackendNVMeOF\\\", \\\"OS::TripleO::Services::CinderBackup\\\", \\\"OS::TripleO::Services::CinderHPELeftHandISCSI\\\", \\\"OS::TripleO::Services::CinderScheduler\\\", \\\"OS::TripleO::Services::CinderVolume\\\", \\\"OS::TripleO::Services::Clustercheck\\\", \\\"OS::TripleO::Services::Collectd\\\", \\\"OS::TripleO::Services::ContainerImagePrepare\\\", \\\"OS::TripleO::Services::DesignateApi\\\", \\\"OS::TripleO::Services::DesignateCentral\\\", \\\"OS::TripleO::Services::DesignateProducer\\\", \\\"OS::TripleO::Services::DesignateWorker\\\", \\\"OS::TripleO::Services::DesignateMDNS\\\", \\\"OS::TripleO::Services::DesignateSink\\\", \\\"OS::TripleO::Services::DesignateBind\\\", \\\"OS::TripleO::Services::Etcd\\\", \\\"OS::TripleO::Services::ExternalSwiftProxy\\\", \\\"OS::TripleO::Services::Frr\\\", \\\"OS::TripleO::Services::GlanceApi\\\", \\\"OS::TripleO::Services::GlanceApiInternal\\\", \\\"OS::TripleO::Services::GnocchiApi\\\", \\\"OS::TripleO::Services::GnocchiMetricd\\\", \\\"OS::TripleO::Services::GnocchiStatsd\\\", \\\"OS::TripleO::Services::HAproxy\\\", \\\"OS::TripleO::Services::HeatApi\\\", \\\"OS::TripleO::Services::HeatApiCloudwatch\\\", \\\"OS::TripleO::Services::HeatApiCfn\\\", \\\"OS::TripleO::Services::HeatEngine\\\", \\\"OS::TripleO::Services::Horizon\\\", \\\"OS::TripleO::Services::IpaClient\\\", \\\"OS::TripleO::Services::Ipsec\\\", \\\"OS::TripleO::Services::IronicApi\\\", \\\"OS::TripleO::Services::IronicConductor\\\", \\\"OS::TripleO::Services::IronicInspector\\\", \\\"OS::TripleO::Services::IronicPxe\\\", \\\"OS::TripleO::Services::IronicNeutronAgent\\\", \\\"OS::TripleO::Services::Iscsid\\\", \\\"OS::TripleO::Services::Kernel\\\", \\\"OS::TripleO::Services::Keystone\\\", \\\"OS::TripleO::Services::LoginDefs\\\", \\\"OS::TripleO::Services::ManilaApi\\\", \\\"OS::TripleO::Services::ManilaBackendCephFs\\\", \\\"OS::TripleO::Services::ManilaBackendFlashBlade\\\", \\\"OS::TripleO::Services::ManilaBackendIsilon\\\", \\\"OS::TripleO::Services::ManilaBackendNetapp\\\", \\\"OS::TripleO::Services::ManilaBackendPowerMax\\\", \\\"OS::TripleO::Services::ManilaBackendUnity\\\", \\\"OS::TripleO::Services::ManilaBackendVNX\\\", \\\"OS::TripleO::Services::ManilaBackendVMAX\\\", \\\"OS::TripleO::Services::ManilaScheduler\\\", \\\"OS::TripleO::Services::ManilaShare\\\", \\\"OS::TripleO::Services::Memcached\\\", \\\"OS::TripleO::Services::MetricsQdr\\\", \\\"OS::TripleO::Services::Multipathd\\\", \\\"OS::TripleO::Services::MySQL\\\", \\\"OS::TripleO::Services::MySQLClient\\\", \\\"OS::TripleO::Services::NeutronApi\\\", \\\"OS::TripleO::Services::NeutronBgpVpnApi\\\", \\\"OS::TripleO::Services::NeutronSfcApi\\\", \\\"OS::TripleO::Services::NeutronCorePlugin\\\", \\\"OS::TripleO::Services::NeutronDhcpAgent\\\", \\\"OS::TripleO::Services::NeutronL2gwAgent\\\", \\\"OS::TripleO::Services::NeutronL2gwApi\\\", \\\"OS::TripleO::Services::NeutronL3Agent\\\", \\\"OS::TripleO::Services::NeutronLinuxbridgeAgent\\\", \\\"OS::TripleO::Services::NeutronMetadataAgent\\\", \\\"OS::TripleO::Services::NeutronOvsAgent\\\", \\\"OS::TripleO::Services::NeutronVppAgent\\\", \\\"OS::TripleO::Services::NeutronAgentsIBConfig\\\", \\\"OS::TripleO::Services::NovaApi\\\", \\\"OS::TripleO::Services::NovaConductor\\\", \\\"OS::TripleO::Services::NovaIronic\\\", \\\"OS::TripleO::Services::NovaMetadata\\\", \\\"OS::TripleO::Services::NovaScheduler\\\", \\\"OS::TripleO::Services::NovaVncProxy\\\", \\\"OS::TripleO::Services::ContainersLogrotateCrond\\\", \\\"OS::TripleO::Services::OctaviaApi\\\", \\\"OS::TripleO::Services::OctaviaDeploymentConfig\\\", \\\"OS::TripleO::Services::OctaviaHealthManager\\\", \\\"OS::TripleO::Services::OctaviaHousekeeping\\\", \\\"OS::TripleO::Services::OctaviaWorker\\\", \\\"OS::TripleO::Services::OpenStackClients\\\", \\\"OS::TripleO::Services::OVNDBs\\\", \\\"OS::TripleO::Services::OVNController\\\", \\\"OS::TripleO::Services::Pacemaker\\\", \\\"OS::TripleO::Services::PlacementApi\\\", \\\"OS::TripleO::Services::OsloMessagingRpc\\\", \\\"OS::TripleO::Services::OsloMessagingNotify\\\", \\\"OS::TripleO::Services::Podman\\\", \\\"OS::TripleO::Services::Redis\\\", \\\"OS::TripleO::Services::Rhsm\\\", \\\"OS::TripleO::Services::Rsyslog\\\", \\\"OS::TripleO::Services::RsyslogSidecar\\\", \\\"OS::TripleO::Services::Securetty\\\", \\\"OS::TripleO::Services::Snmp\\\", \\\"OS::TripleO::Services::Sshd\\\", \\\"OS::TripleO::Services::SwiftProxy\\\", \\\"OS::TripleO::Services::SwiftDispersion\\\", \\\"OS::TripleO::Services::SwiftRingBuilder\\\", \\\"OS::TripleO::Services::SwiftStorage\\\", \\\"OS::TripleO::Services::Timesync\\\", \\\"OS::TripleO::Services::Timezone\\\", \\\"OS::TripleO::Services::TripleoFirewall\\\", \\\"OS::TripleO::Services::TripleoPackages\\\", \\\"OS::TripleO::Services::Tuned\\\", \\\"OS::TripleO::Services::Unbound\\\", \\\"OS::TripleO::Services::Vpp\\\"]}, {\\\"name\\\": \\\"CellController\\\", \\\"description\\\": \\\"Controller role that has the cell controler specific\\\\\\\\nservices and handles Database, Messaging and Network functions.\\\\\\\\n\\\", \\\"CountDefault\\\": 1, \\\"tags\\\": [\\\"primary\\\", \\\"controller\\\"], \\\"networks\\\": {\\\"InternalApi\\\": {\\\"subnet\\\": \\\"internal_api_subnet\\\"}, \\\"Storage\\\": {\\\"subnet\\\": \\\"storage_subnet\\\"}, \\\"StorageMgmt\\\": {\\\"subnet\\\": \\\"storage_mgmt_subnet\\\"}, \\\"Tenant\\\": {\\\"subnet\\\": \\\"tenant_subnet\\\"}}, \\\"default_route_networks\\\": [\\\"ControlPlane\\\"], \\\"HostnameFormatDefault\\\": \\\"%stackname%-controller-%index%\\\", \\\"RoleParametersDefault\\\": {\\\"OVNCMSOptions\\\": \\\"enable-chassis-as-gw\\\"}, \\\"uses_deprecated_params\\\": true, \\\"deprecated_param_extraconfig\\\": \\\"controllerExtraConfig\\\", \\\"deprecated_param_flavor\\\": \\\"OvercloudControlFlavor\\\", \\\"deprecated_param_image\\\": \\\"controllerImage\\\", \\\"deprecated_nic_config_name\\\": \\\"controller.yaml\\\", \\\"update_serial\\\": 1, \\\"ServicesDefault\\\": [\\\"OS::TripleO::Services::Aide\\\", \\\"OS::TripleO::Services::AuditD\\\", \\\"OS::TripleO::Services::BootParams\\\", \\\"OS::TripleO::Services::CACerts\\\", \\\"OS::TripleO::Services::Clustercheck\\\", \\\"OS::TripleO::Services::Collectd\\\", \\\"OS::TripleO::Services::ContainerImagePrepare\\\", \\\"OS::TripleO::Services::ContainersLogrotateCrond\\\", \\\"OS::TripleO::Services::Frr\\\", \\\"OS::TripleO::Services::HAproxy\\\", \\\"OS::TripleO::Services::IpaClient\\\", \\\"OS::TripleO::Services::Ipsec\\\", \\\"OS::TripleO::Services::Iscsid\\\", \\\"OS::TripleO::Services::Kernel\\\", \\\"OS::TripleO::Services::LoginDefs\\\", \\\"OS::TripleO::Services::MetricsQdr\\\", \\\"OS::TripleO::Services::MySQL\\\", \\\"OS::TripleO::Services::MySQLClient\\\", \\\"OS::TripleO::Services::NeutronMetadataAgent\\\", \\\"OS::TripleO::Services::NovaConductor\\\", \\\"OS::TripleO::Services::NovaMetadata\\\", \\\"OS::TripleO::Services::NovaVncProxy\\\", \\\"OS::TripleO::Services::OsloMessagingRpc\\\", \\\"OS::TripleO::Services::Pacemaker\\\", \\\"OS::TripleO::Services::Podman\\\", \\\"OS::TripleO::Services::Ptp\\\", \\\"OS::TripleO::Services::Rhsm\\\", \\\"OS::TripleO::Services::Rsyslog\\\", \\\"OS::TripleO::Services::RsyslogSidecar\\\", \\\"OS::TripleO::Services::Securetty\\\", \\\"OS::TripleO::Services::Snmp\\\", \\\"OS::TripleO::Services::Sshd\\\", \\\"OS::TripleO::Services::Timesync\\\", \\\"OS::TripleO::Services::Timezone\\\", \\\"OS::TripleO::Services::TripleoFirewall\\\", \\\"OS::TripleO::Services::TripleoPackages\\\", \\\"OS::TripleO::Services::Tuned\\\", \\\"OS::TripleO::Services::Vpp\\\"]}, {\\\"name\\\": \\\"CellControllerCompute\\\", \\\"description\\\": \\\"Controller and Compute AIO role that has compute and cell controler specific\\\\\\\\nservices loaded and handles Database, Messaging and Network functions.\\\\\\\\n\\\", \\\"CountDefault\\\": 1, \\\"tags\\\": [\\\"primary\\\", \\\"controller\\\", \\\"external_bridge\\\"], \\\"networks\\\": {\\\"InternalApi\\\": {\\\"subnet\\\": \\\"internal_api_subnet\\\"}, \\\"Storage\\\": {\\\"subnet\\\": \\\"storage_subnet\\\"}, \\\"StorageMgmt\\\": {\\\"subnet\\\": \\\"storage_mgmt_subnet\\\"}, \\\"Tenant\\\": {\\\"subnet\\\": \\\"tenant_subnet\\\"}}, \\\"default_route_networks\\\": [\\\"ControlPlane\\\"], \\\"HostnameFormatDefault\\\": \\\"%stackname%-controller-compute-%index%\\\", \\\"RoleParametersDefault\\\": {\\\"OVNCMSOptions\\\": \\\"enable-chassis-as-gw\\\"}, \\\"uses_deprecated_params\\\": true, \\\"deprecated_param_extraconfig\\\": \\\"controllerExtraConfig\\\", \\\"deprecated_param_flavor\\\": \\\"OvercloudControlFlavor\\\", \\\"deprecated_param_image\\\": \\\"controllerImage\\\", \\\"deprecated_nic_config_name\\\": \\\"controller.yaml\\\", \\\"update_serial\\\": 1, \\\"ServicesDefault\\\": [\\\"OS::TripleO::Services::Aide\\\", \\\"OS::TripleO::Services::AuditD\\\", \\\"OS::TripleO::Services::BootParams\\\", \\\"OS::TripleO::Services::CACerts\\\", \\\"OS::TripleO::Services::CephClient\\\", \\\"OS::TripleO::Services::CephExternal\\\", \\\"OS::TripleO::Services::Clustercheck\\\", \\\"OS::TripleO::Services::Collectd\\\", \\\"OS::TripleO::Services::ComputeCeilometerAgent\\\", \\\"OS::TripleO::Services::CeilometerAgentIpmi\\\", \\\"OS::TripleO::Services::ContainerImagePrepare\\\", \\\"OS::TripleO::Services::HAproxy\\\", \\\"OS::TripleO::Services::ComputeNeutronCorePlugin\\\", \\\"OS::TripleO::Services::ComputeNeutronL3Agent\\\", \\\"OS::TripleO::Services::ComputeNeutronMetadataAgent\\\", \\\"OS::TripleO::Services::ComputeNeutronOvsAgent\\\", \\\"OS::TripleO::Services::Frr\\\", \\\"OS::TripleO::Services::IpaClient\\\", \\\"OS::TripleO::Services::Ipsec\\\", \\\"OS::TripleO::Services::Iscsid\\\", \\\"OS::TripleO::Services::Kernel\\\", \\\"OS::TripleO::Services::LoginDefs\\\", \\\"OS::TripleO::Services::MetricsQdr\\\", \\\"OS::TripleO::Services::Multipathd\\\", \\\"OS::TripleO::Services::MySQL\\\", \\\"OS::TripleO::Services::MySQLClient\\\", \\\"OS::TripleO::Services::NeutronBgpVpnBagpipe\\\", \\\"OS::TripleO::Services::NeutronLinuxbridgeAgent\\\", \\\"OS::TripleO::Services::NeutronVppAgent\\\", \\\"OS::TripleO::Services::NovaAZConfig\\\", \\\"OS::TripleO::Services::NovaCompute\\\", \\\"OS::TripleO::Services::NovaLibvirt\\\", \\\"OS::TripleO::Services::NovaLibvirtGuests\\\", \\\"OS::TripleO::Services::NovaMigrationTarget\\\", \\\"OS::TripleO::Services::ContainersLogrotateCrond\\\", \\\"OS::TripleO::Services::NeutronMetadataAgent\\\", \\\"OS::TripleO::Services::NovaConductor\\\", \\\"OS::TripleO::Services::NovaMetadata\\\", \\\"OS::TripleO::Services::NovaVncProxy\\\", \\\"OS::TripleO::Services::OVNController\\\", \\\"OS::TripleO::Services::OVNMetadataAgent\\\", \\\"OS::TripleO::Services::Pacemaker\\\", \\\"OS::TripleO::Services::OsloMessagingRpc\\\", \\\"OS::TripleO::Services::Podman\\\", \\\"OS::TripleO::Services::Ptp\\\", \\\"OS::TripleO::Services::Rhsm\\\", \\\"OS::TripleO::Services::Rsyslog\\\", \\\"OS::TripleO::Services::RsyslogSidecar\\\", \\\"OS::TripleO::Services::Securetty\\\", \\\"OS::TripleO::Services::Snmp\\\", \\\"OS::TripleO::Services::Sshd\\\", \\\"OS::TripleO::Services::Timesync\\\", \\\"OS::TripleO::Services::Timezone\\\", \\\"OS::TripleO::Services::TripleoFirewall\\\", \\\"OS::TripleO::Services::TripleoPackages\\\", \\\"OS::TripleO::Services::Tuned\\\", \\\"OS::TripleO::Services::Vpp\\\"]}, {\\\"name\\\": \\\"Compute\\\", \\\"description\\\": \\\"Basic Compute Node role\\\\\\\\n\\\", \\\"CountDefault\\\": 1, \\\"tags\\\": [\\\"compute\\\", \\\"external_bridge\\\"], \\\"networks\\\": {\\\"InternalApi\\\": {\\\"subnet\\\": \\\"internal_api_subnet\\\"}, \\\"Tenant\\\": {\\\"subnet\\\": \\\"tenant_subnet\\\"}, \\\"Storage\\\": {\\\"subnet\\\": \\\"storage_subnet\\\"}}, \\\"default_route_networks\\\": [\\\"ControlPlane\\\"], \\\"HostnameFormatDefault\\\": \\\"%stackname%-novacompute-%index%\\\", \\\"RoleParametersDefault\\\": {\\\"FsAioMaxNumber\\\": 1048576, \\\"TunedProfileName\\\": \\\"throughput-performance\\\"}, \\\"uses_deprecated_params\\\": true, \\\"deprecated_param_image\\\": \\\"NovaImage\\\", \\\"deprecated_param_extraconfig\\\": \\\"NovaComputeExtraConfig\\\", \\\"deprecated_param_metadata\\\": \\\"NovaComputeServerMetadata\\\", \\\"deprecated_param_scheduler_hints\\\": \\\"NovaComputeSchedulerHints\\\", \\\"deprecated_param_ips\\\": \\\"NovaComputeIPs\\\", \\\"deprecated_server_resource_name\\\": \\\"NovaCompute\\\", \\\"deprecated_nic_config_name\\\": \\\"compute.yaml\\\", \\\"update_serial\\\": 25, \\\"ServicesDefault\\\": [\\\"OS::TripleO::Services::Aide\\\", \\\"OS::TripleO::Services::AuditD\\\", \\\"OS::TripleO::Services::BootParams\\\", \\\"OS::TripleO::Services::CACerts\\\", \\\"OS::TripleO::Services::CephClient\\\", \\\"OS::TripleO::Services::CephExternal\\\", \\\"OS::TripleO::Services::Collectd\\\", \\\"OS::TripleO::Services::ComputeCeilometerAgent\\\", \\\"OS::TripleO::Services::CeilometerAgentIpmi\\\", \\\"OS::TripleO::Services::ComputeNeutronCorePlugin\\\", \\\"OS::TripleO::Services::ComputeNeutronL3Agent\\\", \\\"OS::TripleO::Services::ComputeNeutronMetadataAgent\\\", \\\"OS::TripleO::Services::ComputeNeutronOvsAgent\\\", \\\"OS::TripleO::Services::Frr\\\", \\\"OS::TripleO::Services::IpaClient\\\", \\\"OS::TripleO::Services::Ipsec\\\", \\\"OS::TripleO::Services::Iscsid\\\", \\\"OS::TripleO::Services::Kernel\\\", \\\"OS::TripleO::Services::LoginDefs\\\", \\\"OS::TripleO::Services::MetricsQdr\\\", \\\"OS::TripleO::Services::Multipathd\\\", \\\"OS::TripleO::Services::MySQLClient\\\", \\\"OS::TripleO::Services::NeutronBgpVpnBagpipe\\\", \\\"OS::TripleO::Services::NeutronLinuxbridgeAgent\\\", \\\"OS::TripleO::Services::NeutronVppAgent\\\", \\\"OS::TripleO::Services::NovaAZConfig\\\", \\\"OS::TripleO::Services::NovaCompute\\\", \\\"OS::TripleO::Services::NovaLibvirt\\\", \\\"OS::TripleO::Services::NovaLibvirtGuests\\\", \\\"OS::TripleO::Services::NovaMigrationTarget\\\", \\\"OS::TripleO::Services::ContainersLogrotateCrond\\\", \\\"OS::TripleO::Services::Podman\\\", \\\"OS::TripleO::Services::Rhsm\\\", \\\"OS::TripleO::Services::Rsyslog\\\", \\\"OS::TripleO::Services::RsyslogSidecar\\\", \\\"OS::TripleO::Services::Securetty\\\", \\\"OS::TripleO::Services::Snmp\\\", \\\"OS::TripleO::Services::Sshd\\\", \\\"OS::TripleO::Services::Timesync\\\", \\\"OS::TripleO::Services::Timezone\\\", \\\"OS::TripleO::Services::TripleoFirewall\\\", \\\"OS::TripleO::Services::TripleoPackages\\\", \\\"OS::TripleO::Services::Tuned\\\", \\\"OS::TripleO::Services::Vpp\\\", \\\"OS::TripleO::Services::OVNController\\\", \\\"OS::TripleO::Services::OVNMetadataAgent\\\"]}, {\\\"name\\\": \\\"BlockStorage\\\", \\\"description\\\": \\\"Cinder Block Storage node role\\\\\\\\n\\\", \\\"tags\\\": [\\\"storage\\\"], \\\"networks\\\": {\\\"InternalApi\\\": {\\\"subnet\\\": \\\"internal_api_subnet\\\"}, \\\"Storage\\\": {\\\"subnet\\\": \\\"storage_subnet\\\"}, \\\"StorageMgmt\\\": {\\\"subnet\\\": \\\"storage_mgmt_subnet\\\"}}, \\\"uses_deprecated_params\\\": false, \\\"deprecated_nic_config_name\\\": \\\"cinder-storage.yaml\\\", \\\"update_serial\\\": 25, \\\"ServicesDefault\\\": [\\\"OS::TripleO::Services::Aide\\\", \\\"OS::TripleO::Services::AuditD\\\", \\\"OS::TripleO::Services::BlockStorageCinderVolume\\\", \\\"OS::TripleO::Services::BootParams\\\", \\\"OS::TripleO::Services::CACerts\\\", \\\"OS::TripleO::Services::Collectd\\\", \\\"OS::TripleO::Services::Frr\\\", \\\"OS::TripleO::Services::IpaClient\\\", \\\"OS::TripleO::Services::Ipsec\\\", \\\"OS::TripleO::Services::Iscsid\\\", \\\"OS::TripleO::Services::Kernel\\\", \\\"OS::TripleO::Services::LoginDefs\\\", \\\"OS::TripleO::Services::MetricsQdr\\\", \\\"OS::TripleO::Services::Multipathd\\\", \\\"OS::TripleO::Services::MySQLClient\\\", \\\"OS::TripleO::Services::ContainersLogrotateCrond\\\", \\\"OS::TripleO::Services::Podman\\\", \\\"OS::TripleO::Services::Rhsm\\\", \\\"OS::TripleO::Services::Rsyslog\\\", \\\"OS::TripleO::Services::RsyslogSidecar\\\", \\\"OS::TripleO::Services::Securetty\\\", \\\"OS::TripleO::Services::Snmp\\\", \\\"OS::TripleO::Services::Sshd\\\", \\\"OS::TripleO::Services::Timesync\\\", \\\"OS::TripleO::Services::Timezone\\\", \\\"OS::TripleO::Services::TripleoFirewall\\\", \\\"OS::TripleO::Services::TripleoPackages\\\", \\\"OS::TripleO::Services::Tuned\\\"]}, {\\\"name\\\": \\\"ObjectStorage\\\", \\\"description\\\": \\\"Swift Object Storage node role\\\\\\\\n\\\", \\\"tags\\\": [\\\"storage\\\"], \\\"networks\\\": {\\\"InternalApi\\\": {\\\"subnet\\\": \\\"internal_api_subnet\\\"}, \\\"Storage\\\": {\\\"subnet\\\": \\\"storage_subnet\\\"}, \\\"StorageMgmt\\\": {\\\"subnet\\\": \\\"storage_mgmt_subnet\\\"}}, \\\"uses_deprecated_params\\\": true, \\\"deprecated_param_metadata\\\": \\\"SwiftStorageServerMetadata\\\", \\\"deprecated_param_ips\\\": \\\"SwiftStorageIPs\\\", \\\"deprecated_param_image\\\": \\\"SwiftStorageImage\\\", \\\"deprecated_param_flavor\\\": \\\"OvercloudSwiftStorageFlavor\\\", \\\"deprecated_nic_config_name\\\": \\\"swift-storage.yaml\\\", \\\"deprecated_server_resource_name\\\": \\\"SwiftStorage\\\", \\\"update_serial\\\": 1, \\\"ServicesDefault\\\": [\\\"OS::TripleO::Services::Aide\\\", \\\"OS::TripleO::Services::AuditD\\\", \\\"OS::TripleO::Services::BootParams\\\", \\\"OS::TripleO::Services::CACerts\\\", \\\"OS::TripleO::Services::Collectd\\\", \\\"OS::TripleO::Services::Frr\\\", \\\"OS::TripleO::Services::IpaClient\\\", \\\"OS::TripleO::Services::Ipsec\\\", \\\"OS::TripleO::Services::Kernel\\\", \\\"OS::TripleO::Services::LoginDefs\\\", \\\"OS::TripleO::Services::MetricsQdr\\\", \\\"OS::TripleO::Services::MySQLClient\\\", \\\"OS::TripleO::Services::ContainersLogrotateCrond\\\", \\\"OS::TripleO::Services::Podman\\\", \\\"OS::TripleO::Services::Rhsm\\\", \\\"OS::TripleO::Services::Rsyslog\\\", \\\"OS::TripleO::Services::RsyslogSidecar\\\", \\\"OS::TripleO::Services::Securetty\\\", \\\"OS::TripleO::Services::Snmp\\\", \\\"OS::TripleO::Services::Sshd\\\", \\\"OS::TripleO::Services::SwiftRingBuilder\\\", \\\"OS::TripleO::Services::SwiftStorage\\\", \\\"OS::TripleO::Services::Timesync\\\", \\\"OS::TripleO::Services::Timezone\\\", \\\"OS::TripleO::Services::TripleoFirewall\\\", \\\"OS::TripleO::Services::TripleoPackages\\\", \\\"OS::TripleO::Services::Tuned\\\", \\\"OS::TripleO::Services::Ptp\\\"]}, {\\\"name\\\": \\\"CephStorage\\\", \\\"description\\\": \\\"Ceph OSD Storage node role\\\\\\\\n\\\", \\\"tags\\\": [\\\"ceph\\\", \\\"storage\\\"], \\\"networks\\\": {\\\"Storage\\\": {\\\"subnet\\\": \\\"storage_subnet\\\"}, \\\"StorageMgmt\\\": {\\\"subnet\\\": \\\"storage_mgmt_subnet\\\"}}, \\\"uses_deprecated_params\\\": false, \\\"HostnameFormatDefault\\\": \\\"%stackname%-cephstorage-%index%\\\", \\\"deprecated_nic_config_name\\\": \\\"ceph-storage.yaml\\\", \\\"update_serial\\\": 1, \\\"rhsm_enforce\\\": false, \\\"ServicesDefault\\\": [\\\"OS::TripleO::Services::Aide\\\", \\\"OS::TripleO::Services::AuditD\\\", \\\"OS::TripleO::Services::BootParams\\\", \\\"OS::TripleO::Services::CACerts\\\", \\\"OS::TripleO::Services::CephOSD\\\", \\\"OS::TripleO::Services::Collectd\\\", \\\"OS::TripleO::Services::Frr\\\", \\\"OS::TripleO::Services::IpaClient\\\", \\\"OS::TripleO::Services::Ipsec\\\", \\\"OS::TripleO::Services::Kernel\\\", \\\"OS::TripleO::Services::LoginDefs\\\", \\\"OS::TripleO::Services::MetricsQdr\\\", \\\"OS::TripleO::Services::MySQLClient\\\", \\\"OS::TripleO::Services::ContainersLogrotateCrond\\\", \\\"OS::TripleO::Services::Podman\\\", \\\"OS::TripleO::Services::Rhsm\\\", \\\"OS::TripleO::Services::Rsyslog\\\", \\\"OS::TripleO::Services::RsyslogSidecar\\\", \\\"OS::TripleO::Services::Securetty\\\", \\\"OS::TripleO::Services::Snmp\\\", \\\"OS::TripleO::Services::Sshd\\\", \\\"OS::TripleO::Services::Timesync\\\", \\\"OS::TripleO::Services::Timezone\\\", \\\"OS::TripleO::Services::TripleoFirewall\\\", \\\"OS::TripleO::Services::TripleoPackages\\\", \\\"OS::TripleO::Services::Tuned\\\"]}, {\\\"name\\\": \\\"Networker\\\", \\\"description\\\": \\\"Standalone networking role to run Neutron agents on their own.\\\\\\\\n\\\", \\\"networks\\\": {\\\"InternalApi\\\": {\\\"subnet\\\": \\\"internal_api_subnet\\\"}, \\\"Tenant\\\": {\\\"subnet\\\": \\\"tenant_subnet\\\"}}, \\\"tags\\\": [\\\"external_bridge\\\"], \\\"HostnameFormatDefault\\\": \\\"%stackname%-networker-%index%\\\", \\\"RoleParametersDefault\\\": {\\\"OVNCMSOptions\\\": \\\"enable-chassis-as-gw\\\"}, \\\"update_serial\\\": 1, \\\"ServicesDefault\\\": [\\\"OS::TripleO::Services::Aide\\\", \\\"OS::TripleO::Services::AuditD\\\", \\\"OS::TripleO::Services::BootParams\\\", \\\"OS::TripleO::Services::CACerts\\\", \\\"OS::TripleO::Services::Collectd\\\", \\\"OS::TripleO::Services::Frr\\\", \\\"OS::TripleO::Services::IpaClient\\\", \\\"OS::TripleO::Services::Ipsec\\\", \\\"OS::TripleO::Services::IronicNeutronAgent\\\", \\\"OS::TripleO::Services::Kernel\\\", \\\"OS::TripleO::Services::LoginDefs\\\", \\\"OS::TripleO::Services::MetricsQdr\\\", \\\"OS::TripleO::Services::MySQLClient\\\", \\\"OS::TripleO::Services::NeutronDhcpAgent\\\", \\\"OS::TripleO::Services::NeutronL2gwAgent\\\", \\\"OS::TripleO::Services::NeutronL3Agent\\\", \\\"OS::TripleO::Services::NeutronMetadataAgent\\\", \\\"OS::TripleO::Services::NeutronOvsAgent\\\", \\\"OS::TripleO::Services::NeutronVppAgent\\\", \\\"OS::TripleO::Services::ContainersLogrotateCrond\\\", \\\"OS::TripleO::Services::OctaviaDeploymentConfig\\\", \\\"OS::TripleO::Services::OctaviaHealthManager\\\", \\\"OS::TripleO::Services::OctaviaHousekeeping\\\", \\\"OS::TripleO::Services::OctaviaWorker\\\", \\\"OS::TripleO::Services::OVNController\\\", \\\"OS::TripleO::Services::OVNMetadataAgent\\\", \\\"OS::TripleO::Services::Podman\\\", \\\"OS::TripleO::Services::Rhsm\\\", \\\"OS::TripleO::Services::Rsyslog\\\", \\\"OS::TripleO::Services::Snmp\\\", \\\"OS::TripleO::Services::Sshd\\\", \\\"OS::TripleO::Services::Timesync\\\", \\\"OS::TripleO::Services::Timezone\\\", \\\"OS::TripleO::Services::TripleoFirewall\\\", \\\"OS::TripleO::Services::TripleoPackages\\\", \\\"OS::TripleO::Services::Tuned\\\"]}], \\\"tripleo_container_image_prepare_content\\\": {\\\"parameter_defaults\\\": {\\\"ContainerImagePrepare\\\": {\\\"get_param\\\": \\\"ContainerImagePrepare\\\"}, \\\"DockerInsecureRegistryAddress\\\": {\\\"get_param\\\": \\\"DockerInsecureRegistryAddress\\\"}, \\\"NeutronMechanismDrivers\\\": {\\\"get_param\\\": \\\"NeutronMechanismDrivers\\\"}, \\\"DockerRegistryMirror\\\": {\\\"get_param\\\": \\\"DockerRegistryMirror\\\"}, \\\"ContainerImageRegistryCredentials\\\": {\\\"get_param\\\": \\\"ContainerImageRegistryCredentials\\\"}, \\\"AdditionalArchitectures\\\": {\\\"get_param\\\": \\\"AdditionalArchitectures\\\"}, \\\"ControllerContainerImagePrepare\\\": {\\\"get_param\\\": \\\"ControllerContainerImagePrepare\\\"}, \\\"ControllerServices\\\": {\\\"get_param\\\": \\\"ControllerServices\\\"}, \\\"ControllerCount\\\": {\\\"get_param\\\": \\\"ControllerCount\\\"}, \\\"CellControllerContainerImagePrepare\\\": {\\\"get_param\\\": \\\"CellControllerContainerImagePrepare\\\"}, \\\"CellControllerServices\\\": {\\\"get_param\\\": \\\"CellControllerServices\\\"}, \\\"CellControllerCount\\\": {\\\"get_param\\\": \\\"CellControllerCount\\\"}, \\\"CellControllerComputeContainerImagePrepare\\\": {\\\"get_param\\\": \\\"CellControllerComputeContainerImagePrepare\\\"}, \\\"CellControllerComputeServices\\\": {\\\"get_param\\\": \\\"CellControllerComputeServices\\\"}, \\\"CellControllerComputeCount\\\": {\\\"get_param\\\": \\\"CellControllerComputeCount\\\"}, \\\"ComputeContainerImagePrepare\\\": {\\\"get_param\\\": \\\"ComputeContainerImagePrepare\\\"}, \\\"ComputeServices\\\": {\\\"get_param\\\": \\\"ComputeServices\\\"}, \\\"ComputeCount\\\": {\\\"get_param\\\": \\\"ComputeCount\\\"}, \\\"BlockStorageContainerImagePrepare\\\": {\\\"get_param\\\": \\\"BlockStorageContainerImagePrepare\\\"}, \\\"BlockStorageServices\\\": {\\\"get_param\\\": \\\"BlockStorageServices\\\"}, \\\"BlockStorageCount\\\": {\\\"get_param\\\": \\\"BlockStorageCount\\\"}, \\\"ObjectStorageContainerImagePrepare\\\": {\\\"get_param\\\": \\\"ObjectStorageContainerImagePrepare\\\"}, \\\"ObjectStorageServices\\\": {\\\"get_param\\\": \\\"ObjectStorageServices\\\"}, \\\"ObjectStorageCount\\\": {\\\"get_param\\\": \\\"ObjectStorageCount\\\"}, \\\"CephStorageContainerImagePrepare\\\": {\\\"get_param\\\": \\\"CephStorageContainerImagePrepare\\\"}, \\\"CephStorageServices\\\": {\\\"get_param\\\": \\\"CephStorageServices\\\"}, \\\"CephStorageCount\\\": {\\\"get_param\\\": \\\"CephStorageCount\\\"}, \\\"NetworkerContainerImagePrepare\\\": {\\\"get_param\\\": \\\"NetworkerContainerImagePrepare\\\"}, \\\"NetworkerServices\\\": {\\\"get_param\\\": \\\"NetworkerServices\\\"}, \\\"NetworkerCount\\\": {\\\"get_param\\\": \\\"NetworkerCount\\\"}}}}, \\\"when\\\": [\\\"(step | int) == 1\\\"]}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"MySQL HA clustercheck service deployment using puppet This service is used by HAProxy in a HA scenario to report whether the local galera node is synced\\\\n\\\", \\\"parameters\\\": {\\\"ContainerClustercheckImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerClustercheckConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the clustercheck config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"ClustercheckListener\\\": {\\\"default\\\": \\\"socat\\\", \\\"description\\\": \\\"How to expose the clustercheck service over TCP\\\", \\\"type\\\": \\\"string\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"socat\\\", \\\"xinetd\\\"]}]}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"MysqlPuppetBase\\\": {\\\"type\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\\\", \\\"properties\\\": {\\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerClustercheckImage\\\": \\\"ContainerClustercheckImage\\\", \\\"ContainerClustercheckConfigImage\\\": \\\"ContainerClustercheckConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerClustercheckImage\\\": {\\\"get_param\\\": \\\"ContainerClustercheckImage\\\"}, \\\"ContainerClustercheckConfigImage\\\": {\\\"get_param\\\": \\\"ContainerClustercheckConfigImage\\\"}}}]}}}}, \\\"conditions\\\": {\\\"socat_listener\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"ClustercheckListener\\\"}, \\\"socat\\\"]}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Containerized service clustercheck using composable services.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"clustercheck\\\", \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"MysqlPuppetBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"tripleo::profile::pacemaker::clustercheck::bind_address\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$FQDN$NETWORK\')}\\\", \\\"params\\\": {\\\"$FQDN\\\": {\\\"if\\\": [\\\"socat_listener\\\", \\\"\\\", \\\"fqdn_\\\"]}, \\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MysqlNetwork\\\"]}}}}}]}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"clustercheck\\\", \\\"puppet_tags\\\": \\\"file\\\", \\\"step_config\\\": \\\"include tripleo::profile::pacemaker::clustercheck\\\", \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerClustercheckConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/clustercheck.json\\\": {\\\"command\\\": {\\\"if\\\": [\\\"socat_listener\\\", \\\"bash -c $* -- eval source /etc/sysconfig/clustercheck; exec socat -T\\\\\\\"${TRIPLEO_HEALTHCHECK_TIMEOUT:-2}\\\\\\\" \\\\\\\"$TRIPLEO_SOCAT_BIND\\\\\\\" system:\\\\\\\"grep -qPe \\\\\\\\\\\\\\\"^\\\\\\\\\\\\\\\\r\\\\\\\\$\\\\\\\\\\\\\\\" && /usr/bin/clustercheck\\\\\\\"\\\", \\\"/usr/sbin/xinetd -dontfork\\\"]}, \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}}, \\\"docker_config\\\": {\\\"step_2\\\": {\\\"clustercheck\\\": {\\\"start_order\\\": 1, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerClustercheckImage\\\"]}, \\\"restart\\\": \\\"always\\\", \\\"net\\\": \\\"host\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/clustercheck.json:/var/lib/kolla/config_files/config.json\\\", \\\"/var/lib/config-data/puppet-generated/clustercheck:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/mysql:/var/lib/mysql\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"host_prep_tasks\\\": null, \\\"upgrade_tasks\\\": null, \\\"update_tasks\\\": null, \\\"external_upgrade_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade_transfer_data\\\", \\\"system_upgrade_stop_services\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Stop clustercheck container\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_stop\\\"}, \\\"vars\\\": {\\\"tripleo_containers_to_stop\\\": [\\\"clustercheck\\\"], \\\"tripleo_delegate_to\\\": \\\"{{ groups[\'clustercheck\'] | difference(groups[\'excluded_overcloud\']) }}\\\"}}]}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Install tmpwatch\\\\n\\\", \\\"parameters\\\": {\\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for tmpwatch install\\\", \\\"value\\\": {\\\"service_name\\\": \\\"logrotate_tmpwatch\\\", \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"install tmpwatch on the host\\\", \\\"package\\\": {\\\"name\\\": \\\"tmpwatch\\\", \\\"state\\\": \\\"installed\\\"}}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Barbican API service\\\\n\\\", \\\"parameters\\\": {\\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"ContainerBarbicanApiImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}}, \\\"resources\\\": {\\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerBarbicanApiImage\\\": \\\"ContainerBarbicanApiImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerBarbicanApiImage\\\": {\\\"get_param\\\": \\\"ContainerBarbicanApiImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"cmd_extra_args\\\": {\\\"description\\\": \\\"Extra command line arguments for running the service in the container.\\\", \\\"value\\\": \\\"\\\"}, \\\"config_settings\\\": {\\\"description\\\": \\\"Extra hieradata needed to log to files in the host.\\\", \\\"value\\\": null}, \\\"volumes\\\": {\\\"description\\\": \\\"The volumes needed to log to files in the host.\\\", \\\"value\\\": [\\\"/var/log/containers/barbican:/var/log/barbican:z\\\", \\\"/var/log/containers/httpd/barbican-api:/var/log/httpd:z\\\"]}, \\\"docker_config\\\": {\\\"description\\\": \\\"Extra containers needed for logging to files in the host.\\\", \\\"value\\\": {\\\"step_2\\\": {\\\"barbican_init_log\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerBarbicanApiImage\\\"]}, \\\"net\\\": \\\"none\\\", \\\"user\\\": \\\"root\\\", \\\"volumes\\\": [\\\"/var/log/containers/barbican:/var/log/barbican:z\\\", \\\"/var/log/containers/httpd/barbican-api:/var/log/httpd:z\\\"], \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R barbican:barbican /var/log/barbican\\\"]}}}}, \\\"host_prep_tasks\\\": {\\\"description\\\": \\\"Extra ansible tasks needed for logging to files in the host.\\\", \\\"value\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/barbican\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/log/containers/httpd/barbican-api\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}]}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Glance API service\\\\n\\\", \\\"parameters\\\": {\\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"ContainerGlanceApiImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}}, \\\"resources\\\": {\\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerGlanceApiImage\\\": \\\"ContainerGlanceApiImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerGlanceApiImage\\\": {\\\"get_param\\\": \\\"ContainerGlanceApiImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"config_settings\\\": {\\\"description\\\": \\\"Extra hieradata needed to log to files in the host.\\\", \\\"value\\\": null}, \\\"volumes\\\": {\\\"description\\\": \\\"The volumes needed to log to files in the host.\\\", \\\"value\\\": [\\\"/var/log/containers/glance:/var/log/glance:z\\\", \\\"/var/log/containers/httpd/glance:/var/log/httpd:z\\\"]}, \\\"docker_config\\\": {\\\"description\\\": \\\"Extra containers needed for logging to files in the host.\\\", \\\"value\\\": {\\\"step_2\\\": {\\\"glance_init_logs\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerGlanceApiImage\\\"]}, \\\"net\\\": \\\"none\\\", \\\"privileged\\\": false, \\\"user\\\": \\\"root\\\", \\\"volumes\\\": [\\\"/var/log/containers/glance:/var/log/glance:z\\\", \\\"/var/log/containers/httpd/glance:/var/log/httpd:z\\\"], \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R glance:glance /var/log/glance\\\"]}}}}, \\\"host_prep_tasks\\\": {\\\"description\\\": \\\"Extra ansible tasks needed for logging to files in the host.\\\", \\\"value\\\": [{\\\"name\\\": \\\"create persistent logs directory\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/glance\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/log/containers/httpd/glance\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}]}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized HAProxy API service\\\\n\\\", \\\"outputs\\\": {\\\"config_settings\\\": {\\\"description\\\": \\\"Extra hieradata needed to log to files in the host.\\\", \\\"value\\\": null}, \\\"volumes\\\": {\\\"description\\\": \\\"The volumes needed to log to files in the host.\\\", \\\"value\\\": null}, \\\"docker_config\\\": {\\\"description\\\": \\\"Extra containers needed for logging to files in the host.\\\", \\\"value\\\": {\\\"step_1\\\": {}}}, \\\"host_prep_tasks\\\": {\\\"description\\\": \\\"Extra ansible tasks needed for logging to files in the host.\\\", \\\"value\\\": null}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Heat API service\\\\n\\\", \\\"outputs\\\": {\\\"config_settings\\\": {\\\"description\\\": \\\"Extra hieradata needed to log to files in the host.\\\", \\\"value\\\": null}, \\\"docker_config\\\": {\\\"description\\\": \\\"Extra containers needed for logging to files in the host.\\\", \\\"value\\\": {\\\"step_2\\\": {}}}, \\\"volumes\\\": {\\\"description\\\": \\\"The volumes needed to log to files in the host.\\\", \\\"value\\\": [\\\"/var/log/containers/heat:/var/log/heat:z\\\", \\\"/var/log/containers/httpd/heat-api:/var/log/httpd:z\\\"]}, \\\"host_prep_tasks\\\": {\\\"description\\\": \\\"Extra ansible tasks needed for logging to files in the host.\\\", \\\"value\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/heat\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/log/containers/httpd/heat-api\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}]}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Heat API CFN service\\\\n\\\", \\\"outputs\\\": {\\\"config_settings\\\": {\\\"description\\\": \\\"Extra hieradata needed to log to files in the host.\\\", \\\"value\\\": null}, \\\"docker_config\\\": {\\\"description\\\": \\\"Extra containers needed for logging to files in the host.\\\", \\\"value\\\": {\\\"step_2\\\": {}}}, \\\"volumes\\\": {\\\"description\\\": \\\"The volumes needed to log to files in the host.\\\", \\\"value\\\": [\\\"/var/log/containers/heat:/var/log/heat:z\\\", \\\"/var/log/containers/httpd/heat-api-cfn:/var/log/httpd:z\\\"]}, \\\"host_prep_tasks\\\": {\\\"description\\\": \\\"Extra ansible tasks needed for logging to files in the host.\\\", \\\"value\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/heat\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/log/containers/httpd/heat-api-cfn\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}]}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Glance API service\\\\n\\\", \\\"parameters\\\": {\\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"ContainerHeatEngineImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}}, \\\"resources\\\": {\\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerHeatEngineImage\\\": \\\"ContainerHeatEngineImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerHeatEngineImage\\\": {\\\"get_param\\\": \\\"ContainerHeatEngineImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"cmd_extra_args\\\": {\\\"description\\\": \\\"Extra command line arguments for running the service in the container.\\\", \\\"value\\\": \\\"\\\"}, \\\"config_settings\\\": {\\\"description\\\": \\\"Extra hieradata needed to log to files in the host.\\\", \\\"value\\\": null}, \\\"docker_config\\\": {\\\"description\\\": \\\"Extra containers needed for logging to files in the host.\\\", \\\"value\\\": {\\\"step_2\\\": {\\\"heat_init_log\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHeatEngineImage\\\"]}, \\\"net\\\": \\\"none\\\", \\\"user\\\": \\\"root\\\", \\\"volumes\\\": [\\\"/var/log/containers/heat:/var/log/heat:z\\\"], \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R heat:heat /var/log/heat\\\"]}}}}, \\\"volumes\\\": {\\\"description\\\": \\\"The volumes needed to log to files in the host.\\\", \\\"value\\\": [\\\"/var/log/containers/heat:/var/log/heat:z\\\"]}, \\\"host_prep_tasks\\\": {\\\"description\\\": \\\"Extra ansible tasks needed for logging to files in the host.\\\", \\\"value\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/heat\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}]}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Keystone service\\\\n\\\", \\\"parameters\\\": {\\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"ContainerKeystoneImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}}, \\\"resources\\\": {\\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerKeystoneImage\\\": \\\"ContainerKeystoneImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerKeystoneImage\\\": {\\\"get_param\\\": \\\"ContainerKeystoneImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"config_settings\\\": {\\\"description\\\": \\\"Extra hieradata needed to log to files in the host.\\\", \\\"value\\\": null}, \\\"volumes\\\": {\\\"description\\\": \\\"The volumes needed to log to files in the host.\\\", \\\"value\\\": [\\\"/var/log/containers/keystone:/var/log/keystone:z\\\", \\\"/var/log/containers/httpd/keystone:/var/log/httpd:z\\\"]}, \\\"docker_config\\\": {\\\"description\\\": \\\"Extra containers needed for logging to files in the host.\\\", \\\"value\\\": {\\\"step_2\\\": {\\\"keystone_init_log\\\": {\\\"start_order\\\": 1, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerKeystoneImage\\\"]}, \\\"net\\\": \\\"none\\\", \\\"user\\\": \\\"root\\\", \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R keystone:keystone /var/log/keystone\\\"], \\\"volumes\\\": [\\\"/var/log/containers/keystone:/var/log/keystone:z\\\", \\\"/var/log/containers/httpd/keystone:/var/log/httpd:z\\\"]}}}}, \\\"environment\\\": {\\\"description\\\": \\\"Extra environment variables needed for the service to log to files.\\\", \\\"value\\\": null}, \\\"host_prep_tasks\\\": {\\\"description\\\": \\\"Extra ansible tasks needed for logging to files in the host.\\\", \\\"value\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/keystone\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/log/containers/httpd/keystone\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}]}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Neutron API service\\\\n\\\", \\\"parameters\\\": {\\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"ContainerNeutronApiImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NeutronServiceName\\\": {\\\"description\\\": \\\"service name\\\", \\\"type\\\": \\\"string\\\"}}, \\\"resources\\\": {\\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerNeutronApiImage\\\": \\\"ContainerNeutronApiImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerNeutronApiImage\\\": {\\\"get_param\\\": \\\"ContainerNeutronApiImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"cmd_extra_args\\\": {\\\"description\\\": \\\"Extra command line arguments for running the service in the container.\\\", \\\"value\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"--log-file=/var/log/neutron/SERVICE.log\\\", \\\"params\\\": {\\\"SERVICE\\\": {\\\"get_param\\\": \\\"NeutronServiceName\\\"}}}}}, \\\"config_settings\\\": {\\\"description\\\": \\\"Extra hieradata needed to log to files in the host.\\\", \\\"value\\\": null}, \\\"volumes\\\": {\\\"description\\\": \\\"extra volumes\\\", \\\"value\\\": [\\\"/var/log/containers/neutron:/var/log/neutron:z\\\", \\\"/var/log/containers/httpd/neutron-api:/var/log/httpd:z\\\"]}, \\\"docker_config\\\": {\\\"description\\\": \\\"Extra containers needed for logging to files in the host.\\\", \\\"value\\\": {\\\"step_2\\\": {\\\"neutron_init_logs\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNeutronApiImage\\\"]}, \\\"net\\\": \\\"none\\\", \\\"privileged\\\": false, \\\"user\\\": \\\"root\\\", \\\"volumes\\\": [\\\"/var/log/containers/neutron:/var/log/neutron:z\\\", \\\"/var/log/containers/httpd/neutron-api:/var/log/httpd:z\\\"], \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R neutron:neutron /var/log/neutron\\\"]}}}}, \\\"host_prep_tasks\\\": {\\\"description\\\": \\\"Extra ansible tasks needed for logging to files in the host.\\\", \\\"value\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/neutron\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/log/containers/httpd/neutron-api\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}]}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Neutron service\\\\n\\\", \\\"parameters\\\": {\\\"NeutronServiceName\\\": {\\\"description\\\": \\\"service name\\\", \\\"type\\\": \\\"string\\\"}}, \\\"outputs\\\": {\\\"cmd_extra_args\\\": {\\\"description\\\": \\\"Extra command line arguments for running the service in the container.\\\", \\\"value\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"--log-file=/var/log/neutron/SERVICE.log\\\", \\\"params\\\": {\\\"SERVICE\\\": {\\\"get_param\\\": \\\"NeutronServiceName\\\"}}}}}, \\\"config_settings\\\": {\\\"description\\\": \\\"Extra hieradata needed to log to files in the host.\\\", \\\"value\\\": null}, \\\"docker_config\\\": {\\\"description\\\": \\\"Extra containers needed for logging to files in the host.\\\", \\\"value\\\": {\\\"step_2\\\": {}}}, \\\"volumes\\\": {\\\"description\\\": \\\"The volumes needed to log to files in the host.\\\", \\\"value\\\": [\\\"/var/log/containers/neutron:/var/log/neutron:z\\\"]}, \\\"host_prep_tasks\\\": {\\\"description\\\": \\\"Extra ansible tasks needed for logging to files in the host.\\\", \\\"value\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/neutron\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}]}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Template for nova-api\'s logging to files\\\\n\\\", \\\"parameters\\\": {\\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"ContainerNovaApiImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"DeployIdentifier\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\\\n\\\"}}, \\\"resources\\\": {\\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerNovaApiImage\\\": \\\"ContainerNovaApiImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerNovaApiImage\\\": {\\\"get_param\\\": \\\"ContainerNovaApiImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"config_settings\\\": {\\\"description\\\": \\\"Extra hieradata needed to log to files in the host.\\\", \\\"value\\\": null}, \\\"volumes\\\": {\\\"description\\\": \\\"The volumes needed to log to files in the host.\\\", \\\"value\\\": [\\\"/var/log/containers/nova:/var/log/nova:z\\\", \\\"/var/log/containers/httpd/nova-api:/var/log/httpd:z\\\"]}, \\\"docker_config\\\": {\\\"description\\\": \\\"Extra containers needed for logging to files in the host.\\\", \\\"value\\\": {\\\"step_2\\\": {\\\"nova_api_init_logs\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaApiImage\\\"]}, \\\"net\\\": \\\"none\\\", \\\"privileged\\\": false, \\\"user\\\": \\\"root\\\", \\\"volumes\\\": [\\\"/var/log/containers/nova:/var/log/nova:z\\\", \\\"/var/log/containers/httpd/nova-api:/var/log/httpd:z\\\"], \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R nova:nova /var/log/nova\\\"], \\\"environment\\\": {\\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}}}}}}, \\\"host_prep_tasks\\\": {\\\"description\\\": \\\"Extra ansible tasks needed for logging to files in the host.\\\", \\\"value\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"state\\\": \\\"directory\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/nova\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/log/containers/httpd/nova-api\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}]}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Template for nova-metadata\'s logging to files\\\\n\\\", \\\"parameters\\\": {\\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"ContainerNovaMetadataImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}}, \\\"resources\\\": {\\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerNovaMetadataImage\\\": \\\"ContainerNovaMetadataImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerNovaMetadataImage\\\": {\\\"get_param\\\": \\\"ContainerNovaMetadataImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"config_settings\\\": {\\\"description\\\": \\\"Extra hieradata needed to log to files in the host.\\\", \\\"value\\\": null}, \\\"volumes\\\": {\\\"description\\\": \\\"The volumes needed to log to files in the host.\\\", \\\"value\\\": [\\\"/var/log/containers/nova:/var/log/nova:z\\\", \\\"/var/log/containers/httpd/nova-metadata:/var/log/httpd:z\\\"]}, \\\"docker_config\\\": {\\\"description\\\": \\\"Extra containers needed for logging to files in the host.\\\", \\\"value\\\": {\\\"step_2\\\": {\\\"nova_metadata_init_logs\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerNovaMetadataImage\\\"]}, \\\"net\\\": \\\"none\\\", \\\"privileged\\\": false, \\\"user\\\": \\\"root\\\", \\\"volumes\\\": [\\\"/var/log/containers/nova:/var/log/nova:z\\\", \\\"/var/log/containers/httpd/nova-metadata:/var/log/httpd:z\\\"], \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R nova:nova /var/log/nova\\\"]}}}}, \\\"host_prep_tasks\\\": {\\\"description\\\": \\\"Extra ansible tasks needed for logging to files in the host.\\\", \\\"value\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/nova\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/log/containers/httpd/nova-metadata\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}]}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Nova libvirt service\\\\n\\\", \\\"parameters\\\": {\\\"Debug\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false, \\\"description\\\": \\\"Set to True to enable debugging on all services.\\\"}, \\\"LibvirtDebug\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false, \\\"description\\\": \\\"Set to True to enable debugging libvirt services.\\\"}, \\\"LibvirtLogLevel\\\": {\\\"default\\\": 3, \\\"description\\\": \\\"Defines log level in libvirt to filter log output. See https://libvirt.org/logging.html to find its detail.\\\", \\\"type\\\": \\\"number\\\", \\\"constraints\\\": [{\\\"range\\\": {\\\"min\\\": 1, \\\"max\\\": 4}}]}, \\\"LibvirtVirtlogdLogLevel\\\": {\\\"default\\\": 3, \\\"description\\\": \\\"Defines log level in virtlogd to filter log output. See https://libvirt.org/logging.html to find its detail.\\\", \\\"type\\\": \\\"number\\\", \\\"constraints\\\": [{\\\"range\\\": {\\\"min\\\": 1, \\\"max\\\": 4}}]}, \\\"LibvirtVirtsecretdLogLevel\\\": {\\\"default\\\": 3, \\\"description\\\": \\\"Defines log level in virtsecretd to filter log output. See https://libvirt.org/logging.html to find its detail.\\\", \\\"type\\\": \\\"number\\\", \\\"constraints\\\": [{\\\"range\\\": {\\\"min\\\": 1, \\\"max\\\": 4}}]}, \\\"LibvirtVirtnodedevdLogLevel\\\": {\\\"default\\\": 3, \\\"description\\\": \\\"Defines log level in virtnodedevd to filter log output. See https://libvirt.org/logging.html to find its detail.\\\", \\\"type\\\": \\\"number\\\", \\\"constraints\\\": [{\\\"range\\\": {\\\"min\\\": 1, \\\"max\\\": 4}}]}, \\\"LibvirtVirtqemudLogLevel\\\": {\\\"default\\\": 3, \\\"description\\\": \\\"Defines log level in virtqemud to filter log output. See https://libvirt.org/logging.html to find its detail.\\\", \\\"type\\\": \\\"number\\\", \\\"constraints\\\": [{\\\"range\\\": {\\\"min\\\": 1, \\\"max\\\": 4}}]}, \\\"LibvirtVirtproxydLogLevel\\\": {\\\"default\\\": 3, \\\"description\\\": \\\"Defines log level in virtproxyd to filter log output. See https://libvirt.org/logging.html to find its detail.\\\", \\\"type\\\": \\\"number\\\", \\\"constraints\\\": [{\\\"range\\\": {\\\"min\\\": 1, \\\"max\\\": 4}}]}, \\\"LibvirtVirtstoragedLogLevel\\\": {\\\"default\\\": 3, \\\"description\\\": \\\"Defines log level in virtstoraged to filter log output. See https://libvirt.org/logging.html to find its detail.\\\", \\\"type\\\": \\\"number\\\", \\\"constraints\\\": [{\\\"range\\\": {\\\"min\\\": 1, \\\"max\\\": 4}}]}}, \\\"outputs\\\": {\\\"config_settings\\\": {\\\"description\\\": \\\"Extra hieradata needed to log to files in the host.\\\", \\\"value\\\": {\\\"nova::compute::libvirt::log_outputs\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"LEVEL:file:/var/log/libvirt/libvirtd.log\\\", \\\"params\\\": {\\\"LEVEL\\\": {\\\"if\\\": [{\\\"or\\\": [{\\\"get_param\\\": \\\"Debug\\\"}, {\\\"get_param\\\": \\\"LibvirtDebug\\\"}]}, 1, {\\\"get_param\\\": \\\"LibvirtLogLevel\\\"}]}}}}, \\\"nova::compute::libvirt::virtlogd::log_outputs\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"LEVEL:file:/var/log/libvirt/virtlogd.log\\\", \\\"params\\\": {\\\"LEVEL\\\": {\\\"if\\\": [{\\\"or\\\": [{\\\"get_param\\\": \\\"Debug\\\"}, {\\\"get_param\\\": \\\"LibvirtDebug\\\"}]}, 1, {\\\"get_param\\\": \\\"LibvirtVirtlogdLogLevel\\\"}]}}}}, \\\"nova::compute::libvirt::virtsecretd::log_outputs\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"LEVEL:file:/var/log/libvirt/virtsecretd.log\\\", \\\"params\\\": {\\\"LEVEL\\\": {\\\"if\\\": [{\\\"or\\\": [{\\\"get_param\\\": \\\"Debug\\\"}, {\\\"get_param\\\": \\\"LibvirtDebug\\\"}]}, 1, {\\\"get_param\\\": \\\"LibvirtVirtsecretdLogLevel\\\"}]}}}}, \\\"nova::compute::libvirt::virtnodedevd::log_outputs\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"LEVEL:file:/var/log/libvirt/virtnodedevd.log\\\", \\\"params\\\": {\\\"LEVEL\\\": {\\\"if\\\": [{\\\"or\\\": [{\\\"get_param\\\": \\\"Debug\\\"}, {\\\"get_param\\\": \\\"LibvirtDebug\\\"}]}, 1, {\\\"get_param\\\": \\\"LibvirtVirtnodedevdLogLevel\\\"}]}}}}, \\\"nova::compute::libvirt::virtqemud::log_outputs\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"LEVEL:file:/var/log/libvirt/virtqemud.log\\\", \\\"params\\\": {\\\"LEVEL\\\": {\\\"if\\\": [{\\\"or\\\": [{\\\"get_param\\\": \\\"Debug\\\"}, {\\\"get_param\\\": \\\"LibvirtDebug\\\"}]}, 1, {\\\"get_param\\\": \\\"LibvirtVirtqemudLogLevel\\\"}]}}}}, \\\"nova::compute::libvirt::virtproxyd::log_outputs\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"LEVEL:file:/var/log/libvirt/virtproxyd.log\\\", \\\"params\\\": {\\\"LEVEL\\\": {\\\"if\\\": [{\\\"or\\\": [{\\\"get_param\\\": \\\"Debug\\\"}, {\\\"get_param\\\": \\\"LibvirtDebug\\\"}]}, 1, {\\\"get_param\\\": \\\"LibvirtVirtproxydLogLevel\\\"}]}}}}, \\\"nova::compute::libvirt::virtstoraged::log_outputs\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"LEVEL:file:/var/log/libvirt/virtstoraged.log\\\", \\\"params\\\": {\\\"LEVEL\\\": {\\\"if\\\": [{\\\"or\\\": [{\\\"get_param\\\": \\\"Debug\\\"}, {\\\"get_param\\\": \\\"LibvirtDebug\\\"}]}, 1, {\\\"get_param\\\": \\\"LibvirtVirtstoragedLogLevel\\\"}]}}}}}}, \\\"volumes\\\": {\\\"description\\\": \\\"The volumes needed to log to files in the host.\\\", \\\"value\\\": [\\\"/var/log/containers/libvirt:/var/log/libvirt:shared,z\\\"]}, \\\"docker_config\\\": {\\\"description\\\": \\\"Extra containers needed for logging to file in the host.\\\", \\\"value\\\": null}, \\\"host_prep_tasks\\\": {\\\"description\\\": \\\"Extra ansible tasks needed for logging to files in the host.\\\", \\\"value\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"state\\\": \\\"directory\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/libvirt\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}]}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Template for placement\'s logging to files\\\\n\\\", \\\"parameters\\\": {\\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"ContainerPlacementImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}}, \\\"resources\\\": {\\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerPlacementImage\\\": \\\"ContainerPlacementImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerPlacementImage\\\": {\\\"get_param\\\": \\\"ContainerPlacementImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"config_settings\\\": {\\\"description\\\": \\\"Extra hieradata needed to log to files in the host.\\\", \\\"value\\\": null}, \\\"volumes\\\": {\\\"description\\\": \\\"The volumes needed to log to files in the host.\\\", \\\"value\\\": [\\\"/var/log/containers/placement:/var/log/placement:z\\\", \\\"/var/log/containers/httpd/placement:/var/log/httpd:z\\\"]}, \\\"docker_config\\\": {\\\"description\\\": \\\"Extra containers needed for logging to files in the host.\\\", \\\"value\\\": {\\\"step_2\\\": {\\\"placement_init_log\\\": {\\\"start_order\\\": 1, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerPlacementImage\\\"]}, \\\"net\\\": \\\"none\\\", \\\"user\\\": \\\"root\\\", \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R placement:placement /var/log/placement\\\"], \\\"volumes\\\": [\\\"/var/log/containers/placement:/var/log/placement:z\\\", \\\"/var/log/containers/httpd/placement:/var/log/httpd:z\\\"]}}}}, \\\"host_prep_tasks\\\": {\\\"description\\\": \\\"Extra ansible tasks needed for logging to files in the host.\\\", \\\"value\\\": [{\\\"name\\\": \\\"create persistent logs directory\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/placement\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/log/containers/httpd/placement\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}]}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Host config and reboot service which configures Kernel Args and reboot\\\", \\\"parameters\\\": {\\\"RoleNetIpMap\\\": {\\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"KernelArgs\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Kernel Args to apply to the host\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"KernelArgsDeferReboot\\\": {\\\"default\\\": false, \\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"When enabled, nodes will not get rebooted automatically by tripleo-kernel if KernelArgs have been changed. Operators will have to manually reboot nodes after the deployment or update process is completed.\\\\nLeaving this enabled during a scale-up operation will prevent reboot on new nodes. This might cause deployment errors as the KernelArgs will not be applied.\\\\n\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"TunedProfileName\\\": {\\\"default\\\": \\\"throughput-performance\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Tuned Profile to apply to the host\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"IsolCpusList\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"List of logical CPU ids whic need to be isolated from the host processes. This input is provided to the tuned profile cpu-partitioning to configure systemd and repin interrupts (IRQ repinning).\\\\n\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"NodeRebootWaitTimeout\\\": {\\\"default\\\": 900, \\\"type\\\": \\\"number\\\", \\\"description\\\": \\\"Timeout in seconds to specify the wait time for ansible node reboot\\\"}, \\\"Hugepages\\\": {\\\"default\\\": {}, \\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"Hash for hugepage configuration Example:\\\\n  Hugepages:\\\\n    2048:\\\\n      count: 100\\\\n      default: false\\\\n    1048576:\\\\n      count: 100\\\\n      default: true\\\\n\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ReconfigureHugepages\\\": {\\\"default\\\": false, \\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"By default, tripleo-kernel will configure the provided Hugepages as specified by operators but it won\'t try to remove Hugepages configured on the host that are not part of the TripleO paramater. Enabling this setting will make sure everything is reconfigured exactly like the TripleO parameter, otherwise we just add the content of the Hugepages parameter to what\'s already in place.\\\\n\\\", \\\"tags\\\": [\\\"role_specific\\\"]}}, \\\"resources\\\": {\\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"tuned_profile\\\": \\\"TunedProfileName\\\", \\\"isolated_cores\\\": \\\"IsolCpusList\\\", \\\"kernel_args\\\": \\\"KernelArgs\\\", \\\"kernel_args_defer_reboot\\\": \\\"KernelArgsDeferReboot\\\", \\\"hugepages\\\": \\\"Hugepages\\\", \\\"reconfigure_hugepages\\\": \\\"ReconfigureHugepages\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"TunedProfileName\\\": {\\\"get_param\\\": \\\"TunedProfileName\\\"}, \\\"IsolCpusList\\\": {\\\"get_param\\\": \\\"IsolCpusList\\\"}, \\\"KernelArgs\\\": {\\\"get_param\\\": \\\"KernelArgs\\\"}, \\\"KernelArgsDeferReboot\\\": {\\\"get_param\\\": \\\"KernelArgsDeferReboot\\\"}, \\\"Hugepages\\\": {\\\"get_param\\\": \\\"Hugepages\\\"}, \\\"ReconfigureHugepages\\\": {\\\"get_param\\\": \\\"ReconfigureHugepages\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Host Config Service\\\", \\\"value\\\": {\\\"service_name\\\": \\\"boot_params_service\\\", \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Configure tuned before reboot\\\", \\\"when\\\": \\\"step|int == 0\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tuned\\\"}, \\\"vars\\\": {\\\"tuned_profile\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"tuned_profile\\\"]}, \\\"tuned_isolated_cores\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"isolated_cores\\\"]}}}, {\\\"name\\\": \\\"Configure kernel args and reboot\\\", \\\"when\\\": \\\"step|int == 0\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_kernel\\\", \\\"tasks_from\\\": \\\"kernelargs.yml\\\"}, \\\"vars\\\": {\\\"tripleo_kernel_args\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"kernel_args\\\"]}, \\\"tripleo_kernel_hugepages\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"hugepages\\\"]}, \\\"tripleo_kernel_hugepages_remove\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"reconfigure_hugepages\\\"]}, \\\"tripleo_kernel_defer_reboot\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"kernel_args_defer_reboot\\\"]}, \\\"tripleo_kernel_reboot_timeout\\\": {\\\"get_param\\\": \\\"NodeRebootWaitTimeout\\\"}}}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"upgrade prepare for leapp to align kernel arg shortcommings in leapp\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_prepare\\\"], \\\"when\\\": [\\\"step|int == 3\\\", \\\"upgrade_leapp_enabled\\\"], \\\"block\\\": [{\\\"name\\\": \\\"fix grub entries to have name start with GRUB_\\\", \\\"replace\\\": {\\\"path\\\": \\\"/etc/default/grub\\\", \\\"regexp\\\": \\\"^(TRIPLEO_HEAT_TEMPLATE_KERNEL_ARGS)(.*)\\\", \\\"replace\\\": \\\"GRUB_\\\\\\\\1\\\\\\\\2\\\"}}, {\\\"name\\\": \\\"fix grub entries in append statement\\\", \\\"replace\\\": {\\\"path\\\": \\\"/etc/default/grub\\\", \\\"regexp\\\": \\\"(.*){(TRIPLEO_HEAT_TEMPLATE_KERNEL_ARGS)}(.*)\\\", \\\"replace\\\": \\\"\\\\\\\\1{GRUB_\\\\\\\\2}\\\\\\\\3\\\"}}]}]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/overcloud-resource-registry-puppet.yaml\": \"{\\\"resource_registry\\\": {\\\"OS::TripleO::SoftwareDeployment\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\\\", \\\"OS::Heat::SoftwareDeployment\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-software.yaml\\\", \\\"OS::Heat::StructuredDeployment\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/config-download-structured.yaml\\\", \\\"OS::TripleO::PostDeploySteps\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\\\", \\\"OS::TripleO::AllNodesDeployment\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::DefaultPasswords\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::RandomString\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Controller::PreNetworkConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::ControllerPostDeploySteps\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\\\", \\\"OS::TripleO::Controller\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/controller-role.yaml\\\", \\\"OS::TripleO::Tasks::ControllerPreConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Tasks::ControllerPostConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::ControllerExtraConfigPre\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\\\", \\\"OS::TripleO::Controller::Net::SoftwareConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Controller::Ports::StoragePort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\\\", \\\"OS::TripleO::Controller::Ports::StorageMgmtPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\\\", \\\"OS::TripleO::Controller::Ports::InternalApiPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\\\", \\\"OS::TripleO::Controller::Ports::TenantPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\\\", \\\"OS::TripleO::CellController::PreNetworkConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::CellControllerPostDeploySteps\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\\\", \\\"OS::TripleO::CellController\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontroller-role.yaml\\\", \\\"OS::TripleO::Tasks::CellControllerPreConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Tasks::CellControllerPostConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::CellControllerExtraConfigPre\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\\\", \\\"OS::TripleO::CellController::Net::SoftwareConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::CellController::Ports::StoragePort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\\\", \\\"OS::TripleO::CellController::Ports::StorageMgmtPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\\\", \\\"OS::TripleO::CellController::Ports::InternalApiPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\\\", \\\"OS::TripleO::CellController::Ports::TenantPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\\\", \\\"OS::TripleO::CellControllerCompute::PreNetworkConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::CellControllerComputePostDeploySteps\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\\\", \\\"OS::TripleO::CellControllerCompute\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\\\", \\\"OS::TripleO::Tasks::CellControllerComputePreConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Tasks::CellControllerComputePostConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::CellControllerComputeExtraConfigPre\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\\\", \\\"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::CellControllerCompute::Ports::StoragePort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\\\", \\\"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\\\", \\\"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\\\", \\\"OS::TripleO::CellControllerCompute::Ports::TenantPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\\\", \\\"OS::TripleO::Compute::PreNetworkConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::ComputePostDeploySteps\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\\\", \\\"OS::TripleO::Compute\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/compute-role.yaml\\\", \\\"OS::TripleO::Tasks::ComputePreConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Tasks::ComputePostConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::ComputeExtraConfigPre\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\\\", \\\"OS::TripleO::Compute::Net::SoftwareConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Compute::Ports::StoragePort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\\\", \\\"OS::TripleO::Compute::Ports::InternalApiPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\\\", \\\"OS::TripleO::Compute::Ports::TenantPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\\\", \\\"OS::TripleO::BlockStorage::PreNetworkConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::BlockStoragePostDeploySteps\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\\\", \\\"OS::TripleO::BlockStorage\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/blockstorage-role.yaml\\\", \\\"OS::TripleO::Tasks::BlockStoragePreConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Tasks::BlockStoragePostConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::BlockStorageExtraConfigPre\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\\\", \\\"OS::TripleO::BlockStorage::Net::SoftwareConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::BlockStorage::Ports::StoragePort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\\\", \\\"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\\\", \\\"OS::TripleO::BlockStorage::Ports::InternalApiPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\\\", \\\"OS::TripleO::ObjectStorage::PreNetworkConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::ObjectStoragePostDeploySteps\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\\\", \\\"OS::TripleO::ObjectStorage\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/objectstorage-role.yaml\\\", \\\"OS::TripleO::Tasks::ObjectStoragePreConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Tasks::ObjectStoragePostConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::ObjectStorageExtraConfigPre\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\\\", \\\"OS::TripleO::ObjectStorage::Net::SoftwareConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::ObjectStorage::Ports::StoragePort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\\\", \\\"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\\\", \\\"OS::TripleO::ObjectStorage::Ports::InternalApiPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\\\", \\\"OS::TripleO::CephStorage::PreNetworkConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::CephStoragePostDeploySteps\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\\\", \\\"OS::TripleO::CephStorage\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/cephstorage-role.yaml\\\", \\\"OS::TripleO::Tasks::CephStoragePreConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Tasks::CephStoragePostConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::CephStorageExtraConfigPre\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\\\", \\\"OS::TripleO::CephStorage::Net::SoftwareConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::CephStorage::Ports::StoragePort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\\\", \\\"OS::TripleO::CephStorage::Ports::StorageMgmtPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\\\", \\\"OS::TripleO::Networker::PreNetworkConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::NetworkerPostDeploySteps\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/post.yaml\\\", \\\"OS::TripleO::Networker\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/networker-role.yaml\\\", \\\"OS::TripleO::Tasks::NetworkerPreConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Tasks::NetworkerPostConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::NetworkerExtraConfigPre\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\\\", \\\"OS::TripleO::Networker::Net::SoftwareConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Networker::Ports::InternalApiPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\\\", \\\"OS::TripleO::Networker::Ports::TenantPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\\\", \\\"OS::TripleO::ControllerServiceServerMetadataHook\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::CellControllerServiceServerMetadataHook\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::CellControllerComputeServiceServerMetadataHook\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::ComputeServiceServerMetadataHook\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::BlockStorageServiceServerMetadataHook\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::ObjectStorageServiceServerMetadataHook\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::CephStorageServiceServerMetadataHook\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::NetworkerServiceServerMetadataHook\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Server\\\": \\\"OS::Nova::Server\\\", \\\"OS::TripleO::ControllerServer\\\": \\\"OS::TripleO::Server\\\", \\\"OS::TripleO::CellControllerServer\\\": \\\"OS::TripleO::Server\\\", \\\"OS::TripleO::CellControllerComputeServer\\\": \\\"OS::TripleO::Server\\\", \\\"OS::TripleO::ComputeServer\\\": \\\"OS::TripleO::Server\\\", \\\"OS::TripleO::BlockStorageServer\\\": \\\"OS::TripleO::Server\\\", \\\"OS::TripleO::ObjectStorageServer\\\": \\\"OS::TripleO::Server\\\", \\\"OS::TripleO::CephStorageServer\\\": \\\"OS::TripleO::Server\\\", \\\"OS::TripleO::NetworkerServer\\\": \\\"OS::TripleO::Server\\\", \\\"OS::TripleO::NodeAdminUserData\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\\\", \\\"OS::TripleO::NodeTimesyncUserData\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_timesync.yaml\\\", \\\"OS::TripleO::NodeUserData\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\\\", \\\"OS::TripleO::Controller::NodeUserData\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\\\", \\\"OS::TripleO::CellController::NodeUserData\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\\\", \\\"OS::TripleO::CellControllerCompute::NodeUserData\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\\\", \\\"OS::TripleO::Compute::NodeUserData\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\\\", \\\"OS::TripleO::BlockStorage::NodeUserData\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\\\", \\\"OS::TripleO::ObjectStorage::NodeUserData\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\\\", \\\"OS::TripleO::CephStorage::NodeUserData\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\\\", \\\"OS::TripleO::Networker::NodeUserData\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/firstboot/userdata_default.yaml\\\", \\\"OS::TripleO::NodeTLSCAData\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::NodeTLSData\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::NodeExtraConfig\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\\\", \\\"OS::TripleO::NodeExtraConfigPost\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\\\", \\\"OS::TripleO::AllNodesExtraConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Network\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/networks.yaml\\\", \\\"OS::TripleO::Network::Storage\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Network::StorageMgmt\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Network::InternalApi\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Network::Tenant\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Network::External\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Network::ExtraConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Network::Ports::NetVipMap\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\\\", \\\"OS::TripleO::Network::Ports::NetIpMap\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_map.yaml\\\", \\\"OS::TripleO::Network::Ports::NetIpListMap\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\\\", \\\"OS::TripleO::Network::Ports::StorageVipPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\\\", \\\"OS::TripleO::Network::Ports::StorageMgmtVipPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\\\", \\\"OS::TripleO::Network::Ports::InternalApiVipPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\\\", \\\"OS::TripleO::Network::Ports::ExternalVipPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/noop.yaml\\\", \\\"OS::TripleO::Network::Ports::ControlPlaneVipPort\\\": \\\"OS::Neutron::Port\\\", \\\"OS::TripleO::ServiceNetMap\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/service_net_map.yaml\\\", \\\"OS::TripleO::EndpointMap\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\\\", \\\"OS::TripleO::DeployedServerEnvironment\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::DeploymentSteps\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::WorkflowSteps\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::ControllerServices\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/controller-role.yaml\\\", \\\"OS::TripleO::CellControllerServices\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontroller-role.yaml\\\", \\\"OS::TripleO::CellControllerComputeServices\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\\\", \\\"OS::TripleO::ComputeServices\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/compute-role.yaml\\\", \\\"OS::TripleO::BlockStorageServices\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/blockstorage-role.yaml\\\", \\\"OS::TripleO::ObjectStorageServices\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/objectstorage-role.yaml\\\", \\\"OS::TripleO::CephStorageServices\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/cephstorage-role.yaml\\\", \\\"OS::TripleO::NetworkerServices\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/common/services/networker-role.yaml\\\", \\\"OS::TripleO::Services::Aide\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::Apache\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\\\", \\\"OS::TripleO::Services::CACerts\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\\\", \\\"OS::TripleO::Services::CephMds\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::CephMgr\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::CephMon\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::CephRbdMirror\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::CephRgw\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::CephOSD\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::CephGrafana\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::CephClient\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::CephNfs\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::CephExternal\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::CinderApi\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\\\", \\\"OS::TripleO::Services::CinderBackup\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::CinderScheduler\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\\\", \\\"OS::TripleO::Services::CinderVolume\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\\\", \\\"OS::TripleO::Services::BlockStorageCinderVolume\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\\\", \\\"OS::TripleO::Services::Keystone\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\\\", \\\"OS::TripleO::Services::GlanceApi\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\\\", \\\"OS::TripleO::Services::GlanceApiInternal\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\\\", \\\"OS::TripleO::Services::HeatApi\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\\\", \\\"OS::TripleO::Services::HeatApiCfn\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\\\", \\\"OS::TripleO::Services::HeatApiCloudwatch\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\\\", \\\"OS::TripleO::Services::HeatEngine\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\\\", \\\"OS::TripleO::Services::HeatEphemeral\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::Kernel\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\\\", \\\"OS::TripleO::Services::MySQL\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\\\", \\\"OS::TripleO::Services::NeutronBgpVpnApi\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::NeutronBgpVpnBagpipe\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::NeutronSfcApi\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::NeutronDhcpAgent\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::NeutronL2gwApi\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::NeutronL3Agent\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::NeutronL2gwAgent\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::NeutronMetadataAgent\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::OVNMetadataAgent\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\\\", \\\"OS::TripleO::Services::NeutronApi\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\\\", \\\"OS::TripleO::Services::NeutronCorePlugin\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\\\", \\\"OS::TripleO::Services::ComputeNeutronCorePlugin\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::ComputeNeutronCorePluginNuage\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\\\", \\\"OS::TripleO::Services::NeutronCorePluginML2OVN\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\\\", \\\"OS::TripleO::Services::NeutronCorePluginNuage\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\\\", \\\"OS::TripleO::Services::NeutronCorePluginML2Nuage\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\\\", \\\"OS::TripleO::Services::NeutronCorePluginNSX\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\\\", \\\"OS::TripleO::Services::OVNDBs\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\\\", \\\"OS::TripleO::Services::OVNController\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\\\", \\\"OS::TripleO::Services::OvsDpdkNetcontrold\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::NeutronCorePluginMLNXSDN\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\\\", \\\"OS::TripleO::Services::NeutronCorePluginVTS\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\\\", \\\"OS::TripleO::Services::NeutronCorePluginML2Ansible\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\\\", \\\"OS::TripleO::Services::NeutronNuageVrs\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\\\", \\\"OS::TripleO::Services::NeutronOvsAgent\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::NeutronLinuxbridgeAgent\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::ComputeNeutronOvsAgent\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::ComputeNeutronOvsDpdk\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::Pacemaker\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\\\", \\\"OS::TripleO::Services::PacemakerRemote\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\\\", \\\"OS::TripleO::Services::NeutronSriovAgent\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::NeutronMlnxAgent\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::NeutronAgentsIBConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::OsloMessagingRpc\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\\\", \\\"OS::TripleO::Services::OsloMessagingNotify\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\\\", \\\"OS::TripleO::Services::RabbitMQ\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::Qdr\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::HAproxy\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\\\", \\\"OS::TripleO::Services::HAProxyPublicTLS\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-inject.yaml\\\", \\\"OS::TripleO::Services::HAProxyInternalTLS\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::Iscsid\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\\\", \\\"OS::TripleO::Services::Memcached\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\\\", \\\"OS::TripleO::Services::Tuned\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\\\", \\\"OS::TripleO::Services::Securetty\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::SELinux\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::Sshd\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\\\", \\\"OS::TripleO::Services::Redis\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::NovaApi\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\\\", \\\"OS::TripleO::Services::NovaCompute\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\\\", \\\"OS::TripleO::Services::NovaConductor\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\\\", \\\"OS::TripleO::Services::NovaLibvirt\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\\\", \\\"OS::TripleO::Services::NovaLibvirtLegacy\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\\\", \\\"OS::TripleO::Services::NovaLibvirtGuests\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\\\", \\\"OS::TripleO::Services::NovaManager\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\\\", \\\"OS::TripleO::Services::NovaMetadata\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\\\", \\\"OS::TripleO::Services::NovaMigrationTarget\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\\\", \\\"OS::TripleO::Services::NovaPlacement\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::PlacementApi\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\\\", \\\"OS::TripleO::Services::NovaScheduler\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\\\", \\\"OS::TripleO::Services::NovaVncProxy\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\\\", \\\"OS::TripleO::Services::Novajoin\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::NovaAZConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::ContainersLogrotateCrond\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\\\", \\\"OS::TripleO::Services::SwiftProxy\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\\\", \\\"OS::TripleO::Services::SwiftDispersion\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::ExternalSwiftProxy\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::SwiftStorage\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\\\", \\\"OS::TripleO::Services::SwiftRingBuilder\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\\\", \\\"OS::TripleO::Services::Snmp\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\\\", \\\"OS::TripleO::Services::Timezone\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\\\", \\\"OS::TripleO::Services::UndercloudRemoveNovajoin\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::UndercloudTLS\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::CeilometerAgentCentral\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::CeilometerAgentIpmi\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::CeilometerAgentNotification\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::ComputeCeilometerAgent\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::Horizon\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\\\", \\\"OS::TripleO::Services::GnocchiApi\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::GnocchiMetricd\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::GnocchiStatsd\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::Xinetd\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::Chrony\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\\\", \\\"OS::TripleO::Services::Ptp\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::Timesync\\\": \\\"OS::TripleO::Services::Chrony\\\", \\\"OS::TripleO::Services::TimeMaster\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\\\", \\\"OS::TripleO::Services::IpaClient\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::Ipsec\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::Rhsm\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::MasqueradeNetworks\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::TripleoValidations\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::UndercloudUpgrade\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::Collectd\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::ManilaApi\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::ManilaScheduler\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::ManilaShare\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::ManilaBackendFlashBlade\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::ManilaBackendIsilon\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::ManilaBackendNetapp\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::ManilaBackendPowerMax\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::ManilaBackendUnity\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::ManilaBackendVMAX\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::ManilaBackendCephFs\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::ManilaBackendVNX\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::ComputeNeutronL3Agent\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::ComputeNeutronMetadataAgent\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::BarbicanApi\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::BarbicanBackendSimpleCrypto\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::BarbicanBackendDogtag\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::BarbicanBackendKmip\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::BarbicanClient\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::AodhApi\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::AodhEvaluator\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::AodhListener\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::AodhNotifier\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::MetricsQdr\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::IronicApi\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::IronicConductor\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::IronicInspector\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::IronicPxe\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::IronicNeutronAgent\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::NovaIronic\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::TripleoFirewall\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\\\", \\\"OS::TripleO::Services::TripleoPackages\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\\\", \\\"OS::TripleO::Services::OpenStackClients\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::TLSProxyBase\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::CinderBackendDellSc\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::CinderBackendDellEMCSc\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::CinderBackendDellEMCPowermax\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::CinderBackendDellEMCPowerStore\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::CinderBackendDellEMCUnity\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::CinderBackendDellEMCVNX\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::CinderBackendDellEMCXtremio\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::CinderBackendNetApp\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::CinderBackendPure\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::CinderBackendScaleIO\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::CinderBackendNVMeOF\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::CinderHPELeftHandISCSI\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::CinderVolumeEdge\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::Etcd\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::AuditD\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::OctaviaApi\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::OctaviaHealthManager\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::OctaviaHousekeeping\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::OctaviaWorker\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::OctaviaDeploymentConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::LiquidioCompute\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::MySQLClient\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-client.yaml\\\", \\\"OS::TripleO::Services::Vpp\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::NeutronVppAgent\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::Podman\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\\\", \\\"OS::TripleO::Services::Docker\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::DockerRegistry\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::ContainerImagePrepare\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\\\", \\\"OS::TripleO::Services::CertmongerUser\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::Clustercheck\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\\\", \\\"OS::TripleO::Services::Rsyslog\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::RsyslogSidecar\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::LoginDefs\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::ComputeInstanceHA\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::DesignateApi\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::DesignateCentral\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::DesignateProducer\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::DesignateWorker\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::DesignateMDNS\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::DesignateSink\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::DesignateBind\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::NeutronMl2PluginBase\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\\\", \\\"OS::TripleO::Services::Multipathd\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::GlanceApiEdge\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::HAproxyEdge\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::Frr\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::OVNBgpAgent\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::Unbound\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::Tmpwatch\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\\\", \\\"OS::TripleO::Services::Logging::BarbicanApi\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\\\", \\\"OS::TripleO::Services::Logging::GlanceApi\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\\\", \\\"OS::TripleO::Services::Logging::HAProxy\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\\\", \\\"OS::TripleO::Services::Logging::HeatApi\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\\\", \\\"OS::TripleO::Services::Logging::HeatApiCfn\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\\\", \\\"OS::TripleO::Services::Logging::HeatEngine\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\\\", \\\"OS::TripleO::Services::Logging::Keystone\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/keystone.yaml\\\", \\\"OS::TripleO::Services::Logging::NeutronApi\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\\\", \\\"OS::TripleO::Services::Logging::NeutronCommon\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\\\", \\\"OS::TripleO::Services::Logging::NovaApi\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\\\", \\\"OS::TripleO::Services::Logging::NovaMetadata\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\\\", \\\"OS::TripleO::Services::Logging::NovaCommon\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\\\", \\\"OS::TripleO::Services::Logging::NovaLibvirt\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\\\", \\\"OS::TripleO::Services::Logging::PlacementApi\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\\\", \\\"OS::TripleO::Services::Tempest\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::BootParams\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\\\"}, \\\"parameter_merge_strategies\\\": {\\\"ServiceNetMap\\\": \\\"merge\\\", \\\"VipSubnetMap\\\": \\\"merge\\\", \\\"SshServerOptions\\\": \\\"merge\\\", \\\"ExtraConfig\\\": \\\"merge\\\", \\\"ControllerParameters\\\": \\\"merge\\\", \\\"ControllerExtraConfig\\\": \\\"merge\\\", \\\"ControllerExtraGroupVars\\\": \\\"merge\\\", \\\"CellControllerParameters\\\": \\\"merge\\\", \\\"CellControllerExtraConfig\\\": \\\"merge\\\", \\\"CellControllerExtraGroupVars\\\": \\\"merge\\\", \\\"CellControllerComputeParameters\\\": \\\"merge\\\", \\\"CellControllerComputeExtraConfig\\\": \\\"merge\\\", \\\"CellControllerComputeExtraGroupVars\\\": \\\"merge\\\", \\\"ComputeParameters\\\": \\\"merge\\\", \\\"ComputeExtraConfig\\\": \\\"merge\\\", \\\"ComputeExtraGroupVars\\\": \\\"merge\\\", \\\"BlockStorageParameters\\\": \\\"merge\\\", \\\"BlockStorageExtraConfig\\\": \\\"merge\\\", \\\"BlockStorageExtraGroupVars\\\": \\\"merge\\\", \\\"ObjectStorageParameters\\\": \\\"merge\\\", \\\"ObjectStorageExtraConfig\\\": \\\"merge\\\", \\\"ObjectStorageExtraGroupVars\\\": \\\"merge\\\", \\\"CephStorageParameters\\\": \\\"merge\\\", \\\"CephStorageExtraConfig\\\": \\\"merge\\\", \\\"CephStorageExtraGroupVars\\\": \\\"merge\\\", \\\"NetworkerParameters\\\": \\\"merge\\\", \\\"NetworkerExtraConfig\\\": \\\"merge\\\", \\\"NetworkerExtraGroupVars\\\": \\\"merge\\\"}, \\\"parameter_defaults\\\": {\\\"NeutronMechanismDrivers\\\": \\\"ovn\\\", \\\"ContainerCli\\\": \\\"podman\\\", \\\"EnablePackageInstall\\\": false, \\\"SoftwareConfigTransport\\\": \\\"POLL_SERVER_HEAT\\\", \\\"OVNIntegrationBridge\\\": \\\"br-int\\\", \\\"ExtraConfig\\\": {}, \\\"ControllerServices\\\": [\\\"OS::TripleO::Services::Aide\\\", \\\"OS::TripleO::Services::AodhApi\\\", \\\"OS::TripleO::Services::AodhEvaluator\\\", \\\"OS::TripleO::Services::AodhListener\\\", \\\"OS::TripleO::Services::AodhNotifier\\\", \\\"OS::TripleO::Services::AuditD\\\", \\\"OS::TripleO::Services::BarbicanApi\\\", \\\"OS::TripleO::Services::BarbicanBackendSimpleCrypto\\\", \\\"OS::TripleO::Services::BarbicanBackendDogtag\\\", \\\"OS::TripleO::Services::BarbicanBackendKmip\\\", \\\"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\\\", \\\"OS::TripleO::Services::BootParams\\\", \\\"OS::TripleO::Services::CACerts\\\", \\\"OS::TripleO::Services::CeilometerAgentCentral\\\", \\\"OS::TripleO::Services::CeilometerAgentNotification\\\", \\\"OS::TripleO::Services::CephClient\\\", \\\"OS::TripleO::Services::CephExternal\\\", \\\"OS::TripleO::Services::CephGrafana\\\", \\\"OS::TripleO::Services::CephMds\\\", \\\"OS::TripleO::Services::CephMgr\\\", \\\"OS::TripleO::Services::CephMon\\\", \\\"OS::TripleO::Services::CephNfs\\\", \\\"OS::TripleO::Services::CephRbdMirror\\\", \\\"OS::TripleO::Services::CephRgw\\\", \\\"OS::TripleO::Services::CinderApi\\\", \\\"OS::TripleO::Services::CinderBackendDellSc\\\", \\\"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\\\", \\\"OS::TripleO::Services::CinderBackendDellEMCPowermax\\\", \\\"OS::TripleO::Services::CinderBackendDellEMCPowerStore\\\", \\\"OS::TripleO::Services::CinderBackendDellEMCSc\\\", \\\"OS::TripleO::Services::CinderBackendDellEMCUnity\\\", \\\"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\\\", \\\"OS::TripleO::Services::CinderBackendDellEMCVNX\\\", \\\"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\\\", \\\"OS::TripleO::Services::CinderBackendDellEMCXtremio\\\", \\\"OS::TripleO::Services::CinderBackendNetApp\\\", \\\"OS::TripleO::Services::CinderBackendPure\\\", \\\"OS::TripleO::Services::CinderBackendScaleIO\\\", \\\"OS::TripleO::Services::CinderBackendNVMeOF\\\", \\\"OS::TripleO::Services::CinderBackup\\\", \\\"OS::TripleO::Services::CinderHPELeftHandISCSI\\\", \\\"OS::TripleO::Services::CinderScheduler\\\", \\\"OS::TripleO::Services::CinderVolume\\\", \\\"OS::TripleO::Services::Clustercheck\\\", \\\"OS::TripleO::Services::Collectd\\\", \\\"OS::TripleO::Services::ContainerImagePrepare\\\", \\\"OS::TripleO::Services::DesignateApi\\\", \\\"OS::TripleO::Services::DesignateCentral\\\", \\\"OS::TripleO::Services::DesignateProducer\\\", \\\"OS::TripleO::Services::DesignateWorker\\\", \\\"OS::TripleO::Services::DesignateMDNS\\\", \\\"OS::TripleO::Services::DesignateSink\\\", \\\"OS::TripleO::Services::DesignateBind\\\", \\\"OS::TripleO::Services::Etcd\\\", \\\"OS::TripleO::Services::ExternalSwiftProxy\\\", \\\"OS::TripleO::Services::Frr\\\", \\\"OS::TripleO::Services::GlanceApi\\\", \\\"OS::TripleO::Services::GlanceApiInternal\\\", \\\"OS::TripleO::Services::GnocchiApi\\\", \\\"OS::TripleO::Services::GnocchiMetricd\\\", \\\"OS::TripleO::Services::GnocchiStatsd\\\", \\\"OS::TripleO::Services::HAproxy\\\", \\\"OS::TripleO::Services::HeatApi\\\", \\\"OS::TripleO::Services::HeatApiCloudwatch\\\", \\\"OS::TripleO::Services::HeatApiCfn\\\", \\\"OS::TripleO::Services::HeatEngine\\\", \\\"OS::TripleO::Services::Horizon\\\", \\\"OS::TripleO::Services::IpaClient\\\", \\\"OS::TripleO::Services::Ipsec\\\", \\\"OS::TripleO::Services::IronicApi\\\", \\\"OS::TripleO::Services::IronicConductor\\\", \\\"OS::TripleO::Services::IronicInspector\\\", \\\"OS::TripleO::Services::IronicPxe\\\", \\\"OS::TripleO::Services::IronicNeutronAgent\\\", \\\"OS::TripleO::Services::Iscsid\\\", \\\"OS::TripleO::Services::Kernel\\\", \\\"OS::TripleO::Services::Keystone\\\", \\\"OS::TripleO::Services::LoginDefs\\\", \\\"OS::TripleO::Services::ManilaApi\\\", \\\"OS::TripleO::Services::ManilaBackendCephFs\\\", \\\"OS::TripleO::Services::ManilaBackendFlashBlade\\\", \\\"OS::TripleO::Services::ManilaBackendIsilon\\\", \\\"OS::TripleO::Services::ManilaBackendNetapp\\\", \\\"OS::TripleO::Services::ManilaBackendPowerMax\\\", \\\"OS::TripleO::Services::ManilaBackendUnity\\\", \\\"OS::TripleO::Services::ManilaBackendVNX\\\", \\\"OS::TripleO::Services::ManilaBackendVMAX\\\", \\\"OS::TripleO::Services::ManilaScheduler\\\", \\\"OS::TripleO::Services::ManilaShare\\\", \\\"OS::TripleO::Services::Memcached\\\", \\\"OS::TripleO::Services::MetricsQdr\\\", \\\"OS::TripleO::Services::Multipathd\\\", \\\"OS::TripleO::Services::MySQL\\\", \\\"OS::TripleO::Services::MySQLClient\\\", \\\"OS::TripleO::Services::NeutronApi\\\", \\\"OS::TripleO::Services::NeutronBgpVpnApi\\\", \\\"OS::TripleO::Services::NeutronSfcApi\\\", \\\"OS::TripleO::Services::NeutronCorePlugin\\\", \\\"OS::TripleO::Services::NeutronDhcpAgent\\\", \\\"OS::TripleO::Services::NeutronL2gwAgent\\\", \\\"OS::TripleO::Services::NeutronL2gwApi\\\", \\\"OS::TripleO::Services::NeutronL3Agent\\\", \\\"OS::TripleO::Services::NeutronLinuxbridgeAgent\\\", \\\"OS::TripleO::Services::NeutronMetadataAgent\\\", \\\"OS::TripleO::Services::NeutronOvsAgent\\\", \\\"OS::TripleO::Services::NeutronVppAgent\\\", \\\"OS::TripleO::Services::NeutronAgentsIBConfig\\\", \\\"OS::TripleO::Services::NovaApi\\\", \\\"OS::TripleO::Services::NovaConductor\\\", \\\"OS::TripleO::Services::NovaIronic\\\", \\\"OS::TripleO::Services::NovaMetadata\\\", \\\"OS::TripleO::Services::NovaScheduler\\\", \\\"OS::TripleO::Services::NovaVncProxy\\\", \\\"OS::TripleO::Services::ContainersLogrotateCrond\\\", \\\"OS::TripleO::Services::OctaviaApi\\\", \\\"OS::TripleO::Services::OctaviaDeploymentConfig\\\", \\\"OS::TripleO::Services::OctaviaHealthManager\\\", \\\"OS::TripleO::Services::OctaviaHousekeeping\\\", \\\"OS::TripleO::Services::OctaviaWorker\\\", \\\"OS::TripleO::Services::OpenStackClients\\\", \\\"OS::TripleO::Services::OVNDBs\\\", \\\"OS::TripleO::Services::OVNController\\\", \\\"OS::TripleO::Services::Pacemaker\\\", \\\"OS::TripleO::Services::PlacementApi\\\", \\\"OS::TripleO::Services::OsloMessagingRpc\\\", \\\"OS::TripleO::Services::OsloMessagingNotify\\\", \\\"OS::TripleO::Services::Podman\\\", \\\"OS::TripleO::Services::Redis\\\", \\\"OS::TripleO::Services::Rhsm\\\", \\\"OS::TripleO::Services::Rsyslog\\\", \\\"OS::TripleO::Services::RsyslogSidecar\\\", \\\"OS::TripleO::Services::Securetty\\\", \\\"OS::TripleO::Services::Snmp\\\", \\\"OS::TripleO::Services::Sshd\\\", \\\"OS::TripleO::Services::SwiftProxy\\\", \\\"OS::TripleO::Services::SwiftDispersion\\\", \\\"OS::TripleO::Services::SwiftRingBuilder\\\", \\\"OS::TripleO::Services::SwiftStorage\\\", \\\"OS::TripleO::Services::Timesync\\\", \\\"OS::TripleO::Services::Timezone\\\", \\\"OS::TripleO::Services::TripleoFirewall\\\", \\\"OS::TripleO::Services::TripleoPackages\\\", \\\"OS::TripleO::Services::Tuned\\\", \\\"OS::TripleO::Services::Unbound\\\", \\\"OS::TripleO::Services::Vpp\\\"], \\\"ControllerParameters\\\": {}, \\\"ControllerExtraConfig\\\": {}, \\\"ControllerExtraGroupVars\\\": {}, \\\"CellControllerServices\\\": [\\\"OS::TripleO::Services::Aide\\\", \\\"OS::TripleO::Services::AuditD\\\", \\\"OS::TripleO::Services::BootParams\\\", \\\"OS::TripleO::Services::CACerts\\\", \\\"OS::TripleO::Services::Clustercheck\\\", \\\"OS::TripleO::Services::Collectd\\\", \\\"OS::TripleO::Services::ContainerImagePrepare\\\", \\\"OS::TripleO::Services::ContainersLogrotateCrond\\\", \\\"OS::TripleO::Services::Frr\\\", \\\"OS::TripleO::Services::HAproxy\\\", \\\"OS::TripleO::Services::IpaClient\\\", \\\"OS::TripleO::Services::Ipsec\\\", \\\"OS::TripleO::Services::Iscsid\\\", \\\"OS::TripleO::Services::Kernel\\\", \\\"OS::TripleO::Services::LoginDefs\\\", \\\"OS::TripleO::Services::MetricsQdr\\\", \\\"OS::TripleO::Services::MySQL\\\", \\\"OS::TripleO::Services::MySQLClient\\\", \\\"OS::TripleO::Services::NeutronMetadataAgent\\\", \\\"OS::TripleO::Services::NovaConductor\\\", \\\"OS::TripleO::Services::NovaMetadata\\\", \\\"OS::TripleO::Services::NovaVncProxy\\\", \\\"OS::TripleO::Services::OsloMessagingRpc\\\", \\\"OS::TripleO::Services::Pacemaker\\\", \\\"OS::TripleO::Services::Podman\\\", \\\"OS::TripleO::Services::Ptp\\\", \\\"OS::TripleO::Services::Rhsm\\\", \\\"OS::TripleO::Services::Rsyslog\\\", \\\"OS::TripleO::Services::RsyslogSidecar\\\", \\\"OS::TripleO::Services::Securetty\\\", \\\"OS::TripleO::Services::Snmp\\\", \\\"OS::TripleO::Services::Sshd\\\", \\\"OS::TripleO::Services::Timesync\\\", \\\"OS::TripleO::Services::Timezone\\\", \\\"OS::TripleO::Services::TripleoFirewall\\\", \\\"OS::TripleO::Services::TripleoPackages\\\", \\\"OS::TripleO::Services::Tuned\\\", \\\"OS::TripleO::Services::Vpp\\\"], \\\"CellControllerParameters\\\": {}, \\\"CellControllerExtraConfig\\\": {}, \\\"CellControllerExtraGroupVars\\\": {}, \\\"CellControllerComputeServices\\\": [\\\"OS::TripleO::Services::Aide\\\", \\\"OS::TripleO::Services::AuditD\\\", \\\"OS::TripleO::Services::BootParams\\\", \\\"OS::TripleO::Services::CACerts\\\", \\\"OS::TripleO::Services::CephClient\\\", \\\"OS::TripleO::Services::CephExternal\\\", \\\"OS::TripleO::Services::Clustercheck\\\", \\\"OS::TripleO::Services::Collectd\\\", \\\"OS::TripleO::Services::ComputeCeilometerAgent\\\", \\\"OS::TripleO::Services::CeilometerAgentIpmi\\\", \\\"OS::TripleO::Services::ContainerImagePrepare\\\", \\\"OS::TripleO::Services::HAproxy\\\", \\\"OS::TripleO::Services::ComputeNeutronCorePlugin\\\", \\\"OS::TripleO::Services::ComputeNeutronL3Agent\\\", \\\"OS::TripleO::Services::ComputeNeutronMetadataAgent\\\", \\\"OS::TripleO::Services::ComputeNeutronOvsAgent\\\", \\\"OS::TripleO::Services::Frr\\\", \\\"OS::TripleO::Services::IpaClient\\\", \\\"OS::TripleO::Services::Ipsec\\\", \\\"OS::TripleO::Services::Iscsid\\\", \\\"OS::TripleO::Services::Kernel\\\", \\\"OS::TripleO::Services::LoginDefs\\\", \\\"OS::TripleO::Services::MetricsQdr\\\", \\\"OS::TripleO::Services::Multipathd\\\", \\\"OS::TripleO::Services::MySQL\\\", \\\"OS::TripleO::Services::MySQLClient\\\", \\\"OS::TripleO::Services::NeutronBgpVpnBagpipe\\\", \\\"OS::TripleO::Services::NeutronLinuxbridgeAgent\\\", \\\"OS::TripleO::Services::NeutronVppAgent\\\", \\\"OS::TripleO::Services::NovaAZConfig\\\", \\\"OS::TripleO::Services::NovaCompute\\\", \\\"OS::TripleO::Services::NovaLibvirt\\\", \\\"OS::TripleO::Services::NovaLibvirtGuests\\\", \\\"OS::TripleO::Services::NovaMigrationTarget\\\", \\\"OS::TripleO::Services::ContainersLogrotateCrond\\\", \\\"OS::TripleO::Services::NeutronMetadataAgent\\\", \\\"OS::TripleO::Services::NovaConductor\\\", \\\"OS::TripleO::Services::NovaMetadata\\\", \\\"OS::TripleO::Services::NovaVncProxy\\\", \\\"OS::TripleO::Services::OVNController\\\", \\\"OS::TripleO::Services::OVNMetadataAgent\\\", \\\"OS::TripleO::Services::Pacemaker\\\", \\\"OS::TripleO::Services::OsloMessagingRpc\\\", \\\"OS::TripleO::Services::Podman\\\", \\\"OS::TripleO::Services::Ptp\\\", \\\"OS::TripleO::Services::Rhsm\\\", \\\"OS::TripleO::Services::Rsyslog\\\", \\\"OS::TripleO::Services::RsyslogSidecar\\\", \\\"OS::TripleO::Services::Securetty\\\", \\\"OS::TripleO::Services::Snmp\\\", \\\"OS::TripleO::Services::Sshd\\\", \\\"OS::TripleO::Services::Timesync\\\", \\\"OS::TripleO::Services::Timezone\\\", \\\"OS::TripleO::Services::TripleoFirewall\\\", \\\"OS::TripleO::Services::TripleoPackages\\\", \\\"OS::TripleO::Services::Tuned\\\", \\\"OS::TripleO::Services::Vpp\\\"], \\\"CellControllerComputeParameters\\\": {}, \\\"CellControllerComputeExtraConfig\\\": {}, \\\"CellControllerComputeExtraGroupVars\\\": {}, \\\"ComputeServices\\\": [\\\"OS::TripleO::Services::Aide\\\", \\\"OS::TripleO::Services::AuditD\\\", \\\"OS::TripleO::Services::BootParams\\\", \\\"OS::TripleO::Services::CACerts\\\", \\\"OS::TripleO::Services::CephClient\\\", \\\"OS::TripleO::Services::CephExternal\\\", \\\"OS::TripleO::Services::Collectd\\\", \\\"OS::TripleO::Services::ComputeCeilometerAgent\\\", \\\"OS::TripleO::Services::CeilometerAgentIpmi\\\", \\\"OS::TripleO::Services::ComputeNeutronCorePlugin\\\", \\\"OS::TripleO::Services::ComputeNeutronL3Agent\\\", \\\"OS::TripleO::Services::ComputeNeutronMetadataAgent\\\", \\\"OS::TripleO::Services::ComputeNeutronOvsAgent\\\", \\\"OS::TripleO::Services::Frr\\\", \\\"OS::TripleO::Services::IpaClient\\\", \\\"OS::TripleO::Services::Ipsec\\\", \\\"OS::TripleO::Services::Iscsid\\\", \\\"OS::TripleO::Services::Kernel\\\", \\\"OS::TripleO::Services::LoginDefs\\\", \\\"OS::TripleO::Services::MetricsQdr\\\", \\\"OS::TripleO::Services::Multipathd\\\", \\\"OS::TripleO::Services::MySQLClient\\\", \\\"OS::TripleO::Services::NeutronBgpVpnBagpipe\\\", \\\"OS::TripleO::Services::NeutronLinuxbridgeAgent\\\", \\\"OS::TripleO::Services::NeutronVppAgent\\\", \\\"OS::TripleO::Services::NovaAZConfig\\\", \\\"OS::TripleO::Services::NovaCompute\\\", \\\"OS::TripleO::Services::NovaLibvirt\\\", \\\"OS::TripleO::Services::NovaLibvirtGuests\\\", \\\"OS::TripleO::Services::NovaMigrationTarget\\\", \\\"OS::TripleO::Services::ContainersLogrotateCrond\\\", \\\"OS::TripleO::Services::Podman\\\", \\\"OS::TripleO::Services::Rhsm\\\", \\\"OS::TripleO::Services::Rsyslog\\\", \\\"OS::TripleO::Services::RsyslogSidecar\\\", \\\"OS::TripleO::Services::Securetty\\\", \\\"OS::TripleO::Services::Snmp\\\", \\\"OS::TripleO::Services::Sshd\\\", \\\"OS::TripleO::Services::Timesync\\\", \\\"OS::TripleO::Services::Timezone\\\", \\\"OS::TripleO::Services::TripleoFirewall\\\", \\\"OS::TripleO::Services::TripleoPackages\\\", \\\"OS::TripleO::Services::Tuned\\\", \\\"OS::TripleO::Services::Vpp\\\", \\\"OS::TripleO::Services::OVNController\\\", \\\"OS::TripleO::Services::OVNMetadataAgent\\\"], \\\"ComputeParameters\\\": {}, \\\"ComputeExtraConfig\\\": {}, \\\"ComputeExtraGroupVars\\\": {}, \\\"BlockStorageServices\\\": [\\\"OS::TripleO::Services::Aide\\\", \\\"OS::TripleO::Services::AuditD\\\", \\\"OS::TripleO::Services::BlockStorageCinderVolume\\\", \\\"OS::TripleO::Services::BootParams\\\", \\\"OS::TripleO::Services::CACerts\\\", \\\"OS::TripleO::Services::Collectd\\\", \\\"OS::TripleO::Services::Frr\\\", \\\"OS::TripleO::Services::IpaClient\\\", \\\"OS::TripleO::Services::Ipsec\\\", \\\"OS::TripleO::Services::Iscsid\\\", \\\"OS::TripleO::Services::Kernel\\\", \\\"OS::TripleO::Services::LoginDefs\\\", \\\"OS::TripleO::Services::MetricsQdr\\\", \\\"OS::TripleO::Services::Multipathd\\\", \\\"OS::TripleO::Services::MySQLClient\\\", \\\"OS::TripleO::Services::ContainersLogrotateCrond\\\", \\\"OS::TripleO::Services::Podman\\\", \\\"OS::TripleO::Services::Rhsm\\\", \\\"OS::TripleO::Services::Rsyslog\\\", \\\"OS::TripleO::Services::RsyslogSidecar\\\", \\\"OS::TripleO::Services::Securetty\\\", \\\"OS::TripleO::Services::Snmp\\\", \\\"OS::TripleO::Services::Sshd\\\", \\\"OS::TripleO::Services::Timesync\\\", \\\"OS::TripleO::Services::Timezone\\\", \\\"OS::TripleO::Services::TripleoFirewall\\\", \\\"OS::TripleO::Services::TripleoPackages\\\", \\\"OS::TripleO::Services::Tuned\\\"], \\\"BlockStorageParameters\\\": {}, \\\"BlockStorageExtraConfig\\\": {}, \\\"BlockStorageExtraGroupVars\\\": {}, \\\"ObjectStorageServices\\\": [\\\"OS::TripleO::Services::Aide\\\", \\\"OS::TripleO::Services::AuditD\\\", \\\"OS::TripleO::Services::BootParams\\\", \\\"OS::TripleO::Services::CACerts\\\", \\\"OS::TripleO::Services::Collectd\\\", \\\"OS::TripleO::Services::Frr\\\", \\\"OS::TripleO::Services::IpaClient\\\", \\\"OS::TripleO::Services::Ipsec\\\", \\\"OS::TripleO::Services::Kernel\\\", \\\"OS::TripleO::Services::LoginDefs\\\", \\\"OS::TripleO::Services::MetricsQdr\\\", \\\"OS::TripleO::Services::MySQLClient\\\", \\\"OS::TripleO::Services::ContainersLogrotateCrond\\\", \\\"OS::TripleO::Services::Podman\\\", \\\"OS::TripleO::Services::Rhsm\\\", \\\"OS::TripleO::Services::Rsyslog\\\", \\\"OS::TripleO::Services::RsyslogSidecar\\\", \\\"OS::TripleO::Services::Securetty\\\", \\\"OS::TripleO::Services::Snmp\\\", \\\"OS::TripleO::Services::Sshd\\\", \\\"OS::TripleO::Services::SwiftRingBuilder\\\", \\\"OS::TripleO::Services::SwiftStorage\\\", \\\"OS::TripleO::Services::Timesync\\\", \\\"OS::TripleO::Services::Timezone\\\", \\\"OS::TripleO::Services::TripleoFirewall\\\", \\\"OS::TripleO::Services::TripleoPackages\\\", \\\"OS::TripleO::Services::Tuned\\\", \\\"OS::TripleO::Services::Ptp\\\"], \\\"ObjectStorageParameters\\\": {}, \\\"ObjectStorageExtraConfig\\\": {}, \\\"ObjectStorageExtraGroupVars\\\": {}, \\\"CephStorageServices\\\": [\\\"OS::TripleO::Services::Aide\\\", \\\"OS::TripleO::Services::AuditD\\\", \\\"OS::TripleO::Services::BootParams\\\", \\\"OS::TripleO::Services::CACerts\\\", \\\"OS::TripleO::Services::CephOSD\\\", \\\"OS::TripleO::Services::Collectd\\\", \\\"OS::TripleO::Services::Frr\\\", \\\"OS::TripleO::Services::IpaClient\\\", \\\"OS::TripleO::Services::Ipsec\\\", \\\"OS::TripleO::Services::Kernel\\\", \\\"OS::TripleO::Services::LoginDefs\\\", \\\"OS::TripleO::Services::MetricsQdr\\\", \\\"OS::TripleO::Services::MySQLClient\\\", \\\"OS::TripleO::Services::ContainersLogrotateCrond\\\", \\\"OS::TripleO::Services::Podman\\\", \\\"OS::TripleO::Services::Rhsm\\\", \\\"OS::TripleO::Services::Rsyslog\\\", \\\"OS::TripleO::Services::RsyslogSidecar\\\", \\\"OS::TripleO::Services::Securetty\\\", \\\"OS::TripleO::Services::Snmp\\\", \\\"OS::TripleO::Services::Sshd\\\", \\\"OS::TripleO::Services::Timesync\\\", \\\"OS::TripleO::Services::Timezone\\\", \\\"OS::TripleO::Services::TripleoFirewall\\\", \\\"OS::TripleO::Services::TripleoPackages\\\", \\\"OS::TripleO::Services::Tuned\\\"], \\\"CephStorageParameters\\\": {}, \\\"CephStorageExtraConfig\\\": {}, \\\"CephStorageExtraGroupVars\\\": {}, \\\"NetworkerServices\\\": [\\\"OS::TripleO::Services::Aide\\\", \\\"OS::TripleO::Services::AuditD\\\", \\\"OS::TripleO::Services::BootParams\\\", \\\"OS::TripleO::Services::CACerts\\\", \\\"OS::TripleO::Services::Collectd\\\", \\\"OS::TripleO::Services::Frr\\\", \\\"OS::TripleO::Services::IpaClient\\\", \\\"OS::TripleO::Services::Ipsec\\\", \\\"OS::TripleO::Services::IronicNeutronAgent\\\", \\\"OS::TripleO::Services::Kernel\\\", \\\"OS::TripleO::Services::LoginDefs\\\", \\\"OS::TripleO::Services::MetricsQdr\\\", \\\"OS::TripleO::Services::MySQLClient\\\", \\\"OS::TripleO::Services::NeutronDhcpAgent\\\", \\\"OS::TripleO::Services::NeutronL2gwAgent\\\", \\\"OS::TripleO::Services::NeutronL3Agent\\\", \\\"OS::TripleO::Services::NeutronMetadataAgent\\\", \\\"OS::TripleO::Services::NeutronOvsAgent\\\", \\\"OS::TripleO::Services::NeutronVppAgent\\\", \\\"OS::TripleO::Services::ContainersLogrotateCrond\\\", \\\"OS::TripleO::Services::OctaviaDeploymentConfig\\\", \\\"OS::TripleO::Services::OctaviaHealthManager\\\", \\\"OS::TripleO::Services::OctaviaHousekeeping\\\", \\\"OS::TripleO::Services::OctaviaWorker\\\", \\\"OS::TripleO::Services::OVNController\\\", \\\"OS::TripleO::Services::OVNMetadataAgent\\\", \\\"OS::TripleO::Services::Podman\\\", \\\"OS::TripleO::Services::Rhsm\\\", \\\"OS::TripleO::Services::Rsyslog\\\", \\\"OS::TripleO::Services::Snmp\\\", \\\"OS::TripleO::Services::Sshd\\\", \\\"OS::TripleO::Services::Timesync\\\", \\\"OS::TripleO::Services::Timezone\\\", \\\"OS::TripleO::Services::TripleoFirewall\\\", \\\"OS::TripleO::Services::TripleoPackages\\\", \\\"OS::TripleO::Services::Tuned\\\"], \\\"NetworkerParameters\\\": {}, \\\"NetworkerExtraConfig\\\": {}, \\\"NetworkerExtraGroupVars\\\": {}, \\\"ServiceNetMap\\\": {\\\"ApacheNetwork\\\": \\\"internal_api\\\", \\\"NeutronTenantNetwork\\\": \\\"tenant\\\", \\\"AodhApiNetwork\\\": \\\"internal_api\\\", \\\"BarbicanApiNetwork\\\": \\\"internal_api\\\", \\\"GnocchiApiNetwork\\\": \\\"internal_api\\\", \\\"MongodbNetwork\\\": \\\"internal_api\\\", \\\"CinderApiNetwork\\\": \\\"internal_api\\\", \\\"CinderIscsiNetwork\\\": \\\"storage\\\", \\\"GlanceApiNetwork\\\": \\\"internal_api\\\", \\\"GlanceApiEdgeNetwork\\\": \\\"internal_api\\\", \\\"GlanceApiInternalNetwork\\\": \\\"internal_api\\\", \\\"IronicApiNetwork\\\": \\\"ctlplane\\\", \\\"IronicNetwork\\\": \\\"ctlplane\\\", \\\"IronicInspectorNetwork\\\": \\\"ctlplane\\\", \\\"KeystoneAdminApiNetwork\\\": \\\"ctlplane\\\", \\\"KeystonePublicApiNetwork\\\": \\\"internal_api\\\", \\\"ManilaApiNetwork\\\": \\\"internal_api\\\", \\\"NeutronApiNetwork\\\": \\\"internal_api\\\", \\\"OctaviaApiNetwork\\\": \\\"internal_api\\\", \\\"HeatApiNetwork\\\": \\\"internal_api\\\", \\\"HeatApiCfnNetwork\\\": \\\"internal_api\\\", \\\"HeatApiCloudwatchNetwork\\\": \\\"internal_api\\\", \\\"NovaApiNetwork\\\": \\\"internal_api\\\", \\\"PlacementNetwork\\\": \\\"internal_api\\\", \\\"NovaMetadataNetwork\\\": \\\"internal_api\\\", \\\"NovaLibvirtNetwork\\\": \\\"internal_api\\\", \\\"NovajoinNetwork\\\": \\\"internal_api\\\", \\\"SwiftStorageNetwork\\\": \\\"storage_mgmt\\\", \\\"SwiftProxyNetwork\\\": \\\"storage\\\", \\\"HorizonNetwork\\\": \\\"internal_api\\\", \\\"MemcachedNetwork\\\": \\\"internal_api\\\", \\\"OsloMessagingRpcNetwork\\\": \\\"internal_api\\\", \\\"OsloMessagingNotifyNetwork\\\": \\\"internal_api\\\", \\\"RabbitmqNetwork\\\": \\\"internal_api\\\", \\\"RabbitmqManagementNetwork\\\": \\\"internal_api\\\", \\\"QdrNetwork\\\": \\\"internal_api\\\", \\\"RedisNetwork\\\": \\\"internal_api\\\", \\\"GaneshaNetwork\\\": \\\"external\\\", \\\"MysqlNetwork\\\": \\\"internal_api\\\", \\\"SnmpdNetwork\\\": \\\"ctlplane\\\", \\\"CephClusterNetwork\\\": \\\"storage_mgmt\\\", \\\"CephDashboardNetwork\\\": \\\"ctlplane\\\", \\\"CephGrafanaNetwork\\\": \\\"storage\\\", \\\"CephMonNetwork\\\": \\\"storage\\\", \\\"CephRgwNetwork\\\": \\\"storage\\\", \\\"PublicNetwork\\\": \\\"external\\\", \\\"InternalApiNetwork\\\": \\\"internal_api\\\", \\\"OpendaylightApiNetwork\\\": \\\"internal_api\\\", \\\"OvnDbsNetwork\\\": \\\"internal_api\\\", \\\"DockerRegistryNetwork\\\": \\\"ctlplane\\\", \\\"PacemakerNetwork\\\": \\\"internal_api\\\", \\\"PacemakerRemoteNetwork\\\": \\\"internal_api\\\", \\\"DesignateApiNetwork\\\": \\\"internal_api\\\", \\\"DesignateMdnsNetwork\\\": \\\"internal_api\\\", \\\"DesignateWorkerNetwork\\\": \\\"external\\\", \\\"DesignateBindNetwork\\\": \\\"external\\\", \\\"BINDNetwork\\\": \\\"external\\\", \\\"EtcdNetwork\\\": \\\"internal_api\\\", \\\"HaproxyNetwork\\\": \\\"ctlplane\\\", \\\"UnboundNetwork\\\": \\\"external\\\", \\\"ControllerHostnameResolveNetwork\\\": \\\"internal_api\\\", \\\"ControllerMetricsQdrNetwork\\\": \\\"internal_api\\\", \\\"CellControllerHostnameResolveNetwork\\\": \\\"internal_api\\\", \\\"CellControllerMetricsQdrNetwork\\\": \\\"internal_api\\\", \\\"CellControllerComputeHostnameResolveNetwork\\\": \\\"internal_api\\\", \\\"CellControllerComputeMetricsQdrNetwork\\\": \\\"internal_api\\\", \\\"ComputeHostnameResolveNetwork\\\": \\\"internal_api\\\", \\\"ComputeMetricsQdrNetwork\\\": \\\"internal_api\\\", \\\"BlockStorageHostnameResolveNetwork\\\": \\\"internal_api\\\", \\\"BlockStorageMetricsQdrNetwork\\\": \\\"internal_api\\\", \\\"ObjectStorageHostnameResolveNetwork\\\": \\\"internal_api\\\", \\\"ObjectStorageMetricsQdrNetwork\\\": \\\"internal_api\\\", \\\"CephStorageHostnameResolveNetwork\\\": \\\"storage\\\", \\\"CephStorageMetricsQdrNetwork\\\": \\\"storage\\\", \\\"NetworkerHostnameResolveNetwork\\\": \\\"internal_api\\\", \\\"NetworkerMetricsQdrNetwork\\\": \\\"internal_api\\\"}, \\\"VipSubnetMap\\\": {\\\"ctlplane\\\": \\\"ctlplane-subnet\\\", \\\"Storage\\\": \\\"storage_subnet\\\", \\\"StorageMgmt\\\": \\\"storage_mgmt_subnet\\\", \\\"InternalApi\\\": \\\"internal_api_subnet\\\", \\\"External\\\": \\\"external_subnet\\\", \\\"redis\\\": \\\"internal_api_subnet\\\", \\\"ovn_dbs\\\": \\\"internal_api_subnet\\\"}, \\\"SshServerOptions\\\": {\\\"HostKey\\\": [\\\"/etc/ssh/ssh_host_rsa_key\\\", \\\"/etc/ssh/ssh_host_ecdsa_key\\\", \\\"/etc/ssh/ssh_host_ed25519_key\\\"], \\\"SyslogFacility\\\": \\\"AUTHPRIV\\\", \\\"AuthorizedKeysFile\\\": \\\".ssh/authorized_keys\\\", \\\"ChallengeResponseAuthentication\\\": \\\"no\\\", \\\"GSSAPIAuthentication\\\": \\\"no\\\", \\\"GSSAPICleanupCredentials\\\": \\\"no\\\", \\\"UsePAM\\\": \\\"yes\\\", \\\"UseDNS\\\": \\\"no\\\", \\\"PrintMotd\\\": \\\"no\\\", \\\"X11Forwarding\\\": \\\"yes\\\", \\\"AcceptEnv\\\": [\\\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\\\", \\\"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\\\", \\\"LC_IDENTIFICATION LC_ALL LANGUAGE\\\", \\\"XMODIFIERS\\\"], \\\"Subsystem\\\": \\\"sftp  /usr/libexec/openssh/sftp-server\\\"}}}\", \"file:///home/zuul/hostnamemap.yaml\": \"{\\\"parameter_defaults\\\": {\\\"HostnameMap\\\": {\\\"overcloud-controller-0\\\": \\\"np0000071537\\\", \\\"cell1-controller-0\\\": \\\"np0000071538\\\", \\\"cell1-compute-0\\\": \\\"np0000071539\\\", \\\"cell2-controller-compute-0\\\": \\\"np0000071540\\\"}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/environments/docker-ha.yaml\": \"{\\\"resource_registry\\\": {\\\"OS::TripleO::Services::Pacemaker\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\\\", \\\"OS::TripleO::Services::PacemakerRemote\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\\\", \\\"OS::TripleO::Tasks::ControllerPreConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Tasks::ControllerPostConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::CinderVolume\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\\\", \\\"OS::TripleO::Services::Clustercheck\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\\\", \\\"OS::TripleO::Services::HAproxy\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\\\", \\\"OS::TripleO::Services::MySQL\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\\\", \\\"OS::TripleO::Services::OsloMessagingRpc\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\\\", \\\"OS::TripleO::Services::OsloMessagingNotify\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\\\"}, \\\"parameter_defaults\\\": {\\\"ContainerCli\\\": \\\"podman\\\", \\\"ClusterFullTag\\\": true}}\", \"file:///home/zuul/containers-prepare-parameters.yaml\": \"{\\\"parameter_defaults\\\": {\\\"ContainerImagePrepare\\\": [{\\\"set\\\": {\\\"ceph_alertmanager_image\\\": \\\"ose-prometheus-alertmanager\\\", \\\"ceph_alertmanager_namespace\\\": \\\"registry.redhat.io/openshift4\\\", \\\"ceph_alertmanager_tag\\\": \\\"v4.12\\\", \\\"ceph_grafana_image\\\": \\\"rhceph-6-dashboard-rhel9\\\", \\\"ceph_grafana_namespace\\\": \\\"registry.redhat.io/rhceph\\\", \\\"ceph_grafana_tag\\\": \\\"latest\\\", \\\"ceph_image\\\": \\\"rhceph-7-rhel9\\\", \\\"ceph_namespace\\\": \\\"registry.redhat.io/rhceph\\\", \\\"ceph_node_exporter_image\\\": \\\"ose-prometheus-node-exporter\\\", \\\"ceph_node_exporter_namespace\\\": \\\"registry.redhat.io/openshift4\\\", \\\"ceph_node_exporter_tag\\\": \\\"v4.12\\\", \\\"ceph_prometheus_image\\\": \\\"ose-prometheus\\\", \\\"ceph_prometheus_namespace\\\": \\\"registry.redhat.io/openshift4\\\", \\\"ceph_prometheus_tag\\\": \\\"v4.12\\\", \\\"ceph_tag\\\": \\\"latest\\\", \\\"name_prefix\\\": \\\"openstack-\\\", \\\"name_suffix\\\": \\\"\\\", \\\"namespace\\\": \\\"registry.redhat.io/rhosp-rhel9\\\", \\\"neutron_driver\\\": \\\"ovn\\\", \\\"rhel_containers\\\": false, \\\"tag\\\": \\\"17.1\\\"}, \\\"tag_from_label\\\": \\\"{version}-{release}\\\"}]}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/environments/podman.yaml\": \"{\\\"resource_registry\\\": {\\\"OS::TripleO::Services::Docker\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Services::Podman\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\\\"}, \\\"parameter_defaults\\\": {\\\"ContainerCli\\\": \\\"podman\\\"}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/environments/low-memory-usage.yaml\": \"{\\\"parameter_defaults\\\": {\\\"CinderWorkers\\\": 1, \\\"GlanceWorkers\\\": 1, \\\"HeatWorkers\\\": 1, \\\"KeystoneWorkers\\\": 1, \\\"NeutronWorkers\\\": 1, \\\"NeutronMetadataWorkers\\\": 1, \\\"NovaWorkers\\\": 1, \\\"NovaSchedulerWorkers\\\": 1, \\\"SwiftWorkers\\\": 1, \\\"PlacementWorkers\\\": 1, \\\"GnocchiMetricdWorkers\\\": 1, \\\"ApacheMaxRequestWorkers\\\": 100, \\\"ApacheServerLimit\\\": 100, \\\"ControllerExtraConfig\\\": {\\\"nova::network::neutron::timeout\\\": \\\"60\\\"}, \\\"DatabaseSyncTimeout\\\": 900, \\\"NovaReservedHostMemory\\\": 512, \\\"MysqlInnodbBufferPoolSize\\\": \\\"128M\\\"}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/environments/debug.yaml\": \"{\\\"parameter_defaults\\\": {\\\"Debug\\\": true}}\", \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\": \"#!/usr/bin/bash\\n# Copyright 2018 Red Hat Inc.\\n#\\n# Licensed under the Apache License, Version 2.0 (the \\\"License\\\"); you may\\n# not use this file except in compliance with the License. You may obtain\\n# a copy of the License at\\n#\\n#      http://www.apache.org/licenses/LICENSE-2.0\\n#\\n# Unless required by applicable law or agreed to in writing, software\\n# distributed under the License is distributed on an \\\"AS IS\\\" BASIS, WITHOUT\\n# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the\\n# License for the specific language governing permissions and limitations\\n# under the License.\\n#\\n# Usage: pyshim.sh <script and/or arguments>\\n#\\n# Unfortunately THT doesn\'t know which version of python might be in a\\n# container so we need this script to be able to try python3 or python2\\n# depending on availability.  Since this is a temporary shim until we\'ve\\n# fully cut over to python3, we check for the existence of python3 first\\n# before falling back to python2. This will help in the transition from\\n# python2 based containers to python3.\\n\\nshow_usage() {\\n    echo \\\"Usage: pyshim.sh <script and/or arguments>\\\"\\n}\\n\\nif [ $# -lt 1 ]\\nthen\\n    show_usage\\n    exit 1\\nfi\\n\\nset -x\\nif command -v python3 >/dev/null; then\\n    python3 \\\"$@\\\"\\nelif command -v python2 >/dev/null; then\\n    python2 \\\"$@\\\"\\nelif command -v python >/dev/null; then\\n    python \\\"$@\\\"\\nelse\\n    echo \\\"ERROR: python is not available!\\\"\\n    exit 1\\nfi\\n\", \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\": \"#!/usr/bin/bash\\n\\nset -u\\n\\n# ./pacemaker_restart_bundle.sh mysql galera galera-bundle Master _\\n# ./pacemaker_restart_bundle.sh redis redis redis-bundle Slave Master\\n# ./pacemaker_restart_bundle.sh ovn_dbs ovndb_servers ovn-dbs-bundle Slave Master\\nRESTART_SCRIPTS_DIR=$(dirname $0)\\nTRIPLEO_SERVICE=$1\\nRESOURCE_NAME=$2\\nBUNDLE_NAME=$3\\nWAIT_TARGET_LOCAL=$4\\nWAIT_TARGET_ANYWHERE=${5:-_}\\nTRIPLEO_MINOR_UPDATE=\\\"${TRIPLEO_MINOR_UPDATE:-false}\\\"\\nTRIPLEO_HA_WRAPPER_RESOURCE_EXISTS=\\\"${TRIPLEO_HA_WRAPPER_RESOURCE_EXISTS:-false}\\\"\\n\\nbundle_can_be_restarted() {\\n    local bundle=$1\\n    # As long as the resource bundle is managed by pacemaker and is\\n    # not meant to stay stopped, no matter the state of any inner\\n    # pcmk_remote or ocf resource, we should restart it to give it a\\n    # chance to read the new config.\\n    [ \\\"$(crm_resource --meta -r $1 -g is-managed 2>/dev/null)\\\" != \\\"false\\\" ] && \\\\\\n    [ \\\"$(crm_resource --meta -r $1 -g target-role 2>/dev/null)\\\" != \\\"Stopped\\\" ]\\n}\\n\\nlog() {\\n    local msg=$1\\n    logger -t pcmkrestart \\\"$1\\\"\\n}\\n\\nHOSTNAME=$(/bin/hostname -s)\\nif [ x\\\"${TRIPLEO_MINOR_UPDATE,,}\\\" != x\\\"true\\\" ]; then\\n    if [ x\\\"${TRIPLEO_HA_WRAPPER_RESOURCE_EXISTS,,}\\\" = x\\\"false\\\" ]; then\\n        # Do not restart during initial deployment, as the resource\\n        # has just been created.\\n        SERVICE_NODEID=$(/bin/hiera -c /etc/puppet/hiera.yaml \\\"${TRIPLEO_SERVICE}_short_bootstrap_node_name\\\")\\n        if [[ \\\"${HOSTNAME,,}\\\" == \\\"${SERVICE_NODEID,,}\\\" ]]; then\\n            log \\\"Initial deployment, skipping the restart of ${BUNDLE_NAME}\\\"\\n\\tfi\\n        exit 0\\n    else\\n        # During a stack update, this script is called in parallel on\\n        # every node the resource runs on, after the service\'s configs\\n        # have been updated on all nodes. So we need to run pcs only\\n        # once (e.g. on the service\'s boostrap node).\\n        if bundle_can_be_restarted ${BUNDLE_NAME}; then\\n            SERVICE_NODEID=$(/bin/hiera -c /etc/puppet/hiera.yaml \\\"${TRIPLEO_SERVICE}_short_bootstrap_node_name\\\")\\n            if [[ \\\"${HOSTNAME,,}\\\" == \\\"${SERVICE_NODEID,,}\\\" ]]; then\\n                replicas_running=$(crm_resource -Q -r $BUNDLE_NAME --locate 2>&1 | wc -l)\\n                if [ \\\"$replicas_running\\\" != \\\"0\\\" ]; then\\n                    log \\\"Restarting ${BUNDLE_NAME} globally. Stopping:\\\"\\n                    /sbin/pcs resource disable --wait=__PCMKTIMEOUT__ $BUNDLE_NAME\\n                    log \\\"Restarting ${BUNDLE_NAME} globally. Starting:\\\"\\n                    /sbin/pcs resource enable --wait=__PCMKTIMEOUT__ $BUNDLE_NAME\\n                else\\n                    log \\\"${BUNDLE_NAME} is not running anywhere,\\\" \\\\\\n                         \\\"cleaning up to restart it globally if necessary\\\"\\n                    /sbin/pcs resource cleanup $BUNDLE_NAME\\n                fi\\n            else\\n                log \\\"Skipping global restart of ${BUNDLE_NAME} on ${HOSTNAME} it will be restarted by node ${SERVICE_NODEID}\\\"\\n            fi\\n\\n        else\\n            log \\\"No global restart needed for ${BUNDLE_NAME}.\\\"\\n        fi\\n    fi\\nelse\\n    # During a minor update workflow however, a host gets fully\\n    # updated before updating the next one. So unlike stack\\n    # update, at the time this script is called, the service\'s\\n    # configs aren\'t updated on all nodes yet. So only restart the\\n    # resource locally, where it\'s guaranteed that the config is\\n    # up to date.\\n    HOST=$(facter hostname)\\n\\n    if bundle_can_be_restarted ${BUNDLE_NAME}; then\\n\\t# if the resource is running locally, restart it\\n\\tif crm_resource -r $BUNDLE_NAME --locate 2>&1 | grep -w -q \\\"${HOST}\\\"; then\\n            log \\\"Restarting ${BUNDLE_NAME} locally on \'${HOST}\'\\\"\\n            /sbin/pcs resource restart $BUNDLE_NAME \\\"${HOST}\\\"\\n\\n\\telse\\n\\t    # At this point, if no resource is running locally, it\'s\\n\\t    # either because a) it has failed previously, or b) because\\n\\t    # it\'s an A/P resource running elsewhere.\\n\\t    # By cleaning up resource, we ensure that a) it will try to\\n\\t    # restart, or b) it won\'t do anything if the resource is\\n\\t    # already running elsewhere.\\n            log \\\"${BUNDLE_NAME} is currently not running on \'${HOST}\',\\\" \\\\\\n                 \\\"cleaning up its state to restart it if necessary\\\"\\n            /sbin/pcs resource cleanup $BUNDLE_NAME node=\\\"${HOST}\\\"\\n\\tfi\\n\\n\\t# Wait until the resource is in the expected target state\\n\\t$RESTART_SCRIPTS_DIR/pacemaker_wait_bundle.sh \\\\\\n            $RESOURCE_NAME $BUNDLE_NAME \\\\\\n            \\\"$WAIT_TARGET_LOCAL\\\" \\\"$WAIT_TARGET_ANYWHERE\\\" \\\\\\n\\t    \\\"${HOST}\\\" __PCMKTIMEOUT__\\n    else\\n        log \\\"No restart needed for ${BUNDLE_NAME}.\\\"\\n    fi\\nfi\\n\", \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\": \"#!/usr/bin/bash\\n\\n# ----\\n# Wait for an OCF resource or a bundle to be restarted\\n# ----\\n# e.g.:\\n# M/S OCF:      $0 galera galera-bundle Master\\n# clone OCF:    $0 rabbitmq rabbitmq-bundle Started\\n# A/P M/S OCF:  $0 redis redis-bundle Slave Master\\n# A/P bundle:   $0 openstack-cinder-volume openstack-cinder-volume _ Started\\n# clone bundle: $0 haproxy-bundle haproxy-bundle Started\\n\\n# design note 1:\\n#  - this script is called during a minor update; it is called\\n#    once per node that hosts a service replica.\\n#  - the purpose of this script is to ensure that restarting the\\n#    service replica locally won\'t disrupt the service availability\\n#    for the end user. To reach that goal, the script waits until the\\n#    service is restarted locally or globallu and reaches a given\\n#    target state (i.e. Started, Slave or Master).\\n# design note 2:\\n#   - we don\'t want to track restart error: our only job is to ensure\\n#     service restart synchronization, not service health.\\n#   - In particular, we don\'t want to error out in case the resource\\n#     cannot be restarted locally, because that would make the minor\\n#     update fail, even if potentially other replicas still provide\\n#     the service.\\n# design note 3:\\n#   - we can bail out early if we determine that the resource can\'t\\n#     be restarted automatically by pacemaker (e.g. its \\\"blocked\\\",\\n#     unmanaged or disabled).\\n\\nlog() {\\n    local msg=$1\\n    echo \\\"$(date -u): $1\\\"\\n}\\n\\nusage() {\\n    echo 2>&1 \\\"Usage: $0 NAME BUNDLE_NAME ROLE_LOCAL [ROLE_ANYWHERE] [HOST] [TIMEOUT]\\\"\\n    exit 1\\n}\\n\\npacemaker_supports_promoted() {\\n    # The Promoted token is only matched in recent pacemaker versions\\n    grep -wq \\\"<value>Promoted</value>\\\" /usr/share/pacemaker/resources-*.rng\\n}\\n\\n#\\n# Utility functions to detect stuck resources\\n#\\n\\nbundle_failures_locally() {\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\n    local replicas=$BUNDLE_REPLICAS\\n    local last=$(($replicas - 1))\\n    local replica_name\\n    for i in $(seq 0 $last); do\\n\\treplica_name=${BUNDLE_NAME}-${engine}-${i}\\n\\tcrm_failcount -q -G -r $replica_name -N $HOST\\n    done\\n}\\n\\nbundle_failures_globally() {\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\n    local replicas=$BUNDLE_REPLICAS\\n    local last=$(($replicas - 1))\\n    for i in $(seq 0 $last); do\\n\\tcrm_failcount -q -G -r ${BUNDLE_NAME}-${engine}-${i}\\n    done\\n}\\n\\nbundle_running_globally() {\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\n    # return the number of running bundles replica, i.e. the number of\\n    # docker/podman resource replicas currently running in the cluster\\n    crm_mon --as-xml | xmllint --xpath \\\"count(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource[@resource_agent=\'${OCF}:heartbeat:${engine}\']/node)\\\" -\\n}\\n\\nocf_failures_globally() {\\n    local replicas=$BUNDLE_REPLICAS\\n    local last=$(($replicas - 1))\\n    local bundle_node\\n    for i in $(seq 0 $last); do\\n\\tbundle_node=${BUNDLE_NAME}-${i}\\n\\tcrm_failcount -q -G -r $NAME -N $bundle_node\\n    done\\n}\\n\\ndid_resource_failed_locally() {\\n    local failures\\n    local running\\n    local remotehost\\n    if [ \\\"${NAME}\\\" != \\\"${BUNDLE_NAME}\\\" ]; then\\n\\t# if we\'re dealing with an ocf resource, it is running on a\\n\\t# pacemaker_remote rather that on the real host, and the\\n\\t# failcounts are thus associated to the pcmk remote. Replace\\n\\t# the host\'s name with the pcmk remote\'s name.\\n        remotehost=$(crm_mon --as-xml | xmllint --xpath \\\"string(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource/node[@name=\'${HOST}\']/../../resource[@resource_agent=\'${OCF}:pacemaker:remote\']/@id)\\\" -)\\n\\tif [ -n \\\"${remotehost}\\\" ]; then\\n\\t    crm_failcount -q -G -r $NAME -N $remotehost | grep -q -w INFINITY\\n\\t    return $?\\n\\tfi\\n\\t# If no pcmk remote is currently running, the failcount from\\n\\t# the ocf resource is useless, compute the failcount from the\\n\\t# bundle case instead (computed below).\\n    fi\\n\\n    # for bundles, pacemaker can run any bundle replica locally\\n    # (e.g. galera-bundle-docker-{0,1,2}), and a failure happens when\\n    # there are no more replica to try.\\n    # That is, when _at least_ one replica failed locally, and all the\\n    # others either failed or are currently running elsewhere.\\n    failures=$(bundle_failures_locally $HOST | grep -c -w INFINITY)\\n    running=$(bundle_running_globally)\\n    test $failures -gt 0 && \\\\\\n    test $(( $failures + $running )) -ge $BUNDLE_REPLICAS\\n}\\n\\ndid_resource_failed_globally() {\\n    local remotecount\\n    local failures\\n    if [ \\\"${NAME}\\\" != \\\"${BUNDLE_NAME}\\\" ]; then\\n\\t# we check the state of an ocf resource only if the\\n\\t# pcmkremotes are started\\n        remotecount=$(crm_mon --as-xml | xmllint --xpath \\\"count(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource[@resource_agent=\'${OCF}:pacemaker:remote\']/node)\\\" -)\\n\\tif [ \\\"${remotecount}\\\" = \\\"0\\\" ]; then\\n\\t    # no pcmkremote is running, so check the bundle state\\n\\t    # instead of checking the ocf resource\\n\\t    # bundle failed if all ${BUNDLE_REPLICAS} replicas failed\\n\\t    failures=$(bundle_failures_globally | grep -c -w INFINITY)\\n\\t    test $failures -eq $BUNDLE_REPLICAS\\n\\telse\\n\\t    # ocf resource failed if it failed to start on\\n\\t    # all $BUNDLE_REPLICAS bundle nodes\\n\\t    failures=$(ocf_failures_globally | grep -c -w INFINITY)\\n\\t    test $failures -eq $BUNDLE_REPLICAS\\n\\tfi\\n    else\\n\\t# bundle failed if all ${BUNDLE_REPLICAS} replicas failed\\n\\tfailures=$(bundle_failures_globally | grep -c -w INFINITY)\\n\\ttest $failures -eq $BUNDLE_REPLICAS\\n    fi\\n}\\n\\n\\n# Input validation\\n#\\n\\nNAME=$1\\nif [ -z \\\"${NAME}\\\" ]; then\\n    echo 2>&1 \\\"Error: argument NAME must not be empty\\\"\\n    exit 1\\nfi\\n\\nBUNDLE_NAME=$2\\nif [ -z \\\"${BUNDLE_NAME}\\\" ]; then\\n    echo 2>&1 \\\"Error: argument BUNDLE_NAME must not be empty\\\"\\n    exit 1\\nfi\\n\\nROLE_LOCAL=$3\\nif [ \\\"${ROLE_LOCAL}\\\" = \\\"_\\\" ]; then\\n    ROLE_LOCAL=\\\"\\\"\\nfi\\n\\nROLE_ANYWHERE=$4\\nif [ \\\"${ROLE_ANYWHERE}\\\" = \\\"_\\\" ]; then\\n    ROLE_ANYWHERE=\\\"\\\"\\nfi\\n\\nif [ -z \\\"${ROLE_LOCAL}\\\" ]; then\\n    if [ -z \\\"${ROLE_ANYWHERE}\\\" ]; then\\n        echo 2>&1 \\\"Error: either ROLE_LOCAL or ROLE_ANYWHERE must be non empty\\\"\\n        exit 1\\n    fi\\nelse\\n    if !(echo \\\"${ROLE_LOCAL}\\\" | grep -q -x -E \\\"(Started|Slave|Master|Unpromoted|Promoted)\\\"); then\\n        echo 2>&1 \\\"Error: argument ROLE_LOCAL must be either \'Started\' \'Slave\' \'Master\' \'Unpromoted\' or \'Promoted\'\\\"\\n        exit 1\\n    fi\\nfi\\n\\nif [ -n \\\"${ROLE_ANYWHERE}\\\" ] && !(echo \\\"${ROLE_ANYWHERE}\\\" | grep -q -x -E \\\"(Started|Slave|Master|Unpromoted|Promoted)\\\"); then\\n    echo 2>&1 \\\"Error: argument ROLE_ANYWHERE must be either \'Started\' \'Slave\' \'Master\' \'Unpromoted\' or \'Promoted\'\\\"\\n    exit 1\\nfi\\n\\n# Ensure compatibility with pacemaker 2.1\\nif pacemaker_supports_promoted; then\\n    ROLE_LOCAL=$(echo \\\"$ROLE_LOCAL\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\n    ROLE_ANYWHERE=$(echo \\\"$ROLE_ANYWHERE\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\n    OCF=\\\"ocf\\\"\\nelse\\n    OCF=\\\"ocf:\\\"\\nfi\\n\\nHOST=${5:-$(facter hostname)}\\nTIMEOUT=${6:-__PCMKTIMEOUT__}\\n\\n\\n# Configure the search\\n# ----\\n# Note: we can\'t use crm_resource in all searches because we can\'t\\n# easily extract the host the OCF resources run on (crm_resource\\n# returns the pcmk-remote nodes rather than the hosts)\\n# So instead, we implement various searches with XPath directly.\\n\\nif [ \\\"${BUNDLE_NAME}\\\" != \\\"${NAME}\\\" ]; then\\n# ocf resource\\nlocal_resource_xpath=\\\"//bundle/replica/resource[@resource_agent=\'${OCF}:pacemaker:remote\']/node[@name=\'${HOST}\']/../../resource[@id=\'${NAME}\']\\\"\\nany_resource_xpath=\\\"//bundle//resource[@id=\'${NAME}\']\\\"\\nreplicas_xpath=\\\"//bundle/primitive[@id=\'${BUNDLE_NAME}\']/../*[boolean(@image) and boolean(@replicas)]\\\"\\nelse\\n# bundle resource\\nlocal_resource_xpath=\\\"//bundle[@id=\'${NAME}\']/replica/resource/node[@name=\'${HOST}\']/../../resource\\\"\\nany_resource_xpath=\\\"//bundle[@id=\'${NAME}\']//resource\\\"\\nreplicas_xpath=\\\"//bundle[@id=\'${BUNDLE_NAME}\']/*[boolean(@image) and boolean(@replicas)]\\\"\\nfi\\n\\nbundle_def_xpath=\\\"//bundle[@id=\'${BUNDLE_NAME}\']/*[boolean(@image) and boolean(@replicas)]\\\"\\nBUNDLE_CONTAINER_ENGINE=$(cibadmin -Q | xmllint --xpath \\\"name(${bundle_def_xpath})\\\" -)\\nBUNDLE_REPLICAS=$(cibadmin -Q | xmllint --xpath \\\"string(${bundle_def_xpath}/@replicas)\\\" -)\\n\\n\\n# The wait algorithm follows a two-stage approach\\n#  1. Depending on how the script is called, we first check whether\\n#     the resource is restarted locally. An A/P resource may be\\n#     restarted elsewhere in the cluster.\\n#  2. If needed, check whether the A/P resource has restarted\\n#     elsewhere. For A/P M/S resources, in case the resource is\\n#     restarted as Slave locally, ensure a Master is available.\\n\\nsuccess=1\\nbailout=1\\ntimeout=$TIMEOUT\\nrole=\\\"\\\"\\n\\n# Stage 1: local check\\nif [ -n \\\"$ROLE_LOCAL\\\" ]; then\\n    log \\\"Waiting until ${NAME} has restarted on ${HOST} and is in state ${ROLE_LOCAL}\\\"\\n    log \\\"Will probe resource state with the following XPath pattern: ${local_resource_xpath}\\\"\\n\\n    while [ $timeout -gt 0 ] && [ $bailout -ne 0 ] && [ $success -ne 0 ]; do\\n        resource=$(crm_mon -r --as-xml | xmllint --xpath \\\"${local_resource_xpath}\\\" - 2>/dev/null)\\n        role=$(echo \\\"${resource}\\\" | sed -ne \'s/.*\\\\Wrole=\\\"\\\\([^\\\"]*\\\\)\\\".*/\\\\1/p\')\\n\\n\\tif [ \\\"$(crm_resource --meta -r ${NAME} -g is-managed 2>/dev/null)\\\" = \\\"false\\\" ]; then\\n            log \\\"${NAME} is unmanaged, will never reach target role. Bailing out\\\"\\n            bailout=0\\n            continue\\n\\telif [ \\\"$(crm_resource --meta -r ${NAME} -g target-role 2>/dev/null)\\\" = \\\"Stopped\\\" ]; then\\n            log \\\"${NAME} is disabled, will never reach target role. Bailing out\\\"\\n            bailout=0\\n            continue\\n        elif echo \\\"${resource}\\\" | grep -q -w \\\"\\\\Wblocked=\\\\\\\"true\\\\\\\"\\\"; then\\n            log \\\"${NAME} is blocked, will never reach target role. Bailing out\\\"\\n            bailout=0\\n            continue\\n\\telif did_resource_failed_locally; then\\n            log \\\"${NAME} is in failed state, will never reach target role. Bailing out\\\"\\n            bailout=0\\n            continue\\n        elif [ \\\"$role\\\" = \\\"$ROLE_LOCAL\\\" ]; then\\n            success=0\\n            continue\\n        elif [ -n \\\"$ROLE_ANYWHERE\\\" ] && [ \\\"$role\\\" = \\\"$ROLE_ANYWHERE\\\" ]; then\\n            # A/P: we are restarted in the expected state\\n            success=0\\n            continue\\n        else\\n            log \\\"Waiting for ${NAME} to transition to role ${ROLE_LOCAL} on ${HOST}\\\"\\n        fi\\n\\n        if [ $bailout -ne 0 ] && [ $success -ne 0 ]; then\\n            sleep 4\\n            timeout=$((timeout-4))\\n        fi\\n    done\\nfi\\n\\n# Stage 2: global check\\nif [ $timeout -gt 0 ] && [ -n \\\"$ROLE_ANYWHERE\\\" ] && [ \\\"$role\\\" != \\\"$ROLE_ANYWHERE\\\" ]; then\\n    log \\\"Wait until ${NAME} is restarted anywhere in the cluster in state ${ROLE_ANYWHERE}\\\"\\n    log \\\"Will probe resource state with the following XPath pattern: ${any_resource_xpath}\\\"\\n\\n    success=1\\n    bailout=1\\n    while [ $timeout -gt 0 ] && [ $bailout -ne 0 ] && [ $success -ne 0 ]; do\\n        resources=$(crm_mon -r --as-xml | xmllint --xpath \\\"${any_resource_xpath}\\\" - 2>/dev/null)\\n\\tif [ \\\"$(crm_resource --meta -r ${NAME} -g is-managed 2>/dev/null)\\\" = \\\"false\\\" ]; then\\n            log \\\"${NAME} is unmanaged, will never reach target role. Bailing out\\\"\\n            bailout=0\\n            continue\\n\\telif [ \\\"$(crm_resource --meta -r ${NAME} -g target-role 2>/dev/null)\\\" = \\\"Stopped\\\" ]; then\\n            log \\\"${NAME} is disabled, will never reach target role. Bailing out\\\"\\n            bailout=0\\n            continue\\n        elif ! (echo \\\"${resources}\\\" | grep -q -w \\\"\\\\Wblocked=\\\\\\\"false\\\\\\\"\\\"); then\\n            log \\\"${NAME} blocked, will never reach target role. Bailing out\\\"\\n            bailout=0\\n            continue\\n\\telif did_resource_failed_globally; then\\n            log \\\"${NAME} is in failed state, will never reach target role. Bailing out\\\"\\n            bailout=0\\n            continue\\n        elif echo \\\"${resources}\\\" | grep -q -w \\\"\\\\Wrole=\\\\\\\"${ROLE_ANYWHERE}\\\\\\\"\\\"; then\\n            success=0\\n            continue\\n        else\\n            log \\\"Waiting for ${NAME} to transition to role ${ROLE_ANYWHERE} anywhere in the cluster\\\"\\n        fi\\n\\n        if [ $bailout -ne 0 ] && [ $success -ne 0 ]; then\\n            sleep 4\\n            timeout=$((timeout-4))\\n        fi\\n    done\\nfi\\n\\nif [ $timeout -le 0 ]; then\\n    log \\\"Timeout reached after ${TIMEOUT}s while waiting for ${NAME} to be restarted\\\"\\nelif [ $bailout -le 0 ]; then\\n    log \\\"Restart monitoring for ${NAME} cancelled\\\"\\nfi\\n\\nif [ $success -eq 0 ]; then\\n    log \\\"${NAME} successfully restarted\\\"\\nelse\\n    log \\\"${NAME} was not restarted properly\\\"\\nfi\\n\\n# Don\'t block minor update or stack update if the wait was unsuccessful\\nexit 0\\n\", \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\": \"#!/usr/bin/bash\\nset -eu\\n\\nHOST=$1\\nPORT=$2\\n\\necho \\\"$(date -u): Checking whether we can bind to ${HOST}:${PORT}\\\"\\nwhile (ss -Htnl src \\\"${HOST}\\\" \\\"sport = :${PORT}\\\" | grep -wq \\\"${PORT}\\\"); do\\n    echo \\\"$(date -u): ${HOST}:${PORT} still in use, waiting...\\\";\\n    sleep 10;\\ndone\\n\\nshift 2\\nCOMMAND=\\\"$*\\\"\\nif [ -z \\\"${COMMAND}\\\" ]; then\\n    COMMAND=\\\"true\\\"\\nfi\\nexec $COMMAND\\n\", \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\": \"#!/usr/bin/bash\\n\\nMAX_RETRIES=10\\nCIB_ENOTFOUND=105\\n\\nusage() {\\n   echo \\\"Set a global property in the cluster with a validity timestamp.\\\"\\n   echo \\\"Usage:\\\"\\n   echo \\\"   $0 --acquire <lock_name> <lock_owner> <lock_ttl_in_seconds>\\\"\\n   echo \\\"   $0 --release <lock_name> <lock_owner>\\\"\\n   echo\\n}\\n\\nlog() {\\n    echo \\\"$(date -u): $1\\\" 1>&2\\n}\\n\\nerror() {\\n    echo \\\"$(date -u): $1\\\" 1>&2\\n    exit 1\\n}\\n\\nlock_create() {\\n    local name=$1\\n    local data=$2\\n    # cibadmin won\'t overwrite a key if someone else succeeded to create it concurrently\\n    cibadmin --sync-call --scope crm_config --create --xml-text \\\"<cluster_property_set id=\'${name}\'><nvpair id=\'${name}-pair\' name=\'${name}\' value=\'${data}\'/></cluster_property_set>\\\" &>/dev/null\\n    return $?\\n}\\n\\nlock_update() {\\n    local name=$1\\n    local expected_data=$2\\n    local new_data=$3\\n    # we only update the lock we expect to see, so we can\'t update someone else\'s lock\\n    cibadmin --sync-call --scope crm_config --modify --xpath \\\"//cluster_property_set/nvpair[@name=\'${name}\' and @value=\'${expected_data}\']/..\\\" --xml-text \\\"<nvpair id=\'${name}-pair\' name=\'${name}\' value=\'${new_data}\'/>\\\" &>/dev/null\\n    return $?\\n}\\n\\nlock_delete() {\\n    local name=$1\\n    local expected_data=$2\\n    # we only delete the lock we expect to see, so we can\'t delete someone else\'s lock\\n    cibadmin --sync-call --scope crm_config --delete --xpath \\\"//cluster_property_set/nvpair[@name=\'${name}\' and @value=\'${expected_data}\']/..\\\" &>/dev/null\\n    return $?\\n}\\n\\nlock_get() {\\n    local lockname=$1\\n    local res\\n    local rc\\n    res=$(cibadmin --query --scope crm_config --xpath \\\"//cluster_property_set/nvpair[@name=\'$lockname\']\\\" 2>/dev/null)\\n    rc=$?\\n    if [ $rc -eq 0 ]; then\\n        echo \\\"$res\\\" | sed -n \'s/.*value=\\\"\\\\([^\\\"]*\\\\)\\\".*/\\\\1/p\'\\n    fi\\n    return $rc\\n}\\n\\nlock_owner() {\\n    local lock=$1\\n    echo \\\"$lock\\\" | cut -d\':\' -f1\\n}\\n\\nlock_has_expired() {\\n    local lock=$1\\n    local expiry=$(echo \\\"$lock\\\" | cut -d\':\' -f2)\\n    local now=$(date +%s)\\n    test $now -ge $expiry\\n}\\n\\n\\n# Perform a lock action and restart if the CIB has been modified before\\n# committing the lock action\\ntry_action() {\\n    local fun=$1\\n    local lock=$2\\n    local requester=$3\\n    local args=${4:-}\\n    local tries=$MAX_RETRIES\\n    local rc=1\\n    if [ \\\"$fun\\\" = \\\"lock_acquire\\\" ] || [ \\\"$fun\\\" = \\\"lock_release\\\" ]; then\\n        log \\\"Try running $fun\\\"\\n    else\\n        return 2\\n    fi\\n    while [ $rc -ne 0 ]; do\\n        $fun $lock $requester $args\\n        rc=$?\\n        if [ $rc -eq 0 ]; then\\n            log \\\"Operation $1 succeeded\\\"\\n            return 0\\n        elif [ $rc -eq 3 ]; then\\n            # rc == 3 -> CIB changed before push\\n            if [ $tries -eq 0 ]; then\\n                log \\\"Failed to commit after $MAX_RETRIES retries. Bailing out.\\\"\\n                return 2\\n            else\\n                log \\\"Failed to commit. Retrying operation.\\\"\\n                tries=$(($tries - 1))\\n            fi\\n        elif [ $rc -eq 2 ]; then\\n            # rc == 2 -> unrecoverable cib error (e.g. pacemaker down)\\n            log \\\"Unexpected failure. Bailing out\\\"\\n            return $rc\\n        else\\n            # rc == 1 -> lock error (not owner, lock doesn\'t exists)\\n            return $rc\\n        fi\\n    done\\n}\\n\\n# The lock mechanism uses cibadmin\'s atomic creation so cluster-wide\\n# state coherency is guaranteed by pacemaker\\nlock_acquire() {\\n    local lockname=$1\\n    local requester=$2\\n    local ttl=$3\\n    local rc\\n    local lock\\n    local expiry\\n    local owner\\n\\n    log \\\"Check whether the lock is already held in the CIB\\\"\\n    lock=$(lock_get $lockname)\\n    rc=$?\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\n        log \\\"Could not retrieve info from the CIB\\\"\\n        return 2\\n    fi\\n\\n    if [ -n \\\"$lock\\\" ]; then\\n        lock_has_expired $lock\\n        rc=$?\\n        if [ $rc -eq 0 ]; then\\n            log \\\"Lock has expired, now available for being held\\\"\\n        else\\n            # lock is still held. check whether we\'re the owner\\n            owner=$(lock_owner $lock)\\n            if [ \\\"$owner\\\" = \\\"$requester\\\" ];then\\n                log \\\"Requester already owns the lock, acquiring attempt will just reconfigure the TTL\\\"\\n            else\\n                log \\\"Lock is held by someone else ($owner)\\\"\\n                return 1\\n            fi\\n        fi\\n    else\\n        log \\\"Lock is not held yet\\\"\\n    fi\\n\\n    # prepare the lock info\\n    expiry=$(($(date +%s) + $ttl))\\n\\n    if [ -n \\\"$lock\\\" ]; then\\n        log \\\"Attempting to update the lock\\\"\\n        lock_update $lockname \\\"$lock\\\" \\\"$requester:$expiry\\\"\\n        rc=$?\\n    else\\n        log \\\"Attempting to acquire the lock\\\"\\n        lock_create $lockname \\\"$requester:$expiry\\\"\\n        rc=$?\\n    fi\\n\\n    if [ $rc -eq 0 ]; then\\n        log \\\"Lock \'$lockname\' acquired by \'$requester\', valid until $(date -d @$expiry)\\\"\\n        return 0\\n    else\\n        log \\\"CIB changed, lock cannot be acquired\\\"\\n        return 3\\n    fi\\n}\\n\\n\\n# The lock mechanism uses the CIB\'s num_updates tag to implement\\n# a conditional store. Cluster-wide locking is guaranteed by pacemaker\\nlock_release() {\\n    local lockname=$1\\n    local requester=$2\\n    local rc\\n    local lock\\n    local owner\\n\\n    log \\\"Check whether the lock is already held in the CIB\\\"\\n    lock=$(lock_get $lockname)\\n    rc=$?\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\n        log \\\"Could not retrieve info from the CIB\\\"\\n        return 2\\n    fi\\n\\n    if [ -z \\\"$lock\\\" ]; then\\n        log \\\"Lock doesn\'t exist. Nothing to release\\\"\\n        return 0\\n    else\\n        log \\\"Lock exists, check whether we\'re the owner\\\"\\n        owner=$(lock_owner $lock)\\n        if [ \\\"$owner\\\" != \\\"$requester\\\" ];then\\n            log \\\"Lock is held by someone else ($owner), will not unlock\\\"\\n            return 1\\n        fi\\n    fi\\n\\n    lock_delete $lockname \\\"$lock\\\"\\n    rc=$?\\n\\n    if [ $rc -eq 0 ]; then\\n        log \\\"Lock \'$lockname\' released by \'$requester\'\\\"\\n        return 0\\n    else\\n        log \\\"CIB deletion error, lock cannot be released\\\"\\n        return 3\\n    fi\\n}\\n\\n\\n# Retrieve the owner of a lock from the CIB\\n# this is a read-only operation, so no need to log debug info\\nlock_get_owner() {\\n    local lockname=$1\\n    local rc\\n    local lock\\n    local owner\\n\\n    lock=$(lock_get $lockname)\\n    rc=$?\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\n        return 2\\n    fi\\n\\n    if [ -z \\\"$lock\\\" ]; then\\n        return 1\\n    else\\n        lock_owner $lock\\n        return 0\\n    fi\\n}\\n\\n\\nACTION=$1\\nLOCKNAME=$2\\nREQUESTER=$3\\nTTL=${4:-60}\\n\\nif [ -z \\\"$ACTION\\\" ]; then\\n    error \\\"Action must be specified\\\"\\nfi\\n\\nif [ $ACTION != \\\"--help\\\" ]; then\\n    if [ -z \\\"$LOCKNAME\\\" ]; then\\n        error \\\"You must specific a lock name\\\"\\n    fi\\n    if [ $ACTION != \\\"--owner\\\" ] && [ $ACTION != \\\"-o\\\" ]; then\\n        if [ -z \\\"$REQUESTER\\\" ]; then\\n            error \\\"You must specific a lock requester\\\"\\n        fi\\n    fi\\nfi\\n\\ncase $ACTION in\\n    --help) usage; exit 0;;\\n    --acquire|-a) try_action lock_acquire $LOCKNAME $REQUESTER $TTL;;\\n    --release|-r) try_action lock_release $LOCKNAME $REQUESTER;;\\n    --acquire-once|-A) lock_acquire $LOCKNAME $REQUESTER $TTL;;\\n    --owner|-o) lock_get_owner $LOCKNAME;;\\n    *) error \\\"Invalid action\\\";;\\nesac\\nexit $?\\n\", \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\": \"#!/usr/bin/bash\\n\\n# pacemaker_mutex_restart_bundle.sh --lock mysql galera galera-bundle Master _\\n# pacemaker_mutex_restart_bundle.sh --lock ovn_dbs ovndb_servers ovn-dbs-bundle Slave Master\\n\\nset -u\\n\\nusage() {\\n    echo \\\"Restart a clustered resource in a coordinated way across the cluster\\\"\\n    echo \\\"Usage:\\\"\\n    echo \\\"   $0 --lock <tripleo-service> <pcmk-resource> <pcmk-bundle> <target-state-local> <target-state-cluster>\\\"\\n    echo\\n}\\n\\nlog() {\\n    echo \\\"$(date -u): $1\\\"\\n}\\n\\nerror() {\\n    echo \\\"$(date -u): $1\\\" 1>&2\\n    exit 1\\n}\\n\\npacemaker_supports_promoted() {\\n    # The Promoted token is only matched in recent pacemaker versions\\n    grep -wq \\\"<value>Promoted</value>\\\" /usr/share/pacemaker/resources-*.rng\\n}\\n\\nACTION=$1\\ncase $ACTION in\\n    --help) usage; exit 0;;\\n    --lock) ;;\\n    *) error \\\"Unknown action \'$ACTION\'\\\";;\\nesac\\n\\nTRIPLEO_SERVICE=$2\\nLOCK_NAME=${TRIPLEO_SERVICE}-restart-lock\\nLOCK_OWNER=$(crm_node -n 2>/dev/null)\\nrc=$?\\nif [ $rc -ne 0 ]; then\\n    if [ $rc -eq 102 ]; then\\n        log \\\"Cluster is not running locally, no need to restart resource $TRIPLEO_SERVICE\\\"\\n        exit 0\\n    else\\n        error \\\"Unexpected error while connecting to the cluster (rc: $rc), bailing out\\\"\\n    fi\\nfi\\n\\nRESOURCE_NAME=$3\\nBUNDLE_NAME=$4\\nWAIT_TARGET_LOCAL=$5\\nWAIT_TARGET_ANYWHERE=${6:-_}\\n\\nif pacemaker_supports_promoted; then\\n    WAIT_TARGET_LOCAL=$(echo \\\"$5\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\n    WAIT_TARGET_ANYWHERE=$(echo \\\"${6:-_}\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\n    promoted_role=\\\"Promoted\\\"\\nelse\\n    promoted_role=\\\"Master\\\"\\nfi\\n\\n# The lock TTL should accomodate for the resource start/promote timeout\\nif [ \\\"$RESOURCE_NAME\\\" != \\\"$BUNDLE_NAME\\\" ]; then\\n    if [ \\\"$WAIT_TARGET_LOCAL\\\" = \\\"$promoted_role\\\" ] || [ \\\"$WAIT_TARGET_ANYWHERE\\\" = \\\"$promoted_role\\\" ]; then\\n        rsc_op=\\\"promote\\\"\\n    else\\n        rsc_op=\\\"start\\\"\\n    fi\\n    # <op id=\\\"galera-promote-interval-0s\\\" interval=\\\"0s\\\" name=\\\"promote\\\" on-fail=\\\"block\\\" timeout=\\\"300s\\\"/>\\n    PCMK_TTL=$(cibadmin -Q | xmllint -xpath \\\"string(//primitive[@id=\'${RESOURCE_NAME}\']/operations/op[@name=\'${rsc_op}\']/@timeout)\\\" - | sed \'s/s$//\')\\n    LOCK_TTL=$((PCMK_TTL + 30))\\nelse\\n    # The podman RA\'s default start timeout\\n    LOCK_TTL=90\\nfi\\n\\nlog \\\"Acquire a ${LOCK_TTL}s restart lock for service $TRIPLEO_SERVICE before restarting it\\\"\\n# Loop until we hold the lock. The lock has a TTL, so we\'re guaranteed to get it eventually\\nrc=1\\nwhile [ $rc -ne 0 ]; do\\n    /var/lib/container-config-scripts/pacemaker_resource_lock.sh --acquire $LOCK_NAME $LOCK_OWNER $LOCK_TTL\\n    rc=$?\\n    if [ $rc != 0 ]; then\\n        if [ $rc -gt 1 ]; then\\n            error \\\"Could not acquire lock due to unrecoverable error (rc: $rc), bailing out\\\"\\n        else\\n            log \\\"Could not acquire lock, retrying\\\"\\n            sleep 10\\n        fi\\n    fi\\ndone\\n\\nlog \\\"Restart the service $TRIPLEO_SERVICE locally\\\"\\n# Reuse the local restart script in t-h-t (driven by env var TRIPLEO_MINOR_UPDATE)\\nTRIPLEO_MINOR_UPDATE=true /var/lib/container-config-scripts/pacemaker_restart_bundle.sh $TRIPLEO_SERVICE $RESOURCE_NAME $BUNDLE_NAME $WAIT_TARGET_LOCAL $WAIT_TARGET_ANYWHERE\\n\\n# If we reached this point, always try to release the lock\\nlog \\\"Release the restart lock for service $TRIPLEO_SERVICE\\\"\\n/var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $LOCK_NAME $LOCK_OWNER\\nrc=$?\\nif [ $rc -ne 0 ] && [ $rc -ne 1 ]; then\\n    error \\\"Could not release held lock (rc: $rc)\\\"\\nfi\\n\", \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\": \"#!/usr/bin/bash\\n\\n# pacemaker_mutex_shutdown.sh --acquire\\n# pacemaker_mutex_shutdown.sh --release\\n\\nset -u\\n\\nusage() {\\n    echo \\\"Shutdown a cluster node in a coordinated way across the cluster\\\"\\n    echo \\\"Usage:\\\"\\n    echo \\\"   $0 --acquire # prevent other node from shutting down until we hold the lock\\\"\\n    echo \\\"   $0 --release # release the lock, other node can compete for the shutdown lock\\\"\\n    echo\\n}\\n\\nlog() {\\n    echo \\\"$(date -u): $1\\\"\\n}\\n\\nerror() {\\n    echo \\\"$(date -u): $1\\\" 1>&2\\n    exit 1\\n}\\n\\n# Loop until we hold the lock. The lock has a TTL, so we\'re guaranteed to get it eventually\\nshutdown_lock_acquire() {\\n    local lockname=$1\\n    local requester=$2\\n    local ttl=$3\\n    local rc=1\\n    local current_owner\\n    local owner_stopped\\n    local owner_rc\\n\\n    log \\\"Acquiring the shutdown lock\\\"\\n    while [ $rc -ne 0 ]; do\\n        /var/lib/container-config-scripts/pacemaker_resource_lock.sh --acquire-once $lockname $requester $ttl\\n        rc=$?\\n        if [ $rc -ne 0 ]; then\\n            if [ $rc -eq 2 ]; then\\n                error \\\"Could not acquire the shutdown lock due to unrecoverable error (rc: $rc), bailing out\\\"\\n            else\\n                # The lock is held by another node.\\n                current_owner=$(/var/lib/container-config-scripts/pacemaker_resource_lock.sh --owner $lockname)\\n                owner_rc=$?\\n                if [ $owner_rc -eq 2 ]; then\\n                    error \\\"Could not get the shutdown lock owner due to unrecoverable error (rc: $owner_rc), bailing out\\\"\\n                fi\\n                if [ $owner_rc -eq 0 ]; then\\n                    # If the owner is marked as offline, that means it has shutdown and\\n                    # we can clean the lock preemptively and try to acquire it.\\n                    owner_stopped=$(crm_mon -1X | xmllint --xpath \'count(//nodes/node[@name=\\\"\'${current_owner}\'\\\" and @online=\\\"false\\\" and @unclean=\\\"false\\\"])\' -)\\n                    if [ \\\"${owner_stopped}\\\" = \\\"1\\\" ]; then\\n                        log \\\"Shutdown lock held by stopped node \'${current_owner}\', lock can be released\\\"\\n                        /var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $lockname $current_owner\\n                        continue\\n                    fi\\n                fi\\n                log \\\"Shutdown lock held by another node (rc: $rc), retrying\\\"\\n                sleep 10\\n            fi\\n        fi\\n    done\\n    log \\\"Shutdown lock acquired\\\"\\n    return 0\\n}\\n\\n\\n# Release the lock if we still own it. Not owning it anymore is not fatal\\nshutdown_lock_release() {\\n    local lockname=$1\\n    local requester=$2\\n    local rc\\n\\n    log \\\"Releasing the shutdown lock\\\"\\n    /var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $lockname $requester\\n    rc=$?\\n    if [ $rc -ne 0 ]; then\\n        if [ $rc -gt 1 ]; then\\n            error \\\"Could not release the shutdown lock due to unrecoverable error (rc: $rc), bailing out\\\"\\n        else\\n            log \\\"Shutdown lock no longer held, nothing to do\\\"\\n        fi\\n    else\\n        log \\\"Shutdown lock released\\\"\\n    fi\\n    return 0\\n}\\n\\n\\nACTION=$1\\nif [ -z \\\"$ACTION\\\" ]; then\\n    error \\\"Action must be specified\\\"\\nfi\\n\\nLOCK_NAME=tripleo-shutdown-lock\\nLOCK_OWNER=$(crm_node -n 2>/dev/null)\\nrc=$?\\nif [ $rc -ne 0 ]; then\\n    if [ $rc -eq 102 ]; then\\n        log \\\"Cluster is not running locally, no need to aquire the shutdown lock\\\"\\n        exit 0\\n    else\\n        error \\\"Unexpected error while connecting to the cluster (rc: $rc), bailing out\\\"\\n    fi\\nfi\\n\\n# We start with a very high TTL, that long enough to accomodate a cluster stop.\\n# As soon as the node will get offline, the other competing node will be entitled\\n# to steal the lock, so they should never wait that long in practice.\\nLOCK_TTL=600\\n\\n\\ncase $ACTION in\\n    --help) usage; exit 0;;\\n    --acquire|-a) shutdown_lock_acquire ${LOCK_NAME} ${LOCK_OWNER} ${LOCK_TTL};;\\n    --release|-r) shutdown_lock_release ${LOCK_NAME} ${LOCK_OWNER};;\\n    *) error \\\"Invalid action\\\";;\\nesac\\nexit $?\\n\", \"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Contains a static list of common things necessary for containers\\\\n\\\", \\\"parameters\\\": {\\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"InternalTLSCAFile\\\": {\\\"default\\\": \\\"/etc/ipa/ca.crt\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Specifies the default CA cert to use if TLS is used for services in the internal network.\\\"}, \\\"RpcPort\\\": {\\\"default\\\": 5672, \\\"description\\\": \\\"The network port for messaging backend\\\", \\\"type\\\": \\\"number\\\"}, \\\"PcmkConfigRestartTimeout\\\": {\\\"default\\\": 600, \\\"description\\\": \\\"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\\\", \\\"type\\\": \\\"number\\\"}, \\\"ContainerCli\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"podman\\\", \\\"description\\\": \\\"CLI tool used to manage containers.\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"docker\\\", \\\"podman\\\"]}]}}, \\\"conditions\\\": {\\\"internal_tls_enabled\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, true]}, \\\"docker_enabled\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"docker\\\"]}}, \\\"outputs\\\": {\\\"container_config_scripts\\\": {\\\"description\\\": \\\"Shared container config scripts\\\", \\\"value\\\": {\\\"container_puppet_apply.sh\\\": {\\\"mode\\\": \\\"0700\\\", \\\"content\\\": \\\"#!/bin/bash\\\\nset -eux\\\\nSTEP=$1\\\\nTAGS=$2\\\\nCONFIG=$3\\\\nEXTRA_ARGS=${4:-\'\'}\\\\nif [ -d /tmp/puppet-etc ]; then\\\\n  # ignore copy failures as these may be the same file depending on docker mounts\\\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\\\nfi\\\\necho \\\\\\\"{\\\\\\\\\\\\\\\"step\\\\\\\\\\\\\\\": ${STEP}}\\\\\\\" > /etc/puppet/hieradata/docker_puppet.json\\\\n# $::deployment_type in puppet-tripleo\\\\nexport FACTER_deployment_type=containers\\\\nset +e\\\\npuppet apply $EXTRA_ARGS \\\\\\\\\\\\n    --verbose \\\\\\\\\\\\n    --detailed-exitcodes \\\\\\\\\\\\n    --summarize \\\\\\\\\\\\n    --color=false \\\\\\\\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\\\\\\\n    --tags $TAGS \\\\\\\\\\\\n    -e \\\\\\\"noop_resource(\'package\'); ${CONFIG}\\\\\\\"\\\\nrc=$?\\\\nset -e\\\\nset +ux\\\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\\\n    exit 0\\\\nfi\\\\nexit $rc\\\\n\\\"}, \\\"pyshim.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": {\\\"get_file\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pyshim.sh\\\"}}, \\\"pacemaker_restart_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_file\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\\\"}, \\\"params\\\": {\\\"__PCMKTIMEOUT__\\\": {\\\"get_param\\\": \\\"PcmkConfigRestartTimeout\\\"}}}}}, \\\"pacemaker_wait_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": {\\\"str_replace\\\": {\\\"template\\\": {\\\"get_file\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\\\"}, \\\"params\\\": {\\\"__PCMKTIMEOUT__\\\": {\\\"get_param\\\": \\\"PcmkConfigRestartTimeout\\\"}}}}}, \\\"wait-port-and-run.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": {\\\"get_file\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\\\"}}, \\\"pacemaker_resource_lock.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": {\\\"get_file\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\\\"}}, \\\"pacemaker_mutex_restart_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": {\\\"get_file\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\\\"}}, \\\"pacemaker_mutex_shutdown.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": {\\\"get_file\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\\\"}}}}, \\\"volumes_base\\\": {\\\"description\\\": \\\"Base volume list\\\", \\\"value\\\": {\\\"list_concat\\\": [[\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\"], {\\\"if\\\": [\\\"internal_tls_enabled\\\", [{\\\"list_join\\\": [\\\":\\\", [{\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, \\\"ro\\\"]]}], null]}]}}, \\\"volumes\\\": {\\\"description\\\": \\\"Common volumes for the containers.\\\", \\\"value\\\": {\\\"list_concat\\\": [{\\\"list_concat\\\": [[\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\"], {\\\"if\\\": [\\\"internal_tls_enabled\\\", [{\\\"list_join\\\": [\\\":\\\", [{\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, \\\"ro\\\"]]}], null]}]}, [\\\"/etc/puppet:/etc/puppet:ro\\\"]]}}, \\\"pacemaker_restart_volumes\\\": {\\\"description\\\": \\\"Common volumes for the pacemaker restart containers.\\\", \\\"value\\\": {\\\"list_concat\\\": [{\\\"list_concat\\\": [[\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\"], {\\\"if\\\": [\\\"internal_tls_enabled\\\", [{\\\"list_join\\\": [\\\":\\\", [{\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, \\\"ro\\\"]]}], null]}]}, [\\\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\\\", \\\"/dev/shm:/dev/shm:rw\\\", \\\"/etc/puppet:/etc/puppet:ro\\\"], {\\\"if\\\": [\\\"docker_enabled\\\", [\\\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\\\"], null]}]}}, \\\"container_puppet_apply_volumes\\\": {\\\"description\\\": \\\"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\\\", \\\"value\\\": {\\\"list_concat\\\": [{\\\"list_concat\\\": [[\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\"], {\\\"if\\\": [\\\"internal_tls_enabled\\\", [{\\\"list_join\\\": [\\\":\\\", [{\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, \\\"ro\\\"]]}], null]}]}, [\\\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\\\", \\\"/etc/puppet:/tmp/puppet-etc:ro\\\", \\\"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\\\"]]}}, \\\"healthcheck_rpc_port\\\": {\\\"description\\\": \\\"healthcheck command that probes the RpcPort\\\", \\\"value\\\": {\\\"test\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"/openstack/healthcheck RPCPORT\\\", \\\"params\\\": {\\\"RPCPORT\\\": {\\\"get_param\\\": \\\"RpcPort\\\"}}}}}}}}\", \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack Ceilometer service configured with Puppet\\\\n\\\", \\\"parameters\\\": {\\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"CeilometerMeteringSecret\\\": {\\\"description\\\": \\\"Secret shared by the ceilometer services.\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"CeilometerPassword\\\": {\\\"description\\\": \\\"The password for the ceilometer service account.\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"AmqpRpcAddressPrefix\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Address prefix for RPC addresses\\\", \\\"type\\\": \\\"string\\\"}, \\\"AmqpNotifyAddressPrefix\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Address prefix for Notification addresses\\\", \\\"type\\\": \\\"string\\\"}, \\\"ManagePolling\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to manage polling.yaml.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"Debug\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Set to True to enable debugging on all services.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"CeilometerDebug\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Set to True to enable debugging Ceilometer services.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"KeystoneRegion\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"regionOne\\\", \\\"description\\\": \\\"Keystone region for endpoint\\\"}, \\\"SnmpdReadonlyUserName\\\": {\\\"default\\\": \\\"ro_snmp_user\\\", \\\"description\\\": \\\"The user name for SNMPd with readonly rights running on all Overcloud nodes\\\", \\\"type\\\": \\\"string\\\"}, \\\"SnmpdReadonlyUserPassword\\\": {\\\"description\\\": \\\"The user password for SNMPd with readonly rights running on all Overcloud nodes\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"NotificationDriver\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": \\\"noop\\\", \\\"description\\\": \\\"Driver or drivers to handle sending notifications.\\\"}, \\\"GnocchiArchivePolicy\\\": {\\\"default\\\": \\\"ceilometer-low-rate\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"(DEPRECATED) archive policy to use with gnocchi backend\\\"}, \\\"EnableCache\\\": {\\\"description\\\": \\\"Enable caching with memcached\\\", \\\"type\\\": \\\"boolean\\\", \\\"default\\\": true}, \\\"MemcachedTLS\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\\\", \\\"type\\\": \\\"boolean\\\"}}, \\\"parameter_groups\\\": [{\\\"label\\\": \\\"deprecated\\\", \\\"description\\\": \\\"The following parameters are deprecated and will be removed. They should not\\\\nbe relied on for new deployments. If you have concerns regarding deprecated\\\\nparameters, please contact the TripleO development team on IRC or the\\\\nOpenStack mailing list.\\\\n\\\", \\\"parameters\\\": [\\\"GnocchiArchivePolicy\\\"]}], \\\"conditions\\\": {\\\"tls_cache_enabled\\\": {\\\"and\\\": [{\\\"get_param\\\": \\\"EnableCache\\\"}, {\\\"get_param\\\": \\\"MemcachedTLS\\\"}]}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Ceilometer role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"ceilometer_base\\\", \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"ceilometer::logging::debug\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"CeilometerDebug\\\"}, true, {\\\"get_param\\\": \\\"Debug\\\"}]}, \\\"ceilometer::agent::polling::manage_polling\\\": {\\\"get_param\\\": \\\"ManagePolling\\\"}, \\\"ceilometer::agent::service_credentials::password\\\": {\\\"get_param\\\": \\\"CeilometerPassword\\\"}, \\\"ceilometer::agent::service_credentials::auth_url\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"uri_no_suffix\\\"]}, \\\"ceilometer::agent::service_credentials::region_name\\\": {\\\"get_param\\\": \\\"KeystoneRegion\\\"}, \\\"ceilometer::agent::service_credentials::project_name\\\": \\\"service\\\", \\\"ceilometer::agent::service_credentials::user_domain_name\\\": \\\"Default\\\", \\\"ceilometer::agent::service_credentials::auth_project_domain_name\\\": \\\"Default\\\", \\\"ceilometer::agent::service_credentials::interface\\\": \\\"internalURL\\\", \\\"ceilometer::notification_driver\\\": {\\\"get_param\\\": \\\"NotificationDriver\\\"}, \\\"ceilometer::amqp_rpc_address_prefix\\\": {\\\"get_param\\\": \\\"AmqpRpcAddressPrefix\\\"}, \\\"ceilometer::amqp_notify_address_prefix\\\": {\\\"get_param\\\": \\\"AmqpNotifyAddressPrefix\\\"}, \\\"ceilometer::telemetry_secret\\\": {\\\"get_param\\\": \\\"CeilometerMeteringSecret\\\"}, \\\"ceilometer::snmpd_readonly_username\\\": {\\\"get_param\\\": \\\"SnmpdReadonlyUserName\\\"}, \\\"ceilometer::snmpd_readonly_user_password\\\": {\\\"get_param\\\": \\\"SnmpdReadonlyUserPassword\\\"}, \\\"ceilometer::host\\\": \\\"%{hiera(\'fqdn_canonical\')}\\\", \\\"ceilometer::rabbit_heartbeat_in_pthread\\\": false, \\\"ceilometer::cache::enabled\\\": {\\\"get_param\\\": \\\"EnableCache\\\"}, \\\"ceilometer::cache::tls_enabled\\\": {\\\"get_param\\\": \\\"MemcachedTLS\\\"}}, {\\\"if\\\": [\\\"tls_cache_enabled\\\", {\\\"ceilometer::cache::backend\\\": \\\"dogpile.cache.pymemcache\\\", \\\"ceilometer::cache::enable_socket_keepalive\\\": true}, {\\\"ceilometer::cache::backend\\\": \\\"dogpile.cache.memcached\\\"}]}]}, \\\"service_config_settings\\\": {\\\"keystone\\\": {\\\"tripleo::profile::base::keystone::ceilometer_notification_topics\\\": [\\\"notifications\\\"]}}}}}}\", \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Ceilometer Agent Central service\\\\n\\\", \\\"parameters\\\": {\\\"ContainerCeilometerCentralImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerCeilometerConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the ceilometer config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"CeilometerAgentCentralLoggingSource\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {\\\"tag\\\": \\\"openstack.ceilometer.agent.central\\\", \\\"file\\\": \\\"/var/log/containers/ceilometer/central.log\\\"}}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"RedisPassword\\\": {\\\"description\\\": \\\"The password for the redis service account.\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"MonitoringSubscriptionCeilometerCentral\\\": {\\\"default\\\": \\\"overcloud-ceilometer-agent-central\\\", \\\"type\\\": \\\"string\\\"}, \\\"CeilometerEnableGnocchi\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to enable gnocchi usage.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"CeilometerPassword\\\": {\\\"description\\\": \\\"The password for the ceilometer service account.\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"CeilometerEnableTenantDiscovery\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Identify user and project names from polled metrics.\\\", \\\"type\\\": \\\"boolean\\\"}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"CeilometerServiceBase\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerCeilometerCentralImage\\\": \\\"ContainerCeilometerCentralImage\\\", \\\"ContainerCeilometerConfigImage\\\": \\\"ContainerCeilometerConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerCeilometerCentralImage\\\": {\\\"get_param\\\": \\\"ContainerCeilometerCentralImage\\\"}, \\\"ContainerCeilometerConfigImage\\\": {\\\"get_param\\\": \\\"ContainerCeilometerConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Ceilometer Agent Central role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"ceilometer_agent_central\\\", \\\"monitoring_subscription\\\": {\\\"get_param\\\": \\\"MonitoringSubscriptionCeilometerCentral\\\"}, \\\"keystone_resources\\\": {\\\"ceilometer\\\": {\\\"users\\\": {\\\"ceilometer\\\": {\\\"password\\\": {\\\"get_param\\\": \\\"CeilometerPassword\\\"}, \\\"roles\\\": [\\\"admin\\\", \\\"ResellerAdmin\\\"]}}, \\\"roles\\\": [\\\"ResellerAdmin\\\"]}}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"CeilometerServiceBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"ceilometer_redis_password\\\": {\\\"get_param\\\": \\\"RedisPassword\\\"}, \\\"central_namespace\\\": true, \\\"ceilometer::agent::polling::tenant_name_discovery\\\": {\\\"get_param\\\": \\\"CeilometerEnableTenantDiscovery\\\"}}]}, \\\"service_config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"CeilometerServiceBase\\\", \\\"role_data\\\", \\\"service_config_settings\\\"]}, {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_ceilometer_agent_central\\\": [{\\\"get_param\\\": \\\"CeilometerAgentCentralLoggingSource\\\"}]}}]}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"ceilometer\\\", \\\"puppet_tags\\\": \\\"ceilometer_config\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::ceilometer::agent::polling\\\\n\\\", \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCeilometerConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/ceilometer_agent_central.json\\\": {\\\"command\\\": \\\"/usr/bin/ceilometer-polling --polling-namespaces central --logfile /var/log/ceilometer/central.log\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}, \\\"/var/lib/kolla/config_files/ceilometer_agent_gnocchi_upgrade.json\\\": {\\\"command\\\": \\\"/usr/bin/bootstrap_host_exec ceilometer_agent_central su ceilometer -s /bin/bash -c \'for n in {1..10}; do /usr/bin/ceilometer-upgrade && exit 0 || sleep 30; done; exit 1\'\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}}, \\\"docker_config\\\": {\\\"step_3\\\": {\\\"ceilometer_init_log\\\": {\\\"start_order\\\": 0, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCeilometerCentralImage\\\"]}, \\\"net\\\": \\\"none\\\", \\\"user\\\": \\\"root\\\", \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R ceilometer:ceilometer /var/log/ceilometer\\\"], \\\"volumes\\\": [\\\"/var/log/containers/ceilometer:/var/log/ceilometer:z\\\"]}}, \\\"step_4\\\": {\\\"ceilometer_agent_central\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCeilometerCentralImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/ceilometer_agent_central.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/log/containers/ceilometer:/var/log/ceilometer:z\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}, \\\"step_5\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"CeilometerEnableGnocchi\\\"}, {\\\"ceilometer_gnocchi_upgrade\\\": {\\\"start_order\\\": 99, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCeilometerCentralImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"detach\\\": false, \\\"privileged\\\": false, \\\"user\\\": \\\"root\\\", \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/ceilometer_agent_gnocchi_upgrade.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/log/containers/ceilometer:/var/log/ceilometer:z\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}]}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/ceilometer\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}], \\\"external_upgrade_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade_transfer_data\\\", \\\"system_upgrade_stop_services\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Stop ceilometer agent central container\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_stop\\\"}, \\\"vars\\\": {\\\"tripleo_containers_to_stop\\\": [\\\"ceilometer_agent_central\\\"], \\\"tripleo_delegate_to\\\": \\\"{{ groups[\'ceilometer_agent_central\'] | difference(groups[\'excluded_overcloud\']) }}\\\"}}]}]}}}}\", \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Ceilometer Agent Notification service\\\\n\\\", \\\"parameters\\\": {\\\"ContainerCeilometerNotificationImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerCeilometerConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the ceilometer config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"CeilometerAgentNotificationLoggingSource\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {\\\"tag\\\": \\\"openstack.ceilometer.agent.notification\\\", \\\"file\\\": \\\"/var/log/containers/ceilometer/agent-notification.log\\\"}}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"MonitoringSubscriptionCeilometerNotification\\\": {\\\"default\\\": \\\"overcloud-ceilometer-agent-notification\\\", \\\"type\\\": \\\"string\\\"}, \\\"MetricsQdrPort\\\": {\\\"default\\\": 5666, \\\"description\\\": \\\"Service name or port number on which the qdrouterd will accept connections.\\\", \\\"type\\\": \\\"number\\\"}, \\\"CeilometerQdrPublishEvents\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to send events to MetricsQdr service.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"CeilometerQdrPublishMetrics\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to send telemetry data to MetricsQdr service.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"CeilometerQdrEventsConfig\\\": {\\\"default\\\": {\\\"driver\\\": \\\"amqp\\\", \\\"topic\\\": \\\"event\\\"}, \\\"description\\\": \\\"Configuration for notifier publisher for events.\\\", \\\"type\\\": \\\"json\\\"}, \\\"CeilometerQdrMetricsConfig\\\": {\\\"default\\\": {\\\"driver\\\": \\\"amqp\\\", \\\"topic\\\": \\\"metering\\\"}, \\\"description\\\": \\\"Configuration for notifier publisher for metrics.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ManageEventPipeline\\\": {\\\"default\\\": true, \\\"description\\\": \\\"Whether to manage event_pipeline.yaml.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"EventPipelinePublishers\\\": {\\\"default\\\": [], \\\"description\\\": \\\"A list of publishers to put in event_pipeline.yaml. When the collector is used, override this with notifier:// publisher. Set ManageEventPipeline to true for override to take effect.\\\\n\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"ManagePipeline\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to manage pipeline.yaml.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"PipelinePublishers\\\": {\\\"default\\\": [], \\\"description\\\": \\\"A list of publishers to put in pipeline.yaml. When the collector is used, override this with notifier:// publisher. Set ManagePipeline to true for override to take effect.\\\\n\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"CeilometerServiceBase\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerCeilometerNotificationImage\\\": \\\"ContainerCeilometerNotificationImage\\\", \\\"ContainerCeilometerConfigImage\\\": \\\"ContainerCeilometerConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerCeilometerNotificationImage\\\": {\\\"get_param\\\": \\\"ContainerCeilometerNotificationImage\\\"}, \\\"ContainerCeilometerConfigImage\\\": {\\\"get_param\\\": \\\"ContainerCeilometerConfigImage\\\"}}}]}}}}, \\\"conditions\\\": {\\\"ceilometer_qdr_publish\\\": {\\\"or\\\": [{\\\"get_param\\\": \\\"CeilometerQdrPublishEvents\\\"}, {\\\"get_param\\\": \\\"CeilometerQdrPublishMetrics\\\"}]}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Ceilometer Agent Notification role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"ceilometer_agent_notification\\\", \\\"monitoring_subscription\\\": {\\\"get_param\\\": \\\"MonitoringSubscriptionCeilometerNotification\\\"}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"CeilometerServiceBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"ceilometer::agent::notification::manage_event_pipeline\\\": {\\\"get_param\\\": \\\"ManageEventPipeline\\\"}, \\\"ceilometer::agent::notification::manage_pipeline\\\": {\\\"get_param\\\": \\\"ManagePipeline\\\"}, \\\"tripleo::profile::base::ceilometer::agent::notification::notifier_enabled\\\": {\\\"get_param\\\": \\\"CeilometerQdrPublishMetrics\\\"}, \\\"tripleo::profile::base::ceilometer::agent::notification::notifier_events_enabled\\\": {\\\"get_param\\\": \\\"CeilometerQdrPublishEvents\\\"}, \\\"tripleo::profile::base::ceilometer::agent::notification::pipeline_publishers\\\": {\\\"get_param\\\": \\\"PipelinePublishers\\\"}, \\\"tripleo::profile::base::ceilometer::agent::notification::event_pipeline_publishers\\\": {\\\"get_param\\\": \\\"EventPipelinePublishers\\\"}, \\\"tripleo::profile::base::ceilometer::agent::notification::notifier_params\\\": {\\\"get_param\\\": \\\"CeilometerQdrMetricsConfig\\\"}, \\\"tripleo::profile::base::ceilometer::agent::notification::notifier_event_params\\\": {\\\"get_param\\\": \\\"CeilometerQdrEventsConfig\\\"}}, {\\\"if\\\": [\\\"ceilometer_qdr_publish\\\", {\\\"tripleo::profile::base::ceilometer::agent::notification::notifier_host_addr\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", {\\\"str_replace\\\": {\\\"template\\\": \\\"ROLENAMEMetricsQdrNetwork\\\", \\\"params\\\": {\\\"ROLENAME\\\": {\\\"get_param\\\": \\\"RoleName\\\"}}}}]}}}}, \\\"tripleo::profile::base::ceilometer::agent::notification::notifier_host_port\\\": {\\\"get_param\\\": \\\"MetricsQdrPort\\\"}}]}]}, \\\"service_config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"CeilometerServiceBase\\\", \\\"role_data\\\", \\\"service_config_settings\\\"]}, {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_ceilometer_agent_notification\\\": [{\\\"get_param\\\": \\\"CeilometerAgentNotificationLoggingSource\\\"}]}}]}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"ceilometer\\\", \\\"puppet_tags\\\": \\\"ceilometer_config\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::ceilometer::agent::notification\\\\n\\\", \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCeilometerConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/ceilometer_agent_notification.json\\\": {\\\"command\\\": \\\"/usr/bin/ceilometer-agent-notification --logfile /var/log/ceilometer/agent-notification.log\\\", \\\"config_files\\\": {\\\"list_concat\\\": [[{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]]}}}, \\\"docker_config\\\": {\\\"step_3\\\": {\\\"ceilometer_init_log\\\": {\\\"start_order\\\": 0, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCeilometerNotificationImage\\\"]}, \\\"net\\\": \\\"none\\\", \\\"user\\\": \\\"root\\\", \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R ceilometer:ceilometer /var/log/ceilometer\\\"], \\\"volumes\\\": [\\\"/var/log/containers/ceilometer:/var/log/ceilometer:z\\\"]}}, \\\"step_4\\\": {\\\"ceilometer_agent_notification\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCeilometerNotificationImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"healthcheck_rpc_port\\\"]}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/ceilometer_agent_notification.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/log/containers/ceilometer:/var/log/ceilometer:z\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/ceilometer\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}, {\\\"name\\\": \\\"enable virt_sandbox_use_netlink for healthcheck\\\", \\\"seboolean\\\": {\\\"name\\\": \\\"virt_sandbox_use_netlink\\\", \\\"persistent\\\": true, \\\"state\\\": true}, \\\"when\\\": [\\\"ansible_facts.selinux is defined\\\", \\\"ansible_facts.selinux.status == \\\\\\\"enabled\\\\\\\"\\\"]}], \\\"external_upgrade_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade_transfer_data\\\", \\\"system_upgrade_stop_services\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Stop ceilometer agent notification container\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_stop\\\"}, \\\"vars\\\": {\\\"tripleo_containers_to_stop\\\": [\\\"ceilometer_agent_notification\\\"], \\\"tripleo_delegate_to\\\": \\\"{{ groups[\'ceilometer_agent_notification\'] | difference(groups[\'excluded_overcloud\']) }}\\\"}}]}]}}}}\", \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Ceilometer Agent Ipmi service\\\\n\\\", \\\"parameters\\\": {\\\"ContainerCeilometerIpmiImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerCeilometerConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the ceilometer config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"CeilometerAgentIpmiLoggingSource\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {\\\"tag\\\": \\\"openstack.ceilometer.agent.ipmi\\\", \\\"file\\\": \\\"/var/log/containers/ceilometer/ipmi.log\\\"}}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"RedisPassword\\\": {\\\"description\\\": \\\"The password for the redis service account.\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"MonitoringSubscriptionCeilometerIpmi\\\": {\\\"default\\\": \\\"overcloud-ceilometer-agent-ipmi\\\", \\\"type\\\": \\\"string\\\"}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"CeilometerServiceBase\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"CeilometerAgentCentralBase\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\\\", \\\"properties\\\": {\\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerCeilometerIpmiImage\\\": \\\"ContainerCeilometerIpmiImage\\\", \\\"ContainerCeilometerConfigImage\\\": \\\"ContainerCeilometerConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerCeilometerIpmiImage\\\": {\\\"get_param\\\": \\\"ContainerCeilometerIpmiImage\\\"}, \\\"ContainerCeilometerConfigImage\\\": {\\\"get_param\\\": \\\"ContainerCeilometerConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Ceilometer Agent Ipmi role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"ceilometer_agent_ipmi\\\", \\\"monitoring_subscription\\\": {\\\"get_param\\\": \\\"MonitoringSubscriptionCeilometerIpmi\\\"}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"CeilometerServiceBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"ceilometer_redis_password\\\": {\\\"get_param\\\": \\\"RedisPassword\\\"}, \\\"ipmi_namespace\\\": true}]}, \\\"service_config_settings\\\": {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_ceilometer_agent_ipmi\\\": [{\\\"get_param\\\": \\\"CeilometerAgentIpmiLoggingSource\\\"}]}}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"ceilometer\\\", \\\"puppet_tags\\\": \\\"ceilometer_config\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::ceilometer::agent::polling\\\\n\\\", \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCeilometerConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/ceilometer-agent-ipmi.json\\\": {\\\"command\\\": \\\"/usr/bin/ceilometer-polling --polling-namespaces ipmi --logfile /var/log/ceilometer/ipmi.log\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}}, \\\"docker_config\\\": {\\\"step_3\\\": {\\\"ceilometer_init_log\\\": {\\\"start_order\\\": 0, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCeilometerIpmiImage\\\"]}, \\\"net\\\": \\\"none\\\", \\\"user\\\": \\\"root\\\", \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R ceilometer:ceilometer /var/log/ceilometer\\\"], \\\"volumes\\\": [\\\"/var/log/containers/ceilometer:/var/log/ceilometer:z\\\"]}}, \\\"step_4\\\": {\\\"ceilometer_agent_ipmi\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCeilometerIpmiImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/ceilometer-agent-ipmi.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/log/containers/ceilometer:/var/log/ceilometer:z\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/ceilometer\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}]}}}}\", \"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Ceilometer Agent Compute service\\\\n\\\", \\\"parameters\\\": {\\\"ContainerCeilometerComputeImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerCeilometerConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the ceilometer config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"MonitoringSubscriptionCeilometerCompute\\\": {\\\"default\\\": \\\"overcloud-ceilometer-agent-compute\\\", \\\"type\\\": \\\"string\\\"}, \\\"InstanceDiscoveryMethod\\\": {\\\"default\\\": \\\"libvirt_metadata\\\", \\\"description\\\": \\\"Method used to discover instances running on compute node\\\", \\\"type\\\": \\\"string\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"naive\\\", \\\"libvirt_metadata\\\", \\\"workload_partitioning\\\"]}]}, \\\"RedisPassword\\\": {\\\"description\\\": \\\"The password for the redis service account.\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"CeilometerEnableTenantDiscovery\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Identify user and project names from polled metrics.\\\", \\\"type\\\": \\\"boolean\\\"}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"CeilometerServiceBase\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerCeilometerComputeImage\\\": \\\"ContainerCeilometerComputeImage\\\", \\\"ContainerCeilometerConfigImage\\\": \\\"ContainerCeilometerConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerCeilometerComputeImage\\\": {\\\"get_param\\\": \\\"ContainerCeilometerComputeImage\\\"}, \\\"ContainerCeilometerConfigImage\\\": {\\\"get_param\\\": \\\"ContainerCeilometerConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Ceilometer Agent Compute role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"ceilometer_agent_compute\\\", \\\"monitoring_subscription\\\": {\\\"get_param\\\": \\\"MonitoringSubscriptionCeilometerCompute\\\"}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"CeilometerServiceBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"ceilometer::agent::polling::instance_discovery_method\\\": {\\\"get_param\\\": \\\"InstanceDiscoveryMethod\\\"}}, {\\\"ceilometer_redis_password\\\": {\\\"get_param\\\": \\\"RedisPassword\\\"}, \\\"compute_namespace\\\": true, \\\"ceilometer::agent::polling::tenant_name_discovery\\\": {\\\"get_param\\\": \\\"CeilometerEnableTenantDiscovery\\\"}}]}, \\\"service_config_settings\\\": {\\\"get_attr\\\": [\\\"CeilometerServiceBase\\\", \\\"role_data\\\", \\\"service_config_settings\\\"]}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"ceilometer\\\", \\\"puppet_tags\\\": \\\"ceilometer_config\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::ceilometer::agent::polling\\\", \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCeilometerConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/ceilometer_agent_compute.json\\\": {\\\"command\\\": \\\"/usr/bin/ceilometer-polling --polling-namespaces compute --logfile /var/log/ceilometer/compute.log\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}}, \\\"docker_config\\\": {\\\"step_4\\\": {\\\"ceilometer_agent_compute\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCeilometerComputeImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": [\\\"tripleo_nova_libvirt.target\\\"], \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/ceilometer_agent_compute.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\\\", \\\"/run/libvirt:/run/libvirt:shared,z\\\", \\\"/var/log/containers/ceilometer:/var/log/ceilometer:z\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/ceilometer\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}, {\\\"name\\\": \\\"enable virt_sandbox_use_netlink for healthcheck\\\", \\\"seboolean\\\": {\\\"name\\\": \\\"virt_sandbox_use_netlink\\\", \\\"persistent\\\": true, \\\"state\\\": true}, \\\"when\\\": [\\\"ansible_facts.selinux is defined\\\", \\\"ansible_facts.selinux.status == \\\\\\\"enabled\\\\\\\"\\\"]}]}}}}\", \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/monitoring/collectd_check_health.py\": \"#!/usr/bin/python3\\n#\\n# Copyright 2022 Red Hat Inc.\\n#\\n# Licensed under the Apache License, Version 2.0 (the \\\"License\\\"); you may\\n# not use this file except in compliance with the License. You may obtain\\n# a copy of the License at\\n#\\n#      http://www.apache.org/licenses/LICENSE-2.0\\n#\\n# Unless required by applicable law or agreed to in writing, software\\n# distributed under the License is distributed on an \\\"AS IS\\\" BASIS, WITHOUT\\n# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the\\n# License for the specific language governing permissions and limitations\\n# under the License.\\n\\nimport json\\nimport os\\nimport re\\nimport shutil\\nimport subprocess\\nimport sys\\n\\nfrom pkg_resources import packaging\\n\\n\\nSOCKET = \\\"unix:/run/podman/podman.sock\\\"\\nPS_FORMAT = (\'{\\\"service\\\": \\\"{{.Names}}\\\", \\\"container\\\": \\\"{{.ID}}\\\", \'\\n             \'\\\"status\\\": \\\"{{.State}}\\\", \\\"healthy\\\": \\\"{{.Status}}\\\"},\')\\nBASE_FORMAT = \\\"{service: .Name, container: .Id, status: .State.Running, \\\"\\nRUNNING_REX = re.compile(r\\\"Up .*(?P<health>\\\\(u?n?healthy\\\\))\\\")\\nSKIP_LIST = [\'.*_bootstrap\', \'container-puppet-.*\', \'.*_db_sync\',\\n             \'.*_cron\', \'create_.*_wrapper\', \'.*_wait_bundle\',\\n             \'configure_.*\', \'.*_fix_perms\', \'.*_init_logs?\',\\n             \'.*_init_perm\', \'(nova|placement)_wait_for_.*\', \'nova_.*ensure_\',\\n             \'(swift_)?setup_.*\', \'mysql_data_ownership\', \'swift_copy_rings\',\\n             \'nova_statedir_owner\']\\n\\n\\nclass ExecuteError(Exception):\\n    def __init__(self, rc, msg):\\n        self.rc = rc\\n        self.msg = msg\\n        super().__init__()\\n\\n\\ndef execute(cmd, workdir: str = None,\\n            prev_proc: subprocess.Popen = None) -> subprocess.Popen:\\n    # Note(mmagr): When this script is executed by collectd-sensubility started\\n    #              via collectd the script has non-root permission but inherits\\n    #              environment from collectd with root permission. We need\\n    #              to avoid sensubility access /root when using podman-remote.\\n    #              See https://bugzilla.redhat.com/show_bug.cgi?id=2091076 for\\n    #              more info.\\n    proc_env = os.environ.copy()\\n    proc_env[\\\"HOME\\\"] = \\\"/tmp\\\"\\n    if type(cmd[0]) is list:  # multiple piped commands\\n        last = prev_proc\\n        for c in cmd:\\n            last = execute(c, workdir, last)\\n        return last\\n    else:  # single command\\n        inpipe = prev_proc.stdout if prev_proc is not None else None\\n        proc = subprocess.Popen(cmd, cwd=workdir, env=proc_env, stdin=inpipe,\\n                                stdout=subprocess.PIPE, stderr=subprocess.PIPE)\\n        if prev_proc is not None:\\n            prev_proc.stdout.close()\\n            prev_proc.stderr.close()\\n        return proc\\n\\n\\ndef get_health_from_status(status):\\n    healthy = status in (\'healthy\', \'running\')\\n    return int(healthy)\\n\\n\\ndef fetch_state_from_inspect(cont, fmt):\\n    proc = execute([\\n        [shutil.which(\'podman-remote\'),\\n           \'--url\', SOCKET, \'inspect\', cont[\\\"container\\\"]],\\n        [shutil.which(\'jq\'), \'.[] | %s\' % fmt]\\n    ])\\n    o, e = proc.communicate()\\n    if proc.returncode != 0:\\n        msg = \\\"Failed to fetch status of %s: %s\\\" % (cont, e.decode())\\n        raise ExecuteError(proc.returncode, msg)\\n\\n    item = json.loads(o.decode())\\n    item[\'status\'] = \'running\' if item[\'status\'] else \'stopped\'\\n    if len(item[\'healthy\']) > 0 and item[\'status\'] != \'stopped\':\\n        item[\'status\'] = item[\'healthy\']\\n\\n    item[\'healthy\'] = get_health_from_status(item[\'status\'])\\n    return item\\n\\n\\ndef fetch_state(item):\\n    if \'up \' in item[\'status\'].lower():\\n        item[\'status\'] = \'running\'\\n    if item[\'status\'] != \'running\':\\n        item[\'status\'] = \'stopped\'\\n\\n    match = RUNNING_REX.match(item[\'healthy\'])\\n    if match:\\n        health = match.group(\'health\')\\n    else:\\n        health = \'\'\\n    if health:\\n        item[\'status\'] = health.strip(\\\"()\\\")\\n\\n    item[\'healthy\'] = get_health_from_status(item[\'status\'])\\n    return item\\n\\n\\ndef fetch_container_health(ps_result, inspect_fmt):\\n\\n    def container_filter(item):\\n        for rx in [re.compile(i) for i in SKIP_LIST]:\\n            if rx.match(item[\\\"service\\\"]):\\n                return False\\n        return True\\n    try:\\n        containers = filter(container_filter, json.loads(ps_result))\\n    except json.decoder.JSONDecodeError:\\n        return 1, \\\"%s\\\\nFailed to parse above output.\\\" % ps_result\\n\\n    out = []\\n    for cont in containers:\\n        try:\\n            out.append(fetch_state(cont))\\n        except Exception:\\n            # fallback to slow inspect way in case of any error\\n            try:\\n                out.append(fetch_state_from_inspect(cont, inspect_fmt))\\n            except ExecuteError as ex:\\n                return ex.rc, ex.msg\\n    return 0, out\\n\\n\\nif __name__ == \\\"__main__\\\":\\n    proc = execute([shutil.which(\'podman-remote\'),\\n                    \'--url\', SOCKET, \'version\',\\n                    \'--format\', r\'{{.Server.Version}}\'])\\n    o, e = proc.communicate()\\n    try:\\n        if packaging.version.parse(o.decode().strip()) >= packaging.version.parse(\\\"4.0.0\\\"):\\n            inspect_fmt = BASE_FORMAT + \\\"healthy: .State.Health.Status}\\\"\\n        else:\\n            inspect_fmt = BASE_FORMAT + \\\"healthy: .State.Healthcheck.Status}\\\"\\n    except Exception:\\n        # keep podman-4.0.0+ format in case of version decoding error\\n        inspect_fmt = BASE_FORMAT + \\\"healthy: .State.Health.Status}\\\"\\n\\n    proc = execute([shutil.which(\'podman-remote\'), \'--url\', SOCKET,\\n                    \'ps\', \'--all\', \'--format\', PS_FORMAT])\\n    o, e = proc.communicate()\\n    if proc.returncode != 0:\\n        print(\\\"Failed to list containers:\\\\n%s\\\\n%s\\\" % (o.decode(), e.decode()))\\n        sys.exit(1)\\n\\n    rc, status = fetch_container_health(\\\"[%s]\\\" % o.decode().strip(\\\"\\\\n,\\\"), inspect_fmt)\\n    if rc != 0:\\n        print(\\\"Failed to inspect containers:\\\\n%s\\\" % status)\\n        sys.exit(rc)\\n    print(json.dumps(status))\\n\", \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Containerized collectd service\\\\n\\\", \\\"parameters\\\": {\\\"ContainerCollectdImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerCollectdConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the collectd config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"KeystoneRegion\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Keystone region for endpoint\\\", \\\"default\\\": \\\"regionOne\\\"}, \\\"MetricsQdrPort\\\": {\\\"default\\\": 5666, \\\"description\\\": \\\"Service name or port number on which the qdrouterd will accept connections.\\\", \\\"type\\\": \\\"number\\\"}, \\\"MetricsQdrUsername\\\": {\\\"default\\\": \\\"guest\\\", \\\"description\\\": \\\"Username which should be used to authenticate to the deployed qdrouterd.\\\", \\\"type\\\": \\\"string\\\"}, \\\"MetricsQdrPassword\\\": {\\\"default\\\": \\\"guest\\\", \\\"description\\\": \\\"Password which should be used to authenticate to the deployed qdrouterd.\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"MonitoringSubscriptionCollectd\\\": {\\\"default\\\": \\\"overcloud-collectd\\\", \\\"type\\\": \\\"string\\\"}, \\\"CollectdConnectionType\\\": {\\\"default\\\": \\\"amqp1\\\", \\\"description\\\": \\\"Define which write plugin should collectd use. Currently supported are \'amqp1\' and \'network\'.\\\", \\\"type\\\": \\\"string\\\"}, \\\"CollectdDefaultPollingInterval\\\": {\\\"default\\\": 120, \\\"type\\\": \\\"number\\\", \\\"description\\\": \\\"Controls how often registered read functions are called and with that the resolution of the collected data. This value can be overridden per plugin(per role) by setting \\\\\\\"::collectd::plugin::<plugin_name>::interval\\\\\\\" key in ExtraConfig(<role_name>ExtraConfig) if using puppet, and by setting \\\\\\\"collectd_plugin_<plugin_name>_interval\\\\\\\" in <role_name>ExtraConfig/CollectdVars if using ansible.\\\\n\\\"}, \\\"CollectdDefaultPlugins\\\": {\\\"default\\\": [\\\"cpu\\\", \\\"df\\\", \\\"disk\\\", \\\"hugepages\\\", \\\"interface\\\", \\\"load\\\", \\\"memory\\\", \\\"unixsock\\\", \\\"uptime\\\"], \\\"type\\\": \\\"comma_delimited_list\\\", \\\"description\\\": \\\"List of collectd plugins to activate on all overcloud hosts.  See the documentation for the puppet-collectd module for a list plugins supported by the module (https://github.com/voxpupuli/puppet-collectd). Set this key to override the default list of plugins.  Use CollectdExtraPlugins if you want to load additional plugins without overriding the defaults.\\\\n\\\"}, \\\"CollectdExtraPlugins\\\": {\\\"default\\\": [], \\\"type\\\": \\\"comma_delimited_list\\\", \\\"description\\\": \\\"List of collectd plugins to activate on all overcloud hosts.  See the documentation for the puppet-collectd module for a list plugins supported by the module (https://github.com/voxpupuli/puppet-collectd). Set this key to load plugins in addition to those in CollectdDefaultPlugins.\\\\n\\\"}, \\\"CollectdServer\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Address of remote collectd server to which we will send metrics.\\\\n\\\", \\\"default\\\": \\\"\\\"}, \\\"CollectdServerPort\\\": {\\\"type\\\": \\\"number\\\", \\\"default\\\": 25826, \\\"description\\\": \\\"Port on remote collectd server to which we will send metrics.\\\\n\\\"}, \\\"CollectdUsername\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Username for authenticating to the remote collectd server. The default is to not configure any authentication.\\\\n\\\", \\\"default\\\": \\\"\\\"}, \\\"CollectdPassword\\\": {\\\"type\\\": \\\"string\\\", \\\"hidden\\\": true, \\\"description\\\": \\\"Password for authenticating to the remote collectd server. The default is to not configure any authentication.\\\\n\\\", \\\"default\\\": \\\"\\\"}, \\\"CollectdSecurityLevel\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Security level setting for remote collectd connection. If it is set to Sign or Encrypt the CollectdPassword and CollectdUsername parameters need to be set.\\\\n\\\", \\\"default\\\": \\\"None\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"None\\\", \\\"Sign\\\", \\\"Encrypt\\\"]}]}, \\\"EnableSQLAlchemyCollectd\\\": {\\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"Set to true to enable the SQLAlchemy-collectd server plugin\\\\n\\\", \\\"default\\\": false}, \\\"CollectdSQLAlchemyLogMessages\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"set to \\\\\\\"debug\\\\\\\" to enable message logging.\\\", \\\"default\\\": \\\"info\\\"}, \\\"CollectdSQLAlchemyBindHost\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"hostname for SQLAlchemy-collectd plugin to bind on.  defaults to localhost.\\\\n\\\", \\\"default\\\": \\\"localhost\\\"}, \\\"CollectdAmqpHost\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Hostname or IP address of the AMQP 1.0 intermediary.\\\", \\\"default\\\": \\\"nil\\\"}, \\\"CollectdAmqpPort\\\": {\\\"type\\\": \\\"number\\\", \\\"description\\\": \\\"Service name or port number on which the AMQP 1.0 intermediary accepts connections. This argument must be a string, even if the numeric form is used.\\\\n\\\", \\\"default\\\": 5666}, \\\"CollectdAmqpUser\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"User part of credentials used to authenticate to the AMQP 1.0 intermediary.\\\\n\\\", \\\"default\\\": \\\"guest\\\"}, \\\"CollectdAmqpPassword\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Password part of credentials used to authenticate to the AMQP 1.0 intermediary.\\\\n\\\", \\\"default\\\": \\\"guest\\\", \\\"hidden\\\": true}, \\\"CollectdAmqpTransportName\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Name of the AMQP 1.0 transport.\\\", \\\"default\\\": \\\"metrics\\\"}, \\\"CollectdAmqpAddress\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"This option specifies the prefix for the send-to value in the message.\\\\n\\\", \\\"default\\\": \\\"collectd\\\"}, \\\"CollectdAmqpInstances\\\": {\\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"Hash of hashes. Each inner hash represent Instance block in plugin configuration file. Key of outter hash represents instance name. The \'address\' value concatenated with the \'name\' given will be used as the send-to address for communications over the messaging link.\\\\n\\\", \\\"default\\\": {}}, \\\"CollectdAmqpRetryDelay\\\": {\\\"type\\\": \\\"number\\\", \\\"description\\\": \\\"When the AMQP 1.0 connection is lost, defines the time in seconds to wait before attempting to reconnect.\\\\n\\\", \\\"default\\\": 1}, \\\"CollectdAmqpInterval\\\": {\\\"type\\\": \\\"number\\\", \\\"description\\\": \\\"Interval on which metrics should be sent to AMQP intermediary. If not set the default for all collectd plugins is used.\\\\n\\\", \\\"default\\\": -666}, \\\"CollectdAmqpSendQueueLimit\\\": {\\\"type\\\": \\\"number\\\", \\\"description\\\": \\\"Number of data sets to be kept in memory, older sets will be discarded, if set to -1, this feature is disabled.\\\\n\\\", \\\"default\\\": -1}, \\\"CollectdEnableSensubility\\\": {\\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"Set to true if sensubility should be executed by exec plugin.\\\", \\\"default\\\": false}, \\\"CollectdSensubilityExecSudoRule\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Given rule will be created in /etc/sudoers.d for sensubility to enable it calling restricted commands via sensubility executor.\\\\n\\\", \\\"default\\\": \\\"\\\"}, \\\"CollectdSensubilityLogLevel\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Use for override the default logging level (WARNING).\\\", \\\"default\\\": \\\"WARNING\\\"}, \\\"CollectdSensubilityConnection\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"URL to Sensu sever side\\\", \\\"default\\\": \\\"amqp://sensu:sensu@localhost:5672//sensu\\\"}, \\\"CollectdSensubilityKeepaliveInterval\\\": {\\\"type\\\": \\\"number\\\", \\\"description\\\": \\\"Interval in seconds for sending keepalive messages to Sensu server side.\\\", \\\"default\\\": 20}, \\\"CollectdSensubilityTmpDir\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Path to temporary directory which is used for creation of check scripts.\\\", \\\"default\\\": \\\"/var/tmp/collectd-sensubility-checks\\\"}, \\\"CollectdSensubilityShellPath\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Path to shell used for executing check scripts.\\\", \\\"default\\\": \\\"/usr/bin/sh\\\"}, \\\"CollectdSensubilityWorkerCount\\\": {\\\"type\\\": \\\"number\\\", \\\"description\\\": \\\"Number of goroutines spawned for executing check scripts.\\\", \\\"default\\\": 2}, \\\"CollectdSensubilityChecks\\\": {\\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"JSON formated definition of standalone checks to be scheduled on client side.\\\", \\\"default\\\": {}}, \\\"CollectdSensubilityTransport\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Bus type for sent data. Options are \'sensu\' (rabbitmq) and \'amqp1\'\\\", \\\"default\\\": \\\"sensu\\\"}, \\\"CollectdSensubilityResultsChannel\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"AMQP1 channel address\\\", \\\"default\\\": \\\"collectd/notify\\\"}, \\\"CollectdSensubilityScripts\\\": {\\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"List of hashes of scripts for download for sensubility usage. Value has to be in following format:\\\\n[{\\\\\\\"name\\\\\\\": \\\\\\\"<script name>\\\\\\\", \\\\\\\"source\\\\\\\": \\\\\\\"<http URI to download script>\\\\\\\", \\\\\\\"checksum\\\\\\\": \\\\\\\"<alogithm:sum>\\\\\\\"}]\\\\n\\\", \\\"default\\\": []}, \\\"CollectdEnableContainerHealthCheck\\\": {\\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"Set to false if container health check should not be defined and attached to CollectdEnableContainerHealthCheck.\\\\n\\\", \\\"default\\\": true}, \\\"CollectdContainerHealthCheckCommand\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"/config-scripts/collectd_check_health.py\\\"}, \\\"CollectdContainerHealthCheckInterval\\\": {\\\"type\\\": \\\"number\\\", \\\"description\\\": \\\"The frequency in seconds the docker health check is executed.\\\", \\\"default\\\": 10}, \\\"CollectdContainerHealthCheckHandlers\\\": {\\\"default\\\": [], \\\"description\\\": \\\"The Sensu event handler to use for events created by the docker health check.\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"CollectdContainerHealthCheckOccurrences\\\": {\\\"type\\\": \\\"number\\\", \\\"description\\\": \\\"The number of event occurrences before sensu-plugin-aware handler should take action.\\\", \\\"default\\\": 3}, \\\"CollectdContainerHealthCheckRefresh\\\": {\\\"type\\\": \\\"number\\\", \\\"description\\\": \\\"The number of seconds sensu-plugin-aware handlers should wait before taking second action.\\\", \\\"default\\\": 90}, \\\"EnableSTF\\\": {\\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"Set to true to enable configuration for STF client.\\\", \\\"default\\\": false}, \\\"CollectdEnableMcelog\\\": {\\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"Set to true to enable mcelog\\\", \\\"default\\\": false}, \\\"CollectdEnableLibpodstats\\\": {\\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"Set to true if collectd should run the libpodstats plugin\\\", \\\"default\\\": false}, \\\"CollectdContainerAdditionalCapAdd\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"description\\\": \\\"Additional container capabilities to add to the collectd container. By default is appended to IPC_LOCK.\\\", \\\"default\\\": []}, \\\"CollectdLoggingSource\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {\\\"tag\\\": \\\"collectd\\\", \\\"file\\\": \\\"/var/log/containers/collectd/collectd.log\\\"}}, \\\"DeployedCeph\\\": {\\\"default\\\": false, \\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"If the Ceph cluster has already been deployed but needs to be configured\\\\nso that the overcloud can use it (create cephx keys, pools, configure RGW\\\\nwith haproxy, etc), then this parameter should be set to true. Set this\\\\nparameter to false to have cephadm deploy the ceph cluster during overcloud\\\\ndeployment. DeployedCeph and CephDynamicSpec are mutually exclusive.\\\\n\\\"}, \\\"CephClusterFSID\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"The Ceph cluster FSID. Must be a UUID.\\\"}}, \\\"conditions\\\": {\\\"amqp_connection\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"CollectdConnectionType\\\"}, \\\"amqp1\\\"]}, \\\"amqp_default_connection\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"CollectdAmqpHost\\\"}, \\\"nil\\\"]}, \\\"amqp_default_interval\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"CollectdAmqpInterval\\\"}, -666]}, \\\"amqp_default_send_queue_limit\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"CollectdAmqpSendQueueLimit\\\"}, -1]}, \\\"collectd_connection\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"CollectdConnectionType\\\"}, \\\"network\\\"]}, \\\"enable_sensubility\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"CollectdEnableSensubility\\\"}, true]}, \\\"enable_stf\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"EnableSTF\\\"}, true]}, \\\"enable_sqlalchemy_collectd\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"EnableSQLAlchemyCollectd\\\"}, true]}, \\\"sensubility_needs_sudo\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"CollectdSensubilityExecSudoRule\\\"}, \\\"\\\"]}}, \\\"enable_libpodstats\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"CollectdEnableLibpodstats\\\"}, true]}, \\\"ipmi_monitor\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"IpmiMonitor\\\"]}, \\\"\\\"]}}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerCollectdImage\\\": \\\"ContainerCollectdImage\\\", \\\"ContainerCollectdConfigImage\\\": \\\"ContainerCollectdConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerCollectdImage\\\": {\\\"get_param\\\": \\\"ContainerCollectdImage\\\"}, \\\"ContainerCollectdConfigImage\\\": {\\\"get_param\\\": \\\"ContainerCollectdConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the collectd role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"collectd\\\", \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"tripleo::profile::base::metrics::collectd::enable_file_logging\\\": true, \\\"collectd::plugin::logfile::log_file\\\": \\\"/var/log/collectd/collectd.log\\\"}, {\\\"collectd::manage_repo\\\": false, \\\"collectd::purge\\\": true, \\\"collectd::recurse\\\": true, \\\"collectd::purge_config\\\": true, \\\"collectd::minimum_version\\\": \\\"5.7\\\", \\\"collectd::interval\\\": {\\\"get_param\\\": \\\"CollectdDefaultPollingInterval\\\"}, \\\"collectd::plugin::unixsock::socketgroup\\\": \\\"root\\\", \\\"collectd::plugin::unixsock::socketfile\\\": \\\"/run/collectd-socket\\\", \\\"collectd::plugin::unixsock::deletesocket\\\": true, \\\"collectd::plugin::cpu::reportbycpu\\\": true, \\\"collectd::plugin::cpu::reportbystate\\\": true, \\\"collectd::plugin::cpu::reportnumcpu\\\": false, \\\"collectd::plugin::cpu::valuespercentage\\\": true, \\\"collectd::plugin::df::ignoreselected\\\": true, \\\"collectd::plugin::df::reportbydevice\\\": true, \\\"collectd::plugin::df::fstypes\\\": [\\\"xfs\\\"], \\\"collectd::plugin::load::reportrelative\\\": true, \\\"collectd::plugin::virt::connection\\\": \\\"qemu:///system\\\", \\\"collectd::plugin::virt::extra_stats\\\": {\\\"list_join\\\": [\\\" \\\", [\\\"pcpu\\\", \\\"cpu_util\\\", \\\"vcpu\\\", \\\"memory\\\", \\\"disk\\\", \\\"disk_err\\\", \\\"disk_allocation\\\", \\\"disk_capacity\\\", \\\"disk_physical\\\", \\\"domain_state\\\", \\\"job_stats_background\\\", \\\"perf\\\"]]}, \\\"collectd::plugin::virt::hostname_format\\\": \\\"hostname\\\", \\\"tripleo.collectd.plugins.collectd\\\": {\\\"yaql\\\": {\\\"data\\\": {\\\"default_plugins\\\": {\\\"get_param\\\": \\\"CollectdDefaultPlugins\\\"}, \\\"stf_plugins\\\": {\\\"if\\\": [\\\"enable_stf\\\", [\\\"cpu\\\", \\\"df\\\", \\\"load\\\", \\\"connectivity\\\", \\\"intel_rdt\\\", \\\"procevent\\\"], []]}, \\\"extra_plugins\\\": {\\\"get_param\\\": \\\"CollectdExtraPlugins\\\"}}, \\\"expression\\\": \\\"($.data.default_plugins + $.data.stf_plugins + $.data.extra_plugins) .flatten().distinct()\\\\n\\\"}}}, {\\\"if\\\": [\\\"amqp_connection\\\", {\\\"map_merge\\\": [{\\\"tripleo::profile::base::metrics::collectd::amqp_transport_name\\\": {\\\"get_param\\\": \\\"CollectdAmqpTransportName\\\"}, \\\"tripleo::profile::base::metrics::collectd::amqp_address\\\": {\\\"get_param\\\": \\\"CollectdAmqpAddress\\\"}, \\\"tripleo::profile::base::metrics::collectd::amqp_instances\\\": {\\\"get_param\\\": \\\"CollectdAmqpInstances\\\"}, \\\"tripleo::profile::base::metrics::collectd::amqp_retry_delay\\\": {\\\"get_param\\\": \\\"CollectdAmqpRetryDelay\\\"}}, {\\\"if\\\": [\\\"amqp_default_interval\\\", {}, {\\\"tripleo::profile::base::metrics::collectd::amqp_interval\\\": {\\\"get_param\\\": \\\"CollectdAmqpInterval\\\"}}]}, {\\\"if\\\": [\\\"amqp_default_send_queue_limit\\\", {}, {\\\"tripleo::profile::base::metrics::collectd::amqp_send_queue_limit\\\": {\\\"get_param\\\": \\\"CollectdAmqpSendQueueLimit\\\"}}]}, {\\\"if\\\": [\\\"amqp_default_connection\\\", {\\\"tripleo::profile::base::metrics::collectd::amqp_host\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", {\\\"str_replace\\\": {\\\"template\\\": \\\"ROLENAMEMetricsQdrNetwork\\\", \\\"params\\\": {\\\"ROLENAME\\\": {\\\"get_param\\\": \\\"RoleName\\\"}}}}]}}}}, \\\"tripleo::profile::base::metrics::collectd::amqp_port\\\": {\\\"get_param\\\": \\\"MetricsQdrPort\\\"}, \\\"tripleo::profile::base::metrics::collectd::amqp_user\\\": {\\\"get_param\\\": \\\"MetricsQdrUsername\\\"}, \\\"tripleo::profile::base::metrics::collectd::amqp_password\\\": {\\\"get_param\\\": \\\"MetricsQdrPassword\\\"}}, {\\\"tripleo::profile::base::metrics::collectd::amqp_host\\\": {\\\"get_param\\\": \\\"CollectdAmqpHost\\\"}, \\\"tripleo::profile::base::metrics::collectd::amqp_port\\\": {\\\"get_param\\\": \\\"CollectdAmqpPort\\\"}, \\\"tripleo::profile::base::metrics::collectd::amqp_user\\\": {\\\"get_param\\\": \\\"CollectdAmqpUser\\\"}, \\\"tripleo::profile::base::metrics::collectd::amqp_password\\\": {\\\"get_param\\\": \\\"CollectdAmqpPassword\\\"}}]}]}, {}]}, {\\\"if\\\": [\\\"collectd_connection\\\", {\\\"tripleo::profile::base::metrics::collectd::collectd_server\\\": {\\\"get_param\\\": \\\"CollectdServer\\\"}, \\\"tripleo::profile::base::metrics::collectd::collectd_port\\\": {\\\"get_param\\\": \\\"CollectdServerPort\\\"}, \\\"tripleo::profile::base::metrics::collectd::collectd_username\\\": {\\\"get_param\\\": \\\"CollectdUsername\\\"}, \\\"tripleo::profile::base::metrics::collectd::collectd_password\\\": {\\\"get_param\\\": \\\"CollectdPassword\\\"}, \\\"tripleo::profile::base::metrics::collectd::collectd_securitylevel\\\": {\\\"get_param\\\": \\\"CollectdSecurityLevel\\\"}}, {}]}, {\\\"if\\\": [\\\"enable_sqlalchemy_collectd\\\", {\\\"map_merge\\\": [{\\\"tripleo::profile::base::metrics::collectd::enable_sqlalchemy_collectd\\\": true}, {\\\"tripleo::profile::base::metrics::collectd::sqlalchemy_collectd_bind_host\\\": {\\\"get_param\\\": \\\"CollectdSQLAlchemyBindHost\\\"}}, {\\\"tripleo::profile::base::metrics::collectd::sqlalchemy_collectd_log_messages\\\": {\\\"get_param\\\": \\\"CollectdSQLAlchemyLogMessages\\\"}}]}, {}]}, {\\\"if\\\": [\\\"enable_sensubility\\\", {\\\"map_merge\\\": [{\\\"if\\\": [\\\"sensubility_needs_sudo\\\", {\\\"tripleo::profile::base::metrics::collectd::sensubility::exec_sudo_rule\\\": {\\\"get_param\\\": \\\"CollectdSensubilityExecSudoRule\\\"}}, {}]}, {\\\"tripleo::profile::base::metrics::collectd::enable_sensubility\\\": {\\\"get_param\\\": \\\"CollectdEnableSensubility\\\"}, \\\"tripleo::profile::base::metrics::collectd::sensubility::connection\\\": {\\\"get_param\\\": \\\"CollectdSensubilityConnection\\\"}, \\\"tripleo::profile::base::metrics::collectd::sensubility::log_level\\\": {\\\"get_param\\\": \\\"CollectdSensubilityLogLevel\\\"}, \\\"tripleo::profile::base::metrics::collectd::sensubility::client_name\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'fqdn_NETWORK\')}\\\", \\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", {\\\"str_replace\\\": {\\\"template\\\": \\\"ROLENAMEMetricsQdrNetwork\\\", \\\"params\\\": {\\\"ROLENAME\\\": {\\\"get_param\\\": \\\"RoleName\\\"}}}}]}}}}, \\\"tripleo::profile::base::metrics::collectd::sensubility::client_address\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'NETWORK\')}\\\", \\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", {\\\"str_replace\\\": {\\\"template\\\": \\\"ROLENAMEMetricsQdrNetwork\\\", \\\"params\\\": {\\\"ROLENAME\\\": {\\\"get_param\\\": \\\"RoleName\\\"}}}}]}}}}, \\\"tripleo::profile::base::metrics::collectd::sensubility::keepalive_interval\\\": {\\\"get_param\\\": \\\"CollectdSensubilityKeepaliveInterval\\\"}, \\\"tripleo::profile::base::metrics::collectd::sensubility::tmp_base_dir\\\": {\\\"get_param\\\": \\\"CollectdSensubilityTmpDir\\\"}, \\\"tripleo::profile::base::metrics::collectd::sensubility::shell_path\\\": {\\\"get_param\\\": \\\"CollectdSensubilityShellPath\\\"}, \\\"tripleo::profile::base::metrics::collectd::sensubility::worker_count\\\": {\\\"get_param\\\": \\\"CollectdSensubilityWorkerCount\\\"}, \\\"tripleo::profile::base::metrics::collectd::sensubility::checks\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"CollectdSensubilityChecks\\\"}, {\\\"if\\\": [{\\\"get_param\\\": \\\"CollectdEnableContainerHealthCheck\\\"}, {\\\"check-container-health\\\": {\\\"standalone\\\": true, \\\"command\\\": {\\\"get_param\\\": \\\"CollectdContainerHealthCheckCommand\\\"}, \\\"interval\\\": {\\\"get_param\\\": \\\"CollectdContainerHealthCheckInterval\\\"}, \\\"handlers\\\": {\\\"get_param\\\": \\\"CollectdContainerHealthCheckHandlers\\\"}, \\\"occurrences\\\": {\\\"get_param\\\": \\\"CollectdContainerHealthCheckOccurrences\\\"}, \\\"refresh\\\": {\\\"get_param\\\": \\\"CollectdContainerHealthCheckRefresh\\\"}}}, {}]}]}, \\\"tripleo::profile::base::metrics::collectd::sensubility::results_channel\\\": {\\\"get_param\\\": \\\"CollectdSensubilityResultsChannel\\\"}, \\\"tripleo::profile::base::metrics::collectd::sensubility::transport\\\": {\\\"get_param\\\": \\\"CollectdSensubilityTransport\\\"}, \\\"tripleo::profile::base::metrics::collectd::sensubility::amqp_port\\\": {\\\"get_param\\\": \\\"CollectdAmqpPort\\\"}}]}, {}]}, {\\\"if\\\": [\\\"enable_libpodstats\\\", {\\\"tripleo::profile::base::metrics::collectd::enable_libpodstats\\\": {\\\"get_param\\\": \\\"CollectdEnableLibpodstats\\\"}}, {}]}, {\\\"if\\\": [{\\\"get_param\\\": \\\"DeployedCeph\\\"}, {\\\"collectd::plugin::ceph::ceph_fsid\\\": {\\\"get_param\\\": \\\"CephClusterFSID\\\"}}]}]}, \\\"service_config_settings\\\": {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_collectd\\\": [{\\\"get_param\\\": \\\"CollectdLoggingSource\\\"}]}}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"collectd\\\", \\\"puppet_tags\\\": \\\"collectd_client_config,exec\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::metrics::collectd\\\", \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCollectdConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/collectd.json\\\": {\\\"command\\\": \\\"/usr/sbin/collectd -f\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/etc/collectd.d\\\", \\\"dest\\\": \\\"/etc/\\\", \\\"merge\\\": false, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/collectd\\\", \\\"owner\\\": \\\"collectd:collectd\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/scripts\\\", \\\"owner\\\": \\\"collectd:collectd\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/config-scripts\\\", \\\"owner\\\": \\\"collectd:collectd\\\", \\\"recurse\\\": true}]}}, \\\"container_config_scripts\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"container_config_scripts\\\"]}, {\\\"collectd_check_health.py\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": {\\\"get_file\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/monitoring/collectd_check_health.py\\\"}}}]}, \\\"docker_config\\\": {\\\"step_2\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"CollectdEnableSensubility\\\"}, {\\\"collectd_init_perm\\\": {\\\"image\\\": {\\\"get_param\\\": \\\"ContainerCollectdImage\\\"}, \\\"net\\\": \\\"none\\\", \\\"user\\\": \\\"root\\\", \\\"volumes\\\": [\\\"/var/lib/tripleo-podman/collectd:/tmp/run:rw,z\\\"], \\\"command\\\": [\\\"setfacl\\\", \\\"-R\\\", \\\"-m\\\", \\\"u:collectd:rwx\\\", \\\"/tmp/run\\\"]}}]}, \\\"step_3\\\": {\\\"collectd\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCollectdImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"user\\\": \\\"root\\\", \\\"restart\\\": \\\"always\\\", \\\"memory\\\": \\\"512m\\\", \\\"device\\\": {\\\"if\\\": [\\\"ipmi_monitor\\\", {\\\"get_param\\\": [\\\"RoleParameters\\\", \\\"IpmiMonitor\\\"]}]}, \\\"cap_add\\\": {\\\"list_concat\\\": [{\\\"get_param\\\": \\\"CollectdContainerAdditionalCapAdd\\\"}, [\\\"IPC_LOCK\\\"]]}, \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/collectd.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/containers/storage/overlay-containers:/var/lib/containers/storage/overlay-containers:ro\\\", \\\"/var/lib/config-data/puppet-generated/collectd:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/log/containers/collectd:/var/log/collectd:rw,z\\\", \\\"/var/lib/container-config-scripts:/config-scripts:ro\\\", \\\"/var/lib/container-user-scripts:/scripts:z\\\", \\\"/run:/run:rw\\\", \\\"/sys/fs/cgroup:/sys/fs/cgroup:ro\\\"], {\\\"if\\\": [{\\\"get_param\\\": \\\"CollectdEnableSensubility\\\"}, [\\\"/var/lib/tripleo-podman/collectd:/run/podman:z\\\"]]}]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/collectd\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/lib/container-user-scripts/\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0755\\\"}]}, {\\\"name\\\": \\\"import provision_mcelog\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_provision_mcelog\\\"}, \\\"when\\\": {\\\"get_param\\\": \\\"CollectdEnableMcelog\\\"}}], \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"set enable_sensubility fact\\\", \\\"set_fact\\\": {\\\"enable_sensubility\\\": {\\\"get_param\\\": \\\"CollectdEnableSensubility\\\"}}}, {\\\"name\\\": \\\"create podman socket for sensubility purposes\\\", \\\"block\\\": [{\\\"name\\\": \\\"create podman socket and appropriate systemd service\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_service\\\"}, \\\"vars\\\": {\\\"tripleo_podman_socket_path\\\": \\\"/var/lib/tripleo-podman/collectd/podman.sock\\\"}}, {\\\"name\\\": \\\"create systemd service for ensuring socket file ACL contains collectd\\\", \\\"become\\\": true, \\\"ansible.builtin.copy\\\": {\\\"content\\\": \\\"[Unit]\\\\nDescription=ACL setting for /var/lib/tripleo-podman/collectd/podman.sock\\\\nRequires=tripleo_collectd.service\\\\nAfter=tripleo_podman.service\\\\nAfter=tripleo_collectd.service\\\\n\\\\n[Service]\\\\nType=oneshot\\\\nExecStart=/usr/bin/podman exec -it collectd setfacl -m m:rwx /run/podman/podman.sock\\\\nExecStart=/usr/bin/podman exec -it collectd setfacl -R -m u:collectd:rwx /run/podman\\\\nExecStart=/usr/bin/podman exec -it collectd setfacl -d -m u:collectd:rwx /run/podman\\\\n\\\\n[Install]\\\\nWantedBy=multi-user.target\\\\n\\\", \\\"dest\\\": \\\"/etc/systemd/system/tripleo_podman_collectd_acl.service\\\", \\\"mode\\\": 420}}, {\\\"name\\\": \\\"enable podman.sock ACL service\\\", \\\"ansible.builtin.service\\\": {\\\"name\\\": \\\"tripleo_podman_collectd_acl.service\\\", \\\"enabled\\\": true}}, {\\\"name\\\": \\\"create directory for downloads of users\' scripts\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/container-user-scripts\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0755\\\"}}, {\\\"name\\\": \\\"download exec scripts\\\", \\\"ansible.builtin.get_url\\\": {\\\"url\\\": \\\"{{ item.source }}\\\", \\\"checksum\\\": \\\"{{ item.checksum }}\\\", \\\"dest\\\": \\\"/var/lib/container-user-scripts/{{ item.name }}\\\", \\\"mode\\\": \\\"0755\\\"}, \\\"with_items\\\": {\\\"get_param\\\": \\\"CollectdSensubilityScripts\\\"}}], \\\"when\\\": [\\\"enable_sensubility|bool\\\", \\\"step|int == 1\\\"]}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"remove rsyslog configuration for podman healthcheck log\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_rsyslog_cleanup\\\"}}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"remove rsyslog configuration for podman healthcheck log\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_rsyslog_cleanup\\\"}}, {\\\"name\\\": \\\"Force pull image collectd\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_run\\\"], \\\"when\\\": [\\\"step|int == 3\\\"], \\\"containers.podman.podman_image\\\": {\\\"name\\\": {\\\"get_param\\\": \\\"ContainerCollectdImage\\\"}, \\\"force\\\": true}}, {\\\"name\\\": \\\"UBI8 to UBI9 switch of collectd\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_run\\\"], \\\"when\\\": [\\\"step|int == 5\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Update collectd to UBI9\\\", \\\"tripleo_container_manage\\\": {\\\"config_dir\\\": \\\"/var/lib/tripleo-config/container-startup-config/step_3\\\", \\\"config_patterns\\\": \\\"collectd.json\\\", \\\"config_id\\\": [\\\"tripleo_step3\\\"], \\\"log_base_path\\\": \\\"{{ container_log_stdout_path }}\\\", \\\"debug\\\": \\\"{{ enable_debug | bool }}\\\", \\\"config_overrides\\\": {\\\"collectd\\\": {\\\"image\\\": {\\\"get_param\\\": \\\"ContainerCollectdImage\\\"}}}}}]}]}}}}\", \"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Qpid dispatch router service for metrics and monitoring purposes\\\\n\\\", \\\"parameters\\\": {\\\"ContainerMetricsQdrImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerMetricsQdrConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the qdrouterd config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"MonitoringSubscriptionQdr\\\": {\\\"default\\\": \\\"overcloud-qdr\\\", \\\"type\\\": \\\"string\\\"}, \\\"MetricsQdrLoggingSource\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {\\\"tag\\\": \\\"openstack.nova.consoleauth\\\", \\\"file\\\": \\\"/var/log/containers/metrics_qdr/metrics_qdr.log\\\", \\\"startmsg.regex\\\": \\\"^[0-9]{4}-[0-9]{2}-[0-9]{2} [0-9]{2}:[0-9]{2}:[0-9]{2}(.[0-9]+ \\\\\\\\\\\\\\\\+[0-9]+)? [A-Z]+ \\\\\\\\\\\\\\\\([a-z]+\\\\\\\\\\\\\\\\) \\\"}}, \\\"MetricsQdrPort\\\": {\\\"default\\\": 5666, \\\"description\\\": \\\"Service name or port number on which the qdrouterd will accept connections.\\\", \\\"type\\\": \\\"number\\\"}, \\\"MetricsQdrUsername\\\": {\\\"default\\\": \\\"guest\\\", \\\"description\\\": \\\"Username which should be used to authenticate to the deployed qdrouterd.\\\", \\\"type\\\": \\\"string\\\"}, \\\"MetricsQdrPassword\\\": {\\\"default\\\": \\\"guest\\\", \\\"description\\\": \\\"Password which should be used to authenticate to the deployed qdrouterd.\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"MetricsQdrConnectors\\\": {\\\"default\\\": [], \\\"description\\\": \\\"Connectors configuration (array of hashes).\\\", \\\"type\\\": \\\"json\\\"}, \\\"MetricsQdrSSLProfiles\\\": {\\\"default\\\": [{\\\"name\\\": \\\"sslProfile\\\"}], \\\"description\\\": \\\"SSL Profiles for the connectors (array of hashes).\\\", \\\"type\\\": \\\"json\\\"}, \\\"MetricsQdrAddresses\\\": {\\\"default\\\": [{\\\"prefix\\\": \\\"collectd\\\", \\\"distribution\\\": \\\"multicast\\\"}, {\\\"prefix\\\": \\\"ceilometer/metering.sample\\\", \\\"distribution\\\": \\\"multicast\\\"}, {\\\"prefix\\\": \\\"ceilometer/event.sample\\\", \\\"distribution\\\": \\\"multicast\\\"}], \\\"description\\\": \\\"Addresses configuration (array of hashes).\\\", \\\"type\\\": \\\"json\\\"}, \\\"MetricsQdrAutoLinks\\\": {\\\"default\\\": [], \\\"description\\\": \\\"AutoLinks for the Configured Addresses\\\", \\\"type\\\": \\\"json\\\"}, \\\"MetricsQdrUseSSL\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Set to true if it is required to use SSL or TLS on the connection for the local listener. !WARNING! Currently breaks connections from collectd and ceilometer.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"MetricsQdrUseEncryption\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Set to true if it is required to encrypt connection to the peer for listener. Not currently implemented, use EnableInternalTLS instead. This option can be ignored.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"MetricsQdrSaslMechanisms\\\": {\\\"default\\\": \\\"ANONYMOUS\\\", \\\"description\\\": \\\"List of accepted SASL auth mechanisms for listener in format of comma separated list.\\\", \\\"type\\\": \\\"string\\\"}, \\\"MetricsQdrSslCertDb\\\": {\\\"default\\\": \\\"/etc/ipa/ca.crt\\\", \\\"description\\\": \\\"Path to SSL certificate db for listener.\\\", \\\"type\\\": \\\"string\\\"}, \\\"MetricsQdrSslCertFile\\\": {\\\"default\\\": \\\"/etc/pki/tls/certs/metrics_qdr.crt\\\", \\\"description\\\": \\\"Path to SSL certificate file for listener.\\\", \\\"type\\\": \\\"string\\\"}, \\\"MetricsQdrSslKeyFile\\\": {\\\"default\\\": \\\"/etc/pki/tls/private/metrics_qdr.key\\\", \\\"description\\\": \\\"Path to SSL private key file for listener.\\\", \\\"type\\\": \\\"string\\\"}, \\\"MetricsQdrSslPwFile\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Path to SSL password file for certificate key for listener.\\\", \\\"type\\\": \\\"string\\\"}, \\\"MetricsQdrSslPassword\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"SSL password to be supplied for listener.\\\", \\\"type\\\": \\\"string\\\"}, \\\"MetricsQdrTrustedCerts\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Path to file containing trusted certificates for listener.\\\", \\\"type\\\": \\\"string\\\"}, \\\"MetricsQdrAuthenticateClient\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Authenticate the client using SSL/TLS\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"MetricsQdrExternalEndpoint\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether QDR should listen on external network interface. To enable listening on external network one must deploy QDRs in mesh mode.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"InternalTLSCAFile\\\": {\\\"default\\\": \\\"/etc/ipa/ca.crt\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Specifies the default CA cert to use if TLS is used for services in the internal network.\\\"}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"EnableSTF\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Set to true to enable configuration for STF client.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"CertificateKeySize\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"2048\\\", \\\"description\\\": \\\"Specifies the private key size used when creating the certificate.\\\"}, \\\"QdrCertificateKeySize\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Override the private key size used when creating the certificate for this service\\\"}}, \\\"conditions\\\": {\\\"internal_tls_enabled\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, true]}, \\\"listener_ssl_enabled\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"MetricsQdrUseSSL\\\"}, true]}, \\\"enable_stf\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"EnableSTF\\\"}, true]}, \\\"key_size_override_unset\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"QdrCertificateKeySize\\\"}, \\\"\\\"]}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerMetricsQdrImage\\\": \\\"ContainerMetricsQdrImage\\\", \\\"ContainerMetricsQdrConfigImage\\\": \\\"ContainerMetricsQdrConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerMetricsQdrImage\\\": {\\\"get_param\\\": \\\"ContainerMetricsQdrImage\\\"}, \\\"ContainerMetricsQdrConfigImage\\\": {\\\"get_param\\\": \\\"ContainerMetricsQdrConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the metrics Qdr role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"metrics_qdr\\\", \\\"firewall_rules\\\": {\\\"map_merge\\\": [{\\\"109 metrics qdr\\\": {\\\"dport\\\": [{\\\"get_param\\\": \\\"MetricsQdrPort\\\"}]}}, {\\\"map_merge\\\": {\\\"repeat\\\": {\\\"for_each\\\": {\\\"<%net_cidr%>\\\": {\\\"get_param\\\": [\\\"ServiceData\\\", \\\"net_cidr_map\\\", \\\"ctlplane\\\"]}}, \\\"template\\\": {\\\"109 accept internal metrics qdr ctlplane subnet <%net_cidr%>\\\": {\\\"dport\\\": [5667, 5668]}}}}}]}, \\\"monitoring_subscription\\\": {\\\"get_param\\\": \\\"MonitoringSubscriptionQdr\\\"}, \\\"service_config_settings\\\": {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_metrics_qdr\\\": [{\\\"get_param\\\": \\\"MetricsQdrLoggingSource\\\"}]}}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"tripleo::profile::base::metrics::qdr::listener_addr\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", {\\\"str_replace\\\": {\\\"template\\\": \\\"ROLENAMEMetricsQdrNetwork\\\", \\\"params\\\": {\\\"ROLENAME\\\": {\\\"get_param\\\": \\\"RoleName\\\"}}}}]}}}}, \\\"tripleo::haproxy::metrics_qdr\\\": {\\\"get_param\\\": \\\"MetricsQdrExternalEndpoint\\\"}, \\\"tripleo::profile::base::metrics::qdr::listener_port\\\": {\\\"get_param\\\": \\\"MetricsQdrPort\\\"}, \\\"tripleo::profile::base::metrics::qdr::username\\\": {\\\"get_param\\\": \\\"MetricsQdrUsername\\\"}, \\\"tripleo::profile::base::metrics::qdr::password\\\": {\\\"get_param\\\": \\\"MetricsQdrPassword\\\"}, \\\"tripleo::profile::base::metrics::qdr::connectors\\\": {\\\"get_param\\\": \\\"MetricsQdrConnectors\\\"}, \\\"tripleo::profile::base::metrics::qdr::addresses\\\": {\\\"get_param\\\": \\\"MetricsQdrAddresses\\\"}, \\\"tripleo::profile::base::metrics::qdr::autolink_addresses\\\": {\\\"get_param\\\": \\\"MetricsQdrAutoLinks\\\"}, \\\"tripleo::profile::base::metrics::qdr::listener_require_ssl\\\": {\\\"if\\\": [\\\"listener_ssl_enabled\\\", true, false]}, \\\"tripleo::profile::base::metrics::qdr::listener_require_encrypt\\\": {\\\"get_param\\\": \\\"MetricsQdrUseEncryption\\\"}, \\\"tripleo::profile::base::metrics::qdr::listener_sasl_mech\\\": {\\\"get_param\\\": \\\"MetricsQdrSaslMechanisms\\\"}, \\\"tripleo::profile::base::metrics::qdr::listener_ssl_cert_db\\\": {\\\"get_param\\\": \\\"MetricsQdrSslCertDb\\\"}, \\\"tripleo::profile::base::metrics::qdr::listener_ssl_cert_file\\\": {\\\"get_param\\\": \\\"MetricsQdrSslCertFile\\\"}, \\\"tripleo::profile::base::metrics::qdr::listener_ssl_key_file\\\": {\\\"get_param\\\": \\\"MetricsQdrSslKeyFile\\\"}, \\\"tripleo::profile::base::metrics::qdr::listener_ssl_pw_file\\\": {\\\"get_param\\\": \\\"MetricsQdrSslPwFile\\\"}, \\\"tripleo::profile::base::metrics::qdr::listener_ssl_password\\\": {\\\"get_param\\\": \\\"MetricsQdrSslPassword\\\"}, \\\"tripleo::profile::base::metrics::qdr::listener_trusted_certs\\\": {\\\"get_param\\\": \\\"MetricsQdrTrustedCerts\\\"}, \\\"qdr::log_enable\\\": \\\"info+\\\", \\\"qdr::log_output\\\": \\\"/var/log/qdrouterd/metrics_qdr.log\\\", \\\"qdr::listener_auth_peer\\\": {\\\"get_param\\\": \\\"MetricsQdrAuthenticateClient\\\"}}, {\\\"if\\\": [\\\"internal_tls_enabled\\\", {\\\"tripleo::profile::base::metrics::qdr::ssl_profiles\\\": {\\\"list_concat\\\": [{\\\"get_param\\\": \\\"MetricsQdrSSLProfiles\\\"}, [{\\\"name\\\": \\\"tlsProfile\\\", \\\"certFile\\\": \\\"/etc/pki/tls/certs/metrics_qdr.crt\\\", \\\"keyFile\\\": \\\"/etc/pki/tls/private/metrics_qdr.key\\\", \\\"caCertFile\\\": {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}}]]}}, {\\\"tripleo::profile::base::metrics::qdr::ssl_profiles\\\": {\\\"get_param\\\": \\\"MetricsQdrSSLProfiles\\\"}}]}, {\\\"if\\\": [\\\"enable_stf\\\", {\\\"tripleo::profile::base::metrics::qdr::interior_mesh_nodes\\\": \\\"\\\", \\\"tripleo::profile::base::metrics::qdr::router_mode\\\": \\\"edge\\\"}, null]}]}, \\\"metadata_settings\\\": {\\\"if\\\": [\\\"internal_tls_enabled\\\", [{\\\"service\\\": \\\"metrics_qdr\\\", \\\"network\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", {\\\"str_replace\\\": {\\\"template\\\": \\\"ROLENAMEMetricsQdrNetwork\\\", \\\"params\\\": {\\\"ROLENAME\\\": {\\\"get_param\\\": \\\"RoleName\\\"}}}}]}, \\\"type\\\": \\\"node\\\"}], null]}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"metrics_qdr\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::metrics::qdr\\\\n\\\", \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMetricsQdrConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/metrics_qdr.json\\\": {\\\"command\\\": \\\"/usr/sbin/qdrouterd -c /etc/qpid-dispatch/qdrouterd.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-tls/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true, \\\"optional\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/lib/qdrouterd\\\", \\\"owner\\\": \\\"qdrouterd:qdrouterd\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/certs/metrics_qdr.crt\\\", \\\"owner\\\": \\\"qdrouterd:qdrouterd\\\", \\\"optional\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/private/metrics_qdr.key\\\", \\\"owner\\\": \\\"qdrouterd:qdrouterd\\\", \\\"optional\\\": true}]}}, \\\"docker_config\\\": {\\\"step_1\\\": {\\\"metrics_qdr_init_logs\\\": {\\\"start_order\\\": 0, \\\"detach\\\": false, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMetricsQdrImage\\\"]}, \\\"net\\\": \\\"none\\\", \\\"privileged\\\": false, \\\"user\\\": \\\"root\\\", \\\"volumes\\\": [\\\"/var/log/containers/metrics_qdr:/var/log/qdrouterd:z\\\"], \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R qdrouterd:qdrouterd /var/log/qdrouterd\\\"]}, \\\"metrics_qdr\\\": {\\\"start_order\\\": 1, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMetricsQdrImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"user\\\": \\\"qdrouterd\\\", \\\"privileged\\\": false, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/metrics_qdr.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/metrics_qdr:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/metrics_qdr:/var/lib/qdrouterd:z\\\", \\\"/var/log/containers/metrics_qdr:/var/log/qdrouterd:z\\\"], {\\\"if\\\": [\\\"internal_tls_enabled\\\", [\\\"/etc/pki/tls/certs/metrics_qdr.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/metrics_qdr.crt:ro\\\", \\\"/etc/pki/tls/private/metrics_qdr.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/metrics_qdr.key:ro\\\"], null]}]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Certificate generation\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"enable_internal_tls\\\"], \\\"block\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"linux-system-roles.certificate\\\"}, \\\"vars\\\": {\\\"certificate_requests\\\": [{\\\"name\\\": \\\"metrics_qdr\\\", \\\"dns\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"{{fqdn_NETWORK}}\\\", \\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", {\\\"str_replace\\\": {\\\"template\\\": \\\"ROLENAMEMetricsQdrNetwork\\\", \\\"params\\\": {\\\"ROLENAME\\\": {\\\"get_param\\\": \\\"RoleName\\\"}}}}]}}}}, \\\"principal\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"metrics_qdr/{{fqdn_NETWORK}}@{{idm_realm}}\\\", \\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", {\\\"str_replace\\\": {\\\"template\\\": \\\"ROLENAMEMetricsQdrNetwork\\\", \\\"params\\\": {\\\"ROLENAME\\\": {\\\"get_param\\\": \\\"RoleName\\\"}}}}]}}}}, \\\"run_after\\\": \\\"container_name=$({{container_cli}} ps --format=\\\\\\\\{\\\\\\\\{.Names\\\\\\\\}\\\\\\\\} | grep metrics_qdr)\\\\nservice_crt=\\\\\\\"/etc/pki/tls/certs/metrics_qdr.crt\\\\\\\"\\\\nservice_key=\\\\\\\"/etc/pki/tls/private/metrics_qdr.key\\\\n# Copy the new cert from the mount-point to the real path\\\\n{{container_cli}} exec \\\\\\\"$container_name\\\\\\\" cp \\\\\\\"/var/lib/kolla/config_files/src-tls$service_crt\\\\\\\" \\\\\\\"$service_crt\\\\\\\"\\\\n# Copy the new key from the mount-point to the real path\\\\n{{container_cli}} exec \\\\\\\"$container_name\\\\\\\" cp \\\\\\\"/var/lib/kolla/config_files/src-tls$service_key\\\\\\\" \\\\\\\"$service_key\\\\\\\"\\\\n# Set appropriate permissions\\\\n{{container_cli}} exec \\\\\\\"$container_name\\\\\\\" chown qdrouterd:qdrouterd \\\\\\\"$service_crt\\\\\\\"\\\\n{{container_cli}} exec \\\\\\\"$container_name\\\\\\\" chown qdrouterd:qdrouterd \\\\\\\"$service_key\\\\\\\"\\\\n# Trigger a container restart to read the new certificate\\\\n{{container_cli}} restart \\\\\\\"$container_name\\\\\\\"\\\\n\\\", \\\"key_size\\\": {\\\"if\\\": [\\\"key_size_override_unset\\\", {\\\"get_param\\\": \\\"CertificateKeySize\\\"}, {\\\"get_param\\\": \\\"QdrCertificateKeySize\\\"}]}, \\\"ca\\\": \\\"ipa\\\"}]}}]}], \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent logs directory\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode|default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/metrics_qdr\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/lib/metrics_qdr\\\", \\\"setype\\\": \\\"container_file_t\\\"}]}]}}}}\", \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Rabbitmq service\\\\n\\\", \\\"parameters\\\": {\\\"ContainerRabbitmqImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerRabbitmqConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the rabbitmq config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"RabbitCookie\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"hidden\\\": true}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"RabbitUserName\\\": {\\\"default\\\": \\\"guest\\\", \\\"description\\\": \\\"The username for RabbitMQ\\\", \\\"type\\\": \\\"string\\\"}, \\\"RabbitPassword\\\": {\\\"description\\\": \\\"The password for RabbitMQ\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"RabbitFDLimit\\\": {\\\"default\\\": 65536, \\\"description\\\": \\\"Configures RabbitMQ FD limit\\\", \\\"type\\\": \\\"number\\\"}, \\\"RabbitTCPBacklog\\\": {\\\"default\\\": 4096, \\\"description\\\": \\\"Configures RabbitMQ maximum TCP Backlog\\\", \\\"type\\\": \\\"number\\\"}, \\\"RabbitIPv6\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Enable IPv6 in RabbitMQ\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"RabbitHAQueues\\\": {\\\"description\\\": \\\"The number of HA queues to be configured in rabbit. The default is -1 which translates to \\\\\\\"ha-mode all\\\\\\\". The special value 0 will be automatically overridden to CEIL(N/2) where N is the number of nodes running rabbitmq.\\\", \\\"default\\\": 0, \\\"type\\\": \\\"number\\\"}, \\\"RabbitNetTickTime\\\": {\\\"description\\\": \\\"The number of seconds to configure the value of the erlang net_ticktime kernel variable.\\\", \\\"default\\\": 15, \\\"type\\\": \\\"number\\\"}, \\\"RabbitFIPS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false, \\\"description\\\": \\\"Configures RabbitMQ to run in FIPS mode\\\"}, \\\"RabbitAdditionalErlArgs\\\": {\\\"description\\\": \\\"Additional parameters passed to the Erlang subsystem. The string needs to be enclosed in quotes twice. We default to \'+sbwt none +sbwtdcpu none +sbwtdio none\' in order to have the erlang vm be less busy on spinlocks, but we allow a simple way of overriding it.\\\", \\\"default\\\": \\\"\'+sbwt none +sbwtdcpu none +sbwtdio none\'\\\", \\\"type\\\": \\\"string\\\"}, \\\"MonitoringSubscriptionRabbitmq\\\": {\\\"default\\\": \\\"overcloud-rabbitmq\\\", \\\"type\\\": \\\"string\\\"}, \\\"DeployIdentifier\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\\\n\\\"}, \\\"CertificateKeySize\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"2048\\\", \\\"description\\\": \\\"Specifies the private key size used when creating the certificate.\\\"}, \\\"RabbitmqCertificateKeySize\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Override the private key size used when creating the certificate for this service\\\"}, \\\"InternalTLSCAFile\\\": {\\\"default\\\": \\\"/etc/ipa/ca.crt\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Specifies the default CA cert to use if TLS is used for services in the internal network.\\\"}, \\\"RabbitmqEnableManagementAccess\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false, \\\"description\\\": \\\"Allow access to RabbitMQ management plugin over network\\\"}}, \\\"parameter_groups\\\": [{\\\"label\\\": \\\"deprecated\\\", \\\"description\\\": \\\"The following parameters are deprecated and will be removed. They should not\\\\nbe relied on for new deployments. If you have concerns regarding deprecated\\\\nparameters, please contact the TripleO development team on IRC or the\\\\nOpenStack mailing list.\\\\n\\\", \\\"parameters\\\": [\\\"RabbitIPv6\\\"]}], \\\"conditions\\\": {\\\"internal_tls_enabled\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, true]}, \\\"is_ipv6\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"ServiceData\\\", \\\"net_ip_version_map\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"RabbitmqNetwork\\\"]}]}, 6]}, \\\"key_size_override_unset\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"RabbitmqCertificateKeySize\\\"}, \\\"\\\"]}, \\\"rabbitmq_cacert_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, \\\"\\\"]}}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerRabbitmqImage\\\": \\\"ContainerRabbitmqImage\\\", \\\"ContainerRabbitmqConfigImage\\\": \\\"ContainerRabbitmqConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerRabbitmqImage\\\": {\\\"get_param\\\": \\\"ContainerRabbitmqImage\\\"}, \\\"ContainerRabbitmqConfigImage\\\": {\\\"get_param\\\": \\\"ContainerRabbitmqConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Rabbitmq API role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"rabbitmq\\\", \\\"firewall_rules\\\": {\\\"109 rabbitmq\\\": {\\\"dport\\\": {\\\"list_concat\\\": [[4369, 5672, 25672, \\\"25673-25683\\\"], {\\\"if\\\": [{\\\"get_param\\\": \\\"RabbitmqEnableManagementAccess\\\"}, [15672]]}]}}}, \\\"monitoring_subscription\\\": {\\\"get_param\\\": \\\"MonitoringSubscriptionRabbitmq\\\"}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"rabbitmq::file_limit\\\": {\\\"get_param\\\": \\\"RabbitFDLimit\\\"}, \\\"rabbitmq::default_user\\\": {\\\"get_param\\\": \\\"RabbitUserName\\\"}, \\\"rabbitmq::default_pass\\\": {\\\"get_param\\\": \\\"RabbitPassword\\\"}, \\\"rabbit_ipv6\\\": {\\\"if\\\": [\\\"is_ipv6\\\", true, false]}, \\\"rabbitmq::delete_guest_user\\\": false, \\\"rabbitmq::wipe_db_on_cookie_change\\\": true, \\\"rabbitmq::port\\\": 5672, \\\"rabbitmq::loopback_users\\\": [], \\\"rabbitmq::tcp_backlog\\\": {\\\"get_param\\\": \\\"RabbitTCPBacklog\\\"}, \\\"rabbitmq::repos_ensure\\\": false, \\\"rabbitmq::tcp_keepalive\\\": true, \\\"rabbitmq_environment\\\": {\\\"LANG\\\": \\\"en_US.UTF-8\\\", \\\"LC_ALL\\\": \\\"en_US.UTF-8\\\", \\\"NODE_PORT\\\": \\\"\\\", \\\"NODE_IP_ADDRESS\\\": \\\"\\\", \\\"RABBITMQ_NODENAME\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"rabbit@%{hiera(\'fqdn_$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"RabbitmqNetwork\\\"]}}}}, \\\"RABBITMQ_USE_LONGNAME\\\": \\\"true\\\", \\\"RABBITMQ_CTL_DIST_PORT_MIN\\\": \\\"25673\\\", \\\"RABBITMQ_CTL_DIST_PORT_MAX\\\": \\\"25683\\\", \\\"export ERL_EPMD_ADDRESS\\\": \\\"%{hiera(\'rabbitmq::interface\')}\\\"}, \\\"tripleo::profile::base::rabbitmq::additional_erl_args\\\": {\\\"get_param\\\": \\\"RabbitAdditionalErlArgs\\\"}, \\\"rabbitmq_kernel_variables\\\": {\\\"inet_dist_listen_min\\\": \\\"25672\\\", \\\"inet_dist_listen_max\\\": \\\"25672\\\", \\\"net_ticktime\\\": {\\\"get_param\\\": \\\"RabbitNetTickTime\\\"}}, \\\"rabbitmq_config_variables\\\": {\\\"cluster_partition_handling\\\": \\\"ignore\\\", \\\"queue_master_locator\\\": \\\"<<\\\\\\\"min-masters\\\\\\\">>\\\"}, \\\"rabbitmq::config_additional_variables\\\": {\\\"lager\\\": \\\"[{crash_log_count, 0}, { crash_log_date, \\\\\\\"\\\\\\\"}, { crash_log_size, 0 }]\\\"}, \\\"rabbitmq::erlang_cookie\\\": {\\\"get_param\\\": \\\"RabbitCookie\\\"}, \\\"rabbitmq::interface\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"RabbitmqNetwork\\\"]}}}}, \\\"rabbitmq::nr_ha_queues\\\": {\\\"get_param\\\": \\\"RabbitHAQueues\\\"}, \\\"rabbitmq::ssl\\\": {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, \\\"rabbitmq::ssl_erl_dist\\\": {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, \\\"rabbitmq::ssl_port\\\": 5672, \\\"rabbitmq::ssl_depth\\\": 1, \\\"rabbitmq::ssl_only\\\": {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, \\\"rabbitmq::ssl_interface\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"RabbitmqNetwork\\\"]}}}}, \\\"tripleo::profile::base::rabbitmq::enable_internal_tls\\\": {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, \\\"tripleo::profile::base::rabbitmq::fips_mode\\\": {\\\"get_param\\\": \\\"RabbitFIPS\\\"}, \\\"rabbitmq::collect_statistics_interval\\\": 30000}, {\\\"if\\\": [\\\"internal_tls_enabled\\\", {\\\"tripleo::rabbitmq::service_certificate\\\": \\\"/etc/pki/tls/certs/rabbitmq.crt\\\", \\\"tripleo::profile::base::rabbitmq::certificate_specs\\\": {\\\"service_certificate\\\": \\\"/etc/pki/tls/certs/rabbitmq.crt\\\", \\\"service_key\\\": \\\"/etc/pki/tls/private/rabbitmq.key\\\"}, \\\"rabbitmq::ssl_versions\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"RabbitFIPS\\\"}, [\\\"tlsv1.2\\\", \\\"tlsv1.3\\\"], [\\\"tlsv1.2\\\"]]}}, {}]}, {\\\"rabbitmq::admin_enable\\\": false, \\\"rabbitmq::management_enable\\\": true, \\\"rabbitmq::use_config_file_for_plugins\\\": true, \\\"rabbitmq::management_ip_address\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"RabbitmqEnableManagementAccess\\\"}, {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"RabbitmqManagementNetwork\\\"]}}}}, \\\"127.0.0.1\\\"]}, \\\"rabbitmq::management_port\\\": 15672, \\\"rabbitmq::config_management_variables\\\": {\\\"rates_mode\\\": \\\"none\\\"}}, {\\\"if\\\": [\\\"rabbitmq_cacert_set\\\", {\\\"rabbitmq::ssl_cacert\\\": {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, \\\"rabbitmq::ssl_management_cacert\\\": {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}}]}, {\\\"if\\\": [\\\"internal_tls_enabled\\\", {\\\"tripleo::certmonger::rabbitmq::postsave_cmd\\\": \\\"true\\\"}, {}]}]}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"rabbitmq\\\", \\\"step_config\\\": {\\\"list_join\\\": [\\\"\\\\n\\\", [\\\"[\'Rabbitmq_policy\', \'Rabbitmq_user\'].each |String $val| { noop_resource($val) }\\\", \\\"include tripleo::profile::base::rabbitmq\\\"]]}, \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/rabbitmq.json\\\": {\\\"command\\\": \\\"/usr/lib/rabbitmq/bin/rabbitmq-server\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-tls/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true, \\\"optional\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/lib/rabbitmq\\\", \\\"owner\\\": \\\"rabbitmq:rabbitmq\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/certs/rabbitmq.crt\\\", \\\"owner\\\": \\\"rabbitmq:rabbitmq\\\", \\\"optional\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/private/rabbitmq.key\\\", \\\"owner\\\": \\\"rabbitmq:rabbitmq\\\", \\\"optional\\\": true}]}}, \\\"docker_config\\\": {\\\"step_1\\\": {\\\"rabbitmq_init_logs\\\": {\\\"start_order\\\": 0, \\\"detach\\\": false, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}, \\\"net\\\": \\\"none\\\", \\\"privileged\\\": false, \\\"user\\\": \\\"root\\\", \\\"volumes\\\": [\\\"/var/log/containers/rabbitmq:/var/log/rabbitmq\\\"], \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R rabbitmq:rabbitmq /var/log/rabbitmq\\\"]}, \\\"rabbitmq_bootstrap\\\": {\\\"start_order\\\": 1, \\\"detach\\\": false, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"user\\\": \\\"root\\\", \\\"command\\\": [\\\"bash\\\", \\\"-ec\\\", {\\\"list_join\\\": [\\\"\\\\n\\\", [\\\"kolla_set_configs\\\", \\\"if [[ -e \\\\\\\"/var/lib/rabbitmq/.erlang.cookie\\\\\\\" ]]; then rm -f /var/lib/rabbitmq/.erlang.cookie; fi\\\", \\\"hiera \'rabbitmq::erlang_cookie\' > /var/lib/rabbitmq/.erlang.cookie\\\", \\\"chown rabbitmq:rabbitmq /var/lib/rabbitmq/.erlang.cookie\\\", \\\"chmod 400 /var/lib/rabbitmq/.erlang.cookie\\\"]]}], \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/rabbitmq.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/rabbitmq:/var/lib/kolla/config_files/src:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/lib/rabbitmq:/var/lib/rabbitmq\\\", \\\"/var/log/containers/rabbitmq:/var/log/rabbitmq\\\"], {\\\"if\\\": [\\\"internal_tls_enabled\\\", [\\\"/etc/pki/tls/certs/rabbitmq.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/rabbitmq.crt:ro\\\", \\\"/etc/pki/tls/private/rabbitmq.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/rabbitmq.key:ro\\\"], null]}]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\", \\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}}}, \\\"rabbitmq\\\": {\\\"start_order\\\": 2, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/rabbitmq.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/rabbitmq:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/rabbitmq:/var/lib/rabbitmq:z\\\", \\\"/var/log/containers/rabbitmq:/var/log/rabbitmq:z\\\"], {\\\"if\\\": [\\\"internal_tls_enabled\\\", [\\\"/etc/pki/tls/certs/rabbitmq.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/rabbitmq.crt:ro\\\", \\\"/etc/pki/tls/private/rabbitmq.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/rabbitmq.key:ro\\\"], null]}]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"container_puppet_tasks\\\": {\\\"step_2\\\": {\\\"config_volume\\\": \\\"rabbit_init_tasks\\\", \\\"puppet_tags\\\": \\\"rabbitmq_policy,rabbitmq_user\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::rabbitmq\\\", \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqConfigImage\\\"]}, \\\"volumes\\\": [\\\"/var/lib/config-data/puppet-generated/rabbitmq/etc/rabbitmq:/etc/rabbitmq:ro\\\", \\\"/var/lib/rabbitmq:/var/lib/rabbitmq\\\"]}}, \\\"metadata_settings\\\": {\\\"if\\\": [\\\"internal_tls_enabled\\\", [{\\\"service\\\": \\\"rabbitmq\\\", \\\"network\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"RabbitmqNetwork\\\"]}, \\\"type\\\": \\\"node\\\"}], null]}, \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Certificate generation\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"enable_internal_tls\\\"], \\\"block\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"linux-system-roles.certificate\\\"}, \\\"vars\\\": {\\\"certificate_requests\\\": [{\\\"name\\\": \\\"rabbitmq\\\", \\\"dns\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"{{fqdn_$NETWORK}}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"RabbitmqNetwork\\\"]}}}}, \\\"principal\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"rabbitmq/{{fqdn_$NETWORK}}@{{idm_realm}}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"RabbitmqNetwork\\\"]}}}}, \\\"run_after\\\": \\\"container_name=$({{container_cli}} ps --format=\\\\\\\\{\\\\\\\\{.Names\\\\\\\\}\\\\\\\\} | grep -w -E \'rabbitmq(-bundle-.*-[0-9]+)?\')\\\\nservice_crt=\\\\\\\"/etc/pki/tls/certs/rabbitmq.crt\\\\\\\"\\\\nservice_key=\\\\\\\"/etc/pki/tls/private/rabbitmq.key\\\\\\\"\\\\nif echo \\\\\\\"$container_name\\\\\\\" | grep -q \\\\\\\"^rabbitmq-bundle\\\\\\\"; then\\\\n  # lp#1917868: Do not use podman cp with HA containers as they get\\\\n  # frozen temporarily and that can make pacemaker operation fail.\\\\n  tar -c \\\\\\\"$service_crt\\\\\\\" \\\\\\\"$service_key\\\\\\\" | {{container_cli}} exec -i \\\\\\\"$container_name\\\\\\\" tar -C / -xv\\\\n  # no need to update the mount point, because pacemaker\\\\n  # recreates the container when it\'s restarted\\\\nelse\\\\n  # Refresh the cert at the mount-point\\\\n  {{container_cli}} cp $service_crt \\\\\\\"$container_name:/var/lib/kolla/config_files/src-tls/$service_crt\\\\\\\"\\\\n  # Refresh the key at the mount-point\\\\n  {{container_cli}} cp $service_key \\\\\\\"$container_name:/var/lib/kolla/config_files/src-tls/$service_key\\\\\\\"\\\\n  # Copy the new cert from the mount-point to the real path\\\\n  {{container_cli}} exec -u root \\\\\\\"$container_name\\\\\\\" cp \\\\\\\"/var/lib/kolla/config_files/src-tls$service_crt\\\\\\\" \\\\\\\"$service_crt\\\\\\\"\\\\n  # Copy the new key from the mount-point to the real path\\\\n  {{container_cli}} exec -u root \\\\\\\"$container_name\\\\\\\" cp \\\\\\\"/var/lib/kolla/config_files/src-tls$service_key\\\\\\\" \\\\\\\"$service_key\\\\\\\"\\\\nfi\\\\n# Set appropriate permissions\\\\n{{container_cli}} exec -u root \\\\\\\"$container_name\\\\\\\" chown rabbitmq:rabbitmq \\\\\\\"$service_crt\\\\\\\"\\\\n{{container_cli}} exec -u root \\\\\\\"$container_name\\\\\\\" chown rabbitmq:rabbitmq \\\\\\\"$service_key\\\\\\\"\\\\n# Trigger a pem cache clear in RabbitMQ to read the new certificates\\\\n{{container_cli}} exec \\\\\\\"$container_name\\\\\\\" rabbitmqctl eval \\\\\\\"ssl:clear_pem_cache().\\\\\\\"\\\\n\\\", \\\"key_size\\\": {\\\"if\\\": [\\\"key_size_override_unset\\\", {\\\"get_param\\\": \\\"CertificateKeySize\\\"}, {\\\"get_param\\\": \\\"RabbitmqCertificateKeySize\\\"}]}, \\\"ca\\\": \\\"ipa\\\"}]}}]}], \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"creat fcontext entry for rabbitmq data\\\", \\\"community.general.sefcontext\\\": {\\\"target\\\": \\\"/var/lib/rabbitmq(/.*)?\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"state\\\": \\\"present\\\"}}, {\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode|default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/rabbitmq\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/lib/rabbitmq\\\", \\\"setype\\\": \\\"container_file_t\\\"}]}], \\\"upgrade_tasks\\\": [], \\\"update_tasks\\\": null}}}}\", \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Rabbitmq service\\\\n\\\", \\\"parameters\\\": {\\\"ContainerRabbitmqImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerRabbitmqConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the rabbitmq config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"RabbitCookie\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"hidden\\\": true}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"RpcPort\\\": {\\\"default\\\": 5672, \\\"description\\\": \\\"The network port for messaging backend\\\", \\\"type\\\": \\\"number\\\"}, \\\"RpcUserName\\\": {\\\"default\\\": \\\"guest\\\", \\\"description\\\": \\\"The username for messaging backend\\\", \\\"type\\\": \\\"string\\\"}, \\\"RpcPassword\\\": {\\\"description\\\": \\\"The password for messaging backend\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"RpcUseSSL\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Messaging client subscriber parameter to specify an SSL connection to the messaging host.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"DeployIdentifier\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\\\n\\\"}, \\\"CertificateKeySize\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"2048\\\", \\\"description\\\": \\\"Specifies the private key size used when creating the certificate.\\\"}, \\\"RpcCertificateKeySize\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Override the private key size used when creating the certificate for this service\\\"}, \\\"RabbitFIPS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false, \\\"description\\\": \\\"Configures RabbitMQ to run in FIPS mode\\\"}}, \\\"conditions\\\": {\\\"internal_tls_enabled\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, true]}, \\\"key_size_override_unset\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"RpcCertificateKeySize\\\"}, \\\"\\\"]}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"RabbitMQServiceBase\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-container-puppet.yaml\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerRabbitmqImage\\\": \\\"ContainerRabbitmqImage\\\", \\\"ContainerRabbitmqConfigImage\\\": \\\"ContainerRabbitmqConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerRabbitmqImage\\\": {\\\"get_param\\\": \\\"ContainerRabbitmqImage\\\"}, \\\"ContainerRabbitmqConfigImage\\\": {\\\"get_param\\\": \\\"ContainerRabbitmqConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Rabbitmq API role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"oslo_messaging_rpc\\\", \\\"firewall_rules\\\": {\\\"109 rabbitmq\\\": {\\\"dport\\\": [4369, {\\\"get_param\\\": \\\"RpcPort\\\"}, 25672, \\\"25673-25683\\\"]}}, \\\"monitoring_subscription\\\": {\\\"get_attr\\\": [\\\"RabbitMQServiceBase\\\", \\\"role_data\\\", \\\"monitoring_subscription\\\"]}, \\\"global_config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"RabbitMQServiceBase\\\", \\\"role_data\\\", \\\"global_config_settings\\\"]}, {\\\"oslo_messaging_rpc_scheme\\\": \\\"rabbit\\\", \\\"oslo_messaging_rpc_user_name\\\": {\\\"get_param\\\": \\\"RpcUserName\\\"}, \\\"oslo_messaging_rpc_password\\\": {\\\"get_param\\\": \\\"RpcPassword\\\"}, \\\"oslo_messaging_rpc_use_ssl\\\": {\\\"get_param\\\": \\\"RpcUseSSL\\\"}, \\\"oslo_messaging_rpc_port\\\": {\\\"get_param\\\": \\\"RpcPort\\\"}}]}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"RabbitMQServiceBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"rabbitmq::default_user\\\": {\\\"get_param\\\": \\\"RpcUserName\\\"}, \\\"rabbitmq::default_pass\\\": {\\\"get_param\\\": \\\"RpcPassword\\\"}, \\\"rabbitmq::port\\\": {\\\"get_param\\\": \\\"RpcPort\\\"}, \\\"rabbitmq::interface\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OsloMessagingRpcNetwork\\\"]}}}}, \\\"rabbitmq::ssl\\\": {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, \\\"rabbitmq::ssl_erl_dist\\\": {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, \\\"rabbitmq::ssl_port\\\": {\\\"get_param\\\": \\\"RpcPort\\\"}, \\\"rabbitmq::ssl_only\\\": {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, \\\"rabbitmq::ssl_interface\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OsloMessagingRpcNetwork\\\"]}}}}, \\\"tripleo::profile::base::rabbitmq::enable_internal_tls\\\": {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, \\\"rabbitmq::collect_statistics_interval\\\": 30000, \\\"rabbitmq::admin_enable\\\": false, \\\"rabbitmq::management_enable\\\": true, \\\"rabbitmq::use_config_file_for_plugins\\\": true, \\\"rabbitmq::management_ip_address\\\": \\\"127.0.0.1\\\", \\\"rabbitmq::config_management_variables\\\": {\\\"rates_mode\\\": \\\"none\\\"}}, {\\\"if\\\": [\\\"internal_tls_enabled\\\", {\\\"tripleo::rabbitmq::service_certificate\\\": \\\"/etc/pki/tls/certs/rabbitmq.crt\\\", \\\"tripleo::certmonger::rabbitmq::postsave_cmd\\\": \\\"true\\\", \\\"tripleo::profile::base::rabbitmq::certificate_specs\\\": {\\\"service_certificate\\\": \\\"/etc/pki/tls/certs/rabbitmq.crt\\\", \\\"service_key\\\": \\\"/etc/pki/tls/private/rabbitmq.key\\\"}, \\\"rabbitmq::ssl_versions\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"RabbitFIPS\\\"}, [\\\"tlsv1.2\\\", \\\"tlsv1.3\\\"], [\\\"tlsv1.2\\\"]]}}, {}]}]}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"rabbitmq\\\", \\\"step_config\\\": {\\\"list_join\\\": [\\\"\\\\n\\\", [\\\"[\'Rabbitmq_policy\', \'Rabbitmq_user\'].each |String $val| { noop_resource($val) }\\\", \\\"include tripleo::profile::base::rabbitmq\\\"]]}, \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/rabbitmq.json\\\": {\\\"command\\\": \\\"/usr/lib/rabbitmq/bin/rabbitmq-server\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-tls/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true, \\\"optional\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/lib/rabbitmq\\\", \\\"owner\\\": \\\"rabbitmq:rabbitmq\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/certs/rabbitmq.crt\\\", \\\"owner\\\": \\\"rabbitmq:rabbitmq\\\", \\\"optional\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/private/rabbitmq.key\\\", \\\"owner\\\": \\\"rabbitmq:rabbitmq\\\", \\\"optional\\\": true}]}}, \\\"docker_config\\\": {\\\"step_1\\\": {\\\"rabbitmq_init_logs\\\": {\\\"start_order\\\": 0, \\\"detach\\\": false, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}, \\\"net\\\": \\\"none\\\", \\\"privileged\\\": false, \\\"user\\\": \\\"root\\\", \\\"volumes\\\": [\\\"/var/log/containers/rabbitmq:/var/log/rabbitmq:z\\\"], \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R rabbitmq:rabbitmq /var/log/rabbitmq\\\"]}, \\\"rabbitmq_bootstrap\\\": {\\\"start_order\\\": 1, \\\"detach\\\": false, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"user\\\": \\\"root\\\", \\\"command\\\": [\\\"bash\\\", \\\"-ec\\\", {\\\"list_join\\\": [\\\"\\\\n\\\", [\\\"kolla_set_configs\\\", \\\"if [[ -e \\\\\\\"/var/lib/rabbitmq/.erlang.cookie\\\\\\\" ]]; then rm -f /var/lib/rabbitmq/.erlang.cookie; fi\\\", \\\"hiera \'rabbitmq::erlang_cookie\' > /var/lib/rabbitmq/.erlang.cookie\\\", \\\"chown rabbitmq:rabbitmq /var/lib/rabbitmq/.erlang.cookie\\\", \\\"chmod 400 /var/lib/rabbitmq/.erlang.cookie\\\"]]}], \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/rabbitmq.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/rabbitmq:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/rabbitmq:/var/lib/rabbitmq:z\\\", \\\"/var/log/containers/rabbitmq:/var/log/rabbitmq:z\\\"], {\\\"if\\\": [\\\"internal_tls_enabled\\\", [\\\"/etc/pki/tls/certs/rabbitmq.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/rabbitmq.crt:ro\\\", \\\"/etc/pki/tls/private/rabbitmq.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/rabbitmq.key:ro\\\"], null]}]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\", \\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}}}, \\\"rabbitmq\\\": {\\\"start_order\\\": 2, \\\"stop_grace_period\\\": 60, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/rabbitmq.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/rabbitmq:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/rabbitmq:/var/lib/rabbitmq:z\\\", \\\"/var/log/containers/rabbitmq:/var/log/rabbitmq:z\\\"], {\\\"if\\\": [\\\"internal_tls_enabled\\\", [\\\"/etc/pki/tls/certs/rabbitmq.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/rabbitmq.crt:ro\\\", \\\"/etc/pki/tls/private/rabbitmq.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/rabbitmq.key:ro\\\"], null]}]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"container_puppet_tasks\\\": {\\\"step_2\\\": {\\\"config_volume\\\": \\\"rabbit_init_tasks\\\", \\\"puppet_tags\\\": \\\"rabbitmq_policy,rabbitmq_user\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::rabbitmq\\\", \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqConfigImage\\\"]}, \\\"volumes\\\": [\\\"/var/lib/config-data/puppet-generated/rabbitmq/etc/rabbitmq:/etc/rabbitmq:ro\\\", \\\"/var/lib/rabbitmq:/var/lib/rabbitmq:z\\\"]}}, \\\"metadata_settings\\\": {\\\"if\\\": [\\\"internal_tls_enabled\\\", [{\\\"service\\\": \\\"rabbitmq\\\", \\\"network\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OsloMessagingRpcNetwork\\\"]}, \\\"type\\\": \\\"node\\\"}], null]}, \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Certificate generation\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"enable_internal_tls\\\"], \\\"block\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"linux-system-roles.certificate\\\"}, \\\"vars\\\": {\\\"certificate_requests\\\": [{\\\"name\\\": \\\"rabbitmq\\\", \\\"dns\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"{{fqdn_$NETWORK}}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OsloMessagingRpcNetwork\\\"]}}}}, \\\"principal\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"rabbitmq/{{fqdn_$NETWORK}}@{{idm_realm}}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"OsloMessagingRpcNetwork\\\"]}}}}, \\\"run_after\\\": \\\"container_name=$({{container_cli}} ps --format=\\\\\\\\{\\\\\\\\{.Names\\\\\\\\}\\\\\\\\} | grep -w -E \'rabbitmq(-bundle-.*-[0-9]+)?\')\\\\nservice_crt=\\\\\\\"/etc/pki/tls/certs/rabbitmq.crt\\\\\\\"\\\\nservice_key=\\\\\\\"/etc/pki/tls/private/rabbitmq.key\\\\\\\"\\\\nif echo \\\\\\\"$container_name\\\\\\\" | grep -q \\\\\\\"^rabbitmq-bundle\\\\\\\"; then\\\\n  # lp#1917868: Do not use podman cp with HA containers as they get\\\\n  # frozen temporarily and that can make pacemaker operation fail.\\\\n  tar -c \\\\\\\"$service_crt\\\\\\\" \\\\\\\"$service_key\\\\\\\" | {{container_cli}} exec -i \\\\\\\"$container_name\\\\\\\" tar -C / -xv\\\\n  # no need to update the mount point, because pacemaker\\\\n  # recreates the container when it\'s restarted\\\\nelse\\\\n  # Refresh the cert at the mount-point\\\\n  {{container_cli}} cp $service_crt \\\\\\\"$container_name:/var/lib/kolla/config_files/src-tls/$service_crt\\\\\\\"\\\\n  # Refresh the key at the mount-point\\\\n  {{container_cli}} cp $service_key \\\\\\\"$container_name:/var/lib/kolla/config_files/src-tls/$service_key\\\\\\\"\\\\n  # Copy the new cert from the mount-point to the real path\\\\n  {{container_cli}} exec -u root \\\\\\\"$container_name\\\\\\\" cp \\\\\\\"/var/lib/kolla/config_files/src-tls$service_crt\\\\\\\" \\\\\\\"$service_crt\\\\\\\"\\\\n  # Copy the new key from the mount-point to the real path\\\\n  {{container_cli}} exec -u root \\\\\\\"$container_name\\\\\\\" cp \\\\\\\"/var/lib/kolla/config_files/src-tls$service_key\\\\\\\" \\\\\\\"$service_key\\\\\\\"\\\\nfi\\\\n# Set appropriate permissions\\\\n{{container_cli}} exec -u root \\\\\\\"$container_name\\\\\\\" chown rabbitmq:rabbitmq \\\\\\\"$service_crt\\\\\\\"\\\\n{{container_cli}} exec -u root \\\\\\\"$container_name\\\\\\\" chown rabbitmq:rabbitmq \\\\\\\"$service_key\\\\\\\"\\\\n# Trigger a pem cache clear in RabbitMQ to read the new certificates\\\\n{{container_cli}} exec \\\\\\\"$container_name\\\\\\\" rabbitmqctl eval \\\\\\\"ssl:clear_pem_cache().\\\\\\\"\\\\n\\\", \\\"key_size\\\": {\\\"if\\\": [\\\"key_size_override_unset\\\", {\\\"get_param\\\": \\\"CertificateKeySize\\\"}, {\\\"get_param\\\": \\\"RpcCertificateKeySize\\\"}]}, \\\"ca\\\": \\\"ipa\\\"}]}}]}], \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create fcontext for rabbitmq data\\\", \\\"community.general.sefcontext\\\": {\\\"target\\\": \\\"/var/lib/rabbitmq(/.*)?\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"state\\\": \\\"present\\\"}}, {\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode|default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/rabbitmq\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/lib/rabbitmq\\\", \\\"setype\\\": \\\"container_file_t\\\"}]}], \\\"upgrade_tasks\\\": [], \\\"update_tasks\\\": null}}}}\", \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Rabbitmq service\\\\n\\\", \\\"parameters\\\": {\\\"ContainerRabbitmqImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerRabbitmqConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the rabbitmq config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ClusterCommonTag\\\": {\\\"default\\\": false, \\\"description\\\": \\\"When set to false, a pacemaker service is configured to use a floating tag for its container image name, e.g. \'REGISTRY/NAMESPACE/IMAGENAME:pcmklatest\'. When set to true, the service uses a floating prefix as well, e.g. \'cluster.common.tag/IMAGENAME:pcmklatest\'.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"ClusterFullTag\\\": {\\\"default\\\": true, \\\"description\\\": \\\"When set to true, the pacemaker service uses a fully constant tag for its container image name, e.g. \'cluster.common.tag/SERVICENAME:pcmklatest\'.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RabbitCookie\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"hidden\\\": true}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"ConfigDebug\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to run config management (e.g. Puppet) in debug mode.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"ContainerCli\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"podman\\\", \\\"description\\\": \\\"CLI tool used to manage containers.\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"docker\\\", \\\"podman\\\"]}]}, \\\"DeployIdentifier\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\\\n\\\"}}, \\\"conditions\\\": {\\\"puppet_debug_enabled\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"docker_enabled\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"docker\\\"]}, \\\"common_tag_enabled\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, true]}, \\\"common_tag_full\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, true]}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"RabbitmqBase\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-container-puppet.yaml\\\", \\\"properties\\\": {\\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerRabbitmqImage\\\": \\\"ContainerRabbitmqImage\\\", \\\"ContainerRabbitmqConfigImage\\\": \\\"ContainerRabbitmqConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerRabbitmqImage\\\": {\\\"get_param\\\": \\\"ContainerRabbitmqImage\\\"}, \\\"ContainerRabbitmqConfigImage\\\": {\\\"get_param\\\": \\\"ContainerRabbitmqConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Rabbitmq API role.\\\", \\\"value\\\": {\\\"service_name\\\": {\\\"get_attr\\\": [\\\"RabbitmqBase\\\", \\\"role_data\\\", \\\"service_name\\\"]}, \\\"firewall_rules\\\": {\\\"109 rabbitmq-bundle\\\": {\\\"dport\\\": [3122, 4369, 5672, 25672, \\\"25673-25683\\\"]}}, \\\"global_config_settings\\\": {\\\"get_attr\\\": [\\\"RabbitmqBase\\\", \\\"role_data\\\", \\\"global_config_settings\\\"]}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"RabbitmqBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"rabbitmq::service_manage\\\": false, \\\"tripleo::profile::pacemaker::rabbitmq_bundle::rabbitmq_docker_image\\\": {\\\"if\\\": [\\\"common_tag_full\\\", \\\"cluster.common.tag/rabbitmq:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [\\\"common_tag_enabled\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"tripleo::profile::pacemaker::rabbitmq_bundle::control_port\\\": 3122, \\\"tripleo::profile::pacemaker::rabbitmq_bundle::container_backend\\\": {\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"tripleo::profile::pacemaker::rabbitmq_bundle::force_ocf\\\": true}]}, \\\"service_config_settings\\\": {\\\"get_attr\\\": [\\\"RabbitmqBase\\\", \\\"role_data\\\", \\\"service_config_settings\\\"]}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"rabbitmq\\\", \\\"puppet_tags\\\": \\\"file,file_line\\\", \\\"step_config\\\": {\\\"list_join\\\": [\\\"\\\\n\\\", [\\\"[\'Rabbitmq_policy\', \'Rabbitmq_user\'].each |String $val| { noop_resource($val) }\\\", \\\"include tripleo::profile::pacemaker::rabbitmq_bundle\\\"]]}, \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/rabbitmq.json\\\": {\\\"command\\\": \\\"/usr/sbin/pacemaker_remoted\\\", \\\"config_files\\\": [{\\\"dest\\\": \\\"/etc/libqb/force-filesystem-sockets\\\", \\\"source\\\": \\\"/dev/null\\\", \\\"owner\\\": \\\"root\\\", \\\"perm\\\": \\\"0644\\\"}, {\\\"dest\\\": \\\"/var/log/btmp\\\", \\\"source\\\": \\\"/dev/null\\\", \\\"owner\\\": \\\"root:utmp\\\", \\\"perm\\\": \\\"0600\\\"}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-tls/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"optional\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/lib/rabbitmq\\\", \\\"owner\\\": \\\"rabbitmq:rabbitmq\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/var/log/rabbitmq\\\", \\\"owner\\\": \\\"rabbitmq:rabbitmq\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/certs/rabbitmq.crt\\\", \\\"owner\\\": \\\"rabbitmq:rabbitmq\\\", \\\"perm\\\": \\\"0600\\\", \\\"optional\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/private/rabbitmq.key\\\", \\\"owner\\\": \\\"rabbitmq:rabbitmq\\\", \\\"perm\\\": \\\"0600\\\", \\\"optional\\\": true}]}}, \\\"container_config_scripts\\\": {\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"container_config_scripts\\\"]}, \\\"docker_config\\\": {\\\"step_1\\\": {\\\"rabbitmq_bootstrap\\\": {\\\"start_order\\\": 0, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"user\\\": \\\"root\\\", \\\"command\\\": [\\\"bash\\\", \\\"-ec\\\", {\\\"list_join\\\": [\\\"\\\\n\\\", [\\\"kolla_set_configs\\\", \\\"if [[ -e \\\\\\\"/var/lib/rabbitmq/.erlang.cookie\\\\\\\" ]]; then rm -f /var/lib/rabbitmq/.erlang.cookie; fi\\\", \\\"hiera \'rabbitmq::erlang_cookie\' > /var/lib/rabbitmq/.erlang.cookie\\\", \\\"chown rabbitmq:rabbitmq /var/lib/rabbitmq/.erlang.cookie\\\", \\\"chmod 400 /var/lib/rabbitmq/.erlang.cookie\\\"]]}], \\\"volumes\\\": [\\\"/var/lib/kolla/config_files/rabbitmq.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/rabbitmq:/var/lib/kolla/config_files/src:ro\\\", \\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/var/lib/rabbitmq:/var/lib/rabbitmq:z\\\", \\\"/etc/puppet:/etc/puppet:ro,z\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\", \\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}}}}, \\\"step_2\\\": {\\\"rabbitmq_wait_bundle\\\": {\\\"start_order\\\": 0, \\\"detach\\\": false, \\\"net\\\": \\\"host\\\", \\\"ipc\\\": \\\"host\\\", \\\"user\\\": \\\"root\\\", \\\"command\\\": {\\\"list_concat\\\": [[\\\"/container_puppet_apply.sh\\\", \\\"2\\\", \\\"file,file_line,concat,augeas,rabbitmq_policy,rabbitmq_user,rabbitmq_ready\\\", \\\"include tripleo::profile::pacemaker::rabbitmq_bundle\\\"], {\\\"if\\\": [\\\"puppet_debug_enabled\\\", [\\\"--debug\\\"], [\\\"\\\"]]}]}, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"container_puppet_apply_volumes\\\"]}, [\\\"/bin/true:/bin/epmd\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\", \\\"KOLLA_BOOTSTRAP\\\": true, \\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}}}}}, \\\"metadata_settings\\\": {\\\"get_attr\\\": [\\\"RabbitmqBase\\\", \\\"role_data\\\", \\\"metadata_settings\\\"]}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create fcontext for rabbitmq data\\\", \\\"community.general.sefcontext\\\": {\\\"target\\\": \\\"/var/lib/rabbitmq(/.*)?\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"state\\\": \\\"present\\\"}}, {\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode|default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/lib/rabbitmq\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/log/containers/rabbitmq\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}, {\\\"name\\\": \\\"stop the Erlang port mapper on the host and make sure it cannot bind to the port used by container\\\", \\\"shell\\\": \\\"echo \'export ERL_EPMD_ADDRESS=127.0.0.1\' > /etc/rabbitmq/rabbitmq-env.conf\\\\necho \'export ERL_EPMD_PORT=4370\' >> /etc/rabbitmq/rabbitmq-env.conf\\\\nfor pid in $(pgrep epmd --ns 1 --nslist pid); do kill $pid; done\\\\n\\\"}], \\\"deploy_steps_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"RabbitmqBase\\\", \\\"role_data\\\", \\\"deploy_steps_tasks\\\"]}, [{\\\"name\\\": \\\"RabbitMQ tag container image for pacemaker\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_tag\\\"}, \\\"vars\\\": {\\\"container_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}, \\\"container_image_latest\\\": {\\\"if\\\": [\\\"common_tag_full\\\", \\\"cluster.common.tag/rabbitmq:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [\\\"common_tag_enabled\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}}}, {\\\"name\\\": \\\"RabbitMQ RPC HA Wrappers Step\\\", \\\"when\\\": \\\"step|int == 2\\\", \\\"block\\\": [{\\\"name\\\": \\\"Rabbitmq rpc puppet bundle\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_ha_wrapper\\\"}, \\\"vars\\\": {\\\"tripleo_ha_wrapper_service_name\\\": \\\"oslo_messaging_rpc\\\", \\\"tripleo_ha_wrapper_resource_name\\\": \\\"rabbitmq\\\", \\\"tripleo_ha_wrapper_bundle_name\\\": \\\"rabbitmq-bundle\\\", \\\"tripleo_ha_wrapper_resource_state\\\": \\\"Started\\\", \\\"tripleo_ha_wrapper_puppet_config_volume\\\": \\\"rabbitmq\\\", \\\"tripleo_ha_wrapper_puppet_execute\\\": \\\"[\\\\\\\"Rabbitmq_policy\\\\\\\", \\\\\\\"Rabbitmq_user\\\\\\\"].each |String $val| { noop_resource($val) }; include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::rabbitmq_bundle\\\", \\\"tripleo_ha_wrapper_puppet_tags\\\": \\\"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\\\", \\\"tripleo_ha_wrapper_puppet_debug\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"tripleo_ha_wrapper_config_suffix\\\": \\\".previous_run\\\"}}]}]]}, \\\"external_update_tasks\\\": [{\\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": \\\"ha_image_update\\\", \\\"block\\\": [{\\\"block\\\": [{\\\"name\\\": \\\"Get rabbitmq image from pacemaker\\\", \\\"become\\\": true, \\\"register\\\": \\\"xmllint_pcmk_rabbitmq_rpc_image\\\", \\\"shell\\\": \\\"xmllint --xpath \\\\\\\"string(//bundle[@id=\'rabbitmq-bundle\']/podman/@image)\\\\\\\" /var/lib/pacemaker/cib/cib.xml\\\"}, {\\\"name\\\": \\\"Get container rabbitmq image\\\", \\\"set_fact\\\": {\\\"rabbitmq_rpc_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}, \\\"rabbitmq_rpc_image_latest\\\": {\\\"if\\\": [\\\"common_tag_full\\\", \\\"cluster.common.tag/rabbitmq:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [\\\"common_tag_enabled\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"pcmk_rabbitmq_rpc_image\\\": \\\"{{xmllint_pcmk_rabbitmq_rpc_image.stdout}}\\\"}}], \\\"delegate_to\\\": \\\"{{ (groups[\\\\\\\"oslo_messaging_rpc\\\\\\\"] | difference(groups[\\\\\\\"excluded_overcloud\\\\\\\"]))[0] }}\\\"}, {\\\"name\\\": \\\"rabbitmq temporary pacemaker container tag in case of image switch\\\", \\\"become\\\": true, \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_ha_image_update\\\"}, \\\"vars\\\": {\\\"tripleo_ha_image_update_node_names\\\": \\\"{{ groups[\\\\\\\"oslo_messaging_rpc\\\\\\\"] | difference(groups[\\\\\\\"excluded_overcloud\\\\\\\"]) }}\\\", \\\"tripleo_ha_image_update_bundle\\\": \\\"rabbitmq-bundle\\\", \\\"tripleo_ha_image_update_new_image\\\": \\\"{{rabbitmq_rpc_image_latest}}\\\", \\\"tripleo_ha_image_update_old_image\\\": \\\"{{pcmk_rabbitmq_rpc_image}}\\\"}, \\\"when\\\": [\\\"(pcmk_rabbitmq_rpc_image != \\\\\\\"\\\\\\\")\\\", \\\"(pcmk_rabbitmq_rpc_image != rabbitmq_rpc_image_latest)\\\"]}]}], \\\"update_tasks\\\": [{\\\"block\\\": [{\\\"name\\\": \\\"Get rabbitmq image from pacemaker\\\", \\\"become\\\": true, \\\"register\\\": \\\"xmllint_pcmk_rabbitmq_rpc_image\\\", \\\"shell\\\": \\\"xmllint --xpath \\\\\\\"string(//bundle[@id=\'rabbitmq-bundle\']/podman/@image)\\\\\\\" /var/lib/pacemaker/cib/cib.xml\\\"}, {\\\"name\\\": \\\"Get container rabbitmq image\\\", \\\"set_fact\\\": {\\\"rabbitmq_rpc_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}, \\\"rabbitmq_rpc_image_latest\\\": {\\\"if\\\": [\\\"common_tag_full\\\", \\\"cluster.common.tag/rabbitmq:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [\\\"common_tag_enabled\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"pcmk_rabbitmq_rpc_image\\\": \\\"{{xmllint_pcmk_rabbitmq_rpc_image.stdout}}\\\"}}], \\\"when\\\": \\\"(step|int == 0 or step|int == 2)\\\"}, {\\\"name\\\": \\\"Check for update of rabbitmq container image name\\\", \\\"when\\\": \\\"step|int == 0\\\", \\\"assert\\\": {\\\"that\\\": \\\"pcmk_rabbitmq_rpc_image == rabbitmq_rpc_image_latest\\\", \\\"fail_msg\\\": \\\"rabbitmq image change detected, run overcloud external-update --tags ha_image_update first\\\"}}, {\\\"name\\\": \\\"Tear-down non-HA rabbitmq container\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Remove non-HA rabbitmq container\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_rm\\\"}, \\\"vars\\\": {\\\"tripleo_container_cli\\\": \\\"{{ container_cli }}\\\", \\\"tripleo_containers_to_rm\\\": [\\\"rabbitmq\\\"]}}]}, {\\\"name\\\": \\\"Rabbitmq fetch and retag container image for pacemaker\\\", \\\"when\\\": \\\"step|int == 2\\\", \\\"block\\\": [{\\\"name\\\": \\\"Retag pcmklatest to latest rabbitmq image\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_tag\\\"}, \\\"vars\\\": {\\\"container_image\\\": \\\"{{rabbitmq_rpc_image}}\\\", \\\"container_image_latest\\\": \\\"{{rabbitmq_rpc_image_latest}}\\\"}}]}], \\\"post_update_tasks\\\": [{\\\"name\\\": \\\"Rabbitmq rpc bundle post update\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Rabbitmq rpc puppet bundle\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_ha_wrapper\\\"}, \\\"vars\\\": {\\\"tripleo_ha_wrapper_service_name\\\": \\\"oslo_messaging_rpc\\\", \\\"tripleo_ha_wrapper_resource_name\\\": \\\"rabbitmq\\\", \\\"tripleo_ha_wrapper_bundle_name\\\": \\\"rabbitmq-bundle\\\", \\\"tripleo_ha_wrapper_resource_state\\\": \\\"Started\\\", \\\"tripleo_ha_wrapper_puppet_config_volume\\\": \\\"rabbitmq\\\", \\\"tripleo_ha_wrapper_puppet_execute\\\": \\\"[\\\\\\\"Rabbitmq_policy\\\\\\\", \\\\\\\"Rabbitmq_user\\\\\\\"].each |String $val| { noop_resource($val) }; include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::rabbitmq_bundle\\\", \\\"tripleo_ha_wrapper_puppet_tags\\\": \\\"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\\\", \\\"tripleo_ha_wrapper_puppet_debug\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"tripleo_ha_wrapper_config_suffix\\\": \\\".previous_run\\\"}}], \\\"vars\\\": {\\\"tripleo_ha_wrapper_minor_update\\\": true}}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"Tear-down non-HA rabbitmq container\\\", \\\"when\\\": [\\\"step|int == 0\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Remove non-HA rabbitmq container\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_rm\\\"}, \\\"vars\\\": {\\\"tripleo_container_cli\\\": \\\"{{ container_cli }}\\\", \\\"tripleo_containers_to_rm\\\": [\\\"rabbitmq\\\"]}}]}, {\\\"name\\\": \\\"Prepare switch of rabbitmq image name\\\", \\\"when\\\": [\\\"step|int == 0\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Get rabbitmq image id currently used by pacemaker\\\", \\\"shell\\\": \\\"pcs resource config rabbitmq-bundle | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\\\", \\\"register\\\": \\\"rabbitmq_rpc_image_current_res\\\", \\\"failed_when\\\": false}, {\\\"name\\\": \\\"Image facts for rabbitmq\\\", \\\"set_fact\\\": {\\\"rabbitmq_rpc_image_latest\\\": {\\\"if\\\": [\\\"common_tag_full\\\", \\\"cluster.common.tag/rabbitmq:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [\\\"common_tag_enabled\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"rabbitmq_rpc_image_current\\\": \\\"{{rabbitmq_rpc_image_current_res.stdout}}\\\"}}, {\\\"name\\\": \\\"Temporarily tag the current rabbitmq image id with the upgraded image name\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_tag\\\"}, \\\"vars\\\": {\\\"container_image\\\": \\\"{{rabbitmq_rpc_image_current}}\\\", \\\"container_image_latest\\\": \\\"{{rabbitmq_rpc_image_latest}}\\\", \\\"pull_image\\\": false}, \\\"when\\\": [\\\"rabbitmq_rpc_image_current != \'\'\\\", \\\"rabbitmq_rpc_image_current != rabbitmq_rpc_image_latest\\\"]}, {\\\"name\\\": \\\"Create rabbitmq_rpc retag statefile\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/tripleo/rabbitmq_rpc_needs_retag\\\", \\\"state\\\": \\\"touch\\\"}, \\\"when\\\": [\\\"rabbitmq_rpc_image_current != \'\'\\\", \\\"rabbitmq_rpc_image_current != rabbitmq_rpc_image_latest\\\"]}]}, {\\\"name\\\": \\\"Update rabbitmq-bundle pcs resource bundle for new container image\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"set is_rpc_rabbitmq_bootstrap_node fact\\\", \\\"set_fact\\\": \\\"is_rpc_rabbitmq_bootstrap_node={{oslo_messaging_rpc_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\\\"}, {\\\"name\\\": \\\"Check for rabbitmq_rpc retag statefile\\\", \\\"stat\\\": {\\\"path\\\": \\\"/var/lib/tripleo/rabbitmq_rpc_needs_retag\\\"}, \\\"register\\\": \\\"rabbitmq_rpc_retag_state_file\\\"}]}, {\\\"name\\\": \\\"Update rabbitmq-bundle pcs resource bundle for new container image\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"is_rpc_rabbitmq_bootstrap_node|bool\\\", \\\"rabbitmq_rpc_retag_state_file.stat.exists|bool\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Disable the rabbitmq cluster resource before container upgrade\\\", \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"rabbitmq-bundle\\\", \\\"state\\\": \\\"disable\\\", \\\"wait_for_resource\\\": true}, \\\"register\\\": \\\"output\\\", \\\"retries\\\": 5, \\\"until\\\": \\\"output.rc == 0\\\"}, {\\\"name\\\": \\\"Check rabbitmq logging configuration in pacemaker\\\", \\\"command\\\": \\\"cibadmin --query --xpath \\\\\\\"//storage-mapping[@id=\'rabbitmq-log\']\\\\\\\"\\\", \\\"failed_when\\\": false, \\\"register\\\": \\\"rabbitmq_logs_moved\\\"}, {\\\"name\\\": \\\"Add a bind mount for logging in the rabbitmq bundle\\\", \\\"when\\\": \\\"rabbitmq_logs_moved.rc == 6\\\", \\\"command\\\": \\\"pcs resource bundle update rabbitmq-bundle storage-map add id=rabbitmq-log source-dir=/var/log/containers/rabbitmq target-dir=/var/log/rabbitmq options=rw\\\"}, {\\\"name\\\": \\\"Update the rabbitmq bundle to use the new container image name\\\", \\\"command\\\": \\\"pcs resource bundle update rabbitmq-bundle container image={{rabbitmq_rpc_image_latest}}\\\"}, {\\\"name\\\": \\\"Enable the rabbitmq cluster resource\\\", \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"rabbitmq-bundle\\\", \\\"state\\\": \\\"enable\\\", \\\"wait_for_resource\\\": true}, \\\"register\\\": \\\"output\\\", \\\"retries\\\": 5, \\\"until\\\": \\\"output.rc == 0\\\"}]}, {\\\"name\\\": \\\"Check for rabbitmq_rpc retag statefile\\\", \\\"when\\\": [\\\"step|int == 3\\\"], \\\"stat\\\": {\\\"path\\\": \\\"/var/lib/tripleo/rabbitmq_rpc_needs_retag\\\"}, \\\"register\\\": \\\"rabbitmq_rpc_retag_state_file\\\"}, {\\\"name\\\": \\\"Retag rabbitmq-bundle container image\\\", \\\"when\\\": [\\\"step|int == 3\\\", \\\"rabbitmq_rpc_retag_state_file.stat.exists|bool\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Disable the rabbitmq cluster resource before container upgrade\\\", \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"rabbitmq-bundle\\\", \\\"state\\\": \\\"disable\\\", \\\"wait_for_resource\\\": true}, \\\"register\\\": \\\"output\\\", \\\"retries\\\": 5, \\\"until\\\": \\\"output.rc == 0\\\"}, {\\\"name\\\": \\\"Retag the pacemaker image if containerized\\\", \\\"block\\\": [{\\\"block\\\": [{\\\"name\\\": \\\"Get rabbitmq image from pacemaker\\\", \\\"become\\\": true, \\\"register\\\": \\\"xmllint_pcmk_rabbitmq_rpc_image\\\", \\\"shell\\\": \\\"xmllint --xpath \\\\\\\"string(//bundle[@id=\'rabbitmq-bundle\']/podman/@image)\\\\\\\" /var/lib/pacemaker/cib/cib.xml\\\"}, {\\\"name\\\": \\\"Get container rabbitmq image\\\", \\\"set_fact\\\": {\\\"rabbitmq_rpc_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}, \\\"rabbitmq_rpc_image_latest\\\": {\\\"if\\\": [\\\"common_tag_full\\\", \\\"cluster.common.tag/rabbitmq:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [\\\"common_tag_enabled\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRabbitmqImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"pcmk_rabbitmq_rpc_image\\\": \\\"{{xmllint_pcmk_rabbitmq_rpc_image.stdout}}\\\"}}]}, {\\\"block\\\": [{\\\"name\\\": \\\"Retag pcmklatest to latest rabbitmq image\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_tag\\\"}, \\\"vars\\\": {\\\"container_image\\\": \\\"{{rabbitmq_rpc_image}}\\\", \\\"container_image_latest\\\": \\\"{{rabbitmq_rpc_image_latest}}\\\"}}]}]}, {\\\"name\\\": \\\"Enable the rabbitmq cluster resource\\\", \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"rabbitmq-bundle\\\", \\\"state\\\": \\\"enable\\\", \\\"wait_for_resource\\\": true}, \\\"register\\\": \\\"output\\\", \\\"retries\\\": 5, \\\"until\\\": \\\"output.rc == 0\\\"}, {\\\"name\\\": \\\"Remove rabbitmq_rpc retag statefile\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/tripleo/rabbitmq_rpc_needs_retag\\\", \\\"state\\\": \\\"absent\\\"}}]}]}}}}\", \"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Oslo Notify using a shared OpenStack containerized Rabbitmq service\\\\n\\\", \\\"parameters\\\": {\\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"RpcPort\\\": {\\\"default\\\": 5672, \\\"description\\\": \\\"The network port for messaging backend\\\", \\\"type\\\": \\\"number\\\"}, \\\"RpcUserName\\\": {\\\"default\\\": \\\"guest\\\", \\\"description\\\": \\\"The username for messaging backend\\\", \\\"type\\\": \\\"string\\\"}, \\\"RpcPassword\\\": {\\\"description\\\": \\\"The password for messaging backend\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"RpcUseSSL\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Messaging client subscriber parameter to specify an SSL connection to the messaging host.\\\\n\\\", \\\"type\\\": \\\"string\\\"}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\\\"}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the oslo messaging notify role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"oslo_messaging_notify\\\", \\\"global_config_settings\\\": {\\\"oslo_messaging_notify_scheme\\\": \\\"rabbit\\\", \\\"oslo_messaging_notify_user_name\\\": {\\\"get_param\\\": \\\"RpcUserName\\\"}, \\\"oslo_messaging_notify_password\\\": {\\\"get_param\\\": \\\"RpcPassword\\\"}, \\\"oslo_messaging_notify_use_ssl\\\": {\\\"get_param\\\": \\\"RpcUseSSL\\\"}, \\\"oslo_messaging_notify_port\\\": {\\\"get_param\\\": \\\"RpcPort\\\"}}}}}}\", \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized HAproxy service\\\\n\\\", \\\"parameters\\\": {\\\"ContainerHAProxyImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerHAProxyConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the haproxy config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"HAProxyStatsPassword\\\": {\\\"description\\\": \\\"Password for HAProxy stats endpoint\\\", \\\"hidden\\\": true, \\\"type\\\": \\\"string\\\"}, \\\"HAProxyStatsUser\\\": {\\\"description\\\": \\\"User for HAProxy stats endpoint\\\", \\\"default\\\": \\\"admin\\\", \\\"type\\\": \\\"string\\\"}, \\\"HAProxyLoggingSource\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {\\\"tag\\\": \\\"openstack.haproxy\\\", \\\"file\\\": \\\"/var/log/containers/haproxy/haproxy.log\\\", \\\"startmsg.regex\\\": \\\"^[a-zA-Z]{3} [ 123][0-9] [:0-9]{8}\\\"}}, \\\"HAProxySyslogAddress\\\": {\\\"default\\\": \\\"/dev/log\\\", \\\"description\\\": \\\"Syslog address where HAproxy will send its log\\\", \\\"type\\\": \\\"string\\\"}, \\\"HAProxySyslogFacility\\\": {\\\"default\\\": \\\"local0\\\", \\\"description\\\": \\\"Syslog facility HAProxy will use for its logs\\\", \\\"type\\\": \\\"string\\\"}, \\\"SSLCertificate\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The content of the SSL certificate (without Key) in PEM format.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"PublicSSLCertificateAutogenerated\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether the public SSL certificate was autogenerated or not.\\\\n\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"EnablePublicTLS\\\": {\\\"default\\\": true, \\\"description\\\": \\\"Whether to enable TLS on the public interface or not.\\\\n\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"DeployedSSLCertificatePath\\\": {\\\"default\\\": \\\"/etc/pki/tls/private/overcloud_endpoint.pem\\\", \\\"description\\\": \\\"The filepath of the certificate as it will be stored in the controller.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"RedisPassword\\\": {\\\"description\\\": \\\"The password for the redis service account.\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"MonitoringSubscriptionHaproxy\\\": {\\\"default\\\": \\\"overcloud-haproxy\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"InternalTLSCAFile\\\": {\\\"default\\\": \\\"/etc/ipa/ca.crt\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Specifies the default CA cert to use if TLS is used for services in the internal network.\\\"}, \\\"ConfigDebug\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to run config management (e.g. Puppet) in debug mode.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"EnableLoadBalancer\\\": {\\\"default\\\": true, \\\"description\\\": \\\"Whether to deploy a LoadBalancer, set to false when an external load balancer is used.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"HAProxyStatsEnabled\\\": {\\\"default\\\": true, \\\"description\\\": \\\"Whether or not to enable the HAProxy stats interface.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"InternalTLSCRLPEMFile\\\": {\\\"default\\\": \\\"/etc/pki/CA/crl/overcloud-crl.pem\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Specifies the default CRL PEM file to use for revocation if TLS is used for services in the internal network.\\\"}, \\\"InternalTLSCRLPEMDir\\\": {\\\"default\\\": \\\"/etc/pki/CA/crl/\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"The directory of the CRL PEM file to be mounted.\\\"}}, \\\"conditions\\\": {\\\"public_tls_enabled\\\": {\\\"and\\\": [{\\\"get_param\\\": \\\"EnablePublicTLS\\\"}, {\\\"or\\\": [{\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"SSLCertificate\\\"}, \\\"\\\"]}}, {\\\"get_param\\\": \\\"PublicSSLCertificateAutogenerated\\\"}]}]}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"HAProxyLogging\\\": {\\\"type\\\": \\\"OS::TripleO::Services::Logging::HAProxy\\\"}, \\\"HAProxyPublicTLS\\\": {\\\"type\\\": \\\"OS::TripleO::Services::HAProxyPublicTLS\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"HAProxyInternalTLS\\\": {\\\"type\\\": \\\"OS::TripleO::Services::HAProxyInternalTLS\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerHAProxyImage\\\": \\\"ContainerHAProxyImage\\\", \\\"ContainerHAProxyConfigImage\\\": \\\"ContainerHAProxyConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerHAProxyImage\\\": {\\\"get_param\\\": \\\"ContainerHAProxyImage\\\"}, \\\"ContainerHAProxyConfigImage\\\": {\\\"get_param\\\": \\\"ContainerHAProxyConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the HAproxy role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"haproxy\\\", \\\"firewall_rules\\\": {\\\"107 haproxy stats\\\": {\\\"dport\\\": 1993}}, \\\"monitoring_subscription\\\": {\\\"get_param\\\": \\\"MonitoringSubscriptionHaproxy\\\"}, \\\"ansible_group_vars\\\": {\\\"tripleo_firewall_frontend_enabled\\\": true, \\\"tripleo_firewall_ssl_frontend_enabled\\\": {\\\"if\\\": [\\\"public_tls_enabled\\\", true]}}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"HAProxyLogging\\\", \\\"config_settings\\\"]}, {\\\"tripleo::haproxy::haproxy_service_manage\\\": false, \\\"tripleo::haproxy::haproxy_log_address\\\": {\\\"get_param\\\": \\\"HAProxySyslogAddress\\\"}, \\\"tripleo::haproxy::haproxy_log_facility\\\": {\\\"get_param\\\": \\\"HAProxySyslogFacility\\\"}, \\\"tripleo::haproxy::haproxy_stats_user\\\": {\\\"get_param\\\": \\\"HAProxyStatsUser\\\"}, \\\"tripleo::haproxy::haproxy_stats_password\\\": {\\\"get_param\\\": \\\"HAProxyStatsPassword\\\"}, \\\"tripleo::haproxy::haproxy_stats_bind_address\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"HaproxyNetwork\\\"]}}}}, \\\"tripleo::haproxy::redis_password\\\": {\\\"get_param\\\": \\\"RedisPassword\\\"}, \\\"tripleo::haproxy::crl_file\\\": null, \\\"tripleo::haproxy::haproxy_stats\\\": {\\\"get_param\\\": \\\"HAProxyStatsEnabled\\\"}, \\\"enable_load_balancer\\\": {\\\"get_param\\\": \\\"EnableLoadBalancer\\\"}, \\\"tripleo::profile::base::haproxy::certificates_specs\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"HAProxyPublicTLS\\\", \\\"role_data\\\", \\\"certificates_specs\\\"]}, {\\\"get_attr\\\": [\\\"HAProxyInternalTLS\\\", \\\"role_data\\\", \\\"certificates_specs\\\"]}]}, \\\"tripleo::haproxy::service_certificate\\\": {\\\"if\\\": [\\\"public_tls_enabled\\\", {\\\"get_param\\\": \\\"DeployedSSLCertificatePath\\\"}]}, \\\"tripleo::haproxy::ca_bundle\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}]}}, {\\\"get_attr\\\": [\\\"HAProxyPublicTLS\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"get_attr\\\": [\\\"HAProxyInternalTLS\\\", \\\"role_data\\\", \\\"config_settings\\\"]}]}, \\\"service_config_settings\\\": {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_haproxy\\\": [{\\\"get_param\\\": \\\"HAProxyLoggingSource\\\"}]}}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"haproxy\\\", \\\"puppet_tags\\\": \\\"haproxy_config\\\", \\\"step_config\\\": \\\"class {\'tripleo::profile::base::haproxy\': manage_firewall => false}\\\\n\\\", \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHAProxyConfigImage\\\"]}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"if\\\": [\\\"public_tls_enabled\\\", [{\\\"list_join\\\": [\\\":\\\", [{\\\"get_param\\\": \\\"DeployedSSLCertificatePath\\\"}, {\\\"get_param\\\": \\\"DeployedSSLCertificatePath\\\"}, \\\"ro,shared\\\"]]}]]}, {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, [\\\"/etc/pki/tls/certs/haproxy:/etc/pki/tls/certs/haproxy:ro,shared\\\", \\\"/etc/pki/tls/private/haproxy:/etc/pki/tls/private/haproxy:ro,shared\\\", {\\\"list_join\\\": [\\\":\\\", [{\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, \\\"ro,shared\\\"]]}, {\\\"list_join\\\": [\\\":\\\", [{\\\"get_param\\\": \\\"InternalTLSCRLPEMDir\\\"}, {\\\"get_param\\\": \\\"InternalTLSCRLPEMDir\\\"}, \\\"ro,shared\\\"]]}]]}]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/haproxy.json\\\": {\\\"command\\\": \\\"bash -c $* -- eval if [ -f /usr/sbin/haproxy-systemd-wrapper ]; then exec /usr/sbin/haproxy-systemd-wrapper -f /etc/haproxy/haproxy.cfg; else exec /usr/sbin/haproxy -f /etc/haproxy/haproxy.cfg -Ws; fi\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-tls/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true, \\\"optional\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/lib/haproxy\\\", \\\"owner\\\": \\\"haproxy:haproxy\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/certs/haproxy\\\", \\\"owner\\\": \\\"haproxy:haproxy\\\", \\\"recurse\\\": true, \\\"optional\\\": true}]}}, \\\"container_config_scripts\\\": {\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"container_config_scripts\\\"]}, \\\"docker_config\\\": {\\\"step_1\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"HAProxyLogging\\\", \\\"docker_config\\\", \\\"step_1\\\"]}, {\\\"haproxy\\\": {\\\"start_order\\\": 1, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHAProxyImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"restart\\\": \\\"always\\\", \\\"security_opt\\\": [\\\"label=disable\\\"], \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, {\\\"get_attr\\\": [\\\"HAProxyLogging\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/haproxy.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/haproxy:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/haproxy:/var/lib/haproxy:rw,z\\\"], {\\\"if\\\": [\\\"public_tls_enabled\\\", [{\\\"list_join\\\": [\\\":\\\", [{\\\"get_param\\\": \\\"DeployedSSLCertificatePath\\\"}, {\\\"list_join\\\": [\\\"\\\", [\\\"/var/lib/kolla/config_files/src-tls\\\", {\\\"get_param\\\": \\\"DeployedSSLCertificatePath\\\"}]]}, \\\"ro,shared\\\"]]}]]}, {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, [\\\"/etc/pki/tls/certs/haproxy:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/haproxy:ro,shared\\\", \\\"/etc/pki/tls/private/haproxy:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/haproxy:ro,shared\\\", {\\\"list_join\\\": [\\\":\\\", [{\\\"get_param\\\": \\\"InternalTLSCRLPEMDir\\\"}, {\\\"get_param\\\": \\\"InternalTLSCRLPEMDir\\\"}, \\\"ro\\\"]]}]]}]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}]}}, \\\"deploy_steps_tasks\\\": {\\\"list_concat\\\": [[{\\\"name\\\": \\\"Configure rsyslog for HAproxy container\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Check if rsyslog exists\\\", \\\"shell\\\": \\\"systemctl is-active rsyslog\\\", \\\"register\\\": \\\"rsyslog_config\\\"}, {\\\"when\\\": [\\\"rsyslog_config is changed\\\", \\\"rsyslog_config.rc == 0\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Forward logging to haproxy.log file\\\", \\\"blockinfile\\\": {\\\"content\\\": \\\"if $syslogfacility-text == \'{{facility}}\' and $programname == \'haproxy\' then -/var/log/containers/haproxy/haproxy.log\\\\n& stop\\\\n\\\", \\\"create\\\": true, \\\"path\\\": \\\"/etc/rsyslog.d/openstack-haproxy.conf\\\"}, \\\"vars\\\": {\\\"facility\\\": {\\\"get_param\\\": \\\"HAProxySyslogFacility\\\"}}, \\\"register\\\": \\\"logconfig\\\"}, {\\\"name\\\": \\\"restart rsyslog service after logging conf change\\\", \\\"service\\\": {\\\"name\\\": \\\"rsyslog\\\", \\\"state\\\": \\\"restarted\\\"}, \\\"when\\\": \\\"logconfig is changed\\\"}]}]}, {\\\"name\\\": \\\"Run puppet on the host to apply IPtables rules\\\", \\\"no_log\\\": true, \\\"when\\\": \\\"step|int == 1\\\", \\\"register\\\": \\\"puppet_host_outputs\\\", \\\"shell\\\": \\\"puppet apply {{ (puppet_debug|bool) | ternary(\'--debug --verbose\', \'\') }} --detailed-exitcodes --summarize --color=false \\\\\\\\\\\\n    --modulepath \'{{ puppet_modulepath }}\' --tags \'{{ puppet_tags }}\' -e \'{{ puppet_execute }}\'\\\\n\\\", \\\"changed_when\\\": \\\"puppet_host_outputs.rc == 2\\\", \\\"failed_when\\\": false, \\\"vars\\\": {\\\"puppet_execute\\\": \\\"include tripleo::profile::base::haproxy\\\", \\\"puppet_tags\\\": \\\"tripleo::firewall::rule\\\", \\\"puppet_modulepath\\\": \\\"/etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules\\\", \\\"puppet_debug\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}}}, {\\\"name\\\": \\\"Debug output for task: Run puppet on the host to apply IPtables rules\\\", \\\"debug\\\": {\\\"var\\\": \\\"puppet_host_outputs.stdout_lines | default([]) | union(puppet_host_outputs.stderr_lines | default([]))\\\"}, \\\"when\\\": [\\\"not (ansible_check_mode | bool)\\\", \\\"puppet_host_outputs.rc is defined\\\"], \\\"failed_when\\\": \\\"puppet_host_outputs.rc not in [0, 2]\\\"}], {\\\"if\\\": [\\\"public_tls_enabled\\\", {\\\"get_attr\\\": [\\\"HAProxyPublicTLS\\\", \\\"role_data\\\", \\\"deploy_steps_tasks\\\"]}]}, {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, {\\\"get_attr\\\": [\\\"HAProxyInternalTLS\\\", \\\"role_data\\\", \\\"deploy_steps_tasks\\\"]}]}]}, \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"ensure we have haproxy log dir with the correct setype\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/log/containers/haproxy\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"var_log_t\\\", \\\"recurse\\\": true}, \\\"when\\\": \\\"step|int == 1\\\"}], \\\"external_upgrade_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade_transfer_data\\\", \\\"system_upgrade_stop_services\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Stop haproxy container\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_stop\\\"}, \\\"vars\\\": {\\\"tripleo_containers_to_stop\\\": [\\\"haproxy\\\"], \\\"tripleo_delegate_to\\\": \\\"{{ groups[\'haproxy\'] | difference(groups[\'excluded_overcloud\']) }}\\\"}}]}], \\\"host_prep_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"HAProxyPublicTLS\\\", \\\"role_data\\\", \\\"host_prep_tasks\\\"]}, [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode|default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/haproxy\\\", \\\"setype\\\": \\\"var_log_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/lib/haproxy\\\", \\\"setype\\\": \\\"container_file_t\\\"}]}]]}, \\\"metadata_settings\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"HAProxyPublicTLS\\\", \\\"role_data\\\", \\\"metadata_settings\\\"]}, {\\\"get_attr\\\": [\\\"HAProxyInternalTLS\\\", \\\"role_data\\\", \\\"metadata_settings\\\"]}]}}}}}\", \"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized HAproxy service for pacemaker\\\\n\\\", \\\"parameters\\\": {\\\"ContainerHAProxyImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerHAProxyConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the haproxy config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ClusterCommonTag\\\": {\\\"default\\\": false, \\\"description\\\": \\\"When set to false, a pacemaker service is configured to use a floating tag for its container image name, e.g. \'REGISTRY/NAMESPACE/IMAGENAME:pcmklatest\'. When set to true, the service uses a floating prefix as well, e.g. \'cluster.common.tag/IMAGENAME:pcmklatest\'.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"ClusterFullTag\\\": {\\\"default\\\": true, \\\"description\\\": \\\"When set to true, the pacemaker service uses a fully constant tag for its container image name, e.g. \'cluster.common.tag/SERVICENAME:pcmklatest\'.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"SSLCertificate\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The content of the SSL certificate (without Key) in PEM format.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"PublicSSLCertificateAutogenerated\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether the public SSL certificate was autogenerated or not.\\\\n\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"EnablePublicTLS\\\": {\\\"default\\\": true, \\\"description\\\": \\\"Whether to enable TLS on the public interface or not.\\\\n\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"DeployedSSLCertificatePath\\\": {\\\"default\\\": \\\"/etc/pki/tls/private/overcloud_endpoint.pem\\\", \\\"description\\\": \\\"The filepath of the certificate as it will be stored in the controller.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"InternalTLSCAFile\\\": {\\\"default\\\": \\\"/etc/ipa/ca.crt\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Specifies the default CA cert to use if TLS is used for services in the internal network.\\\"}, \\\"HAProxyInternalTLSCertsDirectory\\\": {\\\"default\\\": \\\"/etc/pki/tls/certs/haproxy\\\", \\\"type\\\": \\\"string\\\"}, \\\"HAProxyInternalTLSKeysDirectory\\\": {\\\"default\\\": \\\"/etc/pki/tls/private/haproxy\\\", \\\"type\\\": \\\"string\\\"}, \\\"HAProxyLoggingSource\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {\\\"tag\\\": \\\"openstack.haproxy\\\", \\\"file\\\": \\\"/var/log/containers/haproxy/haproxy.log\\\", \\\"startmsg.regex\\\": \\\"^[a-zA-Z]{3} [ 123][0-9] [:0-9]{8}\\\"}}, \\\"HAProxySyslogAddress\\\": {\\\"default\\\": \\\"/dev/log\\\", \\\"description\\\": \\\"Syslog address where HAproxy will send its log\\\", \\\"type\\\": \\\"string\\\"}, \\\"HAProxySyslogFacility\\\": {\\\"default\\\": \\\"local0\\\", \\\"description\\\": \\\"Syslog facility HAProxy will use for its logs\\\", \\\"type\\\": \\\"string\\\"}, \\\"ConfigDebug\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to run config management (e.g. Puppet) in debug mode.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"ContainerCli\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"podman\\\", \\\"description\\\": \\\"CLI tool used to manage containers.\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"docker\\\", \\\"podman\\\"]}]}, \\\"DeployIdentifier\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\\\n\\\"}}, \\\"conditions\\\": {\\\"public_tls_enabled\\\": {\\\"and\\\": [{\\\"get_param\\\": \\\"EnablePublicTLS\\\"}, {\\\"or\\\": [{\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"SSLCertificate\\\"}, \\\"\\\"]}}, {\\\"get_param\\\": \\\"PublicSSLCertificateAutogenerated\\\"}]}]}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"HAProxyBase\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-container-puppet.yaml\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"HAProxyPublicTLS\\\": {\\\"type\\\": \\\"OS::TripleO::Services::HAProxyPublicTLS\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"HAProxyInternalTLS\\\": {\\\"type\\\": \\\"OS::TripleO::Services::HAProxyInternalTLS\\\", \\\"properties\\\": {\\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerHAProxyImage\\\": \\\"ContainerHAProxyImage\\\", \\\"ContainerHAProxyConfigImage\\\": \\\"ContainerHAProxyConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerHAProxyImage\\\": {\\\"get_param\\\": \\\"ContainerHAProxyImage\\\"}, \\\"ContainerHAProxyConfigImage\\\": {\\\"get_param\\\": \\\"ContainerHAProxyConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the HAproxy role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"haproxy\\\", \\\"firewall_rules\\\": {\\\"get_attr\\\": [\\\"HAProxyBase\\\", \\\"role_data\\\", \\\"firewall_rules\\\"]}, \\\"monitoring_subscription\\\": {\\\"get_attr\\\": [\\\"HAProxyBase\\\", \\\"role_data\\\", \\\"monitoring_subscription\\\"]}, \\\"ansible_group_vars\\\": {\\\"get_attr\\\": [\\\"HAProxyBase\\\", \\\"role_data\\\", \\\"ansible_group_vars\\\"]}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"HAProxyBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"tripleo::haproxy::haproxy_service_manage\\\": false, \\\"tripleo::haproxy::mysql_clustercheck\\\": true, \\\"tripleo::haproxy::haproxy_log_address\\\": {\\\"get_param\\\": \\\"HAProxySyslogAddress\\\"}, \\\"tripleo::haproxy::haproxy_log_facility\\\": {\\\"get_param\\\": \\\"HAProxySyslogFacility\\\"}}, {\\\"haproxy_docker\\\": true, \\\"tripleo::profile::pacemaker::haproxy_bundle::container_backend\\\": {\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"tripleo::profile::pacemaker::haproxy_bundle::tls_mapping\\\": {\\\"list_concat\\\": [{\\\"if\\\": [\\\"public_tls_enabled\\\", [{\\\"get_param\\\": \\\"DeployedSSLCertificatePath\\\"}]]}, {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, [{\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, {\\\"get_param\\\": \\\"HAProxyInternalTLSKeysDirectory\\\"}, {\\\"get_param\\\": \\\"HAProxyInternalTLSCertsDirectory\\\"}]]}]}, \\\"tripleo::profile::pacemaker::haproxy_bundle::tls_mapping_init_bundle\\\": {\\\"list_concat\\\": [{\\\"if\\\": [\\\"public_tls_enabled\\\", [{\\\"get_param\\\": \\\"DeployedSSLCertificatePath\\\"}]]}, {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, [{\\\"get_param\\\": \\\"HAProxyInternalTLSKeysDirectory\\\"}, {\\\"get_param\\\": \\\"HAProxyInternalTLSCertsDirectory\\\"}]]}]}, \\\"tripleo::profile::pacemaker::haproxy_bundle::internal_certs_directory\\\": {\\\"get_param\\\": \\\"HAProxyInternalTLSCertsDirectory\\\"}, \\\"tripleo::profile::pacemaker::haproxy_bundle::internal_keys_directory\\\": {\\\"get_param\\\": \\\"HAProxyInternalTLSKeysDirectory\\\"}, \\\"tripleo::profile::pacemaker::haproxy_bundle::haproxy_docker_image\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/haproxy:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHAProxyImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHAProxyImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}}]}, \\\"service_config_settings\\\": {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_haproxy\\\": [{\\\"get_param\\\": \\\"HAProxyLoggingSource\\\"}]}}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"haproxy\\\", \\\"puppet_tags\\\": \\\"haproxy_config\\\", \\\"step_config\\\": {\\\"list_join\\\": [\\\"\\\\n\\\", [\\\"exec {\'wait-for-settle\': command => \'/bin/true\' }\\\", \\\"class tripleo::firewall(){}; define tripleo::firewall::rule( $port = undef, $dport = undef, $sport = undef, $proto = undef, $action = undef, $state = undef, $source = undef, $iniface = undef, $chain = undef, $destination = undef, $extras = undef){}\\\", \\\"[\'pcmk_bundle\', \'pcmk_resource\', \'pcmk_property\', \'pcmk_constraint\', \'pcmk_resource_default\'].each |String $val| { noop_resource($val) }\\\", \\\"include tripleo::profile::pacemaker::haproxy_bundle\\\"]]}, \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHAProxyConfigImage\\\"]}, \\\"volumes\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"$.data.select($+\\\\\\\":\\\\\\\"+$+\\\\\\\":ro\\\\\\\")\\\", \\\"data\\\": {\\\"list_concat\\\": [{\\\"if\\\": [\\\"public_tls_enabled\\\", [{\\\"get_param\\\": \\\"DeployedSSLCertificatePath\\\"}]]}, {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, [{\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, {\\\"get_param\\\": \\\"HAProxyInternalTLSKeysDirectory\\\"}, {\\\"get_param\\\": \\\"HAProxyInternalTLSCertsDirectory\\\"}]]}]}}}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/haproxy.json\\\": {\\\"command\\\": \\\"bash -c $* -- eval if [ -f /usr/sbin/haproxy-systemd-wrapper ]; then exec /usr/sbin/haproxy-systemd-wrapper -f /etc/haproxy/haproxy.cfg; else exec /usr/sbin/haproxy -f /etc/haproxy/haproxy.cfg -Ws; fi\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true, \\\"optional\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-tls/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"optional\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/lib/haproxy\\\", \\\"owner\\\": \\\"haproxy:haproxy\\\", \\\"recurse\\\": true}, {\\\"path\\\": {\\\"list_join\\\": [\\\"\\\", [{\\\"get_param\\\": \\\"HAProxyInternalTLSCertsDirectory\\\"}, \\\"/*\\\"]]}, \\\"owner\\\": \\\"haproxy:haproxy\\\", \\\"perm\\\": \\\"0600\\\", \\\"optional\\\": true}, {\\\"path\\\": {\\\"list_join\\\": [\\\"\\\", [{\\\"get_param\\\": \\\"HAProxyInternalTLSKeysDirectory\\\"}, \\\"/*\\\"]]}, \\\"owner\\\": \\\"haproxy:haproxy\\\", \\\"perm\\\": \\\"0600\\\", \\\"optional\\\": true}]}}, \\\"container_config_scripts\\\": {\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"container_config_scripts\\\"]}, \\\"host_prep_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"HAProxyBase\\\", \\\"role_data\\\", \\\"host_prep_tasks\\\"]}, [{\\\"name\\\": \\\"Run puppet on the host to apply IPtables rules\\\", \\\"no_log\\\": true, \\\"shell\\\": \\\"puppet apply {{ (puppet_debug|bool) | ternary(\'--debug --verbose\', \'\') }} --detailed-exitcodes --summarize --color=false \\\\\\\\\\\\n    --modulepath \'{{ puppet_modulepath }}\' --tags \'{{ puppet_tags }}\' -e \'{{ puppet_execute }}\'\\\\n\\\", \\\"register\\\": \\\"puppet_host_outputs\\\", \\\"changed_when\\\": \\\"puppet_host_outputs.rc == 2\\\", \\\"failed_when\\\": false, \\\"vars\\\": {\\\"puppet_execute\\\": \\\"if hiera(\'enable_load_balancer\', true) { class {\'::tripleo::haproxy\': use_internal_certificates => false, manage_firewall => hiera(\'tripleo::firewall::manage_firewall\', true), }}\\\", \\\"puppet_tags\\\": \\\"tripleo::firewall::rule\\\", \\\"puppet_modulepath\\\": \\\"/etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules\\\", \\\"puppet_debug\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}}}, {\\\"name\\\": \\\"Debug output for task: Run puppet on the host to apply IPtables rules\\\", \\\"debug\\\": {\\\"var\\\": \\\"puppet_host_outputs.stdout_lines | default([]) | union(puppet_host_outputs.stderr_lines | default([]))\\\"}, \\\"when\\\": [\\\"not (ansible_check_mode | bool)\\\", \\\"puppet_host_outputs.rc is defined\\\"], \\\"failed_when\\\": \\\"puppet_host_outputs.rc not in [0, 2]\\\"}]]}, \\\"metadata_settings\\\": {\\\"get_attr\\\": [\\\"HAProxyBase\\\", \\\"role_data\\\", \\\"metadata_settings\\\"]}, \\\"deploy_steps_tasks\\\": {\\\"list_concat\\\": [[{\\\"name\\\": \\\"Configure rsyslog for HAproxy container managed by Pacemaker\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Check if rsyslog exists\\\", \\\"shell\\\": \\\"systemctl is-active rsyslog\\\", \\\"register\\\": \\\"rsyslog_config\\\"}, {\\\"when\\\": [\\\"rsyslog_config is changed\\\", \\\"rsyslog_config.rc == 0\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Forward logging to haproxy.log file\\\", \\\"blockinfile\\\": {\\\"content\\\": \\\"if $syslogfacility-text == \'{{facility}}\' and $programname == \'haproxy\' then -/var/log/containers/haproxy/haproxy.log\\\\n& stop\\\\n\\\", \\\"create\\\": true, \\\"path\\\": \\\"/etc/rsyslog.d/openstack-haproxy.conf\\\"}, \\\"vars\\\": {\\\"facility\\\": {\\\"get_param\\\": \\\"HAProxySyslogFacility\\\"}}, \\\"register\\\": \\\"logconfig\\\"}, {\\\"name\\\": \\\"restart rsyslog service after logging conf change\\\", \\\"service\\\": {\\\"name\\\": \\\"rsyslog\\\", \\\"state\\\": \\\"restarted\\\"}, \\\"when\\\": \\\"logconfig is changed\\\"}]}]}, {\\\"name\\\": \\\"HAproxy tag container image for pacemaker\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_tag\\\"}, \\\"vars\\\": {\\\"container_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHAProxyImage\\\"]}, \\\"container_image_latest\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/haproxy:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHAProxyImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHAProxyImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}}}, {\\\"name\\\": \\\"HAproxy HA Wrappers Step\\\", \\\"when\\\": \\\"step|int == 2\\\", \\\"block\\\": [{\\\"name\\\": \\\"HAproxy puppet bundle\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_ha_wrapper\\\"}, \\\"vars\\\": {\\\"tripleo_ha_wrapper_service_name\\\": \\\"haproxy\\\", \\\"tripleo_ha_wrapper_resource_name\\\": \\\"haproxy-bundle\\\", \\\"tripleo_ha_wrapper_bundle_name\\\": \\\"haproxy-bundle\\\", \\\"tripleo_ha_wrapper_resource_state\\\": \\\"Started\\\", \\\"tripleo_ha_wrapper_puppet_config_volume\\\": \\\"haproxy\\\", \\\"tripleo_ha_wrapper_puppet_execute\\\": \\\"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::haproxy_bundle\\\", \\\"tripleo_ha_wrapper_puppet_tags\\\": \\\"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\\\", \\\"tripleo_ha_wrapper_puppet_debug\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"tripleo_ha_wrapper_config_suffix\\\": \\\".previous_run\\\"}}]}], {\\\"if\\\": [\\\"public_tls_enabled\\\", {\\\"get_attr\\\": [\\\"HAProxyPublicTLS\\\", \\\"role_data\\\", \\\"deploy_steps_tasks\\\"]}, []]}, {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, {\\\"get_attr\\\": [\\\"HAProxyInternalTLS\\\", \\\"role_data\\\", \\\"deploy_steps_tasks\\\"]}]}]}, \\\"external_update_tasks\\\": [{\\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": \\\"ha_image_update\\\", \\\"block\\\": [{\\\"block\\\": [{\\\"name\\\": \\\"Get haproxy image from pacemaker\\\", \\\"become\\\": true, \\\"register\\\": \\\"xmllint_pcmk_haproxy_image\\\", \\\"shell\\\": \\\"xmllint --xpath \\\\\\\"string(//bundle[@id=\'haproxy-bundle\']/podman/@image)\\\\\\\" /var/lib/pacemaker/cib/cib.xml\\\"}, {\\\"name\\\": \\\"Get container haproxy image\\\", \\\"set_fact\\\": {\\\"haproxy_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHAProxyImage\\\"]}, \\\"haproxy_image_latest\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/haproxy:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHAProxyImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHAProxyImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"pcmk_haproxy_image\\\": \\\"{{xmllint_pcmk_haproxy_image.stdout}}\\\"}}], \\\"delegate_to\\\": \\\"{{ (groups[\\\\\\\"haproxy\\\\\\\"] | difference(groups[\\\\\\\"excluded_overcloud\\\\\\\"]))[0] }}\\\"}, {\\\"name\\\": \\\"haproxy temporary pacemaker container tag in case of image switch\\\", \\\"become\\\": true, \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_ha_image_update\\\"}, \\\"vars\\\": {\\\"tripleo_ha_image_update_node_names\\\": \\\"{{ groups[\\\\\\\"haproxy\\\\\\\"] | difference(groups[\\\\\\\"excluded_overcloud\\\\\\\"]) }}\\\", \\\"tripleo_ha_image_update_bundle\\\": \\\"haproxy-bundle\\\", \\\"tripleo_ha_image_update_new_image\\\": \\\"{{haproxy_image_latest}}\\\", \\\"tripleo_ha_image_update_old_image\\\": \\\"{{pcmk_haproxy_image}}\\\"}, \\\"when\\\": [\\\"(pcmk_haproxy_image != \\\\\\\"\\\\\\\")\\\", \\\"(pcmk_haproxy_image != haproxy_image_latest)\\\"]}]}], \\\"update_tasks\\\": [{\\\"block\\\": [{\\\"name\\\": \\\"Get haproxy image from pacemaker\\\", \\\"become\\\": true, \\\"register\\\": \\\"xmllint_pcmk_haproxy_image\\\", \\\"shell\\\": \\\"xmllint --xpath \\\\\\\"string(//bundle[@id=\'haproxy-bundle\']/podman/@image)\\\\\\\" /var/lib/pacemaker/cib/cib.xml\\\"}, {\\\"name\\\": \\\"Get container haproxy image\\\", \\\"set_fact\\\": {\\\"haproxy_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHAProxyImage\\\"]}, \\\"haproxy_image_latest\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/haproxy:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHAProxyImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHAProxyImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"pcmk_haproxy_image\\\": \\\"{{xmllint_pcmk_haproxy_image.stdout}}\\\"}}], \\\"when\\\": \\\"(step|int == 0 or step|int == 2)\\\"}, {\\\"name\\\": \\\"Check for update of haproxy container image name\\\", \\\"when\\\": \\\"step|int == 0\\\", \\\"assert\\\": {\\\"that\\\": \\\"pcmk_haproxy_image == haproxy_image_latest\\\", \\\"fail_msg\\\": \\\"haproxy image change detected, run overcloud external-update --tags ha_image_update first\\\"}}, {\\\"name\\\": \\\"Tear-down non-HA haproxy container\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Remove non-HA haproxy container\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_rm\\\"}, \\\"vars\\\": {\\\"tripleo_container_cli\\\": \\\"{{ container_cli }}\\\", \\\"tripleo_containers_to_rm\\\": [\\\"haproxy\\\"]}}]}, {\\\"name\\\": \\\"Set HAProxy upgrade facts\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"set is_haproxy_bootstrap_node fact\\\", \\\"tags\\\": \\\"common\\\", \\\"set_fact\\\": \\\"is_haproxy_bootstrap_node={{haproxy_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\\\", \\\"when\\\": [\\\"haproxy_short_bootstrap_node_name|default(false)\\\"]}]}, {\\\"name\\\": \\\"Mount TLS cert if needed\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"is_haproxy_bootstrap_node\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Check haproxy public certificate configuration in pacemaker\\\", \\\"command\\\": \\\"cibadmin --query --xpath \\\\\\\"//storage-mapping[@id=\'haproxy-cert\']\\\\\\\"\\\", \\\"failed_when\\\": false, \\\"register\\\": \\\"haproxy_cert_mounted\\\"}, {\\\"name\\\": \\\"Disable the haproxy cluster resource\\\", \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"haproxy-bundle\\\", \\\"state\\\": \\\"disable\\\", \\\"wait_for_resource\\\": true}, \\\"register\\\": \\\"output\\\", \\\"retries\\\": 5, \\\"until\\\": \\\"output.rc == 0\\\", \\\"when\\\": \\\"haproxy_cert_mounted.rc == 6\\\"}, {\\\"name\\\": \\\"Set HAProxy public cert volume mount fact\\\", \\\"set_fact\\\": {\\\"haproxy_public_cert_path\\\": {\\\"get_param\\\": \\\"DeployedSSLCertificatePath\\\"}, \\\"haproxy_public_tls_enabled\\\": {\\\"if\\\": [\\\"public_tls_enabled\\\", true, false]}}}, {\\\"name\\\": \\\"Add a bind mount for public certificate in the haproxy bundle\\\", \\\"command\\\": \\\"pcs resource bundle update haproxy-bundle storage-map add id=haproxy-cert source-dir={{ haproxy_public_cert_path }} target-dir=/var/lib/kolla/config_files/src-tls/{{ haproxy_public_cert_path }} options=ro\\\", \\\"when\\\": \\\"haproxy_cert_mounted.rc == 6 and haproxy_public_tls_enabled|bool\\\"}, {\\\"name\\\": \\\"Enable the haproxy cluster resource\\\", \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"haproxy-bundle\\\", \\\"state\\\": \\\"enable\\\", \\\"wait_for_resource\\\": true}, \\\"register\\\": \\\"output\\\", \\\"retries\\\": 5, \\\"until\\\": \\\"output.rc == 0\\\", \\\"when\\\": \\\"haproxy_cert_mounted.rc == 6\\\"}]}, {\\\"name\\\": \\\"Haproxy fetch and retag container image for pacemaker\\\", \\\"tags\\\": \\\"haproxy_syn_block\\\", \\\"when\\\": [\\\"step|int == 2\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Retag pcmklatest to latest haproxy image\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_tag\\\"}, \\\"vars\\\": {\\\"container_image\\\": \\\"{{haproxy_image}}\\\", \\\"container_image_latest\\\": \\\"{{haproxy_image_latest}}\\\"}}]}, {\\\"name\\\": \\\"Move virtual IPs to another node before stopping pacemaker\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"hostvars[inventory_hostname][\\\\\\\"haproxy_node_names\\\\\\\"]|default([])|length > 1\\\"], \\\"shell\\\": \\\"CLUSTER_NODE=$(crm_node -n)\\\\necho \\\\\\\"Retrieving all the VIPs which are hosted on this node\\\\\\\"\\\\nVIPS_TO_MOVE=$(crm_mon --as-xml | xmllint --xpath \'//resource[@resource_agent=\\\\\\\"ocf:heartbeat:IPaddr2\\\\\\\" and @role = \\\\\\\"Started\\\\\\\" and @managed = \\\\\\\"true\\\\\\\" and ./node[@name = \\\\\\\"\'${CLUSTER_NODE}\'\\\\\\\"]]/@id\' - | sed -e \'s/id=//g\' -e \'s/\\\\\\\"//g\')\\\\nfor v in ${VIPS_TO_MOVE}; do\\\\n    echo \\\\\\\"Moving VIP $v on another node\\\\\\\"\\\\n    pcs resource ban $v ${CLUSTER_NODE} --wait=300\\\\ndone\\\\necho \\\\\\\"Removing the location constraints that were created to move the VIPs\\\\\\\"\\\\nfor v in ${VIPS_TO_MOVE}; do\\\\n    echo \\\\\\\"Removing location ban for VIP $v\\\\\\\"\\\\n    ban_id=$(cibadmin --query | xmllint --xpath \'string(//rsc_location[@rsc=\\\\\\\"\'${v}\'\\\\\\\" and @node=\\\\\\\"\'${CLUSTER_NODE}\'\\\\\\\" and @score=\\\\\\\"-INFINITY\\\\\\\"]/@id)\' -)\\\\n    if [ -n \\\\\\\"$ban_id\\\\\\\" ]; then\\\\n        pcs constraint remove ${ban_id}\\\\n    else\\\\n        echo \\\\\\\"Could not retrieve and clear location constraint for VIP $v\\\\\\\" 2>&1\\\\n    fi\\\\ndone\\\\n\\\"}, {\\\"name\\\": \\\"Wait for 10s to settle connections on new VIPs\\\", \\\"wait_for\\\": {\\\"timeout\\\": 10}, \\\"when\\\": [\\\"step|int == 1\\\", \\\"hostvars[inventory_hostname][\\\\\\\"haproxy_node_names\\\\\\\"]|default([])|length > 1\\\"]}, {\\\"name\\\": \\\"Block local INPUT SYN packets on the backends except mysql\\\", \\\"tags\\\": \\\"haproxy_syn_block\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"shell\\\": \\\"# server controller-0.storage.redhat.local 172.17.3.93:8080 check fall 5 inter 2000 rise 2\\\\n# server controller-0.internalapi.redhat.local fd00:fd00:fd00:2000::176:9292 check fall 5 inter 2000 rise 2\\\\nset -o pipefail\\\\nsource /etc/os-release; test  \\\\\\\"${VERSION_ID%*}\\\\\\\" = \\\\\\\"9.0\\\\\\\" && exit 0\\\\ngrep {{ ansible_facts[\\\\\\\"hostname\\\\\\\"]|lower }} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg  | grep -v \\\\\\\":3306 \\\\\\\" | \\\\\\\\\\\\nawk \'{print $3}\' | \\\\\\\\\\\\nwhile read BACKEND; do\\\\n    IP=${BACKEND%:*}\\\\n    PORT=${BACKEND#\\\\\\\"$IP:\\\\\\\"}\\\\n    if [[ $IP =~ .*:.* ]]\\\\n      then PROTOCOL=\\\\\\\"ip6\\\\\\\"\\\\n      else PROTOCOL=\\\\\\\"ip\\\\\\\"\\\\n    fi\\\\necho \\\\\\\"insert rule $PROTOCOL filter INPUT $PROTOCOL daddr $IP tcp dport $PORT tcp flags syn / fin,syn,rst,ack meta time\\\\\\\"\\\\ndone | xargs -i nft {} $(date +%s)-$(date -d\'+20 minutes\' +%s) counter drop comment \\\\\\\"{{ ansible_facts[\\\\\\\"hostname\\\\\\\"]|lower }}_haproxy_drop\\\\\\\"\\\\n\\\"}, {\\\"name\\\": \\\"Generate block for other nodes OUTPUT SYN packets on the backends except mysql\\\", \\\"tags\\\": \\\"haproxy_syn_block\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"shell\\\": \\\"set -o pipefail\\\\nsource /etc/os-release; test  \\\\\\\"${VERSION_ID%*}\\\\\\\" = \\\\\\\"9.0\\\\\\\" && exit 0\\\\ngrep {{ ansible_facts[\\\\\\\"hostname\\\\\\\"]|lower }} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg  | grep -v \\\\\\\":3306 \\\\\\\" | \\\\\\\\\\\\nawk \'{print $3}\' | \\\\\\\\\\\\nwhile read BACKEND; do\\\\n    IP=${BACKEND%:*}\\\\n    PORT=${BACKEND#\\\\\\\"$IP:\\\\\\\"}\\\\n    if [[ $IP =~ .*:.* ]]\\\\n      then PROTOCOL=\\\\\\\"ip6\\\\\\\"\\\\n      else PROTOCOL=\\\\\\\"ip\\\\\\\"\\\\n    fi\\\\n echo \\\\\\\"nft insert rule $PROTOCOL \\\\\\\\$TABLE OUTPUT $PROTOCOL daddr $IP tcp dport $PORT tcp flags syn / fin,syn,rst,ack meta time $(date +%s)-$(date -d\'+20 minutes\' +%s) counter drop comment \\\\\\\\\\\\\\\"{{ ansible_facts[\\\\\\\"hostname\\\\\\\"]|lower }}_haproxy_drop\\\\\\\\\\\\\\\" \\\\\\\"\\\\ndone\\\\n\\\", \\\"register\\\": \\\"haproxy_iptables_block\\\"}, {\\\"name\\\": \\\"Block OUTPUT SYN packets to this node on other haproxy nodes\\\", \\\"tags\\\": \\\"haproxy_syn_block\\\", \\\"delegate_to\\\": \\\"{{ item }}\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"shell\\\": \\\"set -o pipefail\\\\ngrep {{ ansible_facts[\\\\\\\"hostname\\\\\\\"]|lower }} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg | head -n 1 \\\\\\\\\\\\nawk \'{print $3}\' | while read BACKEND; do\\\\n    IP=${BACKEND%:*}\\\\n    if [[ $IP =~ .*:.* ]]\\\\n      then PROTOCOL=\\\\\\\"ip6\\\\\\\"\\\\n      else PROTOCOL=\\\\\\\"ip\\\\\\\"\\\\n    fi\\\\ndone\\\\nTABLE=$(nft list tables | grep -q \\\\\\\"$PROTOCOL raw\\\\\\\" && echo raw || echo filter )\\\\necho \\\\\\\"{{ haproxy_iptables_block.stdout}}\\\\\\\" | while read i; do bash -c \\\\\\\"$i\\\\\\\"; done\\\\n\\\", \\\"loop\\\": \\\"{{ groups[\\\\\\\"haproxy\\\\\\\"] | difference(groups[\\\\\\\"excluded_overcloud\\\\\\\"]) | difference(ansible_facts[\\\\\\\"hostname\\\\\\\"]|lower) }}\\\"}], \\\"post_update_tasks\\\": [{\\\"name\\\": \\\"HAProxy bundle post update\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"HAproxy puppet bundle\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_ha_wrapper\\\"}, \\\"vars\\\": {\\\"tripleo_ha_wrapper_service_name\\\": \\\"haproxy\\\", \\\"tripleo_ha_wrapper_resource_name\\\": \\\"haproxy-bundle\\\", \\\"tripleo_ha_wrapper_bundle_name\\\": \\\"haproxy-bundle\\\", \\\"tripleo_ha_wrapper_resource_state\\\": \\\"Started\\\", \\\"tripleo_ha_wrapper_puppet_config_volume\\\": \\\"haproxy\\\", \\\"tripleo_ha_wrapper_puppet_execute\\\": \\\"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::haproxy_bundle\\\", \\\"tripleo_ha_wrapper_puppet_tags\\\": \\\"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\\\", \\\"tripleo_ha_wrapper_puppet_debug\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"tripleo_ha_wrapper_config_suffix\\\": \\\".previous_run\\\"}}], \\\"vars\\\": {\\\"tripleo_ha_wrapper_minor_update\\\": true}}, {\\\"name\\\": \\\"Cleanup local SYN DROP rules\\\", \\\"tags\\\": \\\"haproxy_syn_block\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"shell\\\": \\\"nft -a list chain filter INPUT | grep {{ ansible_facts[\\\\\\\"hostname\\\\\\\"]|lower }} | grep haproxy_drop | \\\\\\\\\\\\nawk -F# \'{print \\\\\\\"nft delete rule filter INPUT \\\\\\\"$2}\' | \\\\\\\\\\\\nwhile read i; do bash -c \\\\\\\"$i\\\\\\\"; done\\\\n\\\"}, {\\\"name\\\": \\\"Cleanup SYN DROP rules from other haproxy nodes\\\", \\\"tags\\\": \\\"haproxy_syn_block\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"delegate_to\\\": \\\"{{ item }}\\\", \\\"loop\\\": \\\"{{ groups[\\\\\\\"haproxy\\\\\\\"] | difference(groups[\\\\\\\"excluded_overcloud\\\\\\\"]) | difference(ansible_facts[\\\\\\\"hostname\\\\\\\"]|lower) }}\\\", \\\"shell\\\": \\\"nft -a list chain raw OUTPUT | grep {{ ansible_facts[\\\\\\\"hostname\\\\\\\"]|lower }} | grep haproxy_drop | \\\\\\\\\\\\nawk -F# \'{print \\\\\\\"nft delete rule raw OUTPUT \\\\\\\"$2}\' | \\\\\\\\\\\\nwhile read i; do bash -c \\\\\\\"$i\\\\\\\"; done\\\\n\\\"}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"Tear-down non-HA haproxy container\\\", \\\"when\\\": [\\\"step|int == 0\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Remove non-HA haproxy container\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_rm\\\"}, \\\"vars\\\": {\\\"tripleo_container_cli\\\": \\\"{{ container_cli }}\\\", \\\"tripleo_containers_to_rm\\\": [\\\"haproxy\\\"]}}]}, {\\\"name\\\": \\\"Prepare switch of haproxy image name\\\", \\\"when\\\": [\\\"step|int == 0\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Get haproxy image id currently used by pacemaker\\\", \\\"shell\\\": \\\"pcs resource config haproxy-bundle | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\\\", \\\"register\\\": \\\"haproxy_image_current_res\\\", \\\"failed_when\\\": false}, {\\\"name\\\": \\\"Image facts for haproxy\\\", \\\"set_fact\\\": {\\\"haproxy_image_latest\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/haproxy:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHAProxyImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHAProxyImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"haproxy_image_current\\\": \\\"{{haproxy_image_current_res.stdout}}\\\"}}, {\\\"name\\\": \\\"Temporarily tag the current haproxy image id with the upgraded image name\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_tag\\\"}, \\\"vars\\\": {\\\"container_image\\\": \\\"{{haproxy_image_current}}\\\", \\\"container_image_latest\\\": \\\"{{haproxy_image_latest}}\\\", \\\"pull_image\\\": false}, \\\"when\\\": [\\\"haproxy_image_current != \'\'\\\", \\\"haproxy_image_current != haproxy_image_latest\\\"]}, {\\\"name\\\": \\\"Create haproxy retag statefile\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/tripleo/haproxy_needs_retag\\\", \\\"state\\\": \\\"touch\\\"}, \\\"when\\\": [\\\"haproxy_image_current != \'\'\\\", \\\"haproxy_image_current != haproxy_image_latest\\\"]}]}, {\\\"name\\\": \\\"Update haproxy pcs resource bundle for new container image\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Set upgrade haproxy facts\\\", \\\"set_fact\\\": {\\\"is_haproxy_bootstrap_node\\\": \\\"{{haproxy_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\\\"}}, {\\\"name\\\": \\\"Check for haproxy retag statefile\\\", \\\"stat\\\": {\\\"path\\\": \\\"/var/lib/tripleo/haproxy_needs_retag\\\"}, \\\"register\\\": \\\"haproxy_retag_state_file\\\"}]}, {\\\"name\\\": \\\"Update haproxy pcs resource bundle for new container image\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"is_haproxy_bootstrap_node|bool\\\", \\\"haproxy_retag_state_file.stat.exists|bool\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Disable the haproxy cluster resource before container upgrade\\\", \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"haproxy-bundle\\\", \\\"state\\\": \\\"disable\\\", \\\"wait_for_resource\\\": true}, \\\"register\\\": \\\"output\\\", \\\"retries\\\": 5, \\\"until\\\": \\\"output.rc == 0\\\"}, {\\\"name\\\": \\\"Expose HAProxy stats socket on the host and mount TLS cert if needed\\\", \\\"block\\\": [{\\\"name\\\": \\\"Check haproxy stats socket configuration in pacemaker\\\", \\\"command\\\": \\\"cibadmin --query --xpath \\\\\\\"//storage-mapping[@id=\'haproxy-var-lib\']\\\\\\\"\\\", \\\"failed_when\\\": false, \\\"register\\\": \\\"haproxy_stats_exposed\\\"}, {\\\"name\\\": \\\"Check haproxy public certificate configuration in pacemaker\\\", \\\"command\\\": \\\"cibadmin --query --xpath \\\\\\\"//storage-mapping[@id=\'haproxy-cert\']\\\\\\\"\\\", \\\"failed_when\\\": false, \\\"register\\\": \\\"haproxy_cert_mounted\\\"}, {\\\"name\\\": \\\"Add a bind mount for stats socket in the haproxy bundle\\\", \\\"command\\\": \\\"pcs resource bundle update haproxy-bundle storage-map add id=haproxy-var-lib source-dir=/var/lib/haproxy target-dir=/var/lib/haproxy options=rw\\\", \\\"when\\\": \\\"haproxy_stats_exposed.rc == 6\\\"}, {\\\"name\\\": \\\"Set HAProxy public cert volume mount fact\\\", \\\"set_fact\\\": {\\\"haproxy_public_cert_path\\\": {\\\"get_param\\\": \\\"DeployedSSLCertificatePath\\\"}, \\\"haproxy_public_tls_enabled\\\": {\\\"if\\\": [\\\"public_tls_enabled\\\", true, false]}}}, {\\\"name\\\": \\\"Add a bind mount for public certificate in the haproxy bundle\\\", \\\"command\\\": \\\"pcs resource bundle update haproxy-bundle storage-map add id=haproxy-cert source-dir={{ haproxy_public_cert_path }} target-dir=/var/lib/kolla/config_files/src-tls/{{ haproxy_public_cert_path }} options=ro\\\", \\\"when\\\": [\\\"haproxy_cert_mounted.rc == 6\\\", \\\"haproxy_public_tls_enabled|bool\\\"]}]}, {\\\"name\\\": \\\"Update the haproxy bundle to use the new container image name\\\", \\\"command\\\": \\\"pcs resource bundle update haproxy-bundle container image={{haproxy_image_latest}}\\\"}, {\\\"name\\\": \\\"Enable the haproxy cluster resource\\\", \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"haproxy-bundle\\\", \\\"state\\\": \\\"enable\\\", \\\"wait_for_resource\\\": true}, \\\"register\\\": \\\"output\\\", \\\"retries\\\": 5, \\\"until\\\": \\\"output.rc == 0\\\"}, {\\\"name\\\": \\\"Remove haproxy retag statefile\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/tripleo/haproxy_needs_retag\\\", \\\"state\\\": \\\"absent\\\"}}]}, {\\\"name\\\": \\\"Retag the pacemaker image if containerized\\\", \\\"when\\\": [\\\"step|int == 3\\\"], \\\"block\\\": [{\\\"block\\\": [{\\\"name\\\": \\\"Get haproxy image from pacemaker\\\", \\\"become\\\": true, \\\"register\\\": \\\"xmllint_pcmk_haproxy_image\\\", \\\"shell\\\": \\\"xmllint --xpath \\\\\\\"string(//bundle[@id=\'haproxy-bundle\']/podman/@image)\\\\\\\" /var/lib/pacemaker/cib/cib.xml\\\"}, {\\\"name\\\": \\\"Get container haproxy image\\\", \\\"set_fact\\\": {\\\"haproxy_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHAProxyImage\\\"]}, \\\"haproxy_image_latest\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/haproxy:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHAProxyImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerHAProxyImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"pcmk_haproxy_image\\\": \\\"{{xmllint_pcmk_haproxy_image.stdout}}\\\"}}]}, {\\\"block\\\": [{\\\"name\\\": \\\"Retag pcmklatest to latest haproxy image\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_tag\\\"}, \\\"vars\\\": {\\\"container_image\\\": \\\"{{haproxy_image}}\\\", \\\"container_image_latest\\\": \\\"{{haproxy_image_latest}}\\\"}}]}, {\\\"name\\\": \\\"Ensure config works for the new config\\\", \\\"shell\\\": \\\"set -o pipefail\\\\nawk -i inplace -v INPLACE_SUFFIX=.bak \'/  rsprep/ {print \\\\\\\"  http-response replace-header Location \\\\\\\" $3\\\\\\\" \\\\\\\"$5; next;}; {print} \' /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg\\\"}]}]}}}}\", \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Pacemaker service configured with Puppet\\\\n\\\", \\\"parameters\\\": {\\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"MonitoringSubscriptionPacemaker\\\": {\\\"default\\\": \\\"overcloud-pacemaker\\\", \\\"type\\\": \\\"string\\\"}, \\\"CorosyncIPv6\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Enable IPv6 in Corosync\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"EnableFencing\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to enable fencing in Pacemaker or not.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"PacemakerTLSPriorities\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Pacemaker TLS Priorities\\\", \\\"default\\\": \\\"\\\"}, \\\"PacemakerRemoteAuthkey\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"The authkey for the pacemaker remote service.\\\", \\\"hidden\\\": true}, \\\"PcsdPassword\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"The password for the \'pcsd\' user for pacemaker.\\\", \\\"hidden\\\": true}, \\\"CorosyncTokenTimeout\\\": {\\\"type\\\": \\\"number\\\", \\\"description\\\": \\\"Time in milliseconds until a token loss is declared after not receiving a token.\\\", \\\"default\\\": 10000}, \\\"CorosyncSettleTries\\\": {\\\"type\\\": \\\"number\\\", \\\"description\\\": \\\"Number of tries for cluster settling. This has the same default as the pacemaker puppet module. Override to a smaller value when in need to replace a controller node.\\\", \\\"default\\\": 360}, \\\"FencingConfig\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Pacemaker fencing configuration. The JSON should have\\\\nthe following structure:\\\\n  {\\\\n    \\\\\\\"devices\\\\\\\": [\\\\n      {\\\\n        \\\\\\\"agent\\\\\\\": \\\\\\\"AGENT_NAME\\\\\\\",\\\\n        \\\\\\\"host_mac\\\\\\\": \\\\\\\"HOST_MAC_ADDRESS\\\\\\\",\\\\n        \\\\\\\"params\\\\\\\": {\\\\\\\"PARAM_NAME\\\\\\\": \\\\\\\"PARAM_VALUE\\\\\\\"}\\\\n      }\\\\n    ]\\\\n  }\\\\nFor instance:\\\\n  {\\\\n    \\\\\\\"devices\\\\\\\": [\\\\n      {\\\\n        \\\\\\\"agent\\\\\\\": \\\\\\\"fence_xvm\\\\\\\",\\\\n        \\\\\\\"host_mac\\\\\\\": \\\\\\\"52:54:00:aa:bb:cc\\\\\\\",\\\\n        \\\\\\\"params\\\\\\\": {\\\\n          \\\\\\\"multicast_address\\\\\\\": \\\\\\\"225.0.0.12\\\\\\\",\\\\n          \\\\\\\"port\\\\\\\": \\\\\\\"baremetal_0\\\\\\\",\\\\n          \\\\\\\"manage_fw\\\\\\\": true,\\\\n          \\\\\\\"manage_key_file\\\\\\\": true,\\\\n          \\\\\\\"key_file\\\\\\\": \\\\\\\"/etc/fence_xvm.key\\\\\\\",\\\\n          \\\\\\\"key_file_password\\\\\\\": \\\\\\\"abcdef\\\\\\\"\\\\n        }\\\\n      }\\\\n    ]\\\\n  }\\\\n\\\", \\\"type\\\": \\\"json\\\"}, \\\"PacemakerLoggingSource\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {\\\"tag\\\": \\\"system.pacemaker\\\", \\\"file\\\": \\\"/var/log/host/pacemaker/pacemaker.log\\\", \\\"startmsg.regex\\\": \\\"^[a-zA-Z]{3} [0-9]{2} [:0-9]{8}\\\"}}, \\\"ContainerCli\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"podman\\\", \\\"description\\\": \\\"CLI tool used to manage containers.\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"docker\\\", \\\"podman\\\"]}]}, \\\"EnableInstanceHA\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to enable an Instance Ha configurarion or not. This setup requires the Compute role to have the PacemakerRemote service added to it.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"PacemakerBundleOperationTimeout\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The timeout for start, monitor and stop operations run by the container resource agent, in seconds. When set to default \'\', the timeout comes from pacemaker\'s default operation timeouts (20s). When set to default and podman is used, force the timeout to 120s.\\\", \\\"constraints\\\": [{\\\"allowed_pattern\\\": \\\"([1-9][0-9]*s)?\\\"}]}}, \\\"parameter_groups\\\": [{\\\"label\\\": \\\"deprecated\\\", \\\"description\\\": \\\"The following parameters are deprecated and will be removed. They should not\\\\nbe relied on for new deployments. If you have concerns regarding deprecated\\\\nparameters, please contact the TripleO development team on IRC or the\\\\nOpenStack mailing list.\\\\n\\\", \\\"parameters\\\": [\\\"CorosyncIPv6\\\"]}], \\\"conditions\\\": {\\\"pcmk_tls_priorities_empty\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"PacemakerTLSPriorities\\\"}, \\\"\\\"]}, \\\"pcmk_bundle_op_timeout_empty\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"PacemakerBundleOperationTimeout\\\"}, \\\"\\\"]}, \\\"podman_enabled\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"podman\\\"]}, \\\"is_ipv6\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"ServiceData\\\", \\\"net_ip_version_map\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PacemakerNetwork\\\"]}]}, 6]}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Pacemaker role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"pacemaker\\\", \\\"monitoring_subscription\\\": {\\\"get_param\\\": \\\"MonitoringSubscriptionPacemaker\\\"}, \\\"firewall_rules\\\": {\\\"130 pacemaker tcp\\\": {\\\"proto\\\": \\\"tcp\\\", \\\"dport\\\": [2224, 3121, 21064]}, \\\"131 pacemaker udp\\\": {\\\"proto\\\": \\\"udp\\\", \\\"dport\\\": 5405}}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"pacemaker::corosync::cluster_name\\\": \\\"tripleo_cluster\\\", \\\"pacemaker::corosync::manage_fw\\\": false, \\\"pacemaker::resource_defaults::defaults\\\": {\\\"resource-stickiness\\\": {\\\"value\\\": \\\"INFINITY\\\"}}, \\\"corosync_token_timeout\\\": {\\\"get_param\\\": \\\"CorosyncTokenTimeout\\\"}, \\\"pacemaker::corosync::settle_tries\\\": {\\\"get_param\\\": \\\"CorosyncSettleTries\\\"}, \\\"pacemaker::resource::bundle::deep_compare\\\": true, \\\"pacemaker::resource::ip::deep_compare\\\": true, \\\"pacemaker::resource::ocf::deep_compare\\\": true, \\\"corosync_ipv6\\\": {\\\"if\\\": [\\\"is_ipv6\\\", true, false]}, \\\"tripleo::fencing::config\\\": {\\\"get_param\\\": \\\"FencingConfig\\\"}, \\\"tripleo::fencing::deep_compare\\\": true, \\\"enable_fencing\\\": {\\\"get_param\\\": \\\"EnableFencing\\\"}, \\\"hacluster_pwd\\\": {\\\"get_param\\\": \\\"PcsdPassword\\\"}, \\\"tripleo::profile::base::pacemaker::remote_authkey\\\": {\\\"get_param\\\": \\\"PacemakerRemoteAuthkey\\\"}, \\\"tripleo::profile::base::pacemaker::pcsd_bind_addr\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PacemakerNetwork\\\"]}}}}}, {\\\"if\\\": [\\\"pcmk_tls_priorities_empty\\\", {}, {\\\"tripleo::pacemaker::tls_priorities\\\": {\\\"get_param\\\": \\\"PacemakerTLSPriorities\\\"}}]}, {\\\"if\\\": [{\\\"and\\\": [\\\"pcmk_bundle_op_timeout_empty\\\", {\\\"not\\\": \\\"podman_enabled\\\"}]}, {}, {\\\"tripleo::profile::base::pacemaker::resource_op_defaults\\\": {\\\"bundle\\\": {\\\"name\\\": \\\"timeout\\\", \\\"value\\\": {\\\"if\\\": [\\\"pcmk_bundle_op_timeout_empty\\\", \\\"120s\\\", {\\\"get_param\\\": \\\"PacemakerBundleOperationTimeout\\\"}]}}}}]}]}, \\\"service_config_settings\\\": {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_pacemaker\\\": [{\\\"get_param\\\": \\\"PacemakerLoggingSource\\\"}]}}, \\\"step_config\\\": \\\"include tripleo::profile::base::pacemaker\\\\n\\\", \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"Make sure python3-novaclient is installed when IHA is enabled\\\", \\\"package\\\": {\\\"name\\\": \\\"python3-novaclient\\\", \\\"state\\\": \\\"present\\\"}, \\\"when\\\": {\\\"get_param\\\": \\\"EnableInstanceHA\\\"}}, {\\\"name\\\": \\\"Remove existing entries from logind conf\\\", \\\"ansible.builtin.lineinfile\\\": {\\\"path\\\": \\\"/etc/systemd/logind.conf\\\", \\\"regexp\\\": \\\"^\\\\\\\\s*#?\\\\\\\\s*HandlePowerKey\\\\\\\\s*=.*\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"Make sure systemd-logind ignores power off\\\", \\\"ansible.builtin.lineinfile\\\": {\\\"path\\\": \\\"/etc/systemd/logind.conf\\\", \\\"regexp\\\": \\\"^#?HandlePowerKey\\\", \\\"line\\\": \\\"HandlePowerKey=ignore\\\"}}, {\\\"name\\\": \\\"Restart systemd-logind\\\", \\\"ansible.builtin.service\\\": {\\\"name\\\": \\\"systemd-logind\\\", \\\"state\\\": \\\"restarted\\\"}}, {\\\"name\\\": \\\"Gather service_facts on pacemaker_bootstrap_node\\\", \\\"ansible.builtin.service_facts\\\": null, \\\"when\\\": [\\\"{{(pacemaker_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower)|bool}}\\\", {\\\"get_param\\\": \\\"EnableInstanceHA\\\"}]}, {\\\"name\\\": \\\"Check and eventually delete duplicate constraints (bootstrap node)\\\", \\\"become\\\": true, \\\"shell\\\": \\\"COUNT=$(cibadmin --query | xmllint --xpath \'//rsc_location[@rsc=\\\\\\\"stonith-fence_compute-fence-nova\\\\\\\"]/@id\' - |grep -oP \'(?<=[\\\\\\\"])[^\\\\\\\"]*\' -c)\\\\nif [[ $COUNT > 1 ]]; then\\\\n    echo \\\\\\\"Detected $COUNT duplicate constraints, deleting them\\\\\\\"\\\\n    # assemble string with current list of computes\\\\n    GOOD=$(echo location-stonith-fence_compute-fence-nova-$(hiera pacemaker_remote_short_node_names |grep -oP \'\\\\\\\".*?\\\\\\\"\' |tr -d \'\\\\\\\"\'|tr -d \'\\\\\\\\n\' )--10000)\\\\n    # delete old constraints\\\\n    for i in $(cibadmin --query | xmllint --xpath \'//rsc_location[@rsc=\\\\\\\"stonith-fence_compute-fence-nova\\\\\\\"]/@id\' - |grep -oP \'(?<=[\\\\\\\"])[^\\\\\\\"]*\' |grep -v $GOOD ); do pcs constraint delete $i ; done\\\\nelse\\\\n    echo \\\\\\\"No duplicate constraint found\\\\\\\"\\\\nfi\\\\n\\\", \\\"when\\\": [\\\"{{(pacemaker_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower)|bool}}\\\", {\\\"get_param\\\": \\\"EnableInstanceHA\\\"}, \\\"ansible_facts[\'services\'][\'pacemaker.service\'][\'state\'] == \'running\'\\\"]}], \\\"scale_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\", \\\"container_cli == \'podman\'\\\", \\\"\\\\\\\"pacemaker_remote\\\\\\\" in enabled_services|list\\\", \\\"inventory_hostname_short in compute_instanceha_short_node_names\\\"], \\\"tags\\\": \\\"down\\\", \\\"become\\\": true, \\\"block\\\": [{\\\"name\\\": \\\"Getting Nova compute hostname\\\", \\\"command\\\": \\\"crm_node -n\\\", \\\"register\\\": \\\"nova_compute_hostname\\\"}, {\\\"name\\\": \\\"Check if pacemaker_short_bootstrap_node_name is a defined variable\\\", \\\"when\\\": \\\"pacemaker_short_bootstrap_node_name is not defined\\\", \\\"fail\\\": {\\\"msg\\\": \\\"Cannot delegate pacemaker cleanup to the bootstrap node. Please delete the resources manually.\\\"}, \\\"ignore_errors\\\": true}, {\\\"name\\\": \\\"Clean up Pacemaker remote and STONITH resources for Compute node\\\", \\\"when\\\": [\\\"nova_compute_hostname.stdout in compute_instanceha_short_node_names\\\", \\\"pacemaker_short_bootstrap_node_name is defined\\\"], \\\"block\\\": [{\\\"name\\\": \\\"List STONITH resource for the Compute node\\\", \\\"command\\\": \\\"stonith_admin -l {{ nova_compute_hostname.stdout }}\\\", \\\"register\\\": \\\"stonith_service_results\\\", \\\"delegate_to\\\": \\\"{{ pacemaker_short_bootstrap_node_name }}\\\"}, {\\\"name\\\": \\\"Disable the STONITH resources for the Compute node\\\", \\\"command\\\": \\\"pcs stonith disable \\\\\\\"{{ item }}\\\\\\\"\\\", \\\"loop\\\": \\\"{{ stonith_service_results.stdout | regex_findall(\'^(stonith-fence(?!_compute-fence-nova).*)\', multiline=True)}}\\\", \\\"delegate_to\\\": \\\"{{ pacemaker_short_bootstrap_node_name }}\\\", \\\"register\\\": \\\"disable_output\\\", \\\"failed_when\\\": \\\"disable_output.rc != 0\\\", \\\"retries\\\": 3, \\\"delay\\\": 5, \\\"until\\\": \\\"disable_output.rc == 0\\\"}, {\\\"name\\\": \\\"Delete the STONITH resources for the Compute node\\\", \\\"command\\\": \\\"pcs stonith delete \\\\\\\"{{ item }}\\\\\\\"\\\", \\\"loop\\\": \\\"{{ stonith_service_results.stdout | regex_findall(\'^(stonith-fence(?!_compute-fence-nova).*)\', multiline=True)}}\\\", \\\"delegate_to\\\": \\\"{{ pacemaker_short_bootstrap_node_name }}\\\", \\\"register\\\": \\\"delete_output\\\", \\\"failed_when\\\": \\\"delete_output.rc != 0\\\", \\\"retries\\\": 3, \\\"delay\\\": 5, \\\"until\\\": \\\"delete_output.rc == 0\\\"}, {\\\"name\\\": \\\"Clear the stonith level hierarchy for the Compute node target\\\", \\\"command\\\": \\\"pcs stonith level clear target {{ nova_compute_hostname.stdout }}\\\", \\\"delegate_to\\\": \\\"{{ pacemaker_short_bootstrap_node_name }}\\\"}, {\\\"name\\\": \\\"Delete Compute node from cluster\\\", \\\"command\\\": \\\"pcs cluster node remove-remote {{ nova_compute_hostname.stdout }}\\\", \\\"delegate_to\\\": \\\"{{ pacemaker_short_bootstrap_node_name }}\\\"}, {\\\"name\\\": \\\"Remove compute node in pcmk_host_list parameter from stonith-fence_compute-fence-nova\\\", \\\"command\\\": \\\"crm_resource --set-parameter=pcmk_host_list -r stonith-fence_compute-fence-nova -v \\\\\\\"{{ pacemaker_remote_short_node_names | reject(\'search\', nova_compute_hostname.stdout) | join(\',\') }}\\\\\\\"\\\", \\\"delegate_to\\\": \\\"{{ pacemaker_short_bootstrap_node_name }}\\\"}]}]}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"Ensure redis is removed\\\", \\\"when\\\": [\\\"step|int == 5\\\", \\\"\\\\\\\"redis\\\\\\\" not in enabled_services|list\\\", \\\"{{ (pacemaker_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower)|bool}}\\\"], \\\"become\\\": true, \\\"shell\\\": \\\"if crm_resource -r redis-bundle -q &>/dev/null; then\\\\n   pcs resource delete redis-bundle || true\\\\n   pcs resource delete ip-$(hiera redis_vip) || true\\\\nfi\\\\n\\\"}, {\\\"name\\\": \\\"Clean up cluster node cache\\\", \\\"when\\\": [\\\"step|int == 5\\\", \\\"\\\\\\\"redis\\\\\\\" not in enabled_services|list\\\", \\\"{{ (pacemaker_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower)|bool}}\\\"], \\\"become\\\": true, \\\"shell\\\": \\\"pcs cluster node clear redis-bundle-0\\\\npcs cluster node clear redis-bundle-1\\\\npcs cluster node clear redis-bundle-2\\\\ncrm_attribute --name redis_REPL_INFO --delete\\\\n\\\"}, {\\\"name\\\": \\\"Clean up redis attribute\\\", \\\"when\\\": [\\\"step|int == 5\\\", \\\"\\\\\\\"redis\\\\\\\" not in enabled_services|list\\\", \\\"{{ (pacemaker_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower)|bool}}\\\"], \\\"become\\\": true, \\\"shell\\\": \\\"pcs node attribute \\\\\\\"{{ item }}\\\\\\\" redis-role= || true\\\\n\\\", \\\"loop\\\": \\\"{{ pacemaker_short_node_names }}\\\"}], \\\"external_upgrade_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade_stop_services\\\", \\\"system_upgrade_transfer_data\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Stop cluster\\\", \\\"become\\\": true, \\\"shell\\\": \\\"set -eu\\\\nFILE=/usr/sbin/pcs\\\\nif test -f \\\\\\\"$FILE\\\\\\\"; then\\\\n  /usr/sbin/pcs cluster stop --force\\\\nfi\\\\n\\\", \\\"delegate_to\\\": \\\"{{ item }}\\\", \\\"with_items\\\": \\\"{{ groups[\'pacemaker\'] | difference(groups[\'excluded_overcloud\']) }}\\\"}]}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"Check pacemaker cluster running before the minor update\\\", \\\"when\\\": \\\"step|int == 0\\\", \\\"pacemaker_cluster\\\": \\\"state=online check_and_fail=true\\\", \\\"async\\\": 30, \\\"poll\\\": 4}, {\\\"name\\\": \\\"Acquire the cluster shutdown lock to stop pacemaker cluster\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"command\\\": \\\"systemd-cat -t ha-shutdown /var/lib/container-config-scripts/pacemaker_mutex_shutdown.sh --acquire\\\"}, {\\\"name\\\": \\\"Stop pacemaker cluster\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"pacemaker_cluster\\\": \\\"state=offline\\\"}, {\\\"name\\\": \\\"Start pacemaker cluster\\\", \\\"when\\\": \\\"step|int == 4\\\", \\\"pacemaker_cluster\\\": \\\"state=online\\\"}, {\\\"name\\\": \\\"Release the cluster shutdown lock\\\", \\\"when\\\": \\\"step|int == 4\\\", \\\"command\\\": \\\"systemd-cat -t ha-shutdown /var/lib/container-config-scripts/pacemaker_mutex_shutdown.sh --release\\\"}]}}}}\", \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Pacemaker remote service configured with Puppet\\\\n\\\", \\\"parameters\\\": {\\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"PacemakerRemoteAuthkey\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"The authkey for the pacemaker remote service.\\\", \\\"hidden\\\": true}, \\\"PcsdPassword\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"The password for the \'pcsd\' user for pacemaker.\\\", \\\"hidden\\\": true}, \\\"MonitoringSubscriptionPacemakerRemote\\\": {\\\"default\\\": \\\"overcloud-pacemaker_remote\\\", \\\"type\\\": \\\"string\\\"}, \\\"EnableFencing\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to enable fencing in Pacemaker or not.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"FencingConfig\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Pacemaker fencing configuration. The JSON should have\\\\nthe following structure:\\\\n  {\\\\n    \\\\\\\"devices\\\\\\\": [\\\\n      {\\\\n        \\\\\\\"agent\\\\\\\": \\\\\\\"AGENT_NAME\\\\\\\",\\\\n        \\\\\\\"host_mac\\\\\\\": \\\\\\\"HOST_MAC_ADDRESS\\\\\\\",\\\\n        \\\\\\\"params\\\\\\\": {\\\\\\\"PARAM_NAME\\\\\\\": \\\\\\\"PARAM_VALUE\\\\\\\"}\\\\n      }\\\\n    ]\\\\n  }\\\\nFor instance:\\\\n  {\\\\n    \\\\\\\"devices\\\\\\\": [\\\\n      {\\\\n        \\\\\\\"agent\\\\\\\": \\\\\\\"fence_xvm\\\\\\\",\\\\n        \\\\\\\"host_mac\\\\\\\": \\\\\\\"52:54:00:aa:bb:cc\\\\\\\",\\\\n        \\\\\\\"params\\\\\\\": {\\\\n          \\\\\\\"multicast_address\\\\\\\": \\\\\\\"225.0.0.12\\\\\\\",\\\\n          \\\\\\\"port\\\\\\\": \\\\\\\"baremetal_0\\\\\\\",\\\\n          \\\\\\\"manage_fw\\\\\\\": true,\\\\n          \\\\\\\"manage_key_file\\\\\\\": true,\\\\n          \\\\\\\"key_file\\\\\\\": \\\\\\\"/etc/fence_xvm.key\\\\\\\",\\\\n          \\\\\\\"key_file_password\\\\\\\": \\\\\\\"abcdef\\\\\\\"\\\\n        }\\\\n      }\\\\n    ]\\\\n  }\\\\n\\\", \\\"type\\\": \\\"json\\\"}, \\\"PacemakerRemoteLoggingSource\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {\\\"tag\\\": \\\"system.pacemaker_remote\\\", \\\"file\\\": \\\"/var/log/host/pacemaker.log\\\", \\\"startmsg.regex\\\": \\\"^[a-zA-Z]{3} [0-9]{2} [:0-9]{8}\\\"}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Pacemaker remote role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"pacemaker_remote\\\", \\\"firewall_rules\\\": {\\\"130 pacemaker_remote tcp\\\": {\\\"proto\\\": \\\"tcp\\\", \\\"dport\\\": [2224, 3121]}}, \\\"monitoring_subscription\\\": {\\\"get_param\\\": \\\"MonitoringSubscriptionPacemakerRemote\\\"}, \\\"config_settings\\\": {\\\"tripleo::fencing::config\\\": {\\\"get_param\\\": \\\"FencingConfig\\\"}, \\\"tripleo::fencing::deep_compare\\\": true, \\\"enable_fencing\\\": {\\\"get_param\\\": \\\"EnableFencing\\\"}, \\\"tripleo::profile::base::pacemaker_remote::remote_authkey\\\": {\\\"get_param\\\": \\\"PacemakerRemoteAuthkey\\\"}, \\\"tripleo::profile::base::pacemaker_remote::pcsd_bind_addr\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"PacemakerRemoteNetwork\\\"]}}}}, \\\"pacemaker::corosync::manage_fw\\\": false, \\\"hacluster_pwd\\\": {\\\"get_param\\\": \\\"PcsdPassword\\\"}}, \\\"service_config_settings\\\": {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_pacemaker_remote\\\": [{\\\"get_param\\\": \\\"PacemakerRemoteLoggingSource\\\"}]}}, \\\"step_config\\\": \\\"include tripleo::profile::base::pacemaker_remote\\\\n\\\", \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"Remove existing entries from logind conf\\\", \\\"ansible.builtin.lineinfile\\\": {\\\"path\\\": \\\"/etc/systemd/logind.conf\\\", \\\"regexp\\\": \\\"^\\\\\\\\s*#?\\\\\\\\s*HandlePowerKey\\\\\\\\s*=.*\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"Make sure systemd-logind ignores power off\\\", \\\"ansible.builtin.lineinfile\\\": {\\\"path\\\": \\\"/etc/systemd/logind.conf\\\", \\\"regexp\\\": \\\"^#?HandlePowerKey\\\", \\\"line\\\": \\\"HandlePowerKey=ignore\\\"}}, {\\\"name\\\": \\\"Restart systemd-logind\\\", \\\"ansible.builtin.service\\\": {\\\"name\\\": \\\"systemd-logind\\\", \\\"state\\\": \\\"restarted\\\"}}]}}}}\", \"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/mysql_upgrade_db.sh\": \"#!/usr/bin/bash\\n\\nset -e\\n\\n# Wait until we know the mysql server is up and responding\\ntimeout ${DB_MAX_TIMEOUT:-60} /bin/bash -c \'until mysqladmin -uroot ping 2>/dev/null; do sleep 1; done\'\\n\\n# After an upgrade, make sure that the running mysql had a chance to\\n# update its data table on disk.\\nmysql_upgrade\\n\\n# Upgrade to 10.3: the default table row format changed from COMPACT\\n# to DYNAMIC, so upgrade the existing tables.\\ncompact_tables=$(mysql -se \'SELECT CONCAT(\\\"`\\\",TABLE_SCHEMA,\\\"`.`\\\",TABLE_NAME,\\\"`\\\") FROM information_schema.tables WHERE ENGINE = \\\"InnoDB\\\" and ROW_FORMAT = \\\"Compact\\\";\');\\nfor i in $compact_tables; do echo converting row format of table $i; mysql -e \\\"ALTER TABLE $i ROW_FORMAT=DYNAMIC;\\\"; done;\\n\", \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-base.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"MySQL service deployment using puppet\\\\n\\\", \\\"parameters\\\": {\\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"MysqlMaxConnections\\\": {\\\"description\\\": \\\"Configures MySQL max_connections config setting\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 4096}, \\\"MysqlIncreaseFileLimit\\\": {\\\"description\\\": \\\"Flag to increase MySQL open-files-limit to 16384\\\", \\\"type\\\": \\\"boolean\\\", \\\"default\\\": true}, \\\"MysqlRootPassword\\\": {\\\"type\\\": \\\"string\\\", \\\"hidden\\\": true, \\\"default\\\": \\\"\\\"}, \\\"MysqlClustercheckPassword\\\": {\\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"EnableGalera\\\": {\\\"default\\\": true, \\\"description\\\": \\\"Whether to use Galera instead of regular MariaDB.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"EnableMysqlAuthEd25519\\\": {\\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"Whether to configure MySQL users to connect to the server using the Ed25519-based client authentication.\\\", \\\"default\\\": false}, \\\"MysqlIPv6\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Enable IPv6 in MySQL\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"MysqlInnodbBufferPoolSize\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Buffer pool size for MySQL database; this needs to be larger for at-scale deployments\\\", \\\"default\\\": \\\"1G\\\"}, \\\"CertificateKeySize\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"2048\\\", \\\"description\\\": \\\"Specifies the private key size used when creating the certificate.\\\"}, \\\"MysqlCertificateKeySize\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Override the private key size used when creating the certificate for this service\\\"}}, \\\"parameter_groups\\\": [{\\\"label\\\": \\\"deprecated\\\", \\\"description\\\": \\\"The following parameters are deprecated and will be removed. They should not\\\\nbe relied on for new deployments. If you have concerns regarding deprecated\\\\nparameters, please contact the TripleO development team on IRC or the\\\\nOpenStack mailing list.\\\\n\\\", \\\"parameters\\\": [\\\"MysqlIPv6\\\"]}], \\\"conditions\\\": {\\\"is_ipv6\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"ServiceData\\\", \\\"net_ip_version_map\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MysqlNetwork\\\"]}]}, 6]}, \\\"innodb_buffer_pool_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"MysqlInnodbBufferPoolSize\\\"}, \\\"\\\"]}}, \\\"key_size_override_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"MysqlCertificateKeySize\\\"}, \\\"\\\"]}}}, \\\"outputs\\\": {\\\"container_config_scripts\\\": {\\\"description\\\": \\\"Shared docker config scripts\\\", \\\"value\\\": {\\\"mysql_upgrade_db.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": {\\\"get_file\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/mysql_upgrade_db.sh\\\"}}}}, \\\"mysql_drop_unused_users\\\": {\\\"description\\\": \\\"Ansible block to clean up unusued Openstack DB users\\\", \\\"value\\\": [{\\\"name\\\": \\\"Drop unused OpenStack DB users\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"mysql_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower\\\"], \\\"block\\\": [{\\\"name\\\": \\\"mysql container id\\\", \\\"command\\\": \\\"podman ps -q --filter name={{ mysql_container_name }} --filter status=running\\\", \\\"register\\\": \\\"mysql_container_id\\\"}, {\\\"name\\\": \\\"set mysql container id fact\\\", \\\"set_fact\\\": {\\\"mysql_container\\\": \\\"{{ mysql_container_id.stdout }}\\\"}}, {\\\"name\\\": \\\"Mysql script to drop unused DB users\\\", \\\"when\\\": \\\"( mysql_container | length ) > 0\\\", \\\"block\\\": [{\\\"name\\\": \\\"Get the list of all OpenStack DB users\\\", \\\"shell\\\": \\\"jq -r \'to_entries[] | select(.key|endswith(\\\\\\\"::db::mysql::user\\\\\\\")) | .value\' /etc/puppet/hieradata/service_configs.json\\\", \\\"register\\\": \\\"openstack_db_users\\\"}, {\\\"name\\\": \\\"List all DB users that match the DB users to be dropped\\\", \\\"shell\\\": \\\"for u in {{ openstack_db_users.stdout_lines | join(\' \') }}; do podman exec -u root -it \\\\\\\"{{ mysql_container }}\\\\\\\" mysql -sNe \\\\\\\"select concat(\'\\\\\\\\`\',user,\'\\\\\\\\`@\\\\\\\\`\',host,\'\\\\\\\\`\') from mysql.user where user = \'$u\' and host != \'%\';\\\\\\\"; done\\\", \\\"register\\\": \\\"mysql_db_users\\\"}, {\\\"name\\\": \\\"resulting DB users to be dropped\\\", \\\"debug\\\": {\\\"msg\\\": \\\"{{ mysql_db_users.stdout_lines }}\\\"}}, {\\\"name\\\": \\\"Drop all unneeded Openstack DB users\\\", \\\"shell\\\": \\\"podman exec -u root -it \\\\\\\"{{ mysql_container }}\\\\\\\" mysql -sNe \'drop user {{ item }};\'\\\", \\\"loop\\\": \\\"{{ mysql_db_users.stdout_lines }}\\\"}]}]}]}, \\\"role_data\\\": {\\\"description\\\": \\\"Service MySQL using composable services.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"mysql\\\", \\\"config_settings\\\": {\\\"mysql::server::package_name\\\": \\\"mariadb-galera-server\\\", \\\"mysql::server::manage_config_file\\\": true, \\\"mysql_ipv6\\\": {\\\"if\\\": [\\\"is_ipv6\\\", true, false]}, \\\"mysql_max_connections\\\": {\\\"get_param\\\": \\\"MysqlMaxConnections\\\"}, \\\"mysql::server::root_password\\\": {\\\"get_param\\\": \\\"MysqlRootPassword\\\"}, \\\"mysql_clustercheck_password\\\": {\\\"get_param\\\": \\\"MysqlClustercheckPassword\\\"}, \\\"enable_galera\\\": {\\\"get_param\\\": \\\"EnableGalera\\\"}, \\\"mysql_auth_ed25519\\\": {\\\"get_param\\\": \\\"EnableMysqlAuthEd25519\\\"}, \\\"mysql_bind_host\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MysqlNetwork\\\"]}}}}, \\\"tripleo::profile::base::database::mysql::bind_address\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'fqdn_$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MysqlNetwork\\\"]}}}}, \\\"tripleo::profile::base::database::mysql::client_bind_address\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MysqlNetwork\\\"]}}}}, \\\"tripleo::profile::base::database::mysql::generate_dropin_file_limit\\\": {\\\"get_param\\\": \\\"MysqlIncreaseFileLimit\\\"}, \\\"tripleo::profile::base::database::mysql::certificate_specs\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, {\\\"service_certificate\\\": \\\"/etc/pki/tls/certs/mysql.crt\\\", \\\"service_key\\\": \\\"/etc/pki/tls/private/mysql.key\\\"}]}, \\\"innodb_buffer_pool_size\\\": {\\\"if\\\": [\\\"innodb_buffer_pool_set\\\", {\\\"get_param\\\": \\\"MysqlInnodbBufferPoolSize\\\"}]}}, \\\"step_config\\\": \\\"include tripleo::profile::base::database::mysql\\\\n\\\", \\\"metadata_settings\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, [{\\\"service\\\": \\\"mysql\\\", \\\"network\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MysqlNetwork\\\"]}, \\\"type\\\": \\\"vip\\\"}, {\\\"service\\\": \\\"mysql\\\", \\\"network\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MysqlNetwork\\\"]}, \\\"type\\\": \\\"node\\\"}]]}, \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Certificate generation\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"enable_internal_tls\\\"], \\\"block\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"linux-system-roles.certificate\\\"}, \\\"vars\\\": {\\\"certificate_requests\\\": [{\\\"name\\\": \\\"mysql\\\", \\\"dns\\\": [{\\\"str_replace\\\": {\\\"template\\\": \\\"{{fqdn_$NETWORK}}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MysqlNetwork\\\"]}}}}, {\\\"str_replace\\\": {\\\"template\\\": \\\"{{cloud_names.cloud_name_NETWORK}}\\\", \\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MysqlNetwork\\\"]}}}}], \\\"principal\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"mysql/{{fqdn_$NETWORK}}@{{idm_realm}}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MysqlNetwork\\\"]}}}}, \\\"key_size\\\": {\\\"if\\\": [\\\"key_size_override_set\\\", {\\\"get_param\\\": \\\"MysqlCertificateKeySize\\\"}, {\\\"get_param\\\": \\\"CertificateKeySize\\\"}]}, \\\"ca\\\": \\\"ipa\\\"}]}}]}]}}}}\", \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"MySQL service deployment with pacemaker bundle\\\\n\\\", \\\"parameters\\\": {\\\"ContainerMysqlImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerMysqlConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the mysql config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ClusterCommonTag\\\": {\\\"default\\\": false, \\\"description\\\": \\\"When set to false, a pacemaker service is configured to use a floating tag for its container image name, e.g. \'REGISTRY/NAMESPACE/IMAGENAME:pcmklatest\'. When set to true, the service uses a floating prefix as well, e.g. \'cluster.common.tag/IMAGENAME:pcmklatest\'.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"ClusterFullTag\\\": {\\\"default\\\": true, \\\"description\\\": \\\"When set to true, the pacemaker service uses a fully constant tag for its container image name, e.g. \'cluster.common.tag/SERVICENAME:pcmklatest\'.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"MysqlRootPassword\\\": {\\\"type\\\": \\\"string\\\", \\\"hidden\\\": true, \\\"default\\\": \\\"\\\"}, \\\"MysqlClustercheckPassword\\\": {\\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"MysqlUpgradePersist\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"MysqlUpgradeTransfer\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": true}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"InternalTLSCAFile\\\": {\\\"default\\\": \\\"/etc/ipa/ca.crt\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Specifies the default CA cert to use if TLS is used for services in the internal network.\\\"}, \\\"ConfigDebug\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to run config management (e.g. Puppet) in debug mode.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"DeployIdentifier\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\\\n\\\"}, \\\"ContainerCli\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"podman\\\", \\\"description\\\": \\\"CLI tool used to manage containers.\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"docker\\\", \\\"podman\\\"]}]}, \\\"MysqlGaleraSSTMethod\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"rsync\\\", \\\"description\\\": \\\"Method used by galera to perform State Snapshot Transfers\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"rsync\\\", \\\"mariabackup\\\"]}]}, \\\"MysqlMariabackupUser\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"mariabackup\\\", \\\"description\\\": \\\"When MysqlGaleraSSTMethod is set to mariabackup, the name of the database user that executes the SST.\\\"}, \\\"MysqlMariabackupPassword\\\": {\\\"type\\\": \\\"string\\\", \\\"hidden\\\": true, \\\"description\\\": \\\"When MysqlGaleraSSTMethod is set to mariabackup, the password of the database user that executes the SST.\\\"}, \\\"MysqlGaleraSSLCipher\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"AES128-SHA256\\\", \\\"description\\\": \\\"Symmetric cipher to use.\\\"}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"MysqlBase\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-base.yaml\\\", \\\"properties\\\": {\\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerMysqlImage\\\": \\\"ContainerMysqlImage\\\", \\\"ContainerMysqlConfigImage\\\": \\\"ContainerMysqlConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerMysqlImage\\\": {\\\"get_param\\\": \\\"ContainerMysqlImage\\\"}, \\\"ContainerMysqlConfigImage\\\": {\\\"get_param\\\": \\\"ContainerMysqlConfigImage\\\"}}}]}}}}, \\\"conditions\\\": {\\\"docker_enabled\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"docker\\\"]}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Containerized service MySQL using composable services.\\\", \\\"value\\\": {\\\"service_name\\\": {\\\"get_attr\\\": [\\\"MysqlBase\\\", \\\"role_data\\\", \\\"service_name\\\"]}, \\\"firewall_rules\\\": {\\\"104 mysql galera-bundle\\\": {\\\"dport\\\": [873, 3123, 3306, 4444, 4567, 4568, 9200]}}, \\\"firewall_frontend_rules\\\": {\\\"100 mysql_haproxy\\\": {\\\"dport\\\": [3306]}}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"MysqlBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"tripleo::profile::pacemaker::database::mysql::bind_address\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'fqdn_$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MysqlNetwork\\\"]}}}}, \\\"tripleo::profile::pacemaker::database::mysql::gmcast_listen_addr\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MysqlNetwork\\\"]}}}}, \\\"tripleo::profile::pacemaker::database::mysql::ca_file\\\": {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}, \\\"tripleo::profile::pacemaker::database::mysql_bundle::mysql_docker_image\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/mariadb:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"tripleo::profile::pacemaker::database::mysql_bundle::control_port\\\": 3123, \\\"tripleo::profile::pacemaker::database::mysql_bundle::container_backend\\\": {\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"tripleo::profile::pacemaker::database::mysql_bundle::bind_address\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'fqdn_$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MysqlNetwork\\\"]}}}}, \\\"tripleo::profile::pacemaker::database::mysql_bundle::ca_file\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}]}, \\\"tripleo::profile::pacemaker::database::mysql_bundle::sst_method\\\": {\\\"get_param\\\": \\\"MysqlGaleraSSTMethod\\\"}, \\\"tripleo::profile::pacemaker::database::mysql_bundle::mariabackup_user\\\": {\\\"get_param\\\": \\\"MysqlMariabackupUser\\\"}, \\\"tripleo::profile::pacemaker::database::mysql_bundle::mariabackup_password\\\": {\\\"get_param\\\": \\\"MysqlMariabackupPassword\\\"}, \\\"tripleo::profile::pacemaker::database::mysql_bundle::force_ocf\\\": true, \\\"tripleo::profile::pacemaker::database::mysql_bundle::gcomm_cipher\\\": {\\\"get_param\\\": \\\"MysqlGaleraSSLCipher\\\"}}]}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"mysql\\\", \\\"puppet_tags\\\": \\\"file\\\", \\\"step_config\\\": {\\\"list_join\\\": [\\\"\\\\n\\\", [\\\"[\'Mysql_datadir\', \'Mysql_user\', \'Mysql_database\', \'Mysql_grant\', \'Mysql_plugin\'].each |String $val| { noop_resource($val) }\\\", \\\"exec {\'wait-for-settle\': command => \'/bin/true\' }\\\", \\\"include tripleo::profile::pacemaker::database::mysql_bundle\\\"]]}, \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/mysql.json\\\": {\\\"command\\\": \\\"/usr/sbin/pacemaker_remoted\\\", \\\"config_files\\\": [{\\\"dest\\\": \\\"/etc/libqb/force-filesystem-sockets\\\", \\\"source\\\": \\\"/dev/null\\\", \\\"owner\\\": \\\"root\\\", \\\"perm\\\": \\\"0644\\\"}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-tls/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"optional\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/mysql\\\", \\\"owner\\\": \\\"mysql:mysql\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/certs/mysql.crt\\\", \\\"owner\\\": \\\"mysql:mysql\\\", \\\"perm\\\": \\\"0600\\\", \\\"optional\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/private/mysql.key\\\", \\\"owner\\\": \\\"mysql:mysql\\\", \\\"perm\\\": \\\"0600\\\", \\\"optional\\\": true}]}}, \\\"container_config_scripts\\\": {\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"container_config_scripts\\\"]}, \\\"docker_config\\\": {\\\"step_1\\\": {\\\"mysql_data_ownership\\\": {\\\"start_order\\\": 0, \\\"detach\\\": false, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"user\\\": \\\"root\\\", \\\"command\\\": [\\\"chown\\\", \\\"-R\\\", \\\"mysql:\\\", \\\"/var/lib/mysql\\\"], \\\"volumes\\\": [\\\"/var/lib/mysql:/var/lib/mysql:z\\\"]}, \\\"mysql_bootstrap\\\": {\\\"start_order\\\": 1, \\\"detach\\\": false, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"user\\\": \\\"root\\\", \\\"command\\\": [\\\"bash\\\", \\\"-ec\\\", {\\\"list_join\\\": [\\\"\\\\n\\\", [\\\"if [ -e /var/lib/mysql/mysql ]; then exit 0; fi\\\", \\\"echo -e \\\\\\\"\\\\\\\\n[mysqld]\\\\\\\\nwsrep_provider=none\\\\\\\" >> /etc/my.cnf\\\", \\\"export DB_ROOT_PASSWORD=$(hiera \'mysql::server::root_password\')\\\", \\\"kolla_set_configs\\\", \\\"sudo -u mysql -E kolla_extend_start\\\", \\\"timeout ${DB_MAX_TIMEOUT} /bin/bash -c \'while pgrep -af /usr/bin/mysqld_safe | grep -q -v grep; do sleep 1; done\'\\\", \\\"mysqld_safe --skip-networking --wsrep-on=OFF &\\\", \\\"timeout ${DB_MAX_TIMEOUT} /bin/bash -c \'until mysqladmin -uroot -p\\\\\\\"$(hiera \'mysql::server::root_password\')\\\\\\\" ping 2>/dev/null; do sleep 1; done\'\\\"], {\\\"if\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"MysqlGaleraSSTMethod\\\"}, \\\"mariabackup\\\"]}, [\\\"mysql -uroot -p\\\\\\\"$(hiera \'mysql::server::root_password\')\\\\\\\" -e \\\\\\\"CREATE USER \'${DB_MARIABACKUP_USER}\'@\'localhost\' IDENTIFIED BY \'${DB_MARIABACKUP_PASSWORD}\';\\\\\\\"\\\", \\\"mysql -uroot -p\\\\\\\"$(hiera \'mysql::server::root_password\')\\\\\\\" -e \\\\\\\"GRANT RELOAD, PROCESS, LOCK TABLES, REPLICATION CLIENT ON *.* TO \'${DB_MARIABACKUP_USER}\'@\'localhost\';\\\\\\\"\\\"]]}, [\\\"mysql -uroot -p\\\\\\\"$(hiera \'mysql::server::root_password\')\\\\\\\" -e \\\\\\\"CREATE USER \'clustercheck\'@\'localhost\' IDENTIFIED BY \'$(hiera mysql_clustercheck_password)\';\\\\\\\"\\\", \\\"mysql -uroot -p\\\\\\\"$(hiera \'mysql::server::root_password\')\\\\\\\" -e \\\\\\\"GRANT PROCESS ON *.* TO \'clustercheck\'@\'localhost\' WITH GRANT OPTION;\\\\\\\"\\\", \\\"mysql -uroot -p\\\\\\\"$(hiera \'mysql::server::root_password\')\\\\\\\" -e \\\\\\\"DELETE FROM mysql.user WHERE user = \'root\' AND host NOT IN (\'%\',\'localhost\');\\\\\\\"\\\", \\\"timeout ${DB_MAX_TIMEOUT} mysqladmin -uroot -p\\\\\\\"$(hiera \'mysql::server::root_password\')\\\\\\\" shutdown\\\"]]}], \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/mysql.json:/var/lib/kolla/config_files/config.json:rw,z\\\", \\\"/var/lib/config-data/puppet-generated/mysql:/var/lib/kolla/config_files/src:ro,z\\\", \\\"/var/lib/mysql:/var/lib/mysql:rw,z\\\"], {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, [\\\"/etc/pki/tls/certs/mysql.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/mysql.crt:ro\\\", \\\"/etc/pki/tls/private/mysql.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/mysql.key:ro\\\"]]}]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\", \\\"KOLLA_BOOTSTRAP\\\": true, \\\"DB_MAX_TIMEOUT\\\": 60, \\\"DB_MARIABACKUP_USER\\\": {\\\"get_param\\\": \\\"MysqlMariabackupUser\\\"}, \\\"DB_MARIABACKUP_PASSWORD\\\": {\\\"get_param\\\": \\\"MysqlMariabackupPassword\\\"}}}}, \\\"step_2\\\": {\\\"mysql_wait_bundle\\\": {\\\"start_order\\\": 0, \\\"detach\\\": false, \\\"net\\\": \\\"host\\\", \\\"ipc\\\": \\\"host\\\", \\\"user\\\": \\\"root\\\", \\\"command\\\": {\\\"list_concat\\\": [[\\\"/container_puppet_apply.sh\\\", \\\"2\\\", \\\"file,file_line,concat,augeas,galera_ready,mysql_database,mysql_grant,mysql_user\\\", \\\"include tripleo::profile::pacemaker::database::mysql_bundle\\\"], {\\\"if\\\": [{\\\"get_param\\\": \\\"ConfigDebug\\\"}, [\\\"--debug\\\"]]}]}, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"container_puppet_apply_volumes\\\"]}, [\\\"/var/lib/mysql:/var/lib/mysql:rw,z\\\", \\\"/var/lib/config-data/puppet-generated/mysql/root:/root:rw\\\"], {\\\"if\\\": [\\\"docker_enabled\\\", [\\\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\\\"]]}]}, \\\"environment\\\": {\\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": {\\\"get_param\\\": \\\"DeployIdentifier\\\"}}}}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode|default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/mysql\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/lib/mysql\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/log/mariadb\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}], \\\"metadata_settings\\\": {\\\"get_attr\\\": [\\\"MysqlBase\\\", \\\"role_data\\\", \\\"metadata_settings\\\"]}, \\\"deploy_steps_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"MysqlBase\\\", \\\"role_data\\\", \\\"deploy_steps_tasks\\\"]}, [{\\\"name\\\": \\\"MySQL tag container image for pacemaker\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_tag\\\"}, \\\"vars\\\": {\\\"container_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}, \\\"container_image_latest\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/mariadb:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}}}, {\\\"name\\\": \\\"MySQL HA Wrappers Step\\\", \\\"when\\\": \\\"step|int == 2\\\", \\\"block\\\": [{\\\"name\\\": \\\"Mysql puppet bundle\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_ha_wrapper\\\"}, \\\"vars\\\": {\\\"tripleo_ha_wrapper_service_name\\\": \\\"mysql\\\", \\\"tripleo_ha_wrapper_resource_name\\\": \\\"galera\\\", \\\"tripleo_ha_wrapper_bundle_name\\\": \\\"galera-bundle\\\", \\\"tripleo_ha_wrapper_resource_state\\\": \\\"Master\\\", \\\"tripleo_ha_wrapper_puppet_config_volume\\\": \\\"mysql\\\", \\\"tripleo_ha_wrapper_puppet_execute\\\": \\\"[\\\\\\\"Mysql_datadir\\\\\\\", \\\\\\\"Mysql_user\\\\\\\", \\\\\\\"Mysql_database\\\\\\\", \\\\\\\"Mysql_grant\\\\\\\", \\\\\\\"Mysql_plugin\\\\\\\"].each |String $val| { noop_resource($val) }; include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::database::mysql_bundle\\\", \\\"tripleo_ha_wrapper_puppet_tags\\\": \\\"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\\\", \\\"tripleo_ha_wrapper_puppet_debug\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"tripleo_ha_wrapper_config_suffix\\\": \\\".previous_run\\\"}}]}]]}, \\\"external_update_tasks\\\": [{\\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": \\\"ha_image_update\\\", \\\"block\\\": [{\\\"block\\\": [{\\\"name\\\": \\\"Get galera image from pacemaker\\\", \\\"become\\\": true, \\\"register\\\": \\\"xmllint_pcmk_galera_image\\\", \\\"shell\\\": \\\"xmllint --xpath \\\\\\\"string(//bundle[@id=\'galera-bundle\']/podman/@image)\\\\\\\" /var/lib/pacemaker/cib/cib.xml\\\"}, {\\\"name\\\": \\\"Get container galera image\\\", \\\"set_fact\\\": {\\\"galera_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}, \\\"galera_image_latest\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/mariadb:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"pcmk_galera_image\\\": \\\"{{xmllint_pcmk_galera_image.stdout}}\\\"}}], \\\"delegate_to\\\": \\\"{{ (groups[\\\\\\\"mysql\\\\\\\"] | difference(groups[\\\\\\\"excluded_overcloud\\\\\\\"]))[0] }}\\\"}, {\\\"name\\\": \\\"MySQL temporary pacemaker container tag in case of image switch\\\", \\\"become\\\": true, \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_ha_image_update\\\"}, \\\"vars\\\": {\\\"tripleo_ha_image_update_node_names\\\": \\\"{{ groups[\\\\\\\"mysql\\\\\\\"] | difference(groups[\\\\\\\"excluded_overcloud\\\\\\\"]) }}\\\", \\\"tripleo_ha_image_update_bundle\\\": \\\"galera-bundle\\\", \\\"tripleo_ha_image_update_new_image\\\": \\\"{{galera_image_latest}}\\\", \\\"tripleo_ha_image_update_old_image\\\": \\\"{{pcmk_galera_image}}\\\"}, \\\"when\\\": [\\\"(pcmk_galera_image != \\\\\\\"\\\\\\\")\\\", \\\"(pcmk_galera_image != galera_image_latest)\\\"]}]}], \\\"update_tasks\\\": [{\\\"block\\\": [{\\\"name\\\": \\\"Get galera image from pacemaker\\\", \\\"become\\\": true, \\\"register\\\": \\\"xmllint_pcmk_galera_image\\\", \\\"shell\\\": \\\"xmllint --xpath \\\\\\\"string(//bundle[@id=\'galera-bundle\']/podman/@image)\\\\\\\" /var/lib/pacemaker/cib/cib.xml\\\"}, {\\\"name\\\": \\\"Get container galera image\\\", \\\"set_fact\\\": {\\\"galera_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}, \\\"galera_image_latest\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/mariadb:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"pcmk_galera_image\\\": \\\"{{xmllint_pcmk_galera_image.stdout}}\\\"}}], \\\"when\\\": \\\"(step|int == 0 or step|int == 2)\\\"}, {\\\"name\\\": \\\"Check for update of galera container image name\\\", \\\"when\\\": \\\"step|int == 0\\\", \\\"assert\\\": {\\\"that\\\": \\\"pcmk_galera_image == galera_image_latest\\\", \\\"fail_msg\\\": \\\"galera image change detected, run overcloud external-update --tags ha_image_update first\\\"}}, {\\\"name\\\": \\\"Tear-down non-HA mysql container\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"stat mysql container\\\", \\\"command\\\": \\\"podman container exists mysql\\\", \\\"failed_when\\\": false, \\\"changed_when\\\": false, \\\"register\\\": \\\"stat_mysql_container\\\"}, {\\\"name\\\": \\\"Create clustercheck user and permissions\\\", \\\"command\\\": {\\\"argv\\\": \\\"{{ mysql_exec_data | container_exec_cmd }}\\\"}, \\\"changed_when\\\": true, \\\"when\\\": [\\\"stat_mysql_container.rc == 0\\\"], \\\"vars\\\": {\\\"mysql_exec_data\\\": {\\\"environment\\\": {\\\"CLUSTERCHECK_PASSWORD\\\": {\\\"get_param\\\": \\\"MysqlClustercheckPassword\\\"}}, \\\"command\\\": [\\\"mysql\\\", \\\"/bin/sh\\\", \\\"-c\\\", \\\"mysql -e \\\\\\\"CREATE USER IF NOT EXISTS \'clustercheck\'@\'localhost\' IDENTIFIED BY \'${CLUSTERCHECK_PASSWORD}\'; GRANT PROCESS ON *.* TO \'clustercheck\'@\'localhost\' WITH GRANT OPTION;\\\\\\\"\\\"]}}}, {\\\"name\\\": \\\"Remove non-HA mysql container\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_rm\\\"}, \\\"vars\\\": {\\\"tripleo_container_cli\\\": \\\"{{ container_cli }}\\\", \\\"tripleo_containers_to_rm\\\": [\\\"mysql\\\"]}}]}, {\\\"name\\\": \\\"Mariadb fetch and retag container image for pacemaker\\\", \\\"when\\\": \\\"step|int == 2\\\", \\\"block\\\": [{\\\"name\\\": \\\"Retag pcmklatest to latest galera image\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_tag\\\"}, \\\"vars\\\": {\\\"container_image\\\": \\\"{{galera_image}}\\\", \\\"container_image_latest\\\": \\\"{{galera_image_latest}}\\\"}}]}, {\\\"name\\\": \\\"Ensure mariadb-server is not installed on the host\\\", \\\"when\\\": \\\"step|int == 2\\\", \\\"yum\\\": {\\\"name\\\": \\\"mariadb-server*\\\", \\\"state\\\": \\\"absent\\\"}}], \\\"post_update_tasks\\\": [{\\\"name\\\": \\\"Mysql bundle post update\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Mysql puppet bundle\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_ha_wrapper\\\"}, \\\"vars\\\": {\\\"tripleo_ha_wrapper_service_name\\\": \\\"mysql\\\", \\\"tripleo_ha_wrapper_resource_name\\\": \\\"galera\\\", \\\"tripleo_ha_wrapper_bundle_name\\\": \\\"galera-bundle\\\", \\\"tripleo_ha_wrapper_resource_state\\\": \\\"Master\\\", \\\"tripleo_ha_wrapper_puppet_config_volume\\\": \\\"mysql\\\", \\\"tripleo_ha_wrapper_puppet_execute\\\": \\\"[\\\\\\\"Mysql_datadir\\\\\\\", \\\\\\\"Mysql_user\\\\\\\", \\\\\\\"Mysql_database\\\\\\\", \\\\\\\"Mysql_grant\\\\\\\", \\\\\\\"Mysql_plugin\\\\\\\"].each |String $val| { noop_resource($val) }; include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::database::mysql_bundle\\\", \\\"tripleo_ha_wrapper_puppet_tags\\\": \\\"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\\\", \\\"tripleo_ha_wrapper_puppet_debug\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"tripleo_ha_wrapper_config_suffix\\\": \\\".previous_run\\\"}}], \\\"vars\\\": {\\\"tripleo_ha_wrapper_minor_update\\\": true}}], \\\"upgrade_tasks\\\": {\\\"list_concat\\\": [[{\\\"name\\\": \\\"Tear-down non-HA mysql container\\\", \\\"when\\\": [\\\"step|int == 0\\\"], \\\"block\\\": [{\\\"name\\\": \\\"stat mysql container\\\", \\\"command\\\": \\\"podman container exists mysql\\\", \\\"failed_when\\\": false, \\\"changed_when\\\": false, \\\"register\\\": \\\"stat_mysql_container\\\"}, {\\\"name\\\": \\\"Create clustercheck user and permissions\\\", \\\"command\\\": {\\\"argv\\\": \\\"{{ mysql_exec_data | container_exec_cmd }}\\\"}, \\\"changed_when\\\": true, \\\"when\\\": [\\\"stat_mysql_container.rc == 0\\\"], \\\"vars\\\": {\\\"mysql_exec_data\\\": {\\\"environment\\\": {\\\"CLUSTERCHECK_PASSWORD\\\": {\\\"get_param\\\": \\\"MysqlClustercheckPassword\\\"}}, \\\"command\\\": [\\\"mysql\\\", \\\"/bin/sh\\\", \\\"-c\\\", \\\"mysql -e \\\\\\\"CREATE USER IF NOT EXISTS \'clustercheck\'@\'localhost\' IDENTIFIED BY \'${CLUSTERCHECK_PASSWORD}\'; GRANT PROCESS ON *.* TO \'clustercheck\'@\'localhost\' WITH GRANT OPTION;\\\\\\\"\\\"]}}}, {\\\"name\\\": \\\"Remove non-HA mysql container\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_rm\\\"}, \\\"vars\\\": {\\\"tripleo_container_cli\\\": \\\"{{ container_cli }}\\\", \\\"tripleo_containers_to_rm\\\": [\\\"mysql\\\"]}}]}], [{\\\"name\\\": \\\"set mysql container name fact\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"set_fact\\\": {\\\"mysql_container_name\\\": \\\"galera-bundle\\\"}}], {\\\"get_attr\\\": [\\\"MysqlBase\\\", \\\"mysql_drop_unused_users\\\"]}, [{\\\"vars\\\": {\\\"mysql_upgrade_persist\\\": {\\\"get_param\\\": \\\"MysqlUpgradePersist\\\"}}, \\\"when\\\": [\\\"step|int == 3\\\", \\\"mysql_upgrade_persist\\\"], \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_prepare\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Persist mysql data\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_persist\\\", \\\"tasks_from\\\": \\\"persist.yml\\\"}, \\\"vars\\\": {\\\"tripleo_persist_dir\\\": \\\"/var/lib/mysql\\\"}}]}, {\\\"vars\\\": {\\\"mysql_upgrade_persist\\\": {\\\"get_param\\\": \\\"MysqlUpgradePersist\\\"}}, \\\"when\\\": [\\\"step|int == 5\\\", \\\"mysql_upgrade_persist\\\"], \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_run\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Restore mysql data\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_persist\\\", \\\"tasks_from\\\": \\\"restore.yml\\\"}, \\\"vars\\\": {\\\"tripleo_persist_dir\\\": \\\"/var/lib/mysql\\\"}}]}, {\\\"name\\\": \\\"Prepare switch of galera image name\\\", \\\"when\\\": [\\\"step|int == 0\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Get galera image id currently used by pacemaker\\\", \\\"shell\\\": \\\"pcs resource config galera-bundle | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\\\", \\\"register\\\": \\\"galera_image_current_res\\\", \\\"failed_when\\\": false}, {\\\"name\\\": \\\"Image facts for galera\\\", \\\"set_fact\\\": {\\\"galera_image_latest\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/mariadb:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"galera_image_current\\\": \\\"{{galera_image_current_res.stdout}}\\\"}}, {\\\"name\\\": \\\"Temporarily tag the current galera image id with the upgraded image name\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_tag\\\"}, \\\"vars\\\": {\\\"container_image\\\": \\\"{{galera_image_current}}\\\", \\\"container_image_latest\\\": \\\"{{galera_image_latest}}\\\", \\\"pull_image\\\": false}, \\\"when\\\": [\\\"galera_image_current != \'\'\\\", \\\"galera_image_current != galera_image_latest\\\"]}, {\\\"name\\\": \\\"Create galera retag statefile\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/tripleo/galera_needs_retag\\\", \\\"state\\\": \\\"touch\\\"}, \\\"when\\\": [\\\"galera_image_current != \'\'\\\", \\\"galera_image_current != galera_image_latest\\\"]}]}, {\\\"name\\\": \\\"Update galera pcs resource bundle for new container image - check\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"set is_mysql_bootstrap_node fact\\\", \\\"tags\\\": \\\"common\\\", \\\"set_fact\\\": \\\"is_mysql_bootstrap_node={{mysql_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\\\"}, {\\\"name\\\": \\\"Check for galera retag statefile\\\", \\\"stat\\\": {\\\"path\\\": \\\"/var/lib/tripleo/galera_needs_retag\\\"}, \\\"register\\\": \\\"galera_retag_state_file\\\"}]}, {\\\"name\\\": \\\"Update galera pcs resource bundle for new container image\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"is_mysql_bootstrap_node|bool\\\", \\\"galera_retag_state_file.stat.exists|bool\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Disable the galera cluster resource before container upgrade\\\", \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"galera-bundle\\\", \\\"state\\\": \\\"disable\\\", \\\"wait_for_resource\\\": true}, \\\"register\\\": \\\"output\\\", \\\"retries\\\": 5, \\\"until\\\": \\\"output.rc == 0\\\"}, {\\\"name\\\": \\\"Move Mysql logging to /var/log/containers\\\", \\\"block\\\": [{\\\"name\\\": \\\"Check Mysql logging configuration in pacemaker\\\", \\\"command\\\": \\\"cibadmin --query --xpath \\\\\\\"//storage-mapping[@id=\'mysql-log\']\\\\\\\"\\\", \\\"failed_when\\\": false, \\\"register\\\": \\\"mysql_logs_moved\\\"}, {\\\"name\\\": \\\"Change Mysql logging configuration in pacemaker\\\", \\\"when\\\": \\\"mysql_logs_moved.rc == 6\\\", \\\"block\\\": [{\\\"name\\\": \\\"Add a bind mount for logging in the galera bundle\\\", \\\"command\\\": \\\"pcs resource bundle update galera-bundle storage-map add id=mysql-log source-dir=/var/log/containers/mysql target-dir=/var/log/mysql options=rw\\\"}, {\\\"name\\\": \\\"Reconfigure Mysql log file in the galera resource agent\\\", \\\"command\\\": \\\"pcs resource update galera log=/var/log/mysql/mysqld.log\\\"}]}]}, {\\\"name\\\": \\\"Update the galera bundle to use the new container image name\\\", \\\"command\\\": \\\"pcs resource bundle update galera-bundle container image={{galera_image_latest}}\\\"}, {\\\"name\\\": \\\"Enable the galera cluster resource\\\", \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"galera-bundle\\\", \\\"state\\\": \\\"enable\\\", \\\"wait_for_resource\\\": true}, \\\"register\\\": \\\"output\\\", \\\"retries\\\": 5, \\\"until\\\": \\\"output.rc == 0\\\"}]}, {\\\"name\\\": \\\"Upgrade galera in step3\\\", \\\"when\\\": [\\\"step|int == 3\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Bind mounts for temporary container\\\", \\\"set_fact\\\": {\\\"mysql_upgrade_db_bind_mounts\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/mysql.json:/var/lib/kolla/config_files/config.json:rw,z\\\", \\\"/var/lib/config-data/puppet-generated/mysql:/var/lib/kolla/config_files/src:ro,z\\\", \\\"/var/lib/mysql:/var/lib/mysql:rw,z\\\"], [\\\"/var/log/containers/mysql:/var/log/mysql:rw,z\\\"], {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, [\\\"/etc/pki/tls/certs/mysql.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/mysql.crt:ro\\\", \\\"/etc/pki/tls/private/mysql.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/mysql.key:ro\\\"]]}]}}}, {\\\"name\\\": \\\"Check if Galera needs upgrade\\\", \\\"shell\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"CONTAINER_CLI run --rm --log-driver=k8s-file --log-opt path=LOG_DIR/db-upgrade.log \\\\\\\\ -u root --net=host UPGRADE_ENV UPGRADE_VOLUMES \\\\\\\"UPGRADE_IMAGE\\\\\\\" /bin/bash -ecx \\\\\\\"$UPGRADE_SCRIPT\\\\\\\"\\\", \\\"params\\\": {\\\"UPGRADE_ENV\\\": \\\"-e \\\\\\\"KOLLA_CONFIG_STRATEGY=COPY_ALWAYS\\\\\\\"\\\", \\\"UPGRADE_IMAGE\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/mariadb:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"UPGRADE_VOLUMES\\\": \\\"-v {{ mysql_upgrade_db_bind_mounts | join(\' -v \')}}\\\", \\\"CONTAINER_CLI\\\": \\\"{{ container_cli }}\\\", \\\"LOG_DIR\\\": \\\"/var/log/containers/mysql\\\"}}}, \\\"environment\\\": {\\\"UPGRADE_SCRIPT\\\": \\\"kolla_set_configs\\\\nupgraded_ver=$(cat /var/lib/mysql/mysql_upgrade_info 2>/dev/null || true)\\\\nmysql_ver=$(mysql --version | awk -F\'[ ,]*\' \'{print $5}\')\\\\nif [ \\\\\\\"${upgraded_ver}\\\\\\\" = \\\\\\\"${mysql_ver}\\\\\\\" ]; then\\\\n    echo \\\\\\\"mysql already upgraded\\\\\\\"\\\\nelse\\\\n    echo \\\\\\\"${upgraded_ver} VS ${mysql_ver}\\\\\\\"\\\\nfi\\\\n\\\"}, \\\"register\\\": \\\"mysql_upgrade_needed\\\"}, {\\\"name\\\": \\\"Set fact upgrade_mysql\\\", \\\"set_fact\\\": {\\\"upgrade_mysql\\\": \\\"{{ (mysql_upgrade_needed.stdout != \\\\\\\"mysql already upgraded\\\\\\\") | bool }}\\\"}}, {\\\"debug\\\": {\\\"msg\\\": \\\"MYSQL check - {{ mysql_upgrade_needed.stdout }} - Upgrade needed: {{ upgrade_mysql }}\\\"}}, {\\\"name\\\": \\\"Disable the galera cluster resource before container upgrade\\\", \\\"when\\\": [\\\"upgrade_mysql|bool\\\"], \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"galera-bundle\\\", \\\"state\\\": \\\"disable\\\", \\\"wait_for_resource\\\": true}, \\\"register\\\": \\\"output\\\", \\\"retries\\\": 5, \\\"until\\\": \\\"output.rc == 0\\\"}, {\\\"block\\\": [{\\\"name\\\": \\\"Get galera image from pacemaker\\\", \\\"become\\\": true, \\\"register\\\": \\\"xmllint_pcmk_galera_image\\\", \\\"shell\\\": \\\"xmllint --xpath \\\\\\\"string(//bundle[@id=\'galera-bundle\']/podman/@image)\\\\\\\" /var/lib/pacemaker/cib/cib.xml\\\"}, {\\\"name\\\": \\\"Get container galera image\\\", \\\"set_fact\\\": {\\\"galera_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}, \\\"galera_image_latest\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/mariadb:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"pcmk_galera_image\\\": \\\"{{xmllint_pcmk_galera_image.stdout}}\\\"}}]}, {\\\"name\\\": \\\"Check for galera retag statefile\\\", \\\"stat\\\": {\\\"path\\\": \\\"/var/lib/tripleo/galera_needs_retag\\\"}, \\\"register\\\": \\\"galera_retag_state_file\\\"}, {\\\"name\\\": \\\"Retag the pacemaker image if containerized\\\", \\\"when\\\": [\\\"galera_retag_state_file.stat.exists|bool\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Retag pcmklatest to latest galera image\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_tag\\\"}, \\\"vars\\\": {\\\"container_image\\\": \\\"{{galera_image}}\\\", \\\"container_image_latest\\\": \\\"{{galera_image_latest}}\\\"}}]}, {\\\"name\\\": \\\"Remove galera retag statefile\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/tripleo/galera_needs_retag\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"Mysql upgrade script\\\", \\\"when\\\": [\\\"upgrade_mysql|bool\\\"], \\\"set_fact\\\": {\\\"mysql_upgrade_script\\\": {\\\"list_join\\\": [\\\"\\\\n\\\", [\\\"kolla_set_configs\\\\nif mysqladmin ping --silent; then exit 0; fi\\\\nupgraded_ver=$(cat /var/lib/mysql/mysql_upgrade_info 2>/dev/null || true)\\\\nmysql_ver=$(mysql --version | awk -F\'[ ,]*\' \'{print $5}\')\\\\nif [ \\\\\\\"${upgraded_ver}\\\\\\\" = \\\\\\\"${mysql_ver}\\\\\\\" ]; then\\\\n    echo \\\\\\\"mysql already upgraded\\\\\\\"\\\\n    exit 0\\\\nfi\\\\nchown -R mysql:mysql /var/lib/mysql\\\\nchown -R mysql:mysql /var/log/mysql\\\\nmysqld_safe --user=mysql --wsrep-provider=none --skip-networking --wsrep-on=off --log-error=/var/log/mysql/mysqld-upgrade.log &\\\\n\\\", {\\\"get_file\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/container_config_scripts/mysql_upgrade_db.sh\\\"}, \\\"mysqladmin shutdown\\\"]]}}}, {\\\"name\\\": \\\"Upgrade Mysql database from a temporary container\\\", \\\"when\\\": [\\\"upgrade_mysql|bool\\\"], \\\"shell\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"CONTAINER_CLI run --rm --log-driver=k8s-file --log-opt path=LOG_DIR/db-upgrade.log \\\\\\\\ -u root --net=host UPGRADE_ENV UPGRADE_VOLUMES \\\\\\\"UPGRADE_IMAGE\\\\\\\" /bin/bash -ecx \\\\\\\"$UPGRADE_SCRIPT\\\\\\\"\\\", \\\"params\\\": {\\\"UPGRADE_ENV\\\": \\\"-e \\\\\\\"KOLLA_CONFIG_STRATEGY=COPY_ALWAYS\\\\\\\"\\\", \\\"UPGRADE_IMAGE\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/mariadb:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerMysqlImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"UPGRADE_VOLUMES\\\": \\\"-v {{ mysql_upgrade_db_bind_mounts | join(\' -v \')}}\\\", \\\"CONTAINER_CLI\\\": \\\"{{ container_cli }}\\\", \\\"LOG_DIR\\\": \\\"/var/log/containers/mysql\\\"}}}, \\\"environment\\\": {\\\"UPGRADE_SCRIPT\\\": \\\"{{ mysql_upgrade_script }}\\\"}}, {\\\"name\\\": \\\"Enable the galera cluster resource\\\", \\\"when\\\": [\\\"upgrade_mysql|bool\\\"], \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"galera-bundle\\\", \\\"state\\\": \\\"enable\\\", \\\"wait_for_resource\\\": true}, \\\"register\\\": \\\"output\\\", \\\"retries\\\": 5, \\\"until\\\": \\\"output.rc == 0\\\"}]}]]}, \\\"external_upgrade_tasks\\\": [{\\\"vars\\\": {\\\"mysql_upgrade_transfer\\\": {\\\"get_param\\\": \\\"MysqlUpgradeTransfer\\\"}}, \\\"when\\\": [\\\"step|int == 2\\\", \\\"mysql_upgrade_transfer\\\"], \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade_transfer_data\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Transfer mysql data\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_transfer\\\"}, \\\"vars\\\": {\\\"tripleo_transfer_src_dir\\\": \\\"/var/lib/mysql\\\", \\\"tripleo_transfer_src_host\\\": \\\"{{hostvars[groups[\'overcloud\'][0]][\'mysql_short_node_names\'][1]}}\\\", \\\"tripleo_transfer_dest_dir\\\": \\\"/var/lib/mysql\\\", \\\"tripleo_transfer_dest_host\\\": \\\"{{hostvars[groups[\'overcloud\'][0]][\'mysql_short_bootstrap_node_name\']}}\\\", \\\"tripleo_transfer_flag_file\\\": \\\"/var/lib/tripleo/transfer-flags/var-lib-mysql\\\", \\\"tripleo_transfer_sync_options\\\": \\\"--whole-file --ignore-times --inplace --archive --delete\\\", \\\"tripleo_transfer_include\\\": [\\\"/ibdata*\\\", \\\"/ib_lru_dump\\\", \\\"/ib_logfile[0-9]*\\\", \\\"/undo*\\\", \\\"/*/\\\"], \\\"tripleo_transfer_exclude\\\": \\\"/*\\\"}}]}]}}}}\", \"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"MySQL HA clustercheck service deployment using puppet This service is used by HAProxy in a HA scenario to report whether the local galera node is synced\\\\n\\\", \\\"parameters\\\": {\\\"ContainerClustercheckImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerClustercheckConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the clustercheck config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"ClustercheckListener\\\": {\\\"default\\\": \\\"socat\\\", \\\"description\\\": \\\"How to expose the clustercheck service over TCP\\\", \\\"type\\\": \\\"string\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"socat\\\", \\\"xinetd\\\"]}]}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"MysqlPuppetBase\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\\\", \\\"properties\\\": {\\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerClustercheckImage\\\": \\\"ContainerClustercheckImage\\\", \\\"ContainerClustercheckConfigImage\\\": \\\"ContainerClustercheckConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerClustercheckImage\\\": {\\\"get_param\\\": \\\"ContainerClustercheckImage\\\"}, \\\"ContainerClustercheckConfigImage\\\": {\\\"get_param\\\": \\\"ContainerClustercheckConfigImage\\\"}}}]}}}}, \\\"conditions\\\": {\\\"socat_listener\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"ClustercheckListener\\\"}, \\\"socat\\\"]}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Containerized service clustercheck using composable services.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"clustercheck\\\", \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"MysqlPuppetBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"tripleo::profile::pacemaker::clustercheck::bind_address\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$FQDN$NETWORK\')}\\\", \\\"params\\\": {\\\"$FQDN\\\": {\\\"if\\\": [\\\"socat_listener\\\", \\\"\\\", \\\"fqdn_\\\"]}, \\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MysqlNetwork\\\"]}}}}}]}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"clustercheck\\\", \\\"puppet_tags\\\": \\\"file\\\", \\\"step_config\\\": \\\"include tripleo::profile::pacemaker::clustercheck\\\", \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerClustercheckConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/clustercheck.json\\\": {\\\"command\\\": {\\\"if\\\": [\\\"socat_listener\\\", \\\"bash -c $* -- eval source /etc/sysconfig/clustercheck; exec socat -T\\\\\\\"${TRIPLEO_HEALTHCHECK_TIMEOUT:-2}\\\\\\\" \\\\\\\"$TRIPLEO_SOCAT_BIND\\\\\\\" system:\\\\\\\"grep -qPe \\\\\\\\\\\\\\\"^\\\\\\\\\\\\\\\\r\\\\\\\\$\\\\\\\\\\\\\\\" && /usr/bin/clustercheck\\\\\\\"\\\", \\\"/usr/sbin/xinetd -dontfork\\\"]}, \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}}, \\\"docker_config\\\": {\\\"step_2\\\": {\\\"clustercheck\\\": {\\\"start_order\\\": 1, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerClustercheckImage\\\"]}, \\\"restart\\\": \\\"always\\\", \\\"net\\\": \\\"host\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/clustercheck.json:/var/lib/kolla/config_files/config.json\\\", \\\"/var/lib/config-data/puppet-generated/clustercheck:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/mysql:/var/lib/mysql\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"host_prep_tasks\\\": null, \\\"upgrade_tasks\\\": null, \\\"update_tasks\\\": null, \\\"external_upgrade_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade_transfer_data\\\", \\\"system_upgrade_stop_services\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Stop clustercheck container\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_stop\\\"}, \\\"vars\\\": {\\\"tripleo_containers_to_stop\\\": [\\\"clustercheck\\\"], \\\"tripleo_delegate_to\\\": \\\"{{ groups[\'clustercheck\'] | difference(groups[\'excluded_overcloud\']) }}\\\"}}]}]}}}}\", \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-base-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack Redis service configured with Puppet\\\\n\\\", \\\"parameters\\\": {\\\"RootStackName\\\": {\\\"description\\\": \\\"The name of the stack/plan.\\\", \\\"type\\\": \\\"string\\\"}, \\\"RedisPassword\\\": {\\\"description\\\": \\\"The password for the redis service account.\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"RedisFDLimit\\\": {\\\"description\\\": \\\"Configure Redis FD limit\\\", \\\"type\\\": \\\"number\\\", \\\"default\\\": 10240}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"RedisIPv6\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Enable IPv6 in Redis\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"RedisVirtualFixedIPs\\\": {\\\"default\\\": [], \\\"description\\\": \\\"Control the IP allocation for the virtual IP used by Redis. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\\\n\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceVips\\\": {\\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}}, \\\"parameter_groups\\\": [{\\\"label\\\": \\\"deprecated\\\", \\\"description\\\": \\\"The following parameters are deprecated and will be removed. They should not\\\\nbe relied on for new deployments. If you have concerns regarding deprecated\\\\nparameters, please contact the TripleO development team on IRC or the\\\\nOpenStack mailing list.\\\\n\\\", \\\"parameters\\\": [\\\"RedisIPv6\\\"]}], \\\"conditions\\\": {\\\"is_ipv6\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"ServiceData\\\", \\\"net_ip_version_map\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"RedisNetwork\\\"]}]}, 6]}, \\\"redis_virtual_fixed_ip_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"RedisVirtualFixedIPs\\\"}, []]}}, \\\"redis_service_vip_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"ServiceVips\\\", \\\"redis\\\"]}, \\\"\\\"]}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the redis role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"redis_base\\\", \\\"config_settings\\\": {\\\"redis::requirepass\\\": {\\\"get_param\\\": \\\"RedisPassword\\\"}, \\\"redis::masterauth\\\": {\\\"get_param\\\": \\\"RedisPassword\\\"}, \\\"redis::sentinel_auth_pass\\\": {\\\"get_param\\\": \\\"RedisPassword\\\"}, \\\"redis_ipv6\\\": {\\\"if\\\": [\\\"is_ipv6\\\", true, false]}, \\\"redis::bind\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, {\\\"if\\\": [\\\"is_ipv6\\\", \\\"::1\\\", \\\"127.0.0.1\\\"]}, {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"RedisNetwork\\\"]}}}}]}, \\\"redis::port\\\": 6379, \\\"redis::sentinel::master_name\\\": \\\"%{hiera(\'redis_short_bootstrap_node_name\')}\\\", \\\"redis::sentinel::redis_host\\\": \\\"%{hiera(\'redis_bootstrap_node_ip\')}\\\", \\\"redis::sentinel::notification_script\\\": \\\"/usr/local/bin/redis-notifications.sh\\\", \\\"redis::sentinel::sentinel_bind\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, {\\\"if\\\": [\\\"is_ipv6\\\", \\\"::1\\\", \\\"127.0.0.1\\\"]}, {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"RedisNetwork\\\"]}}}}]}, \\\"redis::ulimit\\\": {\\\"get_param\\\": \\\"RedisFDLimit\\\"}}, \\\"external_deploy_tasks\\\": [{\\\"when\\\": [\\\"step|int == 0\\\"], \\\"name\\\": \\\"redis_external_deploy_init\\\", \\\"block\\\": [{\\\"name\\\": \\\"create redis virtual ip\\\", \\\"tripleo_service_vip\\\": {\\\"playbook_dir\\\": \\\"{{ playbook_dir }}\\\", \\\"stack_name\\\": {\\\"get_param\\\": \\\"RootStackName\\\"}, \\\"service_name\\\": \\\"redis\\\", \\\"network\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"RedisNetwork\\\"]}, \\\"fixed_ips\\\": {\\\"if\\\": [\\\"redis_virtual_fixed_ip_set\\\", {\\\"get_param\\\": \\\"RedisVirtualFixedIPs\\\"}, {\\\"if\\\": [\\\"redis_service_vip_set\\\", [{\\\"ip_address\\\": {\\\"get_param\\\": [\\\"ServiceVips\\\", \\\"redis\\\"]}}], [{\\\"subnet\\\": {\\\"get_param\\\": [\\\"ServiceData\\\", \\\"vip_subnet_map\\\", \\\"redis\\\"]}}]]}]}}}]}], \\\"external_update_tasks\\\": [{\\\"when\\\": [\\\"step|int == 0\\\"], \\\"name\\\": \\\"redis_external_update_init\\\", \\\"block\\\": [{\\\"name\\\": \\\"create redis virtual ip\\\", \\\"tripleo_service_vip\\\": {\\\"playbook_dir\\\": \\\"{{ playbook_dir }}\\\", \\\"stack_name\\\": {\\\"get_param\\\": \\\"RootStackName\\\"}, \\\"service_name\\\": \\\"redis\\\", \\\"network\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"RedisNetwork\\\"]}, \\\"fixed_ips\\\": {\\\"if\\\": [\\\"redis_virtual_fixed_ip_set\\\", {\\\"get_param\\\": \\\"RedisVirtualFixedIPs\\\"}, {\\\"if\\\": [\\\"redis_service_vip_set\\\", [{\\\"ip_address\\\": {\\\"get_param\\\": [\\\"ServiceVips\\\", \\\"redis\\\"]}}], [{\\\"subnet\\\": {\\\"get_param\\\": [\\\"ServiceData\\\", \\\"vip_subnet_map\\\", \\\"redis\\\"]}}]]}]}}}]}]}}}}\", \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Redis services\\\\n\\\", \\\"parameters\\\": {\\\"ContainerRedisImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerRedisConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the redis config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"CertificateKeySize\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"2048\\\", \\\"description\\\": \\\"Specifies the private key size used when creating the certificate.\\\"}, \\\"RedisCertificateKeySize\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Override the private key size used when creating the certificate for this service\\\"}}, \\\"conditions\\\": {\\\"key_size_override_set\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"RedisCertificateKeySize\\\"}, \\\"\\\"]}}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"RedisBase\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-base-puppet.yaml\\\", \\\"properties\\\": {\\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}}}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerRedisImage\\\": \\\"ContainerRedisImage\\\", \\\"ContainerRedisConfigImage\\\": \\\"ContainerRedisConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerRedisImage\\\": {\\\"get_param\\\": \\\"ContainerRedisImage\\\"}, \\\"ContainerRedisConfigImage\\\": {\\\"get_param\\\": \\\"ContainerRedisConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Redis API role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"redis\\\", \\\"firewall_rules\\\": {\\\"108 redis\\\": {\\\"dport\\\": [6379, 26379]}}, \\\"firewall_frontend_rules\\\": {\\\"100 redis_haproxy_frontend\\\": {\\\"dport\\\": [6379, 26379]}}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"RedisBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"redis::daemonize\\\": false, \\\"tripleo::stunnel::manage_service\\\": false, \\\"tripleo::stunnel::foreground\\\": \\\"yes\\\"}, {\\\"tripleo::profile::base::database::redis::tls_proxy_bind_ip\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"RedisNetwork\\\"]}}}}, \\\"tripleo::profile::base::database::redis::tls_proxy_fqdn\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'fqdn_$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"RedisNetwork\\\"]}}}}, \\\"tripleo::profile::base::database::redis::tls_proxy_port\\\": 6379}, {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, {\\\"tripleo::redis::service_certificate\\\": \\\"/etc/pki/tls/certs/redis.crt\\\", \\\"redis_certificate_specs\\\": {\\\"service_certificate\\\": \\\"/etc/pki/tls/certs/redis.crt\\\", \\\"service_key\\\": \\\"/etc/pki/tls/private/redis.key\\\"}}]}]}, \\\"service_config_settings\\\": {\\\"get_attr\\\": [\\\"RedisBase\\\", \\\"role_data\\\", \\\"service_config_settings\\\"]}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"redis\\\", \\\"puppet_tags\\\": \\\"exec\\\", \\\"step_config\\\": {\\\"list_join\\\": [\\\"\\\\n\\\", [\\\"Exec <| title == \'systemd-reload-redis\' |> { unless => \'true\' }\\\", \\\"include tripleo::profile::base::database::redis\\\", {\\\"get_attr\\\": [\\\"RedisBase\\\", \\\"role_data\\\", \\\"step_config\\\"]}]]}, \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRedisConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/redis.json\\\": {\\\"command\\\": \\\"/usr/bin/redis-server /etc/redis.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/run/redis\\\", \\\"owner\\\": \\\"redis:redis\\\", \\\"recurse\\\": true}]}, \\\"/var/lib/kolla/config_files/redis_tls_proxy.json\\\": {\\\"command\\\": \\\"stunnel /etc/stunnel/stunnel.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}}, \\\"docker_config\\\": {\\\"step_1\\\": {\\\"map_merge\\\": [{\\\"redis_init_logs\\\": {\\\"start_order\\\": 0, \\\"detach\\\": false, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRedisImage\\\"]}, \\\"net\\\": \\\"none\\\", \\\"privileged\\\": false, \\\"user\\\": \\\"root\\\", \\\"volumes\\\": [\\\"/var/log/containers/redis:/var/log/redis:z\\\"], \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R redis:redis /var/log/redis\\\"]}}, {\\\"redis\\\": {\\\"start_order\\\": 1, \\\"stop_grace_period\\\": 60, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRedisImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": [\\\"/var/lib/kolla/config_files/redis.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/redis:/var/lib/kolla/config_files/src:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/var/log/containers/redis:/var/log/redis:z\\\", \\\"/run/redis:/run/redis:z\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}, {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, {\\\"redis_tls_proxy\\\": {\\\"start_order\\\": 2, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRedisImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"user\\\": \\\"root\\\", \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/redis_tls_proxy.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/redis:/var/lib/kolla/config_files/src:ro\\\", \\\"/etc/pki/tls/certs/redis.crt:/etc/pki/tls/certs/redis.crt:ro\\\", \\\"/etc/pki/tls/private/redis.key:/etc/pki/tls/private/redis.key:ro\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}]}]}}, \\\"metadata_settings\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, [{\\\"service\\\": \\\"redis\\\", \\\"network\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"RedisNetwork\\\"]}, \\\"type\\\": \\\"vip\\\"}, {\\\"service\\\": \\\"redis\\\", \\\"network\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"RedisNetwork\\\"]}, \\\"type\\\": \\\"node\\\"}]]}, \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Certificate generation\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"enable_internal_tls\\\"], \\\"block\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"linux-system-roles.certificate\\\"}, \\\"vars\\\": {\\\"certificate_requests\\\": [{\\\"name\\\": \\\"redis\\\", \\\"dns\\\": [{\\\"str_replace\\\": {\\\"template\\\": \\\"{{fqdn_$NETWORK}}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"RedisNetwork\\\"]}}}}, {\\\"str_replace\\\": {\\\"template\\\": \\\"{{cloud_names.cloud_name_NETWORK}}\\\", \\\"params\\\": {\\\"NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"RedisNetwork\\\"]}}}}], \\\"principal\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"redis/{{fqdn_$NETWORK}}@{{idm_realm}}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"RedisNetwork\\\"]}}}}, \\\"run_after\\\": \\\"container_name=$({{container_cli}} ps --format=\\\\\\\\{\\\\\\\\{.Names\\\\\\\\}\\\\\\\\} | grep redis_tls_proxy)\\\\nservice_crt=\\\\\\\"/etc/pki/tls/certs/redis.crt\\\\\\\"\\\\nservice_key=\\\\\\\"/etc/pki/tls/private/redis.key\\\\\\\"\\\\n# Copy the new cert from the mount-point to the real path\\\\n{{container_cli}} exec \\\\\\\"$container_name\\\\\\\" cp \\\\\\\"/var/lib/kolla/config_files/src-tls$service_crt\\\\\\\" \\\\\\\"$service_crt\\\\\\\"\\\\n# Copy the new cert from the mount-point to the real path\\\\n{{container_cli}} exec \\\\\\\"$container_name\\\\\\\" cp \\\\\\\"/var/lib/kolla/config_files/src-tls$service_key\\\\\\\" \\\\\\\"$service_key\\\\\\\"\\\\n# Set appropriate permissions\\\\n{{container_cli}} exec \\\\\\\"$container_name\\\\\\\" chown memcached:memcached \\\\\\\"$service_crt\\\\\\\"\\\\n{{container_cli}} exec \\\\\\\"$container_name\\\\\\\" chown memcached:memcached \\\\\\\"$service_key\\\\\\\"\\\\n# Trigger a reload for stunnel to read the new certificate\\\\n{{container_cli}} exec pkill -o -HUP stunnel\\\\n\\\", \\\"key_size\\\": {\\\"if\\\": [\\\"key_size_override_set\\\", {\\\"get_param\\\": \\\"RedisCertificateKeySize\\\"}, {\\\"get_param\\\": \\\"CertificateKeySize\\\"}]}, \\\"ca\\\": \\\"ipa\\\"}]}}]}], \\\"external_deploy_tasks\\\": {\\\"get_attr\\\": [\\\"RedisBase\\\", \\\"role_data\\\", \\\"external_deploy_tasks\\\"]}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create fcontext entry for redis data\\\", \\\"community.general.sefcontext\\\": {\\\"target\\\": \\\"/var/run/redis(/.*)?\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"state\\\": \\\"present\\\"}}, {\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode|default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/redis\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/run/redis\\\", \\\"setype\\\": \\\"container_file_t\\\"}]}, {\\\"name\\\": \\\"ensure /run/redis is present upon reboot\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/tmpfiles.d/run-redis.conf\\\", \\\"content\\\": \\\"d /run/redis 0755 root root - -\\\\n\\\"}}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"redis_container_puppet_redis_pkg_clean\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Ensure redis is uninstalled on container host\\\", \\\"package\\\": {\\\"name\\\": \\\"redis\\\", \\\"state\\\": \\\"absent\\\"}}]}, {\\\"name\\\": \\\"redis_container_puppet_tmpfile_cleanup\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"remove old tmpfiles.d config\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/tmpfiles.d/var-run-redis.conf\\\", \\\"state\\\": \\\"absent\\\"}}]}], \\\"external_update_tasks\\\": {\\\"get_attr\\\": [\\\"RedisBase\\\", \\\"role_data\\\", \\\"external_update_tasks\\\"]}, \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"redis_container_puppet_redis_pkg_clean\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Ensure redis is uninstalled on container host\\\", \\\"package\\\": {\\\"name\\\": \\\"redis\\\", \\\"state\\\": \\\"absent\\\"}}]}, {\\\"name\\\": \\\"redis_container_puppet_tmpfile_cleanup\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"remove old tmpfiles.d config\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/tmpfiles.d/var-run-redis.conf\\\", \\\"state\\\": \\\"absent\\\"}}]}], \\\"external_upgrade_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade_transfer_data\\\", \\\"system_upgrade_stop_services\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Stop redis container\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_stop\\\"}, \\\"vars\\\": {\\\"tripleo_containers_to_stop\\\": {\\\"with_items\\\": {\\\"list_concat\\\": [[\\\"redis\\\"], [{\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, [\\\"redis_tls_proxy\\\"]]}]]}}, \\\"tripleo_delegate_to\\\": \\\"{{ groups[\'redis\'] | difference(groups[\'excluded_overcloud\']) }}\\\"}}]}]}}}}\", \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Redis services\\\\n\\\", \\\"parameters\\\": {\\\"ContainerRedisImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerRedisConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the redis config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ClusterCommonTag\\\": {\\\"default\\\": false, \\\"description\\\": \\\"When set to false, a pacemaker service is configured to use a floating tag for its container image name, e.g. \'REGISTRY/NAMESPACE/IMAGENAME:pcmklatest\'. When set to true, the service uses a floating prefix as well, e.g. \'cluster.common.tag/IMAGENAME:pcmklatest\'.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"ClusterFullTag\\\": {\\\"default\\\": true, \\\"description\\\": \\\"When set to true, the pacemaker service uses a fully constant tag for its container image name, e.g. \'cluster.common.tag/SERVICENAME:pcmklatest\'.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"ConfigDebug\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to run config management (e.g. Puppet) in debug mode.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"RedisIPv6\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Enable IPv6 in Redis\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"ContainerCli\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"podman\\\", \\\"description\\\": \\\"CLI tool used to manage containers.\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"docker\\\", \\\"podman\\\"]}]}, \\\"DeployIdentifier\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\\\n\\\"}}, \\\"parameter_groups\\\": [{\\\"label\\\": \\\"deprecated\\\", \\\"description\\\": \\\"The following parameters are deprecated and will be removed. They should not\\\\nbe relied on for new deployments. If you have concerns regarding deprecated\\\\nparameters, please contact the TripleO development team on IRC or the\\\\nOpenStack mailing list.\\\\n\\\", \\\"parameters\\\": [\\\"RedisIPv6\\\"]}], \\\"conditions\\\": {\\\"is_ipv6\\\": {\\\"equals\\\": [{\\\"get_param\\\": [\\\"ServiceData\\\", \\\"net_ip_version_map\\\", {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"RedisNetwork\\\"]}]}, 6]}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"RedisBase\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-container-puppet.yaml\\\", \\\"properties\\\": {\\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerRedisImage\\\": \\\"ContainerRedisImage\\\", \\\"ContainerRedisConfigImage\\\": \\\"ContainerRedisConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerRedisImage\\\": {\\\"get_param\\\": \\\"ContainerRedisImage\\\"}, \\\"ContainerRedisConfigImage\\\": {\\\"get_param\\\": \\\"ContainerRedisConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Redis API role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"redis\\\", \\\"firewall_rules\\\": {\\\"108 redis-bundle\\\": {\\\"dport\\\": [3124, 6379, 26379]}}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"RedisBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"redis::service_manage\\\": false, \\\"redis::notify_service\\\": false, \\\"redis::managed_by_cluster_manager\\\": true, \\\"tripleo::profile::pacemaker::database::redis_bundle::redis_docker_image\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/redis:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRedisImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRedisImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"tripleo::profile::pacemaker::database::redis_bundle::control_port\\\": 3124, \\\"tripleo::profile::pacemaker::database::redis_bundle::container_backend\\\": {\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"tripleo::profile::pacemaker::database::redis_bundle::force_ocf\\\": true, \\\"tripleo::stunnel::manage_service\\\": false, \\\"tripleo::stunnel::foreground\\\": \\\"yes\\\", \\\"tripleo::profile::pacemaker::database::redis_bundle::tls_proxy_bind_ip\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"RedisNetwork\\\"]}}}}, \\\"tripleo::profile::pacemaker::database::redis_bundle::tls_proxy_fqdn\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'fqdn_$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"RedisNetwork\\\"]}}}}, \\\"tripleo::profile::pacemaker::database::redis_bundle::tls_proxy_port\\\": 6379, \\\"tripleo::profile::pacemaker::database::redis::tls_proxy_bind_ip\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"RedisNetwork\\\"]}}}}, \\\"tripleo::profile::pacemaker::database::redis::tls_proxy_fqdn\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'fqdn_$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"RedisNetwork\\\"]}}}}, \\\"tripleo::profile::pacemaker::database::redis::tls_proxy_port\\\": 6379}, {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, {\\\"redis::extra_config_file\\\": \\\"/etc/redis-tls.conf\\\", \\\"tripleo::profile::pacemaker::database::redis_bundle::extra_config_file\\\": \\\"/etc/redis-tls.conf\\\", \\\"tripleo::profile::pacemaker::database::redis_bundle::tls_tunnel_base_port\\\": 6660, \\\"tripleo::profile::pacemaker::database::redis_bundle::tls_tunnel_local_name\\\": {\\\"if\\\": [\\\"is_ipv6\\\", \\\"::1\\\", \\\"127.0.0.1\\\"]}}]}]}, \\\"service_config_settings\\\": {\\\"get_attr\\\": [\\\"RedisBase\\\", \\\"role_data\\\", \\\"service_config_settings\\\"]}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"redis\\\", \\\"puppet_tags\\\": \\\"exec\\\", \\\"step_config\\\": \\\"Exec <| title == \'systemd-reload-redis\' |> { unless => \'true\' }\\\\ninclude tripleo::profile::pacemaker::database::redis_bundle\\\\n\\\", \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRedisConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/redis.json\\\": {\\\"command\\\": \\\"/usr/sbin/pacemaker_remoted\\\", \\\"config_files\\\": [{\\\"dest\\\": \\\"/etc/libqb/force-filesystem-sockets\\\", \\\"source\\\": \\\"/dev/null\\\", \\\"owner\\\": \\\"root\\\", \\\"perm\\\": \\\"0644\\\"}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true, \\\"optional\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/run/redis\\\", \\\"owner\\\": \\\"redis:redis\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/var/lib/redis\\\", \\\"owner\\\": \\\"redis:redis\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/var/log/redis\\\", \\\"owner\\\": \\\"redis:redis\\\", \\\"recurse\\\": true}]}, \\\"/var/lib/kolla/config_files/redis_tls_proxy.json\\\": {\\\"command\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"bash -c $* -- eval /wait-port-and-run.sh $(hiera fqdn_$NETWORK) 6379 stunnel /etc/stunnel/stunnel.conf\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"RedisNetwork\\\"]}}}}, \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-tls/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"optional\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/etc/pki/tls/certs/redis.crt\\\", \\\"owner\\\": \\\"root:root\\\", \\\"perm\\\": \\\"0600\\\", \\\"optional\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/private/redis.key\\\", \\\"owner\\\": \\\"root:root\\\", \\\"perm\\\": \\\"0600\\\", \\\"optional\\\": true}]}}, \\\"container_config_scripts\\\": {\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"container_config_scripts\\\"]}, \\\"docker_config\\\": {\\\"step_1\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, {\\\"redis_tls_proxy\\\": {\\\"start_order\\\": 0, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRedisImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"user\\\": \\\"root\\\", \\\"restart\\\": \\\"always\\\", \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/redis_tls_proxy.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/redis:/var/lib/kolla/config_files/src:ro\\\", \\\"/etc/pki/tls/certs/redis.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/redis.crt:ro\\\", \\\"/etc/pki/tls/private/redis.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/redis.key:ro\\\", \\\"/var/lib/container-config-scripts/wait-port-and-run.sh:/wait-port-and-run.sh:ro\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}]}}, \\\"metadata_settings\\\": {\\\"get_attr\\\": [\\\"RedisBase\\\", \\\"role_data\\\", \\\"metadata_settings\\\"]}, \\\"external_deploy_tasks\\\": {\\\"get_attr\\\": [\\\"RedisBase\\\", \\\"role_data\\\", \\\"external_deploy_tasks\\\"]}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode|default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/lib/redis\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/log/containers/redis\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/run/redis\\\", \\\"setype\\\": \\\"container_file_t\\\"}]}, {\\\"name\\\": \\\"ensure /run/redis is present upon reboot\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/tmpfiles.d/run-redis.conf\\\", \\\"content\\\": \\\"d /run/redis 0755 root root - -\\\\n\\\"}}], \\\"deploy_steps_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"RedisBase\\\", \\\"role_data\\\", \\\"deploy_steps_tasks\\\"]}, [{\\\"name\\\": \\\"Redis tag container image for pacemaker\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_tag\\\"}, \\\"vars\\\": {\\\"container_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRedisImage\\\"]}, \\\"container_image_latest\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/redis:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRedisImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRedisImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}}}, {\\\"name\\\": \\\"Redis HA Wrappers Step\\\", \\\"when\\\": \\\"step|int == 2\\\", \\\"block\\\": [{\\\"name\\\": \\\"Redis puppet bundle\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_ha_wrapper\\\"}, \\\"vars\\\": {\\\"tripleo_ha_wrapper_service_name\\\": \\\"redis\\\", \\\"tripleo_ha_wrapper_resource_name\\\": \\\"redis\\\", \\\"tripleo_ha_wrapper_bundle_name\\\": \\\"redis-bundle\\\", \\\"tripleo_ha_wrapper_resource_state\\\": \\\"Slave Master\\\", \\\"tripleo_ha_wrapper_puppet_config_volume\\\": \\\"redis\\\", \\\"tripleo_ha_wrapper_puppet_execute\\\": \\\"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::database::redis_bundle\\\", \\\"tripleo_ha_wrapper_puppet_tags\\\": \\\"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\\\", \\\"tripleo_ha_wrapper_puppet_debug\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"tripleo_ha_wrapper_config_suffix\\\": \\\".previous_run\\\"}}]}]]}, \\\"external_update_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"RedisBase\\\", \\\"role_data\\\", \\\"external_update_tasks\\\"]}, [{\\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": \\\"ha_image_update\\\", \\\"block\\\": [{\\\"block\\\": [{\\\"name\\\": \\\"Get redis image from pacemaker\\\", \\\"become\\\": true, \\\"register\\\": \\\"xmllint_pcmk_redis_image\\\", \\\"shell\\\": \\\"xmllint --xpath \\\\\\\"string(//bundle[@id=\'redis-bundle\']/podman/@image)\\\\\\\" /var/lib/pacemaker/cib/cib.xml\\\"}, {\\\"name\\\": \\\"Get container redis image\\\", \\\"set_fact\\\": {\\\"redis_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRedisImage\\\"]}, \\\"redis_image_latest\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/redis:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRedisImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRedisImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"pcmk_redis_image\\\": \\\"{{xmllint_pcmk_redis_image.stdout}}\\\"}}], \\\"delegate_to\\\": \\\"{{ (groups[\\\\\\\"redis\\\\\\\"] | difference(groups[\\\\\\\"excluded_overcloud\\\\\\\"]))[0] }}\\\"}, {\\\"name\\\": \\\"redis temporary pacemaker container tag in case of image switch\\\", \\\"become\\\": true, \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_ha_image_update\\\"}, \\\"vars\\\": {\\\"tripleo_ha_image_update_node_names\\\": \\\"{{ groups[\\\\\\\"redis\\\\\\\"] | difference(groups[\\\\\\\"excluded_overcloud\\\\\\\"]) }}\\\", \\\"tripleo_ha_image_update_bundle\\\": \\\"redis-bundle\\\", \\\"tripleo_ha_image_update_new_image\\\": \\\"{{redis_image_latest}}\\\", \\\"tripleo_ha_image_update_old_image\\\": \\\"{{pcmk_redis_image}}\\\"}, \\\"when\\\": [\\\"(pcmk_redis_image != \\\\\\\"\\\\\\\")\\\", \\\"(pcmk_redis_image != redis_image_latest)\\\"]}]}]]}, \\\"update_tasks\\\": [{\\\"block\\\": [{\\\"name\\\": \\\"Get redis image from pacemaker\\\", \\\"become\\\": true, \\\"register\\\": \\\"xmllint_pcmk_redis_image\\\", \\\"shell\\\": \\\"xmllint --xpath \\\\\\\"string(//bundle[@id=\'redis-bundle\']/podman/@image)\\\\\\\" /var/lib/pacemaker/cib/cib.xml\\\"}, {\\\"name\\\": \\\"Get container redis image\\\", \\\"set_fact\\\": {\\\"redis_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRedisImage\\\"]}, \\\"redis_image_latest\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/redis:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRedisImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRedisImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"pcmk_redis_image\\\": \\\"{{xmllint_pcmk_redis_image.stdout}}\\\"}}], \\\"when\\\": \\\"(step|int == 0 or step|int == 2)\\\"}, {\\\"name\\\": \\\"Check for update of redis container image name\\\", \\\"when\\\": \\\"step|int == 0\\\", \\\"assert\\\": {\\\"that\\\": \\\"pcmk_redis_image == redis_image_latest\\\", \\\"fail_msg\\\": \\\"redis image change detected, run overcloud external-update --tags ha_image_update first\\\"}}, {\\\"name\\\": \\\"redis_pacemaker_puppet_tmpfile_cleanup\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Clean old tmpfile configuration\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/tmpfiles.d/var-run-redis.conf\\\", \\\"state\\\": \\\"absent\\\"}}]}, {\\\"name\\\": \\\"Tear-down non-HA redis container\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Remove non-HA redis container\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_rm\\\"}, \\\"vars\\\": {\\\"tripleo_container_cli\\\": \\\"{{ container_cli }}\\\", \\\"tripleo_containers_to_rm\\\": [\\\"redis\\\"]}}]}, {\\\"name\\\": \\\"Redis fetch and retag container image for pacemaker\\\", \\\"when\\\": \\\"step|int == 2\\\", \\\"block\\\": [{\\\"name\\\": \\\"Retag pcmklatest to latest redis image\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_tag\\\"}, \\\"vars\\\": {\\\"container_image\\\": \\\"{{redis_image}}\\\", \\\"container_image_latest\\\": \\\"{{redis_image_latest}}\\\"}}]}], \\\"post_update_tasks\\\": [{\\\"name\\\": \\\"Redis bundle post update\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Redis puppet bundle\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_ha_wrapper\\\"}, \\\"vars\\\": {\\\"tripleo_ha_wrapper_service_name\\\": \\\"redis\\\", \\\"tripleo_ha_wrapper_resource_name\\\": \\\"redis\\\", \\\"tripleo_ha_wrapper_bundle_name\\\": \\\"redis-bundle\\\", \\\"tripleo_ha_wrapper_resource_state\\\": \\\"Slave Master\\\", \\\"tripleo_ha_wrapper_puppet_config_volume\\\": \\\"redis\\\", \\\"tripleo_ha_wrapper_puppet_execute\\\": \\\"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::database::redis_bundle\\\", \\\"tripleo_ha_wrapper_puppet_tags\\\": \\\"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\\\", \\\"tripleo_ha_wrapper_puppet_debug\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"tripleo_ha_wrapper_config_suffix\\\": \\\".previous_run\\\"}}], \\\"vars\\\": {\\\"tripleo_ha_wrapper_minor_update\\\": true}}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"redis_pacemaker_puppet_tmpfile_cleanup\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Clean old tmpfile configuration\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/tmpfiles.d/var-run-redis.conf\\\", \\\"state\\\": \\\"absent\\\"}}]}, {\\\"name\\\": \\\"Tear-down non-HA redis container\\\", \\\"when\\\": [\\\"step|int == 0\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Remove non-HA redis container\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_rm\\\"}, \\\"vars\\\": {\\\"tripleo_container_cli\\\": \\\"{{ container_cli }}\\\", \\\"tripleo_containers_to_rm\\\": [\\\"redis\\\"]}}]}, {\\\"name\\\": \\\"Prepare switch of redis image name\\\", \\\"when\\\": [\\\"step|int == 0\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Get redis image id currently used by pacemaker\\\", \\\"shell\\\": \\\"pcs resource config redis-bundle | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\\\", \\\"register\\\": \\\"redis_image_current_res\\\", \\\"failed_when\\\": false}, {\\\"name\\\": \\\"Image facts for redis\\\", \\\"set_fact\\\": {\\\"redis_image_latest\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/redis:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRedisImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRedisImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"redis_image_current\\\": \\\"{{redis_image_current_res.stdout}}\\\"}}, {\\\"name\\\": \\\"Temporarily tag the current redis image id with the upgraded image name\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_tag\\\"}, \\\"vars\\\": {\\\"container_image\\\": \\\"{{redis_image_current}}\\\", \\\"container_image_latest\\\": \\\"{{redis_image_latest}}\\\", \\\"pull_image\\\": false}, \\\"when\\\": [\\\"redis_image_current != \'\'\\\", \\\"redis_image_current != redis_image_latest\\\"]}, {\\\"name\\\": \\\"Create redis retag statefile\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/tripleo/redis_needs_retag\\\", \\\"state\\\": \\\"touch\\\"}, \\\"when\\\": [\\\"redis_image_current != \'\'\\\", \\\"redis_image_current != redis_image_latest\\\"]}]}, {\\\"name\\\": \\\"Update redis-bundle pcs resource bundle for new container image\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Set upgrade redis facts\\\", \\\"set_fact\\\": {\\\"is_redis_bootstrap_node\\\": \\\"{{redis_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\\\"}}, {\\\"name\\\": \\\"Check for redis retag statefile\\\", \\\"stat\\\": {\\\"path\\\": \\\"/var/lib/tripleo/redis_needs_retag\\\"}, \\\"register\\\": \\\"redis_retag_state_file\\\"}]}, {\\\"name\\\": \\\"Update redis-bundle pcs resource bundle for new container image\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"is_redis_bootstrap_node|bool\\\", \\\"redis_retag_state_file.stat.exists|bool\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Disable the redis cluster resource before container upgrade\\\", \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"redis-bundle\\\", \\\"state\\\": \\\"disable\\\", \\\"wait_for_resource\\\": true}, \\\"register\\\": \\\"output\\\", \\\"retries\\\": 5, \\\"until\\\": \\\"output.rc == 0\\\"}, {\\\"name\\\": \\\"Move redis logging to /var/log/containers\\\", \\\"block\\\": [{\\\"name\\\": \\\"Check redis logging configuration in pacemaker\\\", \\\"command\\\": \\\"cibadmin --query --xpath \\\\\\\"//storage-mapping[@id=\'redis-log\' and @source-dir=\'/var/log/containers/redis\']\\\\\\\"\\\", \\\"failed_when\\\": false, \\\"register\\\": \\\"redis_logs_moved\\\"}, {\\\"name\\\": \\\"Change redis logging configuration in pacemaker\\\", \\\"when\\\": \\\"redis_logs_moved.rc == 6\\\", \\\"block\\\": [{\\\"name\\\": \\\"Remove old bind mount for logging in the redis bundle\\\", \\\"command\\\": \\\"pcs resource bundle update redis-bundle storage-map remove redis-log\\\"}, {\\\"name\\\": \\\"Add a bind mount for logging in the redis bundle\\\", \\\"command\\\": \\\"pcs resource bundle update redis-bundle storage-map add id=redis-log source-dir=/var/log/containers/redis target-dir=/var/log/redis options=rw\\\"}]}]}, {\\\"name\\\": \\\"Update the redis bundle to use the new container image name\\\", \\\"command\\\": \\\"pcs resource bundle update redis-bundle container image={{redis_image_latest}}\\\"}, {\\\"name\\\": \\\"Enable the redis cluster resource\\\", \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"redis-bundle\\\", \\\"state\\\": \\\"enable\\\", \\\"wait_for_resource\\\": true}, \\\"register\\\": \\\"output\\\", \\\"retries\\\": 5, \\\"until\\\": \\\"output.rc == 0\\\"}]}, {\\\"name\\\": \\\"Check for redis retag statefile\\\", \\\"when\\\": [\\\"step|int == 3\\\"], \\\"stat\\\": {\\\"path\\\": \\\"/var/lib/tripleo/redis_needs_retag\\\"}, \\\"register\\\": \\\"redis_retag_state_file\\\"}, {\\\"name\\\": \\\"Retag redis-bundle container image\\\", \\\"when\\\": [\\\"step|int == 3\\\", \\\"redis_retag_state_file.stat.exists|bool\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Disable the redis cluster resource before container upgrade\\\", \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"redis-bundle\\\", \\\"state\\\": \\\"disable\\\", \\\"wait_for_resource\\\": true}, \\\"register\\\": \\\"output\\\", \\\"retries\\\": 5, \\\"until\\\": \\\"output.rc == 0\\\"}, {\\\"name\\\": \\\"Retag the pacemaker image if containerized\\\", \\\"block\\\": [{\\\"block\\\": [{\\\"name\\\": \\\"Get redis image from pacemaker\\\", \\\"become\\\": true, \\\"register\\\": \\\"xmllint_pcmk_redis_image\\\", \\\"shell\\\": \\\"xmllint --xpath \\\\\\\"string(//bundle[@id=\'redis-bundle\']/podman/@image)\\\\\\\" /var/lib/pacemaker/cib/cib.xml\\\"}, {\\\"name\\\": \\\"Get container redis image\\\", \\\"set_fact\\\": {\\\"redis_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRedisImage\\\"]}, \\\"redis_image_latest\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/redis:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRedisImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRedisImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"pcmk_redis_image\\\": \\\"{{xmllint_pcmk_redis_image.stdout}}\\\"}}]}, {\\\"block\\\": [{\\\"name\\\": \\\"Retag pcmklatest to latest redis image\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_tag\\\"}, \\\"vars\\\": {\\\"container_image\\\": \\\"{{redis_image}}\\\", \\\"container_image_latest\\\": \\\"{{redis_image_latest}}\\\"}}]}]}, {\\\"name\\\": \\\"Enable the redis-bundle cluster resource\\\", \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"redis-bundle\\\", \\\"state\\\": \\\"enable\\\", \\\"wait_for_resource\\\": true}, \\\"register\\\": \\\"output\\\", \\\"retries\\\": 5, \\\"until\\\": \\\"output.rc == 0\\\"}, {\\\"name\\\": \\\"Remove redis retag statefile\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/tripleo/redis_needs_retag\\\", \\\"state\\\": \\\"absent\\\"}}]}]}}}}\", \"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Containerized rsyslogd service for purposes of centralized log collection of OpenStack services\' logs.\\\\n\\\", \\\"parameters\\\": {\\\"ContainerRsyslogImage\\\": {\\\"description\\\": \\\"The container image to use for container\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerRsyslogConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the rsyslog config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"RsyslogReopenOnTruncate\\\": {\\\"default\\\": true, \\\"description\\\": \\\"Rsyslog imfile reopenOnTruncate parameter\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"RsyslogElasticsearchSetting\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Configuration for rsyslog-elasticsearch plugin\\\", \\\"type\\\": \\\"json\\\"}, \\\"RsyslogElasticsearchTlsCACert\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Contains content of the CA cert for the CA that issued Elasticsearch server cert.\\\", \\\"type\\\": \\\"string\\\"}, \\\"RsyslogElasticsearchTlsClientCert\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Contains content of the client cert for doing client cert auth against Elasticsearch.\\\", \\\"type\\\": \\\"string\\\"}, \\\"RsyslogElasticsearchTlsClientKey\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Contains content of the private key corresponding to the cert RsyslogElasticsearchTlsClientCert.\\\", \\\"type\\\": \\\"string\\\"}, \\\"CloudName\\\": {\\\"default\\\": \\\"overcloud.localdomain\\\", \\\"description\\\": \\\"The DNS name of this cloud. E.g. ci-overcloud.tripleo.org\\\", \\\"type\\\": \\\"string\\\"}, \\\"KeystoneRegion\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"regionOne\\\", \\\"description\\\": \\\"Keystone region for endpoint\\\"}, \\\"RsyslogAmqp1Setting\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Configuration for rsyslog-omamqp1 plugin\\\", \\\"type\\\": \\\"json\\\"}, \\\"RsyslogAmqp1Local\\\": {\\\"default\\\": true, \\\"description\\\": \\\"Set to false to disable prefilling host connection value to local QDR in RsyslogAmqp1Setting.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"MetricsQdrPort\\\": {\\\"default\\\": 5666, \\\"description\\\": \\\"Service name or port number on which the qdrouterd will accept connections.\\\", \\\"type\\\": \\\"number\\\"}, \\\"RsyslogMaxMessageSize\\\": {\\\"default\\\": \\\"32k\\\", \\\"description\\\": \\\"Maximum supported message size (both for sending and receiving) for rsyslogd.\\\", \\\"type\\\": \\\"string\\\"}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerRsyslogImage\\\": \\\"ContainerRsyslogImage\\\", \\\"ContainerRsyslogConfigImage\\\": \\\"ContainerRsyslogConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerRsyslogImage\\\": {\\\"get_param\\\": \\\"ContainerRsyslogImage\\\"}, \\\"ContainerRsyslogConfigImage\\\": {\\\"get_param\\\": \\\"ContainerRsyslogConfigImage\\\"}}}]}}}}, \\\"conditions\\\": {\\\"use_tls\\\": {\\\"not\\\": {\\\"and\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"RsyslogElasticsearchTlsCACert\\\"}, \\\"\\\"]}, {\\\"equals\\\": [{\\\"get_param\\\": \\\"RsyslogElasticsearchTlsClientCert\\\"}, \\\"\\\"]}, {\\\"equals\\\": [{\\\"get_param\\\": \\\"RsyslogElasticsearchTlsClientKey\\\"}, \\\"\\\"]}]}}, \\\"use_elasticsearch\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"RsyslogElasticsearchSetting\\\"}, {}]}}, \\\"use_amqp1\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"RsyslogAmqp1Setting\\\"}, {}]}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the rsyslog role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"rsyslog\\\", \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"rsyslog::server::global_config\\\": {\\\"WorkDirectory\\\": {\\\"type\\\": \\\"legacy\\\", \\\"target\\\": \\\"00_rsyslog.conf\\\", \\\"value\\\": \\\"/var/lib/rsyslog\\\"}, \\\"MaxMessageSize\\\": {\\\"type\\\": \\\"legacy\\\", \\\"target\\\": \\\"00_rsyslog.conf\\\", \\\"value\\\": {\\\"get_param\\\": \\\"RsyslogMaxMessageSize\\\"}}}, \\\"rsyslog::confdir\\\": \\\"/etc/rsyslog.d\\\", \\\"rsyslog::package_name\\\": \\\"rsyslog\\\", \\\"rsyslog::package_version\\\": \\\"installed\\\", \\\"rsyslog::manage_package\\\": true, \\\"rsyslog::manage_confdir\\\": true, \\\"rsyslog::purge_config_files\\\": true, \\\"rsyslog::override_default_config\\\": true, \\\"rsyslog::config_file\\\": \\\"/etc/rsyslog.conf\\\", \\\"rsyslog::manage_service\\\": true, \\\"rsyslog::service_name\\\": \\\"rsyslog\\\", \\\"rsyslog::service_status\\\": \\\"running\\\", \\\"rsyslog::service_enabled\\\": true, \\\"rsyslog::external_service\\\": false, \\\"rsyslog::use_upstream_repo\\\": false, \\\"rsyslog::feature_packages\\\": [\\\"rsyslog-elasticsearch\\\", \\\"rsyslog-mmnormalize\\\"], \\\"rsyslog::global_config_priority\\\": 10, \\\"rsyslog::module_load_priority\\\": 20, \\\"rsyslog::input_priority\\\": 30, \\\"rsyslog::main_queue_priority\\\": 40, \\\"rsyslog::parser_priority\\\": 45, \\\"rsyslog::template_priority\\\": 50, \\\"rsyslog::filter_priority\\\": 55, \\\"rsyslog::action_priority\\\": 60, \\\"rsyslog::ruleset_priority\\\": 65, \\\"rsyslog::lookup_table_priority\\\": 70, \\\"rsyslog::legacy_config_priority\\\": 80, \\\"rsyslog::custom_priority\\\": 90, \\\"rsyslog::target_file\\\": \\\"50_openstack_logs.conf\\\", \\\"rsyslog::server::modules\\\": {\\\"imfile\\\": {}, \\\"omelasticsearch\\\": {}, \\\"omamqp1\\\": {}}, \\\"rsyslog::server::templates\\\": {\\\"rsyslog-node-index\\\": {\\\"type\\\": \\\"list\\\", \\\"list_descriptions\\\": [{\\\"constant\\\": {\\\"value\\\": \\\"%{hiera(\'fqdn_canonical\')}-\\\"}}, {\\\"property\\\": {\\\"name\\\": \\\"timereported\\\", \\\"dateFormat\\\": \\\"year\\\"}}, {\\\"constant\\\": {\\\"value\\\": \\\".\\\"}}, {\\\"property\\\": {\\\"name\\\": \\\"timereported\\\", \\\"dateFormat\\\": \\\"month\\\"}}, {\\\"constant\\\": {\\\"value\\\": \\\".\\\"}}, {\\\"property\\\": {\\\"name\\\": \\\"timereported\\\", \\\"dateFormat\\\": \\\"day\\\"}}]}, \\\"rsyslog-record\\\": {\\\"type\\\": \\\"list\\\", \\\"options\\\": {\\\"jsonf\\\": \\\"on\\\"}, \\\"list_descriptions\\\": [{\\\"property\\\": {\\\"outname\\\": \\\"@timestamp\\\", \\\"name\\\": \\\"timereported\\\", \\\"dateFormat\\\": \\\"rfc3339\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"property\\\": {\\\"outname\\\": \\\"host\\\", \\\"name\\\": \\\"hostname\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"property\\\": {\\\"outname\\\": \\\"severity\\\", \\\"name\\\": \\\"syslogseverity\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"property\\\": {\\\"outname\\\": \\\"facility\\\", \\\"name\\\": \\\"syslogfacility-text\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"property\\\": {\\\"outname\\\": \\\"tag\\\", \\\"name\\\": \\\"syslogtag\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"property\\\": {\\\"outname\\\": \\\"source\\\", \\\"name\\\": \\\"app-name\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"property\\\": {\\\"outname\\\": \\\"message\\\", \\\"name\\\": \\\"msg\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"property\\\": {\\\"outname\\\": \\\"file\\\", \\\"name\\\": \\\"$!metadata!filename\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"constant\\\": {\\\"outname\\\": \\\"cloud\\\", \\\"value\\\": {\\\"get_param\\\": \\\"CloudName\\\"}, \\\"format\\\": \\\"jsonf\\\"}}, {\\\"constant\\\": {\\\"outname\\\": \\\"region\\\", \\\"value\\\": {\\\"get_param\\\": \\\"KeystoneRegion\\\"}, \\\"format\\\": \\\"jsonf\\\"}}]}}}, {\\\"if\\\": [\\\"use_elasticsearch\\\", {\\\"tripleo::profile::base::logging::rsyslog::elasticsearch\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"RsyslogElasticsearchSetting\\\"}, {\\\"template\\\": \\\"rsyslog-record\\\", \\\"searchIndex\\\": \\\"rsyslog-node-index\\\", \\\"dynSearchIndex\\\": \\\"on\\\", \\\"errorfile\\\": \\\"/var/log/rsyslog/omelasticsearch.log\\\"}]}}, {}]}, {\\\"if\\\": [\\\"use_amqp1\\\", {\\\"tripleo::profile::base::logging::rsyslog::amqp1\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"RsyslogAmqp1Setting\\\"}, {\\\"template\\\": \\\"rsyslog-record\\\"}, {\\\"if\\\": [{\\\"get_param\\\": \\\"RsyslogAmqp1Local\\\"}, {\\\"host\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}:$PORT\\\", \\\"params\\\": {\\\"$PORT\\\": {\\\"get_param\\\": \\\"MetricsQdrPort\\\"}, \\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", {\\\"str_replace\\\": {\\\"template\\\": \\\"ROLENAMEMetricsQdrNetwork\\\", \\\"params\\\": {\\\"ROLENAME\\\": {\\\"get_param\\\": \\\"RoleName\\\"}}}}]}}}}}]}]}}, {}]}, {\\\"if\\\": [{\\\"get_param\\\": \\\"RsyslogReopenOnTruncate\\\"}, {\\\"tripleo::profile::base::logging::rsyslog::reopen_on_truncate\\\": \\\"on\\\"}, {}]}, {\\\"if\\\": [\\\"use_tls\\\", {\\\"tripleo::profile::base::logging::rsyslog::elasticsearch_tls_ca_cert\\\": {\\\"get_param\\\": \\\"RsyslogElasticsearchTlsCACert\\\"}, \\\"tripleo::profile::base::logging::rsyslog::elasticsearch_tls_client_cert\\\": {\\\"get_param\\\": \\\"RsyslogElasticsearchTlsClientCert\\\"}, \\\"tripleo::profile::base::logging::rsyslog::elasticsearch_tls_client_key\\\": {\\\"get_param\\\": \\\"RsyslogElasticsearchTlsClientKey\\\"}}]}]}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"rsyslog\\\", \\\"puppet_tags\\\": \\\"rsyslog::generate_concat,concat::fragment\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::logging::rsyslog\\\", \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRsyslogConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/rsyslog.json\\\": {\\\"command\\\": \\\"/usr/sbin/rsyslogd -n -iNONE\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/lib/rsyslog\\\", \\\"owner\\\": \\\"root:root\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/var/log/rsyslog\\\", \\\"owner\\\": \\\"root:root\\\", \\\"recurse\\\": true}]}}, \\\"docker_config\\\": {\\\"step_3\\\": {\\\"rsyslog\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerRsyslogImage\\\"]}, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"user\\\": \\\"root\\\", \\\"restart\\\": \\\"always\\\", \\\"security_opt\\\": [\\\"label=disable\\\"], \\\"volumes\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/kolla/config_files/rsyslog.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/rsyslog:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/log/containers:/var/log/containers:ro\\\", \\\"/var/log/containers/rsyslog:/var/log/rsyslog:rw,z\\\", \\\"/var/log:/var/log/host:ro\\\", \\\"/var/lib/rsyslog.container:/var/lib/rsyslog:rw,z\\\"]]}, \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent logs directory for rsyslog\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/log/containers/rsyslog\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}}, {\\\"name\\\": \\\"create persistent state directory for rsyslog\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/rsyslog.container\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"container_file_t\\\"}}]}}}}\", \"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-client.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Mysql client settings\\\\n\\\", \\\"parameters\\\": {\\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"InternalTLSCAFile\\\": {\\\"default\\\": \\\"/etc/ipa/ca.crt\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Specifies the default CA cert to use if TLS is used for services in the internal network.\\\"}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role for setting mysql client parameters\\\", \\\"value\\\": {\\\"service_name\\\": \\\"mysql_client\\\", \\\"config_settings\\\": {\\\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"MysqlNetwork\\\"]}}}}, \\\"tripleo::profile::base::database::mysql::client::enable_ssl\\\": {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, \\\"tripleo::profile::base::database::mysql::client::ssl_ca\\\": {\\\"get_param\\\": \\\"InternalTLSCAFile\\\"}}, \\\"step_config\\\": \\\"include tripleo::profile::base::database::mysql::client\\\"}}}}\", \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-base.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack Cinder base service. Shared by all Cinder services.\\\\n\\\", \\\"parameters\\\": {\\\"CinderStorageAvailabilityZone\\\": {\\\"default\\\": \\\"nova\\\", \\\"description\\\": \\\"The Cinder service\'s storage availability zone.\\\", \\\"type\\\": \\\"string\\\"}, \\\"CinderPassword\\\": {\\\"description\\\": \\\"The password for the cinder service and db account.\\\", \\\"type\\\": \\\"string\\\", \\\"hidden\\\": true}, \\\"Debug\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Set to True to enable debugging on all services.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"CinderDebug\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Set to True to enable debugging on Cinder services.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"EnableSQLAlchemyCollectd\\\": {\\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"Set to true to enable the SQLAlchemy-collectd server plugin\\\\n\\\", \\\"default\\\": false}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"KeystoneRegion\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"regionOne\\\", \\\"description\\\": \\\"Keystone region for endpoint\\\"}, \\\"CinderCronDbPurgeMinute\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge db entries marked as deleted and older than $age - Minute\\\\n\\\", \\\"default\\\": \\\"1\\\"}, \\\"CinderCronDbPurgeHour\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge db entries marked as deleted and older than $age - Hour\\\\n\\\", \\\"default\\\": \\\"0\\\"}, \\\"CinderCronDbPurgeMonthday\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge db entries marked as deleted and older than $age - Month Day\\\\n\\\", \\\"default\\\": \\\"*\\\"}, \\\"CinderCronDbPurgeMonth\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge db entries marked as deleted and older than $age - Month\\\\n\\\", \\\"default\\\": \\\"*\\\"}, \\\"CinderCronDbPurgeWeekday\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge db entries marked as deleted and older than $age - Week Day\\\\n\\\", \\\"default\\\": \\\"*\\\"}, \\\"CinderCronDbPurgeUser\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge db entries marked as deleted and older than $age - User\\\\n\\\", \\\"default\\\": \\\"cinder\\\"}, \\\"CinderCronDbPurgeAge\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge db entries marked as deleted and older than $age - Age\\\\n\\\", \\\"default\\\": \\\"30\\\"}, \\\"CinderCronDbPurgeDestination\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge db entries marked as deleted and older than $age - Log destination\\\\n\\\", \\\"default\\\": \\\"/var/log/cinder/cinder-rowsflush.log\\\"}, \\\"CinderCronDbPurgeMaxDelay\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Cron to purge db entries marked as deleted and older than $age - Max Delay\\\\n\\\", \\\"default\\\": \\\"3600\\\"}, \\\"CinderRpcResponseTimeout\\\": {\\\"default\\\": 60, \\\"description\\\": \\\"Cinder\'s RPC response timeout, in seconds.\\\", \\\"type\\\": \\\"number\\\"}, \\\"NovaPassword\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"The password for the nova service and db account\\\", \\\"hidden\\\": true}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Cinder base service.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"cinder_base\\\", \\\"config_settings\\\": {\\\"cinder::database_connection\\\": {\\\"make_url\\\": {\\\"scheme\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"MysqlInternal\\\", \\\"protocol\\\"]}, \\\"username\\\": \\\"cinder\\\", \\\"password\\\": {\\\"get_param\\\": \\\"CinderPassword\\\"}, \\\"host\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"MysqlInternal\\\", \\\"host\\\"]}, \\\"path\\\": \\\"/cinder\\\", \\\"query\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"EnableSQLAlchemyCollectd\\\"}, {\\\"read_default_file\\\": \\\"/etc/my.cnf.d/tripleo.cnf\\\", \\\"read_default_group\\\": \\\"tripleo\\\", \\\"plugin\\\": \\\"collectd\\\", \\\"collectd_program_name\\\": \\\"cinder\\\", \\\"collectd_host\\\": \\\"localhost\\\"}, {\\\"read_default_file\\\": \\\"/etc/my.cnf.d/tripleo.cnf\\\", \\\"read_default_group\\\": \\\"tripleo\\\"}]}}}, \\\"cinder::logging::debug\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"CinderDebug\\\"}, true, {\\\"get_param\\\": \\\"Debug\\\"}]}, \\\"cinder::storage_availability_zone\\\": {\\\"get_param\\\": \\\"CinderStorageAvailabilityZone\\\"}, \\\"cinder::rabbit_heartbeat_timeout_threshold\\\": 60, \\\"cinder::rpc_response_timeout\\\": {\\\"get_param\\\": \\\"CinderRpcResponseTimeout\\\"}, \\\"cinder::rabbit_heartbeat_in_pthread\\\": false, \\\"cinder::db::database_db_max_retries\\\": -1, \\\"cinder::db::database_max_retries\\\": -1, \\\"cinder::cron::db_purge::minute\\\": {\\\"get_param\\\": \\\"CinderCronDbPurgeMinute\\\"}, \\\"cinder::cron::db_purge::hour\\\": {\\\"get_param\\\": \\\"CinderCronDbPurgeHour\\\"}, \\\"cinder::cron::db_purge::monthday\\\": {\\\"get_param\\\": \\\"CinderCronDbPurgeMonthday\\\"}, \\\"cinder::cron::db_purge::month\\\": {\\\"get_param\\\": \\\"CinderCronDbPurgeMonth\\\"}, \\\"cinder::cron::db_purge::weekday\\\": {\\\"get_param\\\": \\\"CinderCronDbPurgeWeekday\\\"}, \\\"cinder::cron::db_purge::user\\\": {\\\"get_param\\\": \\\"CinderCronDbPurgeUser\\\"}, \\\"cinder::cron::db_purge::age\\\": {\\\"get_param\\\": \\\"CinderCronDbPurgeAge\\\"}, \\\"cinder::cron::db_purge::destination\\\": {\\\"get_param\\\": \\\"CinderCronDbPurgeDestination\\\"}, \\\"cinder::cron::db_purge::maxdelay\\\": {\\\"get_param\\\": \\\"CinderCronDbPurgeMaxDelay\\\"}, \\\"cinder::glance::glance_api_servers\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"GlanceInternal\\\", \\\"uri\\\"]}, \\\"cinder::keystone::service_user::send_service_user_token\\\": true, \\\"cinder::keystone::service_user::project_name\\\": \\\"service\\\", \\\"cinder::keystone::service_user::auth_type\\\": \\\"password\\\", \\\"cinder::keystone::service_user::auth_url\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"uri\\\"]}, \\\"cinder::keystone::service_user::password\\\": {\\\"get_param\\\": \\\"CinderPassword\\\"}, \\\"cinder::keystone::service_user::region_name\\\": {\\\"get_param\\\": \\\"KeystoneRegion\\\"}, \\\"cinder::nova::interface\\\": \\\"admin\\\", \\\"cinder::nova::project_name\\\": \\\"service\\\", \\\"cinder::nova::auth_type\\\": \\\"password\\\", \\\"cinder::nova::auth_url\\\": {\\\"get_param\\\": [\\\"EndpointMap\\\", \\\"KeystoneInternal\\\", \\\"uri\\\"]}, \\\"cinder::nova::password\\\": {\\\"get_param\\\": \\\"NovaPassword\\\"}, \\\"cinder::nova::region_name\\\": {\\\"get_param\\\": \\\"KeystoneRegion\\\"}}}}}}\", \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Openstack Cinder NVMeOF backend\\\\n\\\", \\\"parameters\\\": {\\\"CinderEnableNVMeOFBackend\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to enable or not the NVMeOF backend for Cinder\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"CinderNVMeOFBackendName\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"tripleo_nvmeof\\\"}, \\\"CinderNVMeOFAvailabilityZone\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"CinderNVMeOFTargetPort\\\": {\\\"type\\\": \\\"number\\\", \\\"default\\\": 4420}, \\\"CinderNVMeOFTargetHelper\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"nvmet\\\"}, \\\"CinderNVMeOFTargetProtocol\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"nvmet_rdma\\\", \\\"description\\\": \\\"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\\\n\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"nvmet_rdma\\\", \\\"nvmet_tcp\\\"]}]}, \\\"CinderNVMeOFTargetPrefix\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"nvme-subsystem\\\"}, \\\"CinderNVMeOFTargetPortId\\\": {\\\"type\\\": \\\"number\\\", \\\"default\\\": 1}, \\\"CinderNVMeOFTargetNameSpaceId\\\": {\\\"type\\\": \\\"number\\\", \\\"default\\\": 10}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\"}}, \\\"outputs\\\": {\\\"cinder_nvmeof_host_prep_tasks\\\": {\\\"description\\\": \\\"Host prep tasks related to cinder\'s NVMeOF backend\\\", \\\"value\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"CinderEnableNVMeOFBackend\\\"}, [{\\\"name\\\": \\\"ensure /etc/nvme exists\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/nvme\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"container_file_t\\\"}}]]}}, \\\"cinder_nvmeof_volumes\\\": {\\\"description\\\": \\\"Volumes related to cinder\'s NVMeOF backend\\\", \\\"value\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"CinderEnableNVMeOFBackend\\\"}, [\\\"/etc/nvme:/etc/nvme:z\\\"]]}}, \\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Cinder NVMeOF backend.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"cinder_backend_nvmeof\\\", \\\"firewall_rules\\\": {\\\"120 LVM nvmet target\\\": {\\\"dport\\\": {\\\"get_param\\\": \\\"CinderNVMeOFTargetPort\\\"}}}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\\\": {\\\"get_param\\\": \\\"CinderEnableNVMeOFBackend\\\"}, \\\"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\\\": {\\\"get_param\\\": \\\"CinderNVMeOFBackendName\\\"}, \\\"tripleo::profile::base::cinder::volume::nvmeof::target_port\\\": {\\\"get_param\\\": \\\"CinderNVMeOFTargetPort\\\"}, \\\"tripleo::profile::base::cinder::volume::nvmeof::target_helper\\\": {\\\"get_param\\\": \\\"CinderNVMeOFTargetHelper\\\"}, \\\"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\\\": {\\\"get_param\\\": \\\"CinderNVMeOFTargetProtocol\\\"}, \\\"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\\\": {\\\"get_param\\\": \\\"CinderNVMeOFTargetPrefix\\\"}, \\\"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\\\": {\\\"get_param\\\": \\\"CinderNVMeOFTargetPortId\\\"}, \\\"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\\\": {\\\"get_param\\\": \\\"CinderNVMeOFTargetNameSpaceId\\\"}, \\\"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderIscsiNetwork\\\"]}}}}, \\\"cinder::backend::nvmeof::volume_backend_name\\\": {\\\"get_param\\\": \\\"CinderNVMeOFBackendName\\\"}}, {\\\"if\\\": [{\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"CinderNVMeOFAvailabilityZone\\\"}, \\\"\\\"]}}, {\\\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\\\": {\\\"get_param\\\": \\\"CinderNVMeOFAvailabilityZone\\\"}}]}]}}}}}\", \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Provides the list of common container volumes and environment used by various cinder services.\\\\n\\\", \\\"parameters\\\": {\\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"CinderVolumeOptVolumes\\\": {\\\"default\\\": [], \\\"description\\\": \\\"list of optional volumes to be mounted\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"CinderBackupOptVolumes\\\": {\\\"default\\\": [], \\\"description\\\": \\\"list of optional volumes to be mounted\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"CinderVolumeOptEnvVars\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"hash of optional environment variables\\\", \\\"type\\\": \\\"json\\\"}, \\\"CinderEnableIscsiBackend\\\": {\\\"default\\\": true, \\\"description\\\": \\\"Whether to enable or not the Iscsi backend for Cinder\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"CinderEnableNVMeOFBackend\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to enable or not the NVMeOF backend for Cinder\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"CinderLVMConfigureVG\\\": {\\\"default\\\": true, \\\"description\\\": \\\"Whether to configure the \'cinder-volumes\' VG used by the LVM driver. When disabled (set to False), the LVM driver will work as long as the \'cinder-volumes\' VG has been created through some other means.\\\\n\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"CinderLVMLoopDeviceSize\\\": {\\\"default\\\": 10280, \\\"description\\\": \\\"The size of the loopback file used by the cinder LVM driver.\\\", \\\"type\\\": \\\"number\\\"}, \\\"MultipathdEnable\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to enable the multipath daemon\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"CinderVolumeCluster\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"CinderImageConversionNfsShare\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"When set, the NFS share to be used for Cinder\'s image conversion directory.\\\", \\\"type\\\": \\\"string\\\"}, \\\"CinderImageConversionNfsOptions\\\": {\\\"default\\\": \\\"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\\\", \\\"description\\\": \\\"NFS mount options when using an NFS share for Cinder\'s image conversion directory.\\\", \\\"type\\\": \\\"string\\\"}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"EnableEtcdInternalTLS\\\": {\\\"description\\\": \\\"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\\\", \\\"type\\\": \\\"boolean\\\", \\\"default\\\": true}, \\\"CephConfigPath\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"/var/lib/tripleo-config/ceph\\\", \\\"description\\\": \\\"The path where the Ceph Cluster config files are stored on the host.\\\\n\\\"}, \\\"CephClientUserName\\\": {\\\"default\\\": \\\"openstack\\\", \\\"type\\\": \\\"string\\\"}, \\\"CephClusterName\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"ceph\\\", \\\"description\\\": \\\"The Ceph cluster name.\\\", \\\"constraints\\\": [{\\\"allowed_pattern\\\": \\\"[a-zA-Z0-9]+\\\", \\\"description\\\": \\\"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\\\n\\\"}]}, \\\"CephExternalMultiConfig\\\": {\\\"type\\\": \\\"json\\\", \\\"hidden\\\": true, \\\"description\\\": \\\"List of maps describing extra overrides which will be applied when configuring\\\\nextra external Ceph clusters. If this list is non-empty, ceph-ansible will run\\\\nan extra count(list) times using the same parameters as the first run except\\\\neach parameter within each map will override the defaults. If the following\\\\nwere used, the second run would configure the overcloud to also use the ceph2\\\\ncluster with all the previous parameters except /etc/ceph/ceph2.conf would have\\\\na mon_host entry containing the value of external_cluster_mon_ips below, and\\\\nnot the default CephExternalMonHost. Subsequent ceph-ansible runs are restricted\\\\nto just ceph clients. CephExternalMultiConfig may not be used to deploy additional\\\\ninternal Ceph clusters within one Heat stack. The map for each list should contain\\\\nnot tripleo-heat-template parameters but ceph-ansible parameters.\\\\n  - cluster: \'ceph2\'\\\\n    fsid: \'e2cba068-5f14-4b0f-b047-acf375c0004a\'\\\\n    external_cluster_mon_ips: \'172.18.0.5,172.18.0.6,172.18.0.7\'\\\\n    keys:\\\\n      - name: \\\\\\\"client.openstack\\\\\\\"\\\\n        caps:\\\\n          mgr: \\\\\\\"allow *\\\\\\\"\\\\n          mon: \\\\\\\"profile rbd\\\\\\\"\\\\n          osd: \\\\\\\"osd: profile rbd pool=volumes, profile rbd pool=backups, profile rbd pool=vms, profile rbd pool=images\\\\\\\"\\\\n        key: \\\\\\\"AQCwmeRcAAAAABAA6SQU/bGqFjlfLro5KxrB1Q==\\\\\\\"\\\\n        mode: \\\\\\\"0600\\\\\\\"\\\\n    dashboard_enabled: false\\\\n\\\", \\\"default\\\": []}}, \\\"conditions\\\": {\\\"cvol_active_active_tls_enabled\\\": {\\\"and\\\": [{\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"CinderVolumeCluster\\\"}, \\\"\\\"]}}, {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, {\\\"get_param\\\": \\\"EnableEtcdInternalTLS\\\"}]}, \\\"cinder_nfs_conversion_dir_enabled\\\": {\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"CinderImageConversionNfsShare\\\"}, \\\"\\\"]}}, \\\"cinder_configure_lvm\\\": {\\\"and\\\": [{\\\"get_param\\\": \\\"CinderLVMConfigureVG\\\"}, {\\\"or\\\": [{\\\"get_param\\\": \\\"CinderEnableIscsiBackend\\\"}, {\\\"get_param\\\": \\\"CinderEnableNVMeOFBackend\\\"}]}]}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"CinderNVMeOF\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\\\"}}, \\\"outputs\\\": {\\\"cinder_image_conversion_nfs_dir\\\": {\\\"description\\\": \\\"The directory where cinder does its image conversion when the directory is backed by an NFS share.\\\", \\\"value\\\": \\\"/var/lib/cinder_image_conversion\\\"}, \\\"cinder_common_host_prep_tasks\\\": {\\\"description\\\": \\\"Common host prep tasks for cinder-volume and cinder-backup services\\\", \\\"value\\\": {\\\"list_concat\\\": [[{\\\"name\\\": \\\"create fcontext entry for cinder data\\\", \\\"community.general.sefcontext\\\": {\\\"target\\\": \\\"/var/lib/cinder(/.*)?\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"state\\\": \\\"present\\\"}}, {\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode|default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/cinder\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/lib/cinder\\\", \\\"setype\\\": \\\"container_file_t\\\"}]}, {\\\"name\\\": \\\"ensure ceph configurations exist\\\", \\\"file\\\": {\\\"path\\\": {\\\"get_param\\\": \\\"CephConfigPath\\\"}, \\\"state\\\": \\\"directory\\\"}}], {\\\"get_attr\\\": [\\\"CinderNVMeOF\\\", \\\"cinder_nvmeof_host_prep_tasks\\\"]}]}}, \\\"cinder_common_volumes\\\": {\\\"description\\\": \\\"Common volumes for all cinder services\\\", \\\"value\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/log/containers/cinder:/var/log/cinder:z\\\"], {\\\"if\\\": [\\\"cvol_active_active_tls_enabled\\\", [\\\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\\\", \\\"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\\\"]]}]}}, \\\"cinder_common_kolla_config_files\\\": {\\\"description\\\": \\\"Common kolla config_files for cinder-volume and cinder-backup services\\\", \\\"value\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-ceph/\\\", \\\"dest\\\": \\\"/etc/ceph/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-iscsid/*\\\", \\\"dest\\\": \\\"/etc/iscsi/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-tls/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true, \\\"optional\\\": true}]}, \\\"cinder_common_kolla_permissions\\\": {\\\"description\\\": \\\"Common kolla permissions for cinder-volume and cinder-backup services\\\", \\\"value\\\": {\\\"list_concat\\\": [[{\\\"path\\\": \\\"/var/log/cinder\\\", \\\"owner\\\": \\\"cinder:cinder\\\", \\\"recurse\\\": true}, {\\\"path\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"/etc/ceph/CLUSTER.client.USER.keyring\\\", \\\"params\\\": {\\\"CLUSTER\\\": {\\\"get_param\\\": \\\"CephClusterName\\\"}, \\\"USER\\\": {\\\"get_param\\\": \\\"CephClientUserName\\\"}}}}, \\\"owner\\\": \\\"cinder:cinder\\\", \\\"perm\\\": \\\"0600\\\"}, {\\\"path\\\": \\\"/etc/pki/tls/certs/etcd.crt\\\", \\\"owner\\\": \\\"cinder:cinder\\\"}, {\\\"path\\\": \\\"/etc/pki/tls/private/etcd.key\\\", \\\"owner\\\": \\\"cinder:cinder\\\"}], {\\\"repeat\\\": {\\\"template\\\": {\\\"path\\\": \\\"/etc/ceph/<%cluster%>.client.*.keyring\\\", \\\"owner\\\": \\\"cinder:cinder\\\", \\\"perm\\\": \\\"0600\\\"}, \\\"for_each\\\": {\\\"<%cluster%>\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"$.data.multiconfig.select($.cluster)\\\", \\\"data\\\": {\\\"multiconfig\\\": {\\\"get_param\\\": \\\"CephExternalMultiConfig\\\"}}}}}}}]}}, \\\"cinder_volume_host_prep_and_system_upgrade_post_tasks\\\": {\\\"description\\\": \\\"Common host_prep and system_upgrade post tasks for cinder-volume\\\", \\\"value\\\": [{\\\"name\\\": \\\"Support using an NFS share for cinder image conversion\\\", \\\"vars\\\": {\\\"image_conversion_nfs_enabled\\\": {\\\"if\\\": [\\\"cinder_nfs_conversion_dir_enabled\\\", true, false]}}, \\\"when\\\": [\\\"image_conversion_nfs_enabled|bool\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Create cinder image conversion directory\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/cinder_image_conversion\\\", \\\"state\\\": \\\"directory\\\"}}, {\\\"name\\\": \\\"Mount cinder\'s image conversion NFS share\\\", \\\"vars\\\": {\\\"image_conversion_nfs_share\\\": {\\\"get_param\\\": \\\"CinderImageConversionNfsShare\\\"}, \\\"image_conversion_nfs_options\\\": {\\\"get_param\\\": \\\"CinderImageConversionNfsOptions\\\"}}, \\\"mount\\\": {\\\"path\\\": \\\"/var/lib/cinder_image_conversion\\\", \\\"state\\\": \\\"mounted\\\", \\\"fstype\\\": \\\"nfs4\\\", \\\"src\\\": \\\"{{ image_conversion_nfs_share }}\\\", \\\"opts\\\": \\\"{{ image_conversion_nfs_options }}\\\"}}]}]}, \\\"cinder_volume_host_prep_tasks\\\": {\\\"description\\\": \\\"Host prep tasks for the cinder-volume service (HA or non-HA)\\\", \\\"value\\\": {\\\"list_concat\\\": [{\\\"list_concat\\\": [[{\\\"name\\\": \\\"create fcontext entry for cinder data\\\", \\\"community.general.sefcontext\\\": {\\\"target\\\": \\\"/var/lib/cinder(/.*)?\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"state\\\": \\\"present\\\"}}, {\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode|default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/cinder\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/lib/cinder\\\", \\\"setype\\\": \\\"container_file_t\\\"}]}, {\\\"name\\\": \\\"ensure ceph configurations exist\\\", \\\"file\\\": {\\\"path\\\": {\\\"get_param\\\": \\\"CephConfigPath\\\"}, \\\"state\\\": \\\"directory\\\"}}], {\\\"get_attr\\\": [\\\"CinderNVMeOF\\\", \\\"cinder_nvmeof_host_prep_tasks\\\"]}]}, [{\\\"name\\\": \\\"Support using an NFS share for cinder image conversion\\\", \\\"vars\\\": {\\\"image_conversion_nfs_enabled\\\": {\\\"if\\\": [\\\"cinder_nfs_conversion_dir_enabled\\\", true, false]}}, \\\"when\\\": [\\\"image_conversion_nfs_enabled|bool\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Create cinder image conversion directory\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/cinder_image_conversion\\\", \\\"state\\\": \\\"directory\\\"}}, {\\\"name\\\": \\\"Mount cinder\'s image conversion NFS share\\\", \\\"vars\\\": {\\\"image_conversion_nfs_share\\\": {\\\"get_param\\\": \\\"CinderImageConversionNfsShare\\\"}, \\\"image_conversion_nfs_options\\\": {\\\"get_param\\\": \\\"CinderImageConversionNfsOptions\\\"}}, \\\"mount\\\": {\\\"path\\\": \\\"/var/lib/cinder_image_conversion\\\", \\\"state\\\": \\\"mounted\\\", \\\"fstype\\\": \\\"nfs4\\\", \\\"src\\\": \\\"{{ image_conversion_nfs_share }}\\\", \\\"opts\\\": \\\"{{ image_conversion_nfs_options }}\\\"}}]}], [{\\\"name\\\": \\\"cinder_configure_lvm fact\\\", \\\"set_fact\\\": {\\\"cinder_configure_lvm\\\": {\\\"if\\\": [\\\"cinder_configure_lvm\\\", true, false]}}}, {\\\"when\\\": \\\"cinder_configure_lvm|bool\\\", \\\"block\\\": [{\\\"name\\\": \\\"ensure LVM rpm dependencies are installed\\\", \\\"package\\\": {\\\"name\\\": \\\"lvm2\\\", \\\"state\\\": \\\"latest\\\"}}, {\\\"name\\\": \\\"cinder create LVM volume group dd\\\", \\\"command\\\": {\\\"list_join\\\": [\\\"\\\", [\\\"dd if=/dev/zero of=/var/lib/cinder/cinder-volumes bs=1 count=0 seek=\\\", {\\\"str_replace\\\": {\\\"template\\\": \\\"VALUE\\\", \\\"params\\\": {\\\"VALUE\\\": {\\\"get_param\\\": \\\"CinderLVMLoopDeviceSize\\\"}}}}, \\\"M\\\"]]}, \\\"args\\\": {\\\"creates\\\": \\\"/var/lib/cinder/cinder-volumes\\\"}}, {\\\"name\\\": \\\"Get or create LVM loopback device\\\", \\\"shell\\\": \\\"exit_code=0\\\\nexisting_device=$(losetup -j /var/lib/cinder/cinder-volumes -l -n -O NAME)\\\\nif [[ -z \\\\\\\"${existing_device}\\\\\\\" ]]; then\\\\n    losetup -f /var/lib/cinder/cinder-volumes --show\\\\n    exit_code=2\\\\nelse\\\\n    echo ${existing_device%$\'\\\\\\\\n\'*}\\\\nfi\\\\nexit ${exit_code}\\\", \\\"args\\\": {\\\"executable\\\": \\\"/bin/bash\\\"}, \\\"register\\\": \\\"_loopback_device\\\", \\\"changed_when\\\": \\\"_loopback_device.rc == 2\\\", \\\"failed_when\\\": \\\"_loopback_device.rc not in [0,2]\\\"}, {\\\"name\\\": \\\"Create LVM volume group\\\", \\\"community.general.lvg\\\": {\\\"vg\\\": \\\"cinder-volumes\\\", \\\"pvs\\\": \\\"{{ _loopback_device.stdout }}\\\", \\\"state\\\": \\\"present\\\"}, \\\"when\\\": [\\\"not (ansible_check_mode | bool)\\\"]}, {\\\"name\\\": \\\"cinder create service to run losetup for LVM on startup\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/cinder-lvm-losetup.service\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Cinder LVM losetup\\\\nDefaultDependencies=no\\\\nConflicts=umount.target\\\\nRequires=lvm2-monitor.service systemd-udev-settle.service\\\\nBefore=local-fs.target umount.target\\\\nAfter=var.mount lvm2-monitor.service systemd-udev-settle.service\\\\n\\\\n[Service]\\\\nType=oneshot\\\\nExecStart=/sbin/losetup {{ _loopback_device.stdout }} /var/lib/cinder/cinder-volumes\\\\nExecStop=/sbin/losetup -d {{ _loopback_device.stdout }}\\\\nRemainAfterExit=yes\\\\n\\\\n[Install]\\\\nWantedBy=local-fs-pre.target\\\\n\\\"}, \\\"when\\\": [\\\"not (ansible_check_mode | bool)\\\"]}, {\\\"name\\\": \\\"cinder enable the LVM losetup service\\\", \\\"systemd\\\": {\\\"name\\\": \\\"cinder-lvm-losetup\\\", \\\"enabled\\\": true, \\\"daemon_reload\\\": true}}]}]]}}, \\\"cinder_volume_upgrade_tasks\\\": {\\\"description\\\": \\\"Upgrade tasks for the cinder-volume service (HA or non-HA)\\\", \\\"value\\\": [{\\\"name\\\": \\\"cinder-volume pre system_upgrade tasks\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_run\\\", \\\"system_upgrade_nfsmounts\\\"], \\\"when\\\": [\\\"step|int == 3\\\", \\\"upgrade_leapp_enabled\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Unmount cinder\'s image conversion NFS share\\\", \\\"vars\\\": {\\\"image_conversion_nfs_share\\\": {\\\"get_param\\\": \\\"CinderImageConversionNfsShare\\\"}, \\\"image_conversion_nfs_options\\\": {\\\"get_param\\\": \\\"CinderImageConversionNfsOptions\\\"}, \\\"image_conversion_nfs_enabled\\\": {\\\"if\\\": [\\\"cinder_nfs_conversion_dir_enabled\\\", true, false]}}, \\\"when\\\": \\\"image_conversion_nfs_enabled|bool\\\", \\\"mount\\\": {\\\"path\\\": \\\"/var/lib/cinder_image_conversion\\\", \\\"state\\\": \\\"absent\\\", \\\"fstype\\\": \\\"nfs4\\\"}}]}, {\\\"name\\\": \\\"cinder-volume post system_upgrade tasks\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_run\\\", \\\"system_upgrade_nfsmounts\\\"], \\\"when\\\": [\\\"step|int == 5\\\", \\\"upgrade_leapp_enabled\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Support using an NFS share for cinder image conversion\\\", \\\"vars\\\": {\\\"image_conversion_nfs_enabled\\\": {\\\"if\\\": [\\\"cinder_nfs_conversion_dir_enabled\\\", true, false]}}, \\\"when\\\": [\\\"image_conversion_nfs_enabled|bool\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Create cinder image conversion directory\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/cinder_image_conversion\\\", \\\"state\\\": \\\"directory\\\"}}, {\\\"name\\\": \\\"Mount cinder\'s image conversion NFS share\\\", \\\"vars\\\": {\\\"image_conversion_nfs_share\\\": {\\\"get_param\\\": \\\"CinderImageConversionNfsShare\\\"}, \\\"image_conversion_nfs_options\\\": {\\\"get_param\\\": \\\"CinderImageConversionNfsOptions\\\"}}, \\\"mount\\\": {\\\"path\\\": \\\"/var/lib/cinder_image_conversion\\\", \\\"state\\\": \\\"mounted\\\", \\\"fstype\\\": \\\"nfs4\\\", \\\"src\\\": \\\"{{ image_conversion_nfs_share }}\\\", \\\"opts\\\": \\\"{{ image_conversion_nfs_options }}\\\"}}]}]}]}, \\\"cinder_volume_config_settings\\\": {\\\"description\\\": \\\"Config settings for the cinder-volume container (HA or non-HA)\\\", \\\"value\\\": {\\\"if\\\": [\\\"cinder_nfs_conversion_dir_enabled\\\", {\\\"cinder::image_conversion_dir\\\": \\\"/var/lib/cinder_image_conversion\\\"}, {}]}}, \\\"cinder_volume_volumes\\\": {\\\"description\\\": \\\"Volumes for the cinder-volume container (HA or non-HA)\\\", \\\"value\\\": {\\\"list_concat\\\": [{\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/log/containers/cinder:/var/log/cinder:z\\\"], {\\\"if\\\": [\\\"cvol_active_active_tls_enabled\\\", [\\\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\\\", \\\"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\\\"]]}]}, {\\\"get_attr\\\": [\\\"CinderNVMeOF\\\", \\\"cinder_nvmeof_volumes\\\"]}, {\\\"get_param\\\": \\\"CinderVolumeOptVolumes\\\"}, [\\\"/var/lib/kolla/config_files/cinder_volume.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\\\", {\\\"list_join\\\": [\\\":\\\", [{\\\"get_param\\\": \\\"CephConfigPath\\\"}], [\\\"/var/lib/kolla/config_files/src-ceph\\\"], [\\\"z\\\"]]}, \\\"/lib/modules:/lib/modules:ro\\\", \\\"/dev:/dev\\\", \\\"/run:/run\\\", \\\"/sys:/sys\\\", \\\"/var/lib/cinder:/var/lib/cinder:z\\\", \\\"/var/lib/iscsi:/var/lib/iscsi:z\\\"], {\\\"if\\\": [{\\\"get_param\\\": \\\"CinderEnableIscsiBackend\\\"}, [\\\"/etc/target:/etc/target:z\\\"]]}, {\\\"if\\\": [{\\\"get_param\\\": \\\"MultipathdEnable\\\"}, [\\\"/etc/multipath:/etc/multipath:z\\\", \\\"/etc/multipath.conf:/etc/multipath.conf:ro\\\"]]}, {\\\"if\\\": [\\\"cinder_nfs_conversion_dir_enabled\\\", [{\\\"str_replace\\\": {\\\"template\\\": \\\"DIR:DIR:slave\\\", \\\"params\\\": {\\\"DIR\\\": \\\"/var/lib/cinder_image_conversion\\\"}}}]]}]}}, \\\"cinder_volume_environment\\\": {\\\"description\\\": \\\"Docker environment for the cinder-volume container (HA or non-HA)\\\", \\\"value\\\": {\\\"map_merge\\\": [{\\\"get_param\\\": \\\"CinderVolumeOptEnvVars\\\"}, {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}]}}, \\\"cinder_backup_host_prep_tasks\\\": {\\\"description\\\": \\\"Host prep tasks for the cinder-backup service (HA or non-HA)\\\", \\\"value\\\": {\\\"list_concat\\\": [[{\\\"name\\\": \\\"create fcontext entry for cinder data\\\", \\\"community.general.sefcontext\\\": {\\\"target\\\": \\\"/var/lib/cinder(/.*)?\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"state\\\": \\\"present\\\"}}, {\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode|default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/cinder\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/lib/cinder\\\", \\\"setype\\\": \\\"container_file_t\\\"}]}, {\\\"name\\\": \\\"ensure ceph configurations exist\\\", \\\"file\\\": {\\\"path\\\": {\\\"get_param\\\": \\\"CephConfigPath\\\"}, \\\"state\\\": \\\"directory\\\"}}], {\\\"get_attr\\\": [\\\"CinderNVMeOF\\\", \\\"cinder_nvmeof_host_prep_tasks\\\"]}]}}, \\\"cinder_backup_volumes\\\": {\\\"description\\\": \\\"Volumes for the cinder-backup container (HA or non-HA)\\\", \\\"value\\\": {\\\"list_concat\\\": [{\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"volumes\\\"]}, [\\\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/log/containers/cinder:/var/log/cinder:z\\\"], {\\\"if\\\": [\\\"cvol_active_active_tls_enabled\\\", [\\\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\\\", \\\"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\\\"]]}]}, {\\\"get_attr\\\": [\\\"CinderNVMeOF\\\", \\\"cinder_nvmeof_volumes\\\"]}, {\\\"get_param\\\": \\\"CinderBackupOptVolumes\\\"}, [\\\"/var/lib/kolla/config_files/cinder_backup.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\\\", {\\\"list_join\\\": [\\\":\\\", [{\\\"get_param\\\": \\\"CephConfigPath\\\"}], [\\\"/var/lib/kolla/config_files/src-ceph\\\"], [\\\"z\\\"]]}, \\\"/dev:/dev\\\", \\\"/run:/run\\\", \\\"/sys:/sys\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/var/lib/cinder:/var/lib/cinder:z\\\", \\\"/var/lib/iscsi:/var/lib/iscsi:z\\\"], {\\\"if\\\": [{\\\"get_param\\\": \\\"MultipathdEnable\\\"}, [\\\"/etc/multipath:/etc/multipath:z\\\", \\\"/etc/multipath.conf:/etc/multipath.conf:ro\\\"]]}]}}, \\\"cinder_backup_environment\\\": {\\\"description\\\": \\\"Docker environment for the cinder-backup container (HA or non-HA)\\\", \\\"value\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}\", \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Cinder Backup service\\\\n\\\", \\\"parameters\\\": {\\\"ContainerCinderBackupImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerCinderConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the cinder config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"CephClusterName\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"ceph\\\", \\\"description\\\": \\\"The Ceph cluster name.\\\", \\\"constraints\\\": [{\\\"allowed_pattern\\\": \\\"[a-zA-Z0-9]+\\\", \\\"description\\\": \\\"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\\\n\\\"}]}, \\\"CephClientUserName\\\": {\\\"default\\\": \\\"openstack\\\", \\\"type\\\": \\\"string\\\"}, \\\"DockerCinderBackupLoggingSource\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {\\\"tag\\\": \\\"openstack.cinder.backup\\\", \\\"file\\\": \\\"/var/log/containers/cinder/cinder-backup.log\\\"}}, \\\"CinderBackupBackend\\\": {\\\"default\\\": \\\"swift\\\", \\\"description\\\": \\\"The short name of the Cinder Backup backend to use.\\\", \\\"type\\\": \\\"string\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"swift\\\", \\\"ceph\\\", \\\"nfs\\\", \\\"gcs\\\", \\\"s3\\\"]}]}, \\\"CinderBackupWorkers\\\": {\\\"type\\\": \\\"number\\\", \\\"default\\\": 1, \\\"description\\\": \\\"The number of cinder-backup processes to launch.\\\"}, \\\"CinderBackupMaxOperations\\\": {\\\"type\\\": \\\"number\\\", \\\"default\\\": 15, \\\"description\\\": \\\"The maximum number of concurrent cinder backup/restore operations (0 means unlimited).\\\"}, \\\"CinderBackupCompressionAlgorithm\\\": {\\\"default\\\": \\\"zlib\\\", \\\"description\\\": \\\"The compression algorithm used by Cinder Backup backends that are based on Cinder\'s \\\\\\\"chunked\\\\\\\" backup driver. This includes the swift, nfs, gcs and s3 backends. The ceph backend does not support the feature.\\\", \\\"type\\\": \\\"string\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"none\\\", \\\"zlib\\\", \\\"bzip2\\\", \\\"zstd\\\"]}]}, \\\"CinderBackupRbdClusterName\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The Ceph cluster where backups are to be stored. If no value is specified then the CephClusterName value is used.\\\"}, \\\"CinderBackupRbdClientUserName\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"The Ceph client name used by the backup service. If no value is specified then the CephClientUserName value is used.\\\"}, \\\"CinderBackupRbdPoolName\\\": {\\\"default\\\": \\\"backups\\\", \\\"type\\\": \\\"string\\\"}, \\\"CinderBackupNfsShare\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"NFS share to be mounted\\\", \\\"type\\\": \\\"string\\\"}, \\\"CinderBackupNfsMountOptions\\\": {\\\"default\\\": \\\"context=system_u:object_r:container_file_t:s0\\\", \\\"description\\\": \\\"Mount options passed to the NFS client. See NFS man page for details.\\\", \\\"type\\\": \\\"string\\\"}, \\\"CinderBackupGcsCredentials\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"The GCS service account credentials, in JSON format.\\\", \\\"type\\\": \\\"json\\\"}, \\\"CinderBackupGcsProjectId\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The GCS project ID.\\\", \\\"type\\\": \\\"string\\\"}, \\\"CinderBackupGcsBucket\\\": {\\\"default\\\": \\\"volumebackups\\\", \\\"description\\\": \\\"The GCS bucket where backups are to be stored.\\\", \\\"type\\\": \\\"string\\\"}, \\\"CinderBackupGcsBucketLocation\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"If set, it specifies the location where the GCS bucket should be created.\\\", \\\"type\\\": \\\"string\\\"}, \\\"CinderBackupS3EndpointUrl\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The URL where the S3 server is listening.\\\", \\\"type\\\": \\\"string\\\"}, \\\"CinderBackupS3AccessKey\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The S3 query token access key.\\\", \\\"type\\\": \\\"string\\\"}, \\\"CinderBackupS3SecretKey\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The S3 query token secret key.\\\", \\\"type\\\": \\\"string\\\"}, \\\"CinderBackupS3Bucket\\\": {\\\"default\\\": \\\"volumebackups\\\", \\\"description\\\": \\\"The S3 bucket where backups are to be stored.\\\", \\\"type\\\": \\\"string\\\"}, \\\"MonitoringSubscriptionCinderBackup\\\": {\\\"default\\\": \\\"overcloud-cinder-backup\\\", \\\"type\\\": \\\"string\\\"}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"MySQLClient\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-client.yaml\\\"}, \\\"CinderBase\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-base.yaml\\\", \\\"properties\\\": {\\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"CinderCommon\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\\\"}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerCinderBackupImage\\\": \\\"ContainerCinderBackupImage\\\", \\\"ContainerCinderConfigImage\\\": \\\"ContainerCinderConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerCinderBackupImage\\\": {\\\"get_param\\\": \\\"ContainerCinderBackupImage\\\"}, \\\"ContainerCinderConfigImage\\\": {\\\"get_param\\\": \\\"ContainerCinderConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Cinder Backup role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"cinder_backup\\\", \\\"monitoring_subscription\\\": {\\\"get_param\\\": \\\"MonitoringSubscriptionCinderBackup\\\"}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"CinderBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"cinder::backup::backup_workers\\\": {\\\"get_param\\\": \\\"CinderBackupWorkers\\\"}, \\\"cinder::backup::backup_max_operations\\\": {\\\"get_param\\\": \\\"CinderBackupMaxOperations\\\"}}, {\\\"if\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"CinderBackupBackend\\\"}, \\\"ceph\\\"]}, {\\\"cinder::backup::ceph::backup_ceph_user\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"USERNAME\\\", \\\"params\\\": {\\\"USERNAME\\\": {\\\"if\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"CinderBackupRbdClientUserName\\\"}, \\\"\\\"]}, {\\\"get_param\\\": \\\"CephClientUserName\\\"}, {\\\"get_param\\\": \\\"CinderBackupRbdClientUserName\\\"}]}}}}, \\\"cinder::backup::ceph::backup_ceph_pool\\\": {\\\"get_param\\\": \\\"CinderBackupRbdPoolName\\\"}, \\\"cinder::backup::ceph::backup_ceph_conf\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"/etc/ceph/CLUSTER.conf\\\", \\\"params\\\": {\\\"CLUSTER\\\": {\\\"if\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"CinderBackupRbdClusterName\\\"}, \\\"\\\"]}, {\\\"get_param\\\": \\\"CephClusterName\\\"}, {\\\"get_param\\\": \\\"CinderBackupRbdClusterName\\\"}]}}}}}]}, {\\\"if\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"CinderBackupBackend\\\"}, \\\"swift\\\"]}, {\\\"cinder::backup::swift::backup_swift_container\\\": \\\"volumebackups\\\", \\\"cinder::backup::swift::backup_compression_algorithm\\\": {\\\"get_param\\\": \\\"CinderBackupCompressionAlgorithm\\\"}, \\\"cinder::backup::swift::swift_catalog_info\\\": \\\"object-store:swift:internalURL\\\"}]}, {\\\"if\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"CinderBackupBackend\\\"}, \\\"nfs\\\"]}, {\\\"cinder::backup::nfs::backup_share\\\": {\\\"get_param\\\": \\\"CinderBackupNfsShare\\\"}, \\\"cinder::backup::nfs::backup_mount_options\\\": {\\\"get_param\\\": \\\"CinderBackupNfsMountOptions\\\"}, \\\"cinder::backup::nfs::backup_compression_algorithm\\\": {\\\"get_param\\\": \\\"CinderBackupCompressionAlgorithm\\\"}}]}, {\\\"if\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"CinderBackupBackend\\\"}, \\\"gcs\\\"]}, {\\\"tripleo::profile::base::cinder::backup::gcs::credentials\\\": {\\\"get_param\\\": \\\"CinderBackupGcsCredentials\\\"}, \\\"cinder::backup::google::backup_gcs_project_id\\\": {\\\"get_param\\\": \\\"CinderBackupGcsProjectId\\\"}, \\\"cinder::backup::google::backup_gcs_bucket\\\": {\\\"get_param\\\": \\\"CinderBackupGcsBucket\\\"}, \\\"cinder::backup::google::backup_gcs_bucket_location\\\": {\\\"get_param\\\": \\\"CinderBackupGcsBucketLocation\\\"}, \\\"cinder::config::cinder_config\\\": {\\\"DEFAULT/backup_compression_algorithm\\\": {\\\"value\\\": {\\\"get_param\\\": \\\"CinderBackupCompressionAlgorithm\\\"}}}}]}, {\\\"if\\\": [{\\\"equals\\\": [{\\\"get_param\\\": \\\"CinderBackupBackend\\\"}, \\\"s3\\\"]}, {\\\"cinder::backup::s3::backup_s3_endpoint_url\\\": {\\\"get_param\\\": \\\"CinderBackupS3EndpointUrl\\\"}, \\\"cinder::backup::s3::backup_s3_store_access_key\\\": {\\\"get_param\\\": \\\"CinderBackupS3AccessKey\\\"}, \\\"cinder::backup::s3::backup_s3_store_secret_key\\\": {\\\"get_param\\\": \\\"CinderBackupS3SecretKey\\\"}, \\\"cinder::backup::s3::backup_s3_store_bucket\\\": {\\\"get_param\\\": \\\"CinderBackupS3Bucket\\\"}, \\\"cinder::backup::s3::backup_compression_algorithm\\\": {\\\"get_param\\\": \\\"CinderBackupCompressionAlgorithm\\\"}}]}]}, \\\"service_config_settings\\\": {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_cinder_backup\\\": [{\\\"get_param\\\": \\\"DockerCinderBackupLoggingSource\\\"}]}}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"cinder\\\", \\\"puppet_tags\\\": \\\"cinder_config,file,concat,file_line\\\", \\\"step_config\\\": {\\\"list_join\\\": [\\\"\\\\n\\\", [{\\\"get_attr\\\": [\\\"CinderBase\\\", \\\"role_data\\\", \\\"step_config\\\"]}, {\\\"str_replace\\\": {\\\"template\\\": \\\"include tripleo::profile::base::cinder::backup::DRIVER\\\", \\\"params\\\": {\\\"DRIVER\\\": {\\\"get_param\\\": \\\"CinderBackupBackend\\\"}}}}, {\\\"get_attr\\\": [\\\"MySQLClient\\\", \\\"role_data\\\", \\\"step_config\\\"]}]]}, \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/cinder_backup.json\\\": {\\\"command\\\": \\\"/usr/bin/cinder-backup --config-file /usr/share/cinder/cinder-dist.conf --config-file /etc/cinder/cinder.conf\\\", \\\"config_files\\\": {\\\"get_attr\\\": [\\\"CinderCommon\\\", \\\"cinder_common_kolla_config_files\\\"]}, \\\"permissions\\\": {\\\"get_attr\\\": [\\\"CinderCommon\\\", \\\"cinder_common_kolla_permissions\\\"]}}}, \\\"docker_config\\\": {\\\"step_3\\\": {\\\"cinder_backup_init_logs\\\": {\\\"start_order\\\": 0, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderBackupImage\\\"]}, \\\"net\\\": \\\"none\\\", \\\"privileged\\\": false, \\\"user\\\": \\\"root\\\", \\\"volumes\\\": [\\\"/var/log/containers/cinder:/var/log/cinder:z\\\"], \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R cinder:cinder /var/log/cinder\\\"]}}, \\\"step_4\\\": {\\\"cinder_backup\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderBackupImage\\\"]}, \\\"ipc\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"user\\\": \\\"root\\\", \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"healthcheck_rpc_port\\\"]}, \\\"volumes\\\": {\\\"get_attr\\\": [\\\"CinderCommon\\\", \\\"cinder_backup_volumes\\\"]}, \\\"environment\\\": {\\\"get_attr\\\": [\\\"CinderCommon\\\", \\\"cinder_backup_environment\\\"]}}}}, \\\"host_prep_tasks\\\": {\\\"list_concat\\\": [{\\\"get_attr\\\": [\\\"CinderCommon\\\", \\\"cinder_backup_host_prep_tasks\\\"]}, [{\\\"name\\\": \\\"enable virt_sandbox_use_netlink for healthcheck\\\", \\\"seboolean\\\": {\\\"name\\\": \\\"virt_sandbox_use_netlink\\\", \\\"persistent\\\": true, \\\"state\\\": true}, \\\"when\\\": [\\\"ansible_facts.selinux is defined\\\", \\\"ansible_facts.selinux.status == \\\\\\\"enabled\\\\\\\"\\\"]}]]}, \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Clean up when switching cinder-backup from pcmk to active-active\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"become\\\": true, \\\"block\\\": [{\\\"name\\\": \\\"Check if cinder-backup is running under pacemaker\\\", \\\"command\\\": \\\"pcs status\\\", \\\"register\\\": \\\"cinder_backup_pcs_status\\\", \\\"check_mode\\\": false, \\\"failed_when\\\": false, \\\"changed_when\\\": false}, {\\\"when\\\": [\\\"\\\\\\\"cinder-backup\\\\\\\" in cinder_backup_pcs_status.stdout\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Remove the openstack-cinder-backup pcs resource\\\", \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"openstack-cinder-backup\\\", \\\"state\\\": \\\"delete\\\"}, \\\"run_once\\\": true}, {\\\"name\\\": \\\"Identify the cinder-backup pcmklatest container image\\\", \\\"shell\\\": \\\"{{container_cli}} images | awk \'$1 ~ \\\\\\\"cinder-backup\\\\\\\" && $2 == \\\\\\\"pcmklatest\\\\\\\" {print $1\\\\\\\":\\\\\\\"$2}\'\\\", \\\"register\\\": \\\"cinder_backup_pcmklatest_image\\\", \\\"check_mode\\\": false, \\\"changed_when\\\": false}, {\\\"name\\\": \\\"Remove the cinder-backup pcmklatest container image\\\", \\\"command\\\": \\\"{{container_cli}} rmi {{cinder_backup_pcmklatest_image.stdout}}\\\", \\\"when\\\": [\\\"cinder_backup_pcmklatest_image.stdout|length > 0\\\"]}]}]}], \\\"external_upgrade_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade_transfer_data\\\", \\\"system_upgrade_stop_services\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Stop cinder backup container\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_stop\\\"}, \\\"vars\\\": {\\\"tripleo_containers_to_stop\\\": [\\\"cinder_backup\\\"], \\\"tripleo_delegate_to\\\": \\\"{{ groups[\'cinder_backup\'] | difference(groups[\'excluded_overcloud\']) }}\\\"}}]}]}}}}\", \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Cinder Backup service\\\\n\\\", \\\"parameters\\\": {\\\"ContainerCinderBackupImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerCinderConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the cinder config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ClusterCommonTag\\\": {\\\"default\\\": false, \\\"description\\\": \\\"When set to false, a pacemaker service is configured to use a floating tag for its container image name, e.g. \'REGISTRY/NAMESPACE/IMAGENAME:pcmklatest\'. When set to true, the service uses a floating prefix as well, e.g. \'cluster.common.tag/IMAGENAME:pcmklatest\'.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"ClusterFullTag\\\": {\\\"default\\\": true, \\\"description\\\": \\\"When set to true, the pacemaker service uses a fully constant tag for its container image name, e.g. \'cluster.common.tag/SERVICENAME:pcmklatest\'.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"CinderBackupBackend\\\": {\\\"default\\\": \\\"swift\\\", \\\"description\\\": \\\"The short name of the Cinder Backup backend to use.\\\", \\\"type\\\": \\\"string\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"swift\\\", \\\"ceph\\\", \\\"nfs\\\", \\\"gcs\\\", \\\"s3\\\"]}]}, \\\"CinderBackupRbdPoolName\\\": {\\\"default\\\": \\\"backups\\\", \\\"type\\\": \\\"string\\\"}, \\\"CephClientUserName\\\": {\\\"default\\\": \\\"openstack\\\", \\\"type\\\": \\\"string\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"ConfigDebug\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to run config management (e.g. Puppet) in debug mode.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"ContainerCli\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"podman\\\", \\\"description\\\": \\\"CLI tool used to manage containers.\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"docker\\\", \\\"podman\\\"]}]}, \\\"DeployIdentifier\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\\\n\\\"}, \\\"DockerCinderBackupLoggingSource\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {\\\"tag\\\": \\\"openstack.cinder.backup\\\", \\\"file\\\": \\\"/var/log/containers/cinder/cinder-backup.log\\\"}}, \\\"CephConfigPath\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"/var/lib/tripleo-config/ceph\\\", \\\"description\\\": \\\"The path where the Ceph Cluster config files are stored on the host.\\\\n\\\"}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"MySQLClient\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-client.yaml\\\"}, \\\"CinderBackupBase\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-container-puppet.yaml\\\", \\\"properties\\\": {\\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}, \\\"CinderBackupBackend\\\": {\\\"get_param\\\": \\\"CinderBackupBackend\\\"}, \\\"CinderBackupRbdPoolName\\\": {\\\"get_param\\\": \\\"CinderBackupRbdPoolName\\\"}, \\\"CephClientUserName\\\": {\\\"get_param\\\": \\\"CephClientUserName\\\"}}}, \\\"CinderCommon\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\\\"}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerCinderBackupImage\\\": \\\"ContainerCinderBackupImage\\\", \\\"ContainerCinderConfigImage\\\": \\\"ContainerCinderConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerCinderBackupImage\\\": {\\\"get_param\\\": \\\"ContainerCinderBackupImage\\\"}, \\\"ContainerCinderConfigImage\\\": {\\\"get_param\\\": \\\"ContainerCinderConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Cinder Backup role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"cinder_backup\\\", \\\"monitoring_subscription\\\": {\\\"get_attr\\\": [\\\"CinderBackupBase\\\", \\\"role_data\\\", \\\"monitoring_subscription\\\"]}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"CinderBackupBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"tripleo::profile::pacemaker::cinder::backup_bundle::cinder_backup_docker_image\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/cinder-backup:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderBackupImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderBackupImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"tripleo::profile::pacemaker::cinder::backup_bundle::docker_volumes\\\": {\\\"get_attr\\\": [\\\"CinderCommon\\\", \\\"cinder_backup_volumes\\\"]}, \\\"tripleo::profile::pacemaker::cinder::backup_bundle::docker_environment\\\": {\\\"get_attr\\\": [\\\"CinderCommon\\\", \\\"cinder_backup_environment\\\"]}, \\\"tripleo::profile::pacemaker::cinder::backup_bundle::container_backend\\\": {\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"tripleo::profile::pacemaker::cinder::backup_bundle::ceph_conf_path\\\": {\\\"get_param\\\": \\\"CephConfigPath\\\"}, \\\"cinder::backup::manage_service\\\": false, \\\"cinder::backup::enabled\\\": false}]}, \\\"service_config_settings\\\": {\\\"get_attr\\\": [\\\"CinderBackupBase\\\", \\\"role_data\\\", \\\"service_config_settings\\\"]}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"cinder\\\", \\\"puppet_tags\\\": \\\"cinder_config,file,concat,file_line\\\", \\\"step_config\\\": {\\\"list_join\\\": [\\\"\\\\n\\\", [{\\\"get_attr\\\": [\\\"CinderBackupBase\\\", \\\"role_data\\\", \\\"puppet_config\\\", \\\"step_config\\\"]}, \\\"include tripleo::profile::pacemaker::cinder::backup_bundle\\\"]]}, \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/cinder_backup.json\\\": {\\\"command\\\": \\\"/usr/bin/cinder-backup --config-file /usr/share/cinder/cinder-dist.conf --config-file /etc/cinder/cinder.conf\\\", \\\"config_files\\\": {\\\"get_attr\\\": [\\\"CinderCommon\\\", \\\"cinder_common_kolla_config_files\\\"]}, \\\"permissions\\\": {\\\"get_attr\\\": [\\\"CinderCommon\\\", \\\"cinder_common_kolla_permissions\\\"]}}}, \\\"container_config_scripts\\\": {\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"container_config_scripts\\\"]}, \\\"docker_config\\\": {\\\"step_3\\\": {\\\"cinder_backup_init_logs\\\": {\\\"start_order\\\": 0, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderBackupImage\\\"]}, \\\"net\\\": \\\"none\\\", \\\"privileged\\\": false, \\\"user\\\": \\\"root\\\", \\\"volumes\\\": [\\\"/var/log/containers/cinder:/var/log/cinder:z\\\"], \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R cinder:cinder /var/log/cinder\\\"]}}}, \\\"host_prep_tasks\\\": {\\\"get_attr\\\": [\\\"CinderCommon\\\", \\\"cinder_backup_host_prep_tasks\\\"]}, \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Cinder Backup tag container image for pacemaker\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_tag\\\"}, \\\"vars\\\": {\\\"container_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderBackupImage\\\"]}, \\\"container_image_latest\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/cinder-backup:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderBackupImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderBackupImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}}}, {\\\"name\\\": \\\"Cinder Backup HA Wrappers Step\\\", \\\"when\\\": \\\"step|int == 5\\\", \\\"block\\\": [{\\\"name\\\": \\\"Cinder backup puppet bundle\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_ha_wrapper\\\"}, \\\"vars\\\": {\\\"tripleo_ha_wrapper_service_name\\\": \\\"cinder_backup\\\", \\\"tripleo_ha_wrapper_resource_name\\\": \\\"openstack-cinder-backup\\\", \\\"tripleo_ha_wrapper_bundle_name\\\": \\\"openstack-cinder-backup\\\", \\\"tripleo_ha_wrapper_resource_state\\\": \\\"_ Started\\\", \\\"tripleo_ha_wrapper_puppet_config_volume\\\": \\\"cinder\\\", \\\"tripleo_ha_wrapper_puppet_execute\\\": \\\"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::cinder::backup_bundle\\\", \\\"tripleo_ha_wrapper_puppet_tags\\\": \\\"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\\\", \\\"tripleo_ha_wrapper_puppet_debug\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"tripleo_ha_wrapper_config_suffix\\\": \\\".cinder_backup_previous_run\\\"}}]}], \\\"external_update_tasks\\\": [{\\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": \\\"ha_image_update\\\", \\\"block\\\": [{\\\"block\\\": [{\\\"name\\\": \\\"Get cinder_backup image from pacemaker\\\", \\\"become\\\": true, \\\"register\\\": \\\"xmllint_pcmk_cinder_backup_image\\\", \\\"shell\\\": \\\"xmllint --xpath \\\\\\\"string(//bundle[@id=\'openstack-cinder-backup\']/podman/@image)\\\\\\\" /var/lib/pacemaker/cib/cib.xml\\\"}, {\\\"name\\\": \\\"Get container cinder_backup image\\\", \\\"set_fact\\\": {\\\"cinder_backup_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderBackupImage\\\"]}, \\\"cinder_backup_image_latest\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/cinder-backup:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderBackupImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderBackupImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"pcmk_cinder_backup_image\\\": \\\"{{xmllint_pcmk_cinder_backup_image.stdout}}\\\"}}], \\\"delegate_to\\\": \\\"{{ (groups[\\\\\\\"cinder_backup\\\\\\\"] | difference(groups[\\\\\\\"excluded_overcloud\\\\\\\"]))[0] }}\\\"}, {\\\"name\\\": \\\"cinder-backup temporary pacemaker container tag in case of image switch\\\", \\\"become\\\": true, \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_ha_image_update\\\"}, \\\"vars\\\": {\\\"tripleo_ha_image_update_node_names\\\": \\\"{{ groups[\\\\\\\"cinder_backup\\\\\\\"] | difference(groups[\\\\\\\"excluded_overcloud\\\\\\\"]) }}\\\", \\\"tripleo_ha_image_update_bundle\\\": \\\"openstack-cinder-backup\\\", \\\"tripleo_ha_image_update_new_image\\\": \\\"{{cinder_backup_image_latest}}\\\", \\\"tripleo_ha_image_update_old_image\\\": \\\"{{pcmk_cinder_backup_image}}\\\"}, \\\"when\\\": [\\\"(pcmk_cinder_backup_image != \\\\\\\"\\\\\\\")\\\", \\\"(pcmk_cinder_backup_image != cinder_backup_image_latest)\\\"]}]}], \\\"update_tasks\\\": [{\\\"block\\\": [{\\\"name\\\": \\\"Get cinder_backup image from pacemaker\\\", \\\"become\\\": true, \\\"register\\\": \\\"xmllint_pcmk_cinder_backup_image\\\", \\\"shell\\\": \\\"xmllint --xpath \\\\\\\"string(//bundle[@id=\'openstack-cinder-backup\']/podman/@image)\\\\\\\" /var/lib/pacemaker/cib/cib.xml\\\"}, {\\\"name\\\": \\\"Get container cinder_backup image\\\", \\\"set_fact\\\": {\\\"cinder_backup_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderBackupImage\\\"]}, \\\"cinder_backup_image_latest\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/cinder-backup:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderBackupImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderBackupImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"pcmk_cinder_backup_image\\\": \\\"{{xmllint_pcmk_cinder_backup_image.stdout}}\\\"}}], \\\"when\\\": \\\"(step|int == 0 or step|int == 2)\\\"}, {\\\"name\\\": \\\"Check for update of cinder-backup container image name\\\", \\\"when\\\": \\\"step|int == 0\\\", \\\"assert\\\": {\\\"that\\\": \\\"pcmk_cinder_backup_image == cinder_backup_image_latest\\\", \\\"fail_msg\\\": \\\"cinder-backup image change detected, run overcloud external-update --tags ha_image_update first\\\"}}, {\\\"name\\\": \\\"Tear-down non-HA cinder-backup container\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Remove non-HA cinder-backup container\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_rm\\\"}, \\\"vars\\\": {\\\"tripleo_container_cli\\\": \\\"{{ container_cli }}\\\", \\\"tripleo_containers_to_rm\\\": [\\\"cinder_backup\\\"]}}]}, {\\\"name\\\": \\\"cinder_backup fetch and retag container image for pacemaker\\\", \\\"when\\\": \\\"step|int == 2\\\", \\\"block\\\": [{\\\"name\\\": \\\"Retag pcmklatest to latest cinder_backup image\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_tag\\\"}, \\\"vars\\\": {\\\"container_image\\\": \\\"{{cinder_backup_image}}\\\", \\\"container_image_latest\\\": \\\"{{cinder_backup_image_latest}}\\\"}}]}], \\\"post_update_tasks\\\": [{\\\"name\\\": \\\"Cinder backup bundle post update\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Cinder backup puppet bundle\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_ha_wrapper\\\"}, \\\"vars\\\": {\\\"tripleo_ha_wrapper_service_name\\\": \\\"cinder_backup\\\", \\\"tripleo_ha_wrapper_resource_name\\\": \\\"openstack-cinder-backup\\\", \\\"tripleo_ha_wrapper_bundle_name\\\": \\\"openstack-cinder-backup\\\", \\\"tripleo_ha_wrapper_resource_state\\\": \\\"_ Started\\\", \\\"tripleo_ha_wrapper_puppet_config_volume\\\": \\\"cinder\\\", \\\"tripleo_ha_wrapper_puppet_execute\\\": \\\"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::cinder::backup_bundle\\\", \\\"tripleo_ha_wrapper_puppet_tags\\\": \\\"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\\\", \\\"tripleo_ha_wrapper_puppet_debug\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"tripleo_ha_wrapper_config_suffix\\\": \\\".cinder_backup_previous_run\\\"}}], \\\"vars\\\": {\\\"tripleo_ha_wrapper_minor_update\\\": true}}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"Tear-down non-HA cinder_backup container\\\", \\\"when\\\": [\\\"step|int == 0\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Remove non-HA cinder-backup container\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_rm\\\"}, \\\"vars\\\": {\\\"tripleo_container_cli\\\": \\\"{{ container_cli }}\\\", \\\"tripleo_containers_to_rm\\\": [\\\"cinder_backup\\\"]}}]}, {\\\"name\\\": \\\"Prepare switch of cinder_backup image name\\\", \\\"when\\\": [\\\"step|int == 0\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Get cinder_backup image id currently used by pacemaker\\\", \\\"shell\\\": \\\"pcs resource config openstack-cinder-backup | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\\\", \\\"register\\\": \\\"cinder_backup_image_current_res\\\", \\\"failed_when\\\": false}, {\\\"name\\\": \\\"cinder_backup image facts\\\", \\\"set_fact\\\": {\\\"cinder_backup_image_latest\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/cinder-backup:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderBackupImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderBackupImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"cinder_backup_image_current\\\": \\\"{{cinder_backup_image_current_res.stdout}}\\\"}}, {\\\"name\\\": \\\"Temporarily tag the current cinder_backup image id with the upgraded image name\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_tag\\\"}, \\\"vars\\\": {\\\"container_image\\\": \\\"{{cinder_backup_image_current}}\\\", \\\"container_image_latest\\\": \\\"{{cinder_backup_image_latest}}\\\", \\\"pull_image\\\": false}, \\\"when\\\": [\\\"cinder_backup_image_current != \'\'\\\", \\\"cinder_backup_image_current != cinder_backup_image_latest\\\"]}, {\\\"name\\\": \\\"Create cinder_backup retag statefile\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/tripleo/cinder_backup_needs_retag\\\", \\\"state\\\": \\\"touch\\\"}, \\\"when\\\": [\\\"cinder_backup_image_current != \'\'\\\", \\\"cinder_backup_image_current != cinder_backup_image_latest\\\"]}]}, {\\\"name\\\": \\\"Update cinder_backup pcs resource bundle for new container image - check\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"set is_cinder_backup_bootstrap_node fact\\\", \\\"tags\\\": \\\"common\\\", \\\"set_fact\\\": \\\"is_cinder_backup_bootstrap_node={{cinder_backup_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\\\"}, {\\\"name\\\": \\\"Check for cinder_backup retag statefile\\\", \\\"stat\\\": {\\\"path\\\": \\\"/var/lib/tripleo/cinder_backup_needs_retag\\\"}, \\\"register\\\": \\\"cinder_backup_retag_state_file\\\"}]}, {\\\"name\\\": \\\"Update cinder_backup pcs resource bundle for new container image\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"is_cinder_backup_bootstrap_node\\\", \\\"cinder_backup_retag_state_file.stat.exists|bool\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Disable the cinder_backup cluster resource before container upgrade step1\\\", \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"openstack-cinder-backup\\\", \\\"state\\\": \\\"disable\\\", \\\"wait_for_resource\\\": true}, \\\"register\\\": \\\"output\\\", \\\"retries\\\": 5, \\\"until\\\": \\\"output.rc == 0\\\"}, {\\\"name\\\": \\\"Update the cinder_backup bundle to use the new container image name\\\", \\\"command\\\": \\\"pcs resource bundle update openstack-cinder-backup container image={{cinder_backup_image_latest}}\\\"}, {\\\"name\\\": \\\"Enable the cinder_backup cluster resource\\\", \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"openstack-cinder-backup\\\", \\\"state\\\": \\\"enable\\\", \\\"wait_for_resource\\\": true}, \\\"register\\\": \\\"output\\\", \\\"retries\\\": 5, \\\"until\\\": \\\"output.rc == 0\\\"}]}, {\\\"name\\\": \\\"Check for cinder_backup retag statefile\\\", \\\"when\\\": [\\\"step|int == 3\\\"], \\\"stat\\\": {\\\"path\\\": \\\"/var/lib/tripleo/cinder_backup_needs_retag\\\"}, \\\"register\\\": \\\"cinder_backup_retag_state_file\\\"}, {\\\"name\\\": \\\"Retag the pacemaker image for cinder_backup\\\", \\\"when\\\": [\\\"step|int == 3\\\", \\\"cinder_backup_retag_state_file.stat.exists|bool\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Disable the cinder_backup cluster resource before container upgrade step3\\\", \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"openstack-cinder-backup\\\", \\\"state\\\": \\\"disable\\\", \\\"wait_for_resource\\\": true}, \\\"register\\\": \\\"output\\\", \\\"retries\\\": 5, \\\"until\\\": \\\"output.rc == 0\\\"}, {\\\"name\\\": \\\"Retag the pacemaker image if containerized\\\", \\\"block\\\": [{\\\"block\\\": [{\\\"name\\\": \\\"Get cinder_backup image from pacemaker\\\", \\\"become\\\": true, \\\"register\\\": \\\"xmllint_pcmk_cinder_backup_image\\\", \\\"shell\\\": \\\"xmllint --xpath \\\\\\\"string(//bundle[@id=\'openstack-cinder-backup\']/podman/@image)\\\\\\\" /var/lib/pacemaker/cib/cib.xml\\\"}, {\\\"name\\\": \\\"Get container cinder_backup image\\\", \\\"set_fact\\\": {\\\"cinder_backup_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderBackupImage\\\"]}, \\\"cinder_backup_image_latest\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/cinder-backup:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderBackupImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderBackupImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"pcmk_cinder_backup_image\\\": \\\"{{xmllint_pcmk_cinder_backup_image.stdout}}\\\"}}]}, {\\\"block\\\": [{\\\"name\\\": \\\"Retag pcmklatest to latest cinder_backup image\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_tag\\\"}, \\\"vars\\\": {\\\"container_image\\\": \\\"{{cinder_backup_image}}\\\", \\\"container_image_latest\\\": \\\"{{cinder_backup_image_latest}}\\\"}}]}]}, {\\\"name\\\": \\\"Enable the cinder_backup cluster resource\\\", \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"openstack-cinder-backup\\\", \\\"state\\\": \\\"enable\\\", \\\"wait_for_resource\\\": true}, \\\"register\\\": \\\"output\\\", \\\"retries\\\": 5, \\\"until\\\": \\\"output.rc == 0\\\"}, {\\\"name\\\": \\\"Remove cinder_backup retag statefile\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/tripleo/cinder_backup_needs_retag\\\", \\\"state\\\": \\\"absent\\\"}}]}]}}}}\", \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Cinder Volume service\\\\n\\\", \\\"parameters\\\": {\\\"ContainerCinderVolumeImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerCinderConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the cinder config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"DockerCinderVolumeUlimit\\\": {\\\"default\\\": [\\\"nofile=131072\\\"], \\\"description\\\": \\\"ulimit for Cinder Volume Container\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"CinderVolumeLoggingSource\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {\\\"tag\\\": \\\"openstack.cinder.volume\\\", \\\"file\\\": \\\"/var/log/containers/cinder/cinder-volume.log\\\"}}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"CephClientUserName\\\": {\\\"default\\\": \\\"openstack\\\", \\\"type\\\": \\\"string\\\"}, \\\"CephClusterName\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"ceph\\\", \\\"description\\\": \\\"The Ceph cluster name.\\\", \\\"constraints\\\": [{\\\"allowed_pattern\\\": \\\"[a-zA-Z0-9]+\\\", \\\"description\\\": \\\"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\\\n\\\"}]}, \\\"CinderVolumeCluster\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"CinderEnableNfsBackend\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to enable or not the NFS backend for Cinder\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"CinderEnableIscsiBackend\\\": {\\\"default\\\": true, \\\"description\\\": \\\"Whether to enable or not the Iscsi backend for Cinder\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"CinderEnableRbdBackend\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to enable or not the Rbd backend for Cinder\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"CinderISCSIAvailabilityZone\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The availability zone of the Iscsi Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"CinderISCSIHelper\\\": {\\\"default\\\": \\\"lioadm\\\", \\\"description\\\": \\\"The iSCSI helper to use with cinder.\\\", \\\"type\\\": \\\"string\\\"}, \\\"CinderISCSIProtocol\\\": {\\\"default\\\": \\\"iscsi\\\", \\\"description\\\": \\\"Whether to use TCP (\'iscsi\') or iSER RDMA (\'iser\') for iSCSI\\\", \\\"type\\\": \\\"string\\\"}, \\\"CinderNfsAvailabilityZone\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The availability zone of the NFS Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"CinderNfsMountOptions\\\": {\\\"default\\\": \\\"context=system_u:object_r:container_file_t:s0\\\", \\\"description\\\": \\\"Mount options for NFS mounts used by Cinder NFS backend. Effective when CinderEnableNfsBackend is true.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"CinderNfsServers\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"NFS servers used by Cinder NFS backend. Effective when CinderEnableNfsBackend is true.\\\\n\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"CinderNfsSnapshotSupport\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to enable support for snapshots in the NFS driver. Effective when CinderEnableNfsBackend is true.\\\\n\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"CinderNasSecureFileOperations\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Controls whether security enhanced NFS file operations are enabled. Valid values are \'auto\', \'true\' or \'false\'. Effective when CinderEnableNfsBackend is true.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"CinderNasSecureFilePermissions\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Controls whether security enhanced NFS file permissions are enabled. Valid values are \'auto\', \'true\' or \'false\'. Effective when CinderEnableNfsBackend is true.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"CinderRbdBackendName\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": \\\"tripleo_ceph\\\", \\\"description\\\": \\\"A list of Cinder RBD backend names.\\\"}, \\\"CinderRbdAvailabilityZone\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The availability zone of the RBD Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"CinderRbdPoolName\\\": {\\\"default\\\": \\\"volumes\\\", \\\"type\\\": \\\"string\\\"}, \\\"CinderRbdExtraPools\\\": {\\\"default\\\": [], \\\"description\\\": \\\"List of extra Ceph pools for use with RBD backends for Cinder. An extra Cinder RBD backend driver is created for each pool in the list. This is in addition to the standard RBD backend driver associated with the CinderRbdPoolName.\\\\n\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"CinderRbdFlattenVolumeFromSnapshot\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether RBD volumes created from a snapshot should be flattened in order to remove a dependency on the snapshot.\\\\n\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"CinderRbdMultiConfig\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {}, \\\"description\\\": \\\"Dictionary of settings when configuring multiple RBD backends. The\\\\nhash key is the backend name, and the value is a dictionary of parameter\\\\nvalues unique to that backend. The following parameters are required,\\\\nand must match the corresponding value defined in CephExternalMultiConfig.\\\\n  CephClusterName (must match the CephExternalMultiConfig entry\'s \'cluster\')\\\\n  CephClusterFSID (must match the CephExternalMultiConfig entry\'s \'fsid\')\\\\nThe following parameters are optional, and override the corresponding\\\\nparameter\'s default value.\\\\n  CephClientUserName\\\\n  CinderRbdPoolName\\\\n  CinderRbdExtraPools\\\\n  CinderRbdAvailabilityZone\\\\n  CinderRbdFlattenVolumeFromSnapshot\\\\n\\\"}, \\\"CephClusterFSID\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"The Ceph cluster FSID. Must be a UUID.\\\"}, \\\"MonitoringSubscriptionCinderVolume\\\": {\\\"default\\\": \\\"overcloud-cinder-volume\\\", \\\"type\\\": \\\"string\\\"}, \\\"CinderEtcdLocalConnect\\\": {\\\"default\\\": false, \\\"type\\\": \\\"boolean\\\", \\\"description\\\": \\\"When running Cinder A/A, whether to connect to Etcd via the local IP for the Etcd network. If set to true, the ip on the local node will be used. If set to false, the VIP on the Etcd network will be used instead. Defaults to false.\\\"}, \\\"EnableInternalTLS\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"EnableEtcdInternalTLS\\\": {\\\"description\\\": \\\"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\\\", \\\"type\\\": \\\"boolean\\\", \\\"default\\\": true}, \\\"CephConfigPath\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"/var/lib/tripleo-config/ceph\\\", \\\"description\\\": \\\"The path where the Ceph Cluster config files are stored on the host.\\\\n\\\"}}, \\\"conditions\\\": {\\\"cvol_active_active_tls_enabled\\\": {\\\"and\\\": [{\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"CinderVolumeCluster\\\"}, \\\"\\\"]}}, {\\\"get_param\\\": \\\"EnableInternalTLS\\\"}, {\\\"get_param\\\": \\\"EnableEtcdInternalTLS\\\"}]}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"MySQLClient\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-client.yaml\\\"}, \\\"CinderBase\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-base.yaml\\\", \\\"properties\\\": {\\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"CinderCommon\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\\\"}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerCinderVolumeImage\\\": \\\"ContainerCinderVolumeImage\\\", \\\"ContainerCinderConfigImage\\\": \\\"ContainerCinderConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerCinderVolumeImage\\\": {\\\"get_param\\\": \\\"ContainerCinderVolumeImage\\\"}, \\\"ContainerCinderConfigImage\\\": {\\\"get_param\\\": \\\"ContainerCinderConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Cinder Volume role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"cinder_volume\\\", \\\"firewall_rules\\\": {\\\"120 iscsi initiator\\\": {\\\"dport\\\": 3260}}, \\\"monitoring_subscription\\\": {\\\"get_param\\\": \\\"MonitoringSubscriptionCinderVolume\\\"}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"CinderBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"get_attr\\\": [\\\"CinderCommon\\\", \\\"cinder_volume_config_settings\\\"]}, {\\\"tripleo::profile::base::lvm::enable_udev\\\": false, \\\"tripleo::profile::base::cinder::volume::cinder_enable_iscsi_backend\\\": {\\\"get_param\\\": \\\"CinderEnableIscsiBackend\\\"}, \\\"tripleo::profile::base::cinder::volume::cinder_enable_nfs_backend\\\": {\\\"get_param\\\": \\\"CinderEnableNfsBackend\\\"}, \\\"tripleo::profile::base::cinder::volume::cinder_enable_rbd_backend\\\": {\\\"get_param\\\": \\\"CinderEnableRbdBackend\\\"}, \\\"tripleo::profile::base::cinder::volume::cinder_volume_cluster\\\": {\\\"get_param\\\": \\\"CinderVolumeCluster\\\"}, \\\"tripleo::profile::base::cinder::volume::nfs::cinder_nfs_mount_options\\\": {\\\"get_param\\\": \\\"CinderNfsMountOptions\\\"}, \\\"tripleo::profile::base::cinder::volume::nfs::cinder_nfs_servers\\\": {\\\"get_param\\\": \\\"CinderNfsServers\\\"}, \\\"tripleo::profile::base::cinder::volume::nfs::cinder_nfs_snapshot_support\\\": {\\\"get_param\\\": \\\"CinderNfsSnapshotSupport\\\"}, \\\"tripleo::profile::base::cinder::volume::nfs::cinder_nas_secure_file_operations\\\": {\\\"get_param\\\": \\\"CinderNasSecureFileOperations\\\"}, \\\"tripleo::profile::base::cinder::volume::nfs::cinder_nas_secure_file_permissions\\\": {\\\"get_param\\\": \\\"CinderNasSecureFilePermissions\\\"}, \\\"tripleo::profile::base::cinder::volume::iscsi::cinder_iscsi_helper\\\": {\\\"get_param\\\": \\\"CinderISCSIHelper\\\"}, \\\"tripleo::profile::base::cinder::volume::iscsi::cinder_iscsi_protocol\\\": {\\\"get_param\\\": \\\"CinderISCSIProtocol\\\"}, \\\"tripleo::profile::base::cinder::volume::rbd::backend_name\\\": {\\\"get_param\\\": \\\"CinderRbdBackendName\\\"}, \\\"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_ceph_conf\\\": {\\\"list_join\\\": [\\\"\\\", [\\\"/etc/ceph/\\\", {\\\"get_param\\\": \\\"CephClusterName\\\"}, \\\".conf\\\"]]}, \\\"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_pool_name\\\": {\\\"get_param\\\": \\\"CinderRbdPoolName\\\"}, \\\"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_extra_pools\\\": {\\\"get_param\\\": \\\"CinderRbdExtraPools\\\"}, \\\"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_secret_uuid\\\": {\\\"get_param\\\": \\\"CephClusterFSID\\\"}, \\\"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_user_name\\\": {\\\"get_param\\\": \\\"CephClientUserName\\\"}, \\\"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_flatten_volume_from_snapshot\\\": {\\\"get_param\\\": \\\"CinderRbdFlattenVolumeFromSnapshot\\\"}, \\\"tripleo::profile::base::cinder::volume::rbd::multi_config\\\": {\\\"get_param\\\": \\\"CinderRbdMultiConfig\\\"}, \\\"tripleo::profile::base::cinder::volume::iscsi::cinder_iscsi_address\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"CinderIscsiNetwork\\\"]}}}}}, {\\\"if\\\": [{\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"CinderISCSIAvailabilityZone\\\"}, \\\"\\\"]}}, {\\\"tripleo::profile::base::cinder::volume::iscsi::backend_availability_zone\\\": {\\\"get_param\\\": \\\"CinderISCSIAvailabilityZone\\\"}}]}, {\\\"if\\\": [{\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"CinderNfsAvailabilityZone\\\"}, \\\"\\\"]}}, {\\\"tripleo::profile::base::cinder::volume::nfs::backend_availability_zone\\\": {\\\"get_param\\\": \\\"CinderNfsAvailabilityZone\\\"}}]}, {\\\"if\\\": [{\\\"not\\\": {\\\"equals\\\": [{\\\"get_param\\\": \\\"CinderRbdAvailabilityZone\\\"}, \\\"\\\"]}}, {\\\"tripleo::profile::base::cinder::volume::rbd::backend_availability_zone\\\": {\\\"get_param\\\": \\\"CinderRbdAvailabilityZone\\\"}}]}, {\\\"if\\\": [{\\\"get_param\\\": \\\"CinderEtcdLocalConnect\\\"}, {\\\"tripleo::profile::base::cinder::volume::etcd_host\\\": {\\\"str_replace\\\": {\\\"template\\\": \\\"%{hiera(\'$NETWORK\')}\\\", \\\"params\\\": {\\\"$NETWORK\\\": {\\\"get_param\\\": [\\\"ServiceNetMap\\\", \\\"EtcdNetwork\\\"]}}}}}]}]}, \\\"service_config_settings\\\": {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_cinder_volume\\\": [{\\\"get_param\\\": \\\"CinderVolumeLoggingSource\\\"}]}}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"cinder\\\", \\\"puppet_tags\\\": \\\"cinder_config,file,concat,file_line\\\", \\\"step_config\\\": {\\\"list_join\\\": [\\\"\\\\n\\\", [\\\"include tripleo::profile::base::lvm\\\", \\\"include tripleo::profile::base::cinder::volume\\\", {\\\"get_attr\\\": [\\\"MySQLClient\\\", \\\"role_data\\\", \\\"step_config\\\"]}]]}, \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/cinder_volume.json\\\": {\\\"command\\\": \\\"/usr/bin/cinder-volume --config-file /usr/share/cinder/cinder-dist.conf --config-file /etc/cinder/cinder.conf\\\", \\\"config_files\\\": {\\\"get_attr\\\": [\\\"CinderCommon\\\", \\\"cinder_common_kolla_config_files\\\"]}, \\\"permissions\\\": {\\\"get_attr\\\": [\\\"CinderCommon\\\", \\\"cinder_common_kolla_permissions\\\"]}}}, \\\"docker_config\\\": {\\\"step_3\\\": {\\\"cinder_volume_init_logs\\\": {\\\"start_order\\\": 0, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderVolumeImage\\\"]}, \\\"net\\\": \\\"none\\\", \\\"privileged\\\": false, \\\"user\\\": \\\"root\\\", \\\"volumes\\\": [\\\"/var/log/containers/cinder:/var/log/cinder:z\\\"], \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R cinder:cinder /var/log/cinder\\\"]}}, \\\"step_4\\\": {\\\"cinder_volume\\\": {\\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderVolumeImage\\\"]}, \\\"ulimit\\\": {\\\"get_param\\\": \\\"DockerCinderVolumeUlimit\\\"}, \\\"ipc\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"healthcheck_rpc_port\\\"]}, \\\"volumes\\\": {\\\"get_attr\\\": [\\\"CinderCommon\\\", \\\"cinder_volume_volumes\\\"]}, \\\"environment\\\": {\\\"get_attr\\\": [\\\"CinderCommon\\\", \\\"cinder_volume_environment\\\"]}}}}, \\\"host_prep_tasks\\\": {\\\"get_attr\\\": [\\\"CinderCommon\\\", \\\"cinder_volume_host_prep_tasks\\\"]}, \\\"upgrade_tasks\\\": {\\\"get_attr\\\": [\\\"CinderCommon\\\", \\\"cinder_volume_upgrade_tasks\\\"]}, \\\"external_upgrade_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade_transfer_data\\\", \\\"system_upgrade_stop_services\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Stop cinder volume container\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_stop\\\"}, \\\"vars\\\": {\\\"tripleo_containers_to_stop\\\": [\\\"cinder_volume\\\"], \\\"tripleo_delegate_to\\\": \\\"{{ groups[\'cinder_volume\'] | difference(groups[\'excluded_overcloud\']) }}\\\"}}]}]}}}}\", \"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"OpenStack containerized Cinder Volume service\\\\n\\\", \\\"parameters\\\": {\\\"ContainerCinderVolumeImage\\\": {\\\"description\\\": \\\"image\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ContainerCinderConfigImage\\\": {\\\"description\\\": \\\"The container image to use for the cinder config_volume\\\", \\\"type\\\": \\\"string\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"ClusterCommonTag\\\": {\\\"default\\\": false, \\\"description\\\": \\\"When set to false, a pacemaker service is configured to use a floating tag for its container image name, e.g. \'REGISTRY/NAMESPACE/IMAGENAME:pcmklatest\'. When set to true, the service uses a floating prefix as well, e.g. \'cluster.common.tag/IMAGENAME:pcmklatest\'.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"ClusterFullTag\\\": {\\\"default\\\": true, \\\"description\\\": \\\"When set to true, the pacemaker service uses a fully constant tag for its container image name, e.g. \'cluster.common.tag/SERVICENAME:pcmklatest\'.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"EndpointMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceData\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Dictionary packing service data\\\", \\\"type\\\": \\\"json\\\"}, \\\"ServiceNetMap\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\\\", \\\"type\\\": \\\"json\\\"}, \\\"RoleName\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"Role name on which the service is applied\\\", \\\"type\\\": \\\"string\\\"}, \\\"RoleParameters\\\": {\\\"default\\\": {}, \\\"description\\\": \\\"Parameters specific to the role\\\", \\\"type\\\": \\\"json\\\"}, \\\"ConfigDebug\\\": {\\\"default\\\": false, \\\"description\\\": \\\"Whether to run config management (e.g. Puppet) in debug mode.\\\", \\\"type\\\": \\\"boolean\\\"}, \\\"ContainerCli\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"podman\\\", \\\"description\\\": \\\"CLI tool used to manage containers.\\\", \\\"constraints\\\": [{\\\"allowed_values\\\": [\\\"docker\\\", \\\"podman\\\"]}]}, \\\"DeployIdentifier\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\\\n\\\"}, \\\"CinderVolumeLoggingSource\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {\\\"tag\\\": \\\"openstack.cinder.volume\\\", \\\"file\\\": \\\"/var/log/containers/cinder/cinder-volume.log\\\"}}, \\\"CephConfigPath\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"/var/lib/tripleo-config/ceph\\\", \\\"description\\\": \\\"The path where the Ceph Cluster config files are stored on the host.\\\\n\\\"}}, \\\"resources\\\": {\\\"ContainersCommon\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/containers-common.yaml\\\"}, \\\"MySQLClient\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-client.yaml\\\"}, \\\"CinderBase\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\\\", \\\"properties\\\": {\\\"EndpointMap\\\": {\\\"get_param\\\": \\\"EndpointMap\\\"}, \\\"ServiceData\\\": {\\\"get_param\\\": \\\"ServiceData\\\"}, \\\"ServiceNetMap\\\": {\\\"get_param\\\": \\\"ServiceNetMap\\\"}, \\\"RoleName\\\": {\\\"get_param\\\": \\\"RoleName\\\"}, \\\"RoleParameters\\\": {\\\"get_param\\\": \\\"RoleParameters\\\"}}}, \\\"CinderCommon\\\": {\\\"type\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\\\"}, \\\"RoleParametersValue\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"type\\\": \\\"json\\\", \\\"value\\\": {\\\"map_replace\\\": [{\\\"map_replace\\\": [{\\\"ContainerCinderVolumeImage\\\": \\\"ContainerCinderVolumeImage\\\", \\\"ContainerCinderConfigImage\\\": \\\"ContainerCinderConfigImage\\\"}, {\\\"values\\\": {\\\"get_param\\\": [\\\"RoleParameters\\\"]}}]}, {\\\"values\\\": {\\\"ContainerCinderVolumeImage\\\": {\\\"get_param\\\": \\\"ContainerCinderVolumeImage\\\"}, \\\"ContainerCinderConfigImage\\\": {\\\"get_param\\\": \\\"ContainerCinderConfigImage\\\"}}}]}}}}, \\\"outputs\\\": {\\\"role_data\\\": {\\\"description\\\": \\\"Role data for the Cinder Volume role.\\\", \\\"value\\\": {\\\"service_name\\\": \\\"cinder_volume\\\", \\\"firewall_rules\\\": {\\\"get_attr\\\": [\\\"CinderBase\\\", \\\"role_data\\\", \\\"firewall_rules\\\"]}, \\\"monitoring_subscription\\\": {\\\"get_attr\\\": [\\\"CinderBase\\\", \\\"role_data\\\", \\\"monitoring_subscription\\\"]}, \\\"config_settings\\\": {\\\"map_merge\\\": [{\\\"get_attr\\\": [\\\"CinderBase\\\", \\\"role_data\\\", \\\"config_settings\\\"]}, {\\\"tripleo::profile::base::lvm::enable_udev\\\": false, \\\"tripleo::profile::pacemaker::cinder::volume_bundle::cinder_volume_docker_image\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/cinder-volume:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderVolumeImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderVolumeImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"tripleo::profile::pacemaker::cinder::volume_bundle::docker_volumes\\\": {\\\"get_attr\\\": [\\\"CinderCommon\\\", \\\"cinder_volume_volumes\\\"]}, \\\"tripleo::profile::pacemaker::cinder::volume_bundle::docker_environment\\\": {\\\"get_attr\\\": [\\\"CinderCommon\\\", \\\"cinder_volume_environment\\\"]}, \\\"tripleo::profile::pacemaker::cinder::volume_bundle::container_backend\\\": {\\\"get_param\\\": \\\"ContainerCli\\\"}, \\\"tripleo::profile::pacemaker::cinder::volume_bundle::ceph_conf_path\\\": {\\\"get_param\\\": \\\"CephConfigPath\\\"}, \\\"cinder::volume::manage_service\\\": false, \\\"cinder::volume::enabled\\\": false, \\\"cinder::backend_host\\\": \\\"hostgroup\\\"}]}, \\\"service_config_settings\\\": {\\\"get_attr\\\": [\\\"CinderBase\\\", \\\"role_data\\\", \\\"service_config_settings\\\"]}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"cinder\\\", \\\"puppet_tags\\\": \\\"cinder_config,file,concat,file_line\\\", \\\"step_config\\\": {\\\"list_join\\\": [\\\"\\\\n\\\", [\\\"include tripleo::profile::base::lvm\\\"], [\\\"include tripleo::profile::pacemaker::cinder::volume_bundle\\\", {\\\"get_attr\\\": [\\\"MySQLClient\\\", \\\"role_data\\\", \\\"step_config\\\"]}]]}, \\\"config_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderConfigImage\\\"]}}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/cinder_volume.json\\\": {\\\"command\\\": \\\"/usr/bin/cinder-volume --config-file /usr/share/cinder/cinder-dist.conf --config-file /etc/cinder/cinder.conf\\\", \\\"config_files\\\": {\\\"get_attr\\\": [\\\"CinderCommon\\\", \\\"cinder_common_kolla_config_files\\\"]}, \\\"permissions\\\": {\\\"get_attr\\\": [\\\"CinderCommon\\\", \\\"cinder_common_kolla_permissions\\\"]}}}, \\\"container_config_scripts\\\": {\\\"get_attr\\\": [\\\"ContainersCommon\\\", \\\"container_config_scripts\\\"]}, \\\"docker_config\\\": {\\\"step_3\\\": {\\\"cinder_volume_init_logs\\\": {\\\"start_order\\\": 0, \\\"image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderVolumeImage\\\"]}, \\\"net\\\": \\\"none\\\", \\\"privileged\\\": false, \\\"user\\\": \\\"root\\\", \\\"volumes\\\": [\\\"/var/log/containers/cinder:/var/log/cinder\\\"], \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R cinder:cinder /var/log/cinder\\\"]}}}, \\\"host_prep_tasks\\\": {\\\"get_attr\\\": [\\\"CinderCommon\\\", \\\"cinder_volume_host_prep_tasks\\\"]}, \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Cinder Volume tag container image for pacemaker\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_tag\\\"}, \\\"vars\\\": {\\\"container_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderVolumeImage\\\"]}, \\\"container_image_latest\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/cinder-volume:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderVolumeImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderVolumeImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}}}, {\\\"name\\\": \\\"Cinder Volume HA Wrappers Step\\\", \\\"when\\\": \\\"step|int == 5\\\", \\\"block\\\": [{\\\"name\\\": \\\"Cinder volume puppet bundle\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_ha_wrapper\\\"}, \\\"vars\\\": {\\\"tripleo_ha_wrapper_service_name\\\": \\\"cinder_volume\\\", \\\"tripleo_ha_wrapper_resource_name\\\": \\\"openstack-cinder-volume\\\", \\\"tripleo_ha_wrapper_bundle_name\\\": \\\"openstack-cinder-volume\\\", \\\"tripleo_ha_wrapper_resource_state\\\": \\\"_ Started\\\", \\\"tripleo_ha_wrapper_puppet_config_volume\\\": \\\"cinder\\\", \\\"tripleo_ha_wrapper_puppet_execute\\\": \\\"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::cinder::volume_bundle\\\", \\\"tripleo_ha_wrapper_puppet_tags\\\": \\\"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\\\", \\\"tripleo_ha_wrapper_puppet_debug\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"tripleo_ha_wrapper_config_suffix\\\": \\\".cinder_volume_previous_run\\\"}}]}], \\\"external_update_tasks\\\": [{\\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": \\\"ha_image_update\\\", \\\"block\\\": [{\\\"block\\\": [{\\\"name\\\": \\\"Get cinder_volume image from pacemaker\\\", \\\"become\\\": true, \\\"register\\\": \\\"xmllint_pcmk_cinder_volume_image\\\", \\\"shell\\\": \\\"xmllint --xpath \\\\\\\"string(//bundle[@id=\'openstack-cinder-volume\']/podman/@image)\\\\\\\" /var/lib/pacemaker/cib/cib.xml\\\"}, {\\\"name\\\": \\\"Get container cinder_volume image\\\", \\\"set_fact\\\": {\\\"cinder_volume_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderVolumeImage\\\"]}, \\\"cinder_volume_image_latest\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/cinder-volume:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderVolumeImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderVolumeImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"pcmk_cinder_volume_image\\\": \\\"{{xmllint_pcmk_cinder_volume_image.stdout}}\\\"}}], \\\"delegate_to\\\": \\\"{{ (groups[\\\\\\\"cinder_volume\\\\\\\"] | difference(groups[\\\\\\\"excluded_overcloud\\\\\\\"]))[0] }}\\\"}, {\\\"name\\\": \\\"cinder-volume temporary pacemaker container tag in case of image switch\\\", \\\"become\\\": true, \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_ha_image_update\\\"}, \\\"vars\\\": {\\\"tripleo_ha_image_update_node_names\\\": \\\"{{ groups[\\\\\\\"cinder_volume\\\\\\\"] | difference(groups[\\\\\\\"excluded_overcloud\\\\\\\"]) }}\\\", \\\"tripleo_ha_image_update_bundle\\\": \\\"openstack-cinder-volume\\\", \\\"tripleo_ha_image_update_new_image\\\": \\\"{{cinder_volume_image_latest}}\\\", \\\"tripleo_ha_image_update_old_image\\\": \\\"{{pcmk_cinder_volume_image}}\\\"}, \\\"when\\\": [\\\"(pcmk_cinder_volume_image != \\\\\\\"\\\\\\\")\\\", \\\"(pcmk_cinder_volume_image != cinder_volume_image_latest)\\\"]}]}], \\\"update_tasks\\\": [{\\\"block\\\": [{\\\"name\\\": \\\"Get cinder_volume image from pacemaker\\\", \\\"become\\\": true, \\\"register\\\": \\\"xmllint_pcmk_cinder_volume_image\\\", \\\"shell\\\": \\\"xmllint --xpath \\\\\\\"string(//bundle[@id=\'openstack-cinder-volume\']/podman/@image)\\\\\\\" /var/lib/pacemaker/cib/cib.xml\\\"}, {\\\"name\\\": \\\"Get container cinder_volume image\\\", \\\"set_fact\\\": {\\\"cinder_volume_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderVolumeImage\\\"]}, \\\"cinder_volume_image_latest\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/cinder-volume:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderVolumeImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderVolumeImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"pcmk_cinder_volume_image\\\": \\\"{{xmllint_pcmk_cinder_volume_image.stdout}}\\\"}}], \\\"when\\\": \\\"(step|int == 0 or step|int == 2)\\\"}, {\\\"name\\\": \\\"Check for update of cinder-volume container image name\\\", \\\"when\\\": \\\"step|int == 0\\\", \\\"assert\\\": {\\\"that\\\": \\\"pcmk_cinder_volume_image == cinder_volume_image_latest\\\", \\\"fail_msg\\\": \\\"cinder-volume image change detected, run overcloud external-update --tags ha_image_update first\\\"}}, {\\\"name\\\": \\\"Tear-down non-HA cinder_volume container\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Remove non-HA cinder_volume container\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_rm\\\"}, \\\"vars\\\": {\\\"tripleo_container_cli\\\": \\\"{{ container_cli }}\\\", \\\"tripleo_containers_to_rm\\\": [\\\"cinder_volume\\\"]}}]}, {\\\"name\\\": \\\"cinder_volume fetch and retag container image for pacemaker\\\", \\\"when\\\": \\\"step|int == 2\\\", \\\"block\\\": [{\\\"name\\\": \\\"Retag pcmklatest to latest cinder_volume image\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_tag\\\"}, \\\"vars\\\": {\\\"container_image\\\": \\\"{{cinder_volume_image}}\\\", \\\"container_image_latest\\\": \\\"{{cinder_volume_image_latest}}\\\"}}]}], \\\"post_update_tasks\\\": [{\\\"name\\\": \\\"Cinder volume bundle post update\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Cinder volume puppet bundle\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_ha_wrapper\\\"}, \\\"vars\\\": {\\\"tripleo_ha_wrapper_service_name\\\": \\\"cinder_volume\\\", \\\"tripleo_ha_wrapper_resource_name\\\": \\\"openstack-cinder-volume\\\", \\\"tripleo_ha_wrapper_bundle_name\\\": \\\"openstack-cinder-volume\\\", \\\"tripleo_ha_wrapper_resource_state\\\": \\\"_ Started\\\", \\\"tripleo_ha_wrapper_puppet_config_volume\\\": \\\"cinder\\\", \\\"tripleo_ha_wrapper_puppet_execute\\\": \\\"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::cinder::volume_bundle\\\", \\\"tripleo_ha_wrapper_puppet_tags\\\": \\\"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\\\", \\\"tripleo_ha_wrapper_puppet_debug\\\": {\\\"get_param\\\": \\\"ConfigDebug\\\"}, \\\"tripleo_ha_wrapper_config_suffix\\\": \\\".cinder_volume_previous_run\\\"}}], \\\"vars\\\": {\\\"tripleo_ha_wrapper_minor_update\\\": true}}], \\\"upgrade_tasks\\\": {\\\"list_concat\\\": [[{\\\"name\\\": \\\"Tear-down non-HA cinder_volume container\\\", \\\"when\\\": [\\\"step|int == 0\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Remove non-HA cinder_volume container\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_rm\\\"}, \\\"vars\\\": {\\\"tripleo_container_cli\\\": \\\"{{ container_cli }}\\\", \\\"tripleo_containers_to_rm\\\": [\\\"cinder_volume\\\"]}}]}, {\\\"name\\\": \\\"Prepare switch of cinder_volume image name\\\", \\\"when\\\": [\\\"step|int == 0\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Get cinder_volume image id currently used by pacemaker\\\", \\\"shell\\\": \\\"pcs resource config openstack-cinder-volume | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\\\", \\\"register\\\": \\\"cinder_volume_image_current_res\\\", \\\"failed_when\\\": false}, {\\\"name\\\": \\\"cinder_volume image facts\\\", \\\"set_fact\\\": {\\\"cinder_volume_image_latest\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/cinder-volume:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderVolumeImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderVolumeImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"cinder_volume_image_current\\\": \\\"{{cinder_volume_image_current_res.stdout}}\\\"}}, {\\\"name\\\": \\\"Temporarily tag the current cinder_volume image id with the upgraded image name\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_tag\\\"}, \\\"vars\\\": {\\\"container_image\\\": \\\"{{cinder_volume_image_current}}\\\", \\\"container_image_latest\\\": \\\"{{cinder_volume_image_latest}}\\\", \\\"pull_image\\\": false}, \\\"when\\\": [\\\"cinder_volume_image_current != \'\'\\\", \\\"cinder_volume_image_current != cinder_volume_image_latest\\\"]}, {\\\"name\\\": \\\"Create cinder_volume retag statefile\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/tripleo/cinder_volume_needs_retag\\\", \\\"state\\\": \\\"touch\\\"}, \\\"when\\\": [\\\"cinder_volume_image_current != \'\'\\\", \\\"cinder_volume_image_current != cinder_volume_image_latest\\\"]}]}, {\\\"name\\\": \\\"Update cinder_volume pcs resource bundle for new container image\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"set is_cinder_volume_bootstrap_node fact\\\", \\\"tags\\\": \\\"common\\\", \\\"set_fact\\\": \\\"is_cinder_volume_bootstrap_node={{cinder_volume_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\\\"}, {\\\"name\\\": \\\"Check for cinder_volume retag statefile\\\", \\\"stat\\\": {\\\"path\\\": \\\"/var/lib/tripleo/cinder_volume_needs_retag\\\"}, \\\"register\\\": \\\"cinder_volume_retag_state_file\\\"}]}, {\\\"name\\\": \\\"Update cinder_volume pcs resource bundle for new container image\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"is_cinder_volume_bootstrap_node\\\", \\\"cinder_volume_retag_state_file.stat.exists|bool\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Disable the cinder_volume cluster resource before container upgrade\\\", \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"openstack-cinder-volume\\\", \\\"state\\\": \\\"disable\\\", \\\"wait_for_resource\\\": true}, \\\"register\\\": \\\"output\\\", \\\"retries\\\": 5, \\\"until\\\": \\\"output.rc == 0\\\"}, {\\\"name\\\": \\\"pcs resource bundle update cinder_volume for new container image name\\\", \\\"command\\\": \\\"pcs resource bundle update openstack-cinder-volume container image={{cinder_volume_image_latest}}\\\"}, {\\\"name\\\": \\\"Enable the cinder_volume cluster resource\\\", \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"openstack-cinder-volume\\\", \\\"state\\\": \\\"enable\\\", \\\"wait_for_resource\\\": true}, \\\"register\\\": \\\"output\\\", \\\"retries\\\": 5, \\\"until\\\": \\\"output.rc == 0\\\"}]}, {\\\"name\\\": \\\"Check for cinder_volume retag statefile\\\", \\\"when\\\": [\\\"step|int == 3\\\"], \\\"stat\\\": {\\\"path\\\": \\\"/var/lib/tripleo/cinder_volume_needs_retag\\\"}, \\\"register\\\": \\\"cinder_volume_retag_state_file\\\"}, {\\\"name\\\": \\\"Retag pacemaker cinder_volume\\\", \\\"when\\\": [\\\"step|int == 3\\\", \\\"cinder_volume_retag_state_file.stat.exists|bool\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Disable the cinder_volume cluster resource before container upgrade\\\", \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"openstack-cinder-volume\\\", \\\"state\\\": \\\"disable\\\", \\\"wait_for_resource\\\": true}, \\\"register\\\": \\\"output\\\", \\\"retries\\\": 5, \\\"until\\\": \\\"output.rc == 0\\\"}, {\\\"name\\\": \\\"Retag the pacemaker image if containerized\\\", \\\"block\\\": [{\\\"block\\\": [{\\\"name\\\": \\\"Get cinder_volume image from pacemaker\\\", \\\"become\\\": true, \\\"register\\\": \\\"xmllint_pcmk_cinder_volume_image\\\", \\\"shell\\\": \\\"xmllint --xpath \\\\\\\"string(//bundle[@id=\'openstack-cinder-volume\']/podman/@image)\\\\\\\" /var/lib/pacemaker/cib/cib.xml\\\"}, {\\\"name\\\": \\\"Get container cinder_volume image\\\", \\\"set_fact\\\": {\\\"cinder_volume_image\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderVolumeImage\\\"]}, \\\"cinder_volume_image_latest\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterFullTag\\\"}, \\\"cluster.common.tag/cinder-volume:pcmklatest\\\", {\\\"yaql\\\": {\\\"data\\\": {\\\"if\\\": [{\\\"get_param\\\": \\\"ClusterCommonTag\\\"}, {\\\"yaql\\\": {\\\"data\\\": {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderVolumeImage\\\"]}, \\\"expression\\\": \\\"concat(\\\\\\\"cluster.common.tag/\\\\\\\", $.data.rightSplit(separator => \\\\\\\"/\\\\\\\", maxSplits => 1)[1])\\\"}}, {\\\"get_attr\\\": [\\\"RoleParametersValue\\\", \\\"value\\\", \\\"ContainerCinderVolumeImage\\\"]}]}, \\\"expression\\\": \\\"concat($.data.rightSplit(separator => \\\\\\\":\\\\\\\", maxSplits => 1)[0], \\\\\\\":pcmklatest\\\\\\\")\\\"}}]}, \\\"pcmk_cinder_volume_image\\\": \\\"{{xmllint_pcmk_cinder_volume_image.stdout}}\\\"}}]}, {\\\"block\\\": [{\\\"name\\\": \\\"Retag pcmklatest to latest cinder_volume image\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_container_tag\\\"}, \\\"vars\\\": {\\\"container_image\\\": \\\"{{cinder_volume_image}}\\\", \\\"container_image_latest\\\": \\\"{{cinder_volume_image_latest}}\\\"}}]}]}, {\\\"name\\\": \\\"Enable the cinder_volume cluster resource\\\", \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"openstack-cinder-volume\\\", \\\"state\\\": \\\"enable\\\", \\\"wait_for_resource\\\": true}, \\\"register\\\": \\\"output\\\", \\\"retries\\\": 5, \\\"until\\\": \\\"output.rc == 0\\\"}, {\\\"name\\\": \\\"Remove cinder_volume retag statefile\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/tripleo/cinder_volume_needs_retag\\\", \\\"state\\\": \\\"absent\\\"}}]}], {\\\"get_attr\\\": [\\\"CinderCommon\\\", \\\"cinder_volume_upgrade_tasks\\\"]}]}, \\\"post_upgrade_tasks\\\": [{\\\"name\\\": \\\"Start cinder_volume service (pacemaker)\\\", \\\"become\\\": true, \\\"when\\\": \\\"step|int == 1\\\", \\\"pacemaker_resource\\\": {\\\"resource\\\": \\\"openstack-cinder-volume\\\", \\\"state\\\": \\\"enable\\\"}}]}}}}\", \"file:///home/zuul/overcloud_services_cell1.yaml\": \"{\\\"resource_registry\\\": {\\\"OS::TripleO::Services::CeilometerAgentCentral\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\\\", \\\"OS::TripleO::Services::CeilometerAgentNotification\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\\\", \\\"OS::TripleO::Services::CeilometerAgentIpmi\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\\\", \\\"OS::TripleO::Services::ComputeCeilometerAgent\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\\\", \\\"OS::TripleO::Services::Collectd\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\\\", \\\"OS::TripleO::Services::MetricsQdr\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\\\", \\\"OS::TripleO::Services::OsloMessagingRpc\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\\\", \\\"OS::TripleO::Services::OsloMessagingNotify\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\\\", \\\"OS::TripleO::Services::HAproxy\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\\\", \\\"OS::TripleO::Services::Pacemaker\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\\\", \\\"OS::TripleO::Services::PacemakerRemote\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\\\", \\\"OS::TripleO::Services::Clustercheck\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\\\", \\\"OS::TripleO::Services::Redis\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\\\", \\\"OS::TripleO::Services::Rsyslog\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\\\", \\\"OS::TripleO::Services::MySQL\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\\\", \\\"OS::TripleO::Services::CinderBackup\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\\\", \\\"OS::TripleO::Services::CinderVolume\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\\\", \\\"OS::TripleO::Network::External\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Network::InternalApi\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Network::Storage\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Network::StorageMgmt\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Network::Tenant\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Network::Management\\\": \\\"OS::Heat::None\\\"}, \\\"parameter_defaults\\\": {\\\"SshFirewallAllowAll\\\": true, \\\"NovaAdditionalCell\\\": true, \\\"ManageNetworks\\\": false, \\\"NovaLocalMetadataPerCell\\\": true, \\\"RedisVirtualFixedIPs\\\": [{\\\"ip_address\\\": \\\"192.168.122.113\\\", \\\"use_neutron\\\": false}], \\\"OVNDBsVirtualFixedIPs\\\": [{\\\"ip_address\\\": \\\"192.168.122.123\\\", \\\"use_neutron\\\": false}], \\\"CellControllerExtraConfig\\\": {\\\"nova::compute::libvirt::services::libvirt_virt_type\\\": \\\"qemu\\\", \\\"nova::compute::libvirt::virt_type\\\": \\\"qemu\\\"}, \\\"CellControllerComputeExtraConfig\\\": {\\\"nova::compute::libvirt::services::libvirt_virt_type\\\": \\\"qemu\\\", \\\"nova::compute::libvirt::virt_type\\\": \\\"qemu\\\"}, \\\"ComputeExtraConfig\\\": {\\\"nova::compute::libvirt::services::libvirt_virt_type\\\": \\\"qemu\\\", \\\"nova::compute::libvirt::virt_type\\\": \\\"qemu\\\"}, \\\"Debug\\\": true, \\\"DockerPuppetDebug\\\": true, \\\"ContainerCli\\\": \\\"podman\\\", \\\"ControllerCount\\\": 0, \\\"CellControllerCount\\\": 1, \\\"CellControllerComputeCount\\\": 0, \\\"ComputeCount\\\": 1, \\\"NeutronGlobalPhysnetMtu\\\": 1350, \\\"CinderLVMLoopDeviceSize\\\": 20480, \\\"CloudName\\\": \\\"multicell.ooo.test\\\", \\\"CloudNameInternal\\\": \\\"multicell.internalapi.localdomain\\\", \\\"CloudNameStorage\\\": \\\"multicell.storage.localdomain\\\", \\\"CloudNameStorageManagement\\\": \\\"multicell.storagemgmt.localdomain\\\", \\\"CloudNameExternal\\\": \\\"multicell.external.localdomain\\\", \\\"CloudNameCtlplane\\\": \\\"multicell.ctlplane.localdomain\\\", \\\"CloudDomain\\\": \\\"ooo.test\\\", \\\"OVNCMSOptions\\\": \\\"enable-chassis-as-gw\\\", \\\"NeutronPhysicalBridge\\\": \\\"br-ex\\\", \\\"NeutronNetworkType\\\": \\\"geneve\\\", \\\"NeutronTunnelTypes\\\": \\\"geneve\\\", \\\"NeutronBridgeMappings\\\": \\\"datacentre:br-ex\\\", \\\"CellControllerComputeHostnameFormat\\\": \\\"%stackname%-controller-compute-%index%\\\", \\\"CellControllerHostnameFormat\\\": \\\"%stackname%-controller-%index%\\\", \\\"ComputeHostnameFormat\\\": \\\"%stackname%-compute-%index%\\\", \\\"ControllerHostnameFormat\\\": \\\"%stackname%-controller-%index%\\\", \\\"NetworkConfigWithAnsible\\\": false, \\\"ControllerNetworkConfigUpdate\\\": false, \\\"ComputeNetworkConfigUpdate\\\": false, \\\"BlockStorageNetworkConfigUpdate\\\": false, \\\"ObjectStorageNetworkConfigUpdate\\\": false, \\\"CephStorageNetworkConfigUpdate\\\": false, \\\"NetworkerNetworkConfigUpdate\\\": false, \\\"CellControllerNetworkConfigUpdate\\\": false, \\\"CellControllerComputeNetworkConfigUpdate\\\": false, \\\"ControllerNetworkConfigTemplate\\\": \\\"templates/single_nic_vlans/single_nic_vlans.j2\\\", \\\"ComputeNetworkConfigTemplate\\\": \\\"templates/single_nic_vlans/single_nic_vlans.j2\\\", \\\"BlockStorageNetworkConfigTemplate\\\": \\\"templates/single_nic_vlans/single_nic_vlans.j2\\\", \\\"ObjectStorageNetworkConfigTemplate\\\": \\\"templates/single_nic_vlans/single_nic_vlans.j2\\\", \\\"CephStorageNetworkConfigTemplate\\\": \\\"templates/single_nic_vlans/single_nic_vlans.j2\\\", \\\"NetworkerNetworkConfigTemplate\\\": \\\"templates/single_nic_vlans/single_nic_vlans.j2\\\", \\\"CellControllerNetworkConfigTemplate\\\": \\\"templates/single_nic_vlans/single_nic_vlans.j2\\\", \\\"CellControllerComputeNetworkConfigTemplate\\\": \\\"templates/single_nic_vlans/single_nic_vlans.j2\\\"}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Deployed port on the External network.\\\\n\\\", \\\"parameters\\\": {\\\"StackName\\\": {\\\"description\\\": \\\"Name of the overcloud heat stack\\\", \\\"default\\\": \\\"overcloud\\\", \\\"type\\\": \\\"string\\\"}, \\\"PortName\\\": {\\\"description\\\": \\\"Name of the port\\\", \\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"DnsName\\\": {\\\"description\\\": \\\"DNS name of the port\\\", \\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneIP\\\": {\\\"description\\\": \\\"IP address on the control plane\\\", \\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneSubnetCidr\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneNetwork\\\": {\\\"description\\\": \\\"The name of the undercloud Neutron control plane\\\", \\\"default\\\": \\\"ctlplane\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneSubnet\\\": {\\\"description\\\": \\\"The name of the undercloud Neutron control plane subnet\\\", \\\"default\\\": \\\"ctlplane-subnet\\\", \\\"type\\\": \\\"string\\\"}, \\\"FixedIPs\\\": {\\\"description\\\": \\\"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\\\n\\\", \\\"default\\\": [], \\\"type\\\": \\\"json\\\"}, \\\"IPPool\\\": {\\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}, \\\"NodeIndex\\\": {\\\"default\\\": 0, \\\"type\\\": \\\"number\\\"}, \\\"NodePortMap\\\": {\\\"description\\\": \\\"A map of deployed port data\\\\n\\\", \\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}, \\\"IsVirtualIP\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"DefaultRoute\\\": {\\\"description\\\": \\\"Whether this interface is used for the default route\\\\n\\\", \\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"Role\\\": {\\\"description\\\": \\\"The TripleO Role Name\\\\n\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\"}}, \\\"resources\\\": {\\\"ExternalDeployedPort\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"value\\\": {\\\"ip_address\\\": {\\\"get_param\\\": [\\\"NodePortMap\\\", {\\\"get_param\\\": \\\"DnsName\\\"}, \\\"external\\\", \\\"ip_address\\\"]}, \\\"ip_address_uri\\\": {\\\"get_param\\\": [\\\"NodePortMap\\\", {\\\"get_param\\\": \\\"DnsName\\\"}, \\\"external\\\", \\\"ip_address_uri\\\"]}, \\\"ip_subnet\\\": {\\\"get_param\\\": [\\\"NodePortMap\\\", {\\\"get_param\\\": \\\"DnsName\\\"}, \\\"external\\\", \\\"ip_subnet\\\"]}}}}}, \\\"outputs\\\": {\\\"ip_address\\\": {\\\"description\\\": \\\"External network IP\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"ExternalDeployedPort\\\", \\\"value\\\", \\\"ip_address\\\"]}}, \\\"ip_address_uri\\\": {\\\"description\\\": \\\"External network IP (with brackets for IPv6 URLs)\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"ExternalDeployedPort\\\", \\\"value\\\", \\\"ip_address_uri\\\"]}}, \\\"ip_subnet\\\": {\\\"description\\\": \\\"IP/Subnet CIDR for the External network IP\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"ExternalDeployedPort\\\", \\\"value\\\", \\\"ip_subnet\\\"]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Deployed port on the InternalApi network.\\\\n\\\", \\\"parameters\\\": {\\\"StackName\\\": {\\\"description\\\": \\\"Name of the overcloud heat stack\\\", \\\"default\\\": \\\"overcloud\\\", \\\"type\\\": \\\"string\\\"}, \\\"PortName\\\": {\\\"description\\\": \\\"Name of the port\\\", \\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"DnsName\\\": {\\\"description\\\": \\\"DNS name of the port\\\", \\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneIP\\\": {\\\"description\\\": \\\"IP address on the control plane\\\", \\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneSubnetCidr\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneNetwork\\\": {\\\"description\\\": \\\"The name of the undercloud Neutron control plane\\\", \\\"default\\\": \\\"ctlplane\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneSubnet\\\": {\\\"description\\\": \\\"The name of the undercloud Neutron control plane subnet\\\", \\\"default\\\": \\\"ctlplane-subnet\\\", \\\"type\\\": \\\"string\\\"}, \\\"FixedIPs\\\": {\\\"description\\\": \\\"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\\\n\\\", \\\"default\\\": [], \\\"type\\\": \\\"json\\\"}, \\\"IPPool\\\": {\\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}, \\\"NodeIndex\\\": {\\\"default\\\": 0, \\\"type\\\": \\\"number\\\"}, \\\"NodePortMap\\\": {\\\"description\\\": \\\"A map of deployed port data\\\\n\\\", \\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}, \\\"IsVirtualIP\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"DefaultRoute\\\": {\\\"description\\\": \\\"Whether this interface is used for the default route\\\\n\\\", \\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"Role\\\": {\\\"description\\\": \\\"The TripleO Role Name\\\\n\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\"}}, \\\"resources\\\": {\\\"InternalApiDeployedPort\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"value\\\": {\\\"ip_address\\\": {\\\"get_param\\\": [\\\"NodePortMap\\\", {\\\"get_param\\\": \\\"DnsName\\\"}, \\\"internal_api\\\", \\\"ip_address\\\"]}, \\\"ip_address_uri\\\": {\\\"get_param\\\": [\\\"NodePortMap\\\", {\\\"get_param\\\": \\\"DnsName\\\"}, \\\"internal_api\\\", \\\"ip_address_uri\\\"]}, \\\"ip_subnet\\\": {\\\"get_param\\\": [\\\"NodePortMap\\\", {\\\"get_param\\\": \\\"DnsName\\\"}, \\\"internal_api\\\", \\\"ip_subnet\\\"]}}}}}, \\\"outputs\\\": {\\\"ip_address\\\": {\\\"description\\\": \\\"InternalApi network IP\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"InternalApiDeployedPort\\\", \\\"value\\\", \\\"ip_address\\\"]}}, \\\"ip_address_uri\\\": {\\\"description\\\": \\\"InternalApi network IP (with brackets for IPv6 URLs)\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"InternalApiDeployedPort\\\", \\\"value\\\", \\\"ip_address_uri\\\"]}}, \\\"ip_subnet\\\": {\\\"description\\\": \\\"IP/Subnet CIDR for the InternalApi network IP\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"InternalApiDeployedPort\\\", \\\"value\\\", \\\"ip_subnet\\\"]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Deployed port on the StorageMgmt network.\\\\n\\\", \\\"parameters\\\": {\\\"StackName\\\": {\\\"description\\\": \\\"Name of the overcloud heat stack\\\", \\\"default\\\": \\\"overcloud\\\", \\\"type\\\": \\\"string\\\"}, \\\"PortName\\\": {\\\"description\\\": \\\"Name of the port\\\", \\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"DnsName\\\": {\\\"description\\\": \\\"DNS name of the port\\\", \\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneIP\\\": {\\\"description\\\": \\\"IP address on the control plane\\\", \\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneSubnetCidr\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneNetwork\\\": {\\\"description\\\": \\\"The name of the undercloud Neutron control plane\\\", \\\"default\\\": \\\"ctlplane\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneSubnet\\\": {\\\"description\\\": \\\"The name of the undercloud Neutron control plane subnet\\\", \\\"default\\\": \\\"ctlplane-subnet\\\", \\\"type\\\": \\\"string\\\"}, \\\"FixedIPs\\\": {\\\"description\\\": \\\"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\\\n\\\", \\\"default\\\": [], \\\"type\\\": \\\"json\\\"}, \\\"IPPool\\\": {\\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}, \\\"NodeIndex\\\": {\\\"default\\\": 0, \\\"type\\\": \\\"number\\\"}, \\\"NodePortMap\\\": {\\\"description\\\": \\\"A map of deployed port data\\\\n\\\", \\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}, \\\"IsVirtualIP\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"DefaultRoute\\\": {\\\"description\\\": \\\"Whether this interface is used for the default route\\\\n\\\", \\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"Role\\\": {\\\"description\\\": \\\"The TripleO Role Name\\\\n\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\"}}, \\\"resources\\\": {\\\"StorageMgmtDeployedPort\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"value\\\": {\\\"ip_address\\\": {\\\"get_param\\\": [\\\"NodePortMap\\\", {\\\"get_param\\\": \\\"DnsName\\\"}, \\\"storage_mgmt\\\", \\\"ip_address\\\"]}, \\\"ip_address_uri\\\": {\\\"get_param\\\": [\\\"NodePortMap\\\", {\\\"get_param\\\": \\\"DnsName\\\"}, \\\"storage_mgmt\\\", \\\"ip_address_uri\\\"]}, \\\"ip_subnet\\\": {\\\"get_param\\\": [\\\"NodePortMap\\\", {\\\"get_param\\\": \\\"DnsName\\\"}, \\\"storage_mgmt\\\", \\\"ip_subnet\\\"]}}}}}, \\\"outputs\\\": {\\\"ip_address\\\": {\\\"description\\\": \\\"StorageMgmt network IP\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"StorageMgmtDeployedPort\\\", \\\"value\\\", \\\"ip_address\\\"]}}, \\\"ip_address_uri\\\": {\\\"description\\\": \\\"StorageMgmt network IP (with brackets for IPv6 URLs)\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"StorageMgmtDeployedPort\\\", \\\"value\\\", \\\"ip_address_uri\\\"]}}, \\\"ip_subnet\\\": {\\\"description\\\": \\\"IP/Subnet CIDR for the StorageMgmt network IP\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"StorageMgmtDeployedPort\\\", \\\"value\\\", \\\"ip_subnet\\\"]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Deployed port on the Storage network.\\\\n\\\", \\\"parameters\\\": {\\\"StackName\\\": {\\\"description\\\": \\\"Name of the overcloud heat stack\\\", \\\"default\\\": \\\"overcloud\\\", \\\"type\\\": \\\"string\\\"}, \\\"PortName\\\": {\\\"description\\\": \\\"Name of the port\\\", \\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"DnsName\\\": {\\\"description\\\": \\\"DNS name of the port\\\", \\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneIP\\\": {\\\"description\\\": \\\"IP address on the control plane\\\", \\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneSubnetCidr\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneNetwork\\\": {\\\"description\\\": \\\"The name of the undercloud Neutron control plane\\\", \\\"default\\\": \\\"ctlplane\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneSubnet\\\": {\\\"description\\\": \\\"The name of the undercloud Neutron control plane subnet\\\", \\\"default\\\": \\\"ctlplane-subnet\\\", \\\"type\\\": \\\"string\\\"}, \\\"FixedIPs\\\": {\\\"description\\\": \\\"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\\\n\\\", \\\"default\\\": [], \\\"type\\\": \\\"json\\\"}, \\\"IPPool\\\": {\\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}, \\\"NodeIndex\\\": {\\\"default\\\": 0, \\\"type\\\": \\\"number\\\"}, \\\"NodePortMap\\\": {\\\"description\\\": \\\"A map of deployed port data\\\\n\\\", \\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}, \\\"IsVirtualIP\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"DefaultRoute\\\": {\\\"description\\\": \\\"Whether this interface is used for the default route\\\\n\\\", \\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"Role\\\": {\\\"description\\\": \\\"The TripleO Role Name\\\\n\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\"}}, \\\"resources\\\": {\\\"StorageDeployedPort\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"value\\\": {\\\"ip_address\\\": {\\\"get_param\\\": [\\\"NodePortMap\\\", {\\\"get_param\\\": \\\"DnsName\\\"}, \\\"storage\\\", \\\"ip_address\\\"]}, \\\"ip_address_uri\\\": {\\\"get_param\\\": [\\\"NodePortMap\\\", {\\\"get_param\\\": \\\"DnsName\\\"}, \\\"storage\\\", \\\"ip_address_uri\\\"]}, \\\"ip_subnet\\\": {\\\"get_param\\\": [\\\"NodePortMap\\\", {\\\"get_param\\\": \\\"DnsName\\\"}, \\\"storage\\\", \\\"ip_subnet\\\"]}}}}}, \\\"outputs\\\": {\\\"ip_address\\\": {\\\"description\\\": \\\"Storage network IP\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"StorageDeployedPort\\\", \\\"value\\\", \\\"ip_address\\\"]}}, \\\"ip_address_uri\\\": {\\\"description\\\": \\\"Storage network IP (with brackets for IPv6 URLs)\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"StorageDeployedPort\\\", \\\"value\\\", \\\"ip_address_uri\\\"]}}, \\\"ip_subnet\\\": {\\\"description\\\": \\\"IP/Subnet CIDR for the Storage network IP\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"StorageDeployedPort\\\", \\\"value\\\", \\\"ip_subnet\\\"]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Deployed port on the Tenant network.\\\\n\\\", \\\"parameters\\\": {\\\"StackName\\\": {\\\"description\\\": \\\"Name of the overcloud heat stack\\\", \\\"default\\\": \\\"overcloud\\\", \\\"type\\\": \\\"string\\\"}, \\\"PortName\\\": {\\\"description\\\": \\\"Name of the port\\\", \\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"DnsName\\\": {\\\"description\\\": \\\"DNS name of the port\\\", \\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneIP\\\": {\\\"description\\\": \\\"IP address on the control plane\\\", \\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneSubnetCidr\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneNetwork\\\": {\\\"description\\\": \\\"The name of the undercloud Neutron control plane\\\", \\\"default\\\": \\\"ctlplane\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneSubnet\\\": {\\\"description\\\": \\\"The name of the undercloud Neutron control plane subnet\\\", \\\"default\\\": \\\"ctlplane-subnet\\\", \\\"type\\\": \\\"string\\\"}, \\\"FixedIPs\\\": {\\\"description\\\": \\\"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\\\n\\\", \\\"default\\\": [], \\\"type\\\": \\\"json\\\"}, \\\"IPPool\\\": {\\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}, \\\"NodeIndex\\\": {\\\"default\\\": 0, \\\"type\\\": \\\"number\\\"}, \\\"NodePortMap\\\": {\\\"description\\\": \\\"A map of deployed port data\\\\n\\\", \\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}, \\\"IsVirtualIP\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"DefaultRoute\\\": {\\\"description\\\": \\\"Whether this interface is used for the default route\\\\n\\\", \\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"Role\\\": {\\\"description\\\": \\\"The TripleO Role Name\\\\n\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\"}}, \\\"resources\\\": {\\\"TenantDeployedPort\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"value\\\": {\\\"ip_address\\\": {\\\"get_param\\\": [\\\"NodePortMap\\\", {\\\"get_param\\\": \\\"DnsName\\\"}, \\\"tenant\\\", \\\"ip_address\\\"]}, \\\"ip_address_uri\\\": {\\\"get_param\\\": [\\\"NodePortMap\\\", {\\\"get_param\\\": \\\"DnsName\\\"}, \\\"tenant\\\", \\\"ip_address_uri\\\"]}, \\\"ip_subnet\\\": {\\\"get_param\\\": [\\\"NodePortMap\\\", {\\\"get_param\\\": \\\"DnsName\\\"}, \\\"tenant\\\", \\\"ip_subnet\\\"]}}}}}, \\\"outputs\\\": {\\\"ip_address\\\": {\\\"description\\\": \\\"Tenant network IP\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"TenantDeployedPort\\\", \\\"value\\\", \\\"ip_address\\\"]}}, \\\"ip_address_uri\\\": {\\\"description\\\": \\\"Tenant network IP (with brackets for IPv6 URLs)\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"TenantDeployedPort\\\", \\\"value\\\", \\\"ip_address_uri\\\"]}}, \\\"ip_subnet\\\": {\\\"description\\\": \\\"IP/Subnet CIDR for the Tenant network IP\\\", \\\"value\\\": {\\\"get_attr\\\": [\\\"TenantDeployedPort\\\", \\\"value\\\", \\\"ip_subnet\\\"]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\" A fake OS::Neutron::Port stack which outputs fixed_ips and subnets based on the input from the DeployedServerPortMap (set via parameter_defaults). This lookup requires the use of port naming conventions. In order for this to work with deployed-server the keys should be <hostname>-<network>. Example: parameter_defaults: DeployedServerPortMap: gatsby-ctlplane: fixed_ips: - ip_address: 127.0.0.1 subnets: - cidr: 127.0.0.0/24 network: tags: - 127.0.0.0/24\\\", \\\"parameters\\\": {\\\"name\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"dns_name\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"network\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"fixed_ips\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"replacement_policy\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"tags\\\": {\\\"default\\\": [], \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"DeployedServerPortMap\\\": {\\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}, \\\"IsVirtualIP\\\": {\\\"default\\\": false, \\\"type\\\": \\\"boolean\\\"}, \\\"Role\\\": {\\\"description\\\": \\\"The TripleO Role Name\\\\n\\\", \\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\"}}, \\\"outputs\\\": {\\\"fixed_ips\\\": {\\\"value\\\": {\\\"get_param\\\": [\\\"DeployedServerPortMap\\\", {\\\"get_param\\\": \\\"name\\\"}, \\\"fixed_ips\\\"]}}, \\\"subnets\\\": {\\\"value\\\": {\\\"get_param\\\": [\\\"DeployedServerPortMap\\\", {\\\"get_param\\\": \\\"name\\\"}, \\\"subnets\\\"]}}, \\\"network\\\": {\\\"value\\\": {\\\"get_param\\\": [\\\"DeployedServerPortMap\\\", {\\\"get_param\\\": \\\"name\\\"}, \\\"network\\\"]}}, \\\"name\\\": {\\\"value\\\": {\\\"get_param\\\": \\\"name\\\"}}, \\\"status\\\": {\\\"value\\\": \\\"DOWN\\\"}, \\\"allowed_address_pairs\\\": {\\\"value\\\": {}}, \\\"device_id\\\": {\\\"value\\\": \\\"\\\"}, \\\"device_owner\\\": {\\\"value\\\": {\\\"get_param\\\": \\\"network\\\"}}, \\\"dns_assignment\\\": {\\\"value\\\": \\\"\\\"}, \\\"port_security_enabled\\\": {\\\"value\\\": false}, \\\"admin_state_up\\\": {\\\"value\\\": false}, \\\"security_groups\\\": {\\\"value\\\": {}}, \\\"network_id\\\": {\\\"value\\\": \\\"\\\"}, \\\"tenant_id\\\": {\\\"value\\\": \\\"\\\"}, \\\"qos_policy_id\\\": {\\\"value\\\": \\\"\\\"}, \\\"mac_address\\\": {\\\"value\\\": \\\"\\\"}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/env-config-download-cell1-xr2_2lie.yaml\": \"{\\\"parameter_defaults\\\": {\\\"CtlplaneNetworkAttributes\\\": {\\\"network\\\": {\\\"dns_domain\\\": \\\"localdomain\\\", \\\"mtu\\\": 1500, \\\"name\\\": \\\"ctlplane\\\", \\\"tags\\\": [\\\"192.168.122.0/24\\\"]}, \\\"subnets\\\": {\\\"ctlplane-subnet\\\": {\\\"cidr\\\": \\\"192.168.122.0/24\\\", \\\"dns_nameservers\\\": [\\\"192.168.122.10\\\", \\\"192.168.122.1\\\"], \\\"gateway_ip\\\": \\\"192.168.122.10\\\", \\\"host_routes\\\": [], \\\"ip_version\\\": 4, \\\"name\\\": \\\"ctlplane-subnet\\\"}}}, \\\"DeployedServerPortMap\\\": {\\\"compute-2-ctlplane\\\": {\\\"fixed_ips\\\": [{\\\"ip_address\\\": \\\"192.168.122.109\\\"}], \\\"network\\\": {\\\"tags\\\": [\\\"192.168.122.0/24\\\"]}, \\\"subnets\\\": [{\\\"cidr\\\": \\\"192.168.122.0/24\\\"}]}, \\\"controller-0-ctlplane\\\": {\\\"fixed_ips\\\": [{\\\"ip_address\\\": \\\"192.168.122.103\\\"}], \\\"network\\\": {\\\"tags\\\": [\\\"192.168.122.0/24\\\"]}, \\\"subnets\\\": [{\\\"cidr\\\": \\\"192.168.122.0/24\\\"}]}, \\\"np0000071538-ctlplane\\\": {\\\"fixed_ips\\\": [{\\\"ip_address\\\": \\\"192.168.122.106\\\"}], \\\"network\\\": {\\\"tags\\\": [\\\"192.168.122.0/24\\\"]}, \\\"subnets\\\": [{\\\"cidr\\\": \\\"192.168.122.0/24\\\"}]}, \\\"np0000071539-ctlplane\\\": {\\\"fixed_ips\\\": [{\\\"ip_address\\\": \\\"192.168.122.107\\\"}], \\\"network\\\": {\\\"tags\\\": [\\\"192.168.122.0/24\\\"]}, \\\"subnets\\\": [{\\\"cidr\\\": \\\"192.168.122.0/24\\\"}]}}, \\\"NodePortMap\\\": {\\\"compute-2\\\": {\\\"ctlplane\\\": {\\\"ip_address\\\": \\\"192.168.122.109\\\", \\\"ip_address_uri\\\": \\\"192.168.122.109\\\", \\\"ip_subnet\\\": \\\"192.168.122.0/24\\\"}, \\\"external\\\": {\\\"ip_address\\\": \\\"172.21.0.109\\\", \\\"ip_address_uri\\\": \\\"172.21.0.109\\\", \\\"ip_subnet\\\": \\\"172.21.0.0/24\\\"}, \\\"internal_api\\\": {\\\"ip_address\\\": \\\"172.17.0.109\\\", \\\"ip_address_uri\\\": \\\"172.17.0.109\\\", \\\"ip_subnet\\\": \\\"172.17.0.0/24\\\"}, \\\"storage\\\": {\\\"ip_address\\\": \\\"172.18.0.109\\\", \\\"ip_address_uri\\\": \\\"172.18.0.109\\\", \\\"ip_subnet\\\": \\\"172.18.0.0/24\\\"}, \\\"storage_mgmt\\\": {\\\"ip_address\\\": \\\"172.20.0.109\\\", \\\"ip_address_uri\\\": \\\"172.20.0.109\\\", \\\"ip_subnet\\\": \\\"172.20.0.0/24\\\"}, \\\"tenant\\\": {\\\"ip_address\\\": \\\"172.19.0.109\\\", \\\"ip_address_uri\\\": \\\"172.19.0.109\\\", \\\"ip_subnet\\\": \\\"172.19.0.0/24\\\"}}, \\\"controller-0\\\": {\\\"ctlplane\\\": {\\\"ip_address\\\": \\\"192.168.122.103\\\", \\\"ip_address_uri\\\": \\\"192.168.122.103\\\", \\\"ip_subnet\\\": \\\"192.168.122.0/24\\\"}, \\\"external\\\": {\\\"ip_address\\\": \\\"172.21.0.103\\\", \\\"ip_address_uri\\\": \\\"172.21.0.103\\\", \\\"ip_subnet\\\": \\\"172.21.0.0/24\\\"}, \\\"internal_api\\\": {\\\"ip_address\\\": \\\"172.17.0.103\\\", \\\"ip_address_uri\\\": \\\"172.17.0.103\\\", \\\"ip_subnet\\\": \\\"172.17.0.0/24\\\"}, \\\"storage\\\": {\\\"ip_address\\\": \\\"172.18.0.103\\\", \\\"ip_address_uri\\\": \\\"172.18.0.103\\\", \\\"ip_subnet\\\": \\\"172.18.0.0/24\\\"}, \\\"storage_mgmt\\\": {\\\"ip_address\\\": \\\"172.20.0.103\\\", \\\"ip_address_uri\\\": \\\"172.20.0.103\\\", \\\"ip_subnet\\\": \\\"172.20.0.0/24\\\"}, \\\"tenant\\\": {\\\"ip_address\\\": \\\"172.19.0.103\\\", \\\"ip_address_uri\\\": \\\"172.19.0.103\\\", \\\"ip_subnet\\\": \\\"172.19.0.0/24\\\"}}, \\\"np0000071538\\\": {\\\"ctlplane\\\": {\\\"ip_address\\\": \\\"192.168.122.106\\\", \\\"ip_address_uri\\\": \\\"192.168.122.106\\\", \\\"ip_subnet\\\": \\\"192.168.122.0/24\\\"}, \\\"external\\\": {\\\"ip_address\\\": \\\"172.21.0.106\\\", \\\"ip_address_uri\\\": \\\"172.21.0.106\\\", \\\"ip_subnet\\\": \\\"172.21.0.0/24\\\"}, \\\"internal_api\\\": {\\\"ip_address\\\": \\\"172.17.0.106\\\", \\\"ip_address_uri\\\": \\\"172.17.0.106\\\", \\\"ip_subnet\\\": \\\"172.17.0.0/24\\\"}, \\\"storage\\\": {\\\"ip_address\\\": \\\"172.18.0.106\\\", \\\"ip_address_uri\\\": \\\"172.18.0.106\\\", \\\"ip_subnet\\\": \\\"172.18.0.0/24\\\"}, \\\"storage_mgmt\\\": {\\\"ip_address\\\": \\\"172.20.0.106\\\", \\\"ip_address_uri\\\": \\\"172.20.0.106\\\", \\\"ip_subnet\\\": \\\"172.20.0.0/24\\\"}, \\\"tenant\\\": {\\\"ip_address\\\": \\\"172.19.0.106\\\", \\\"ip_address_uri\\\": \\\"172.19.0.106\\\", \\\"ip_subnet\\\": \\\"172.19.0.0/24\\\"}}, \\\"np0000071539\\\": {\\\"ctlplane\\\": {\\\"ip_address\\\": \\\"192.168.122.107\\\", \\\"ip_address_uri\\\": \\\"192.168.122.107\\\", \\\"ip_subnet\\\": \\\"192.168.122.0/24\\\"}, \\\"external\\\": {\\\"ip_address\\\": \\\"172.21.0.107\\\", \\\"ip_address_uri\\\": \\\"172.21.0.107\\\", \\\"ip_subnet\\\": \\\"172.21.0.0/24\\\"}, \\\"internal_api\\\": {\\\"ip_address\\\": \\\"172.17.0.107\\\", \\\"ip_address_uri\\\": \\\"172.17.0.107\\\", \\\"ip_subnet\\\": \\\"172.17.0.0/24\\\"}, \\\"storage\\\": {\\\"ip_address\\\": \\\"172.18.0.107\\\", \\\"ip_address_uri\\\": \\\"172.18.0.107\\\", \\\"ip_subnet\\\": \\\"172.18.0.0/24\\\"}, \\\"storage_mgmt\\\": {\\\"ip_address\\\": \\\"172.20.0.107\\\", \\\"ip_address_uri\\\": \\\"172.20.0.107\\\", \\\"ip_subnet\\\": \\\"172.20.0.0/24\\\"}, \\\"tenant\\\": {\\\"ip_address\\\": \\\"172.19.0.107\\\", \\\"ip_address_uri\\\": \\\"172.19.0.107\\\", \\\"ip_subnet\\\": \\\"172.19.0.0/24\\\"}}}}, \\\"resource_registry\\\": {\\\"OS::TripleO::CellController::Ports::ExternalPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\\\", \\\"OS::TripleO::CellController::Ports::InternalApiPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\\\", \\\"OS::TripleO::CellController::Ports::StorageMgmtPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\\\", \\\"OS::TripleO::CellController::Ports::StoragePort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\\\", \\\"OS::TripleO::CellController::Ports::TenantPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\\\", \\\"OS::TripleO::CellControllerCompute::Ports::ExternalPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\\\", \\\"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\\\", \\\"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\\\", \\\"OS::TripleO::CellControllerCompute::Ports::StoragePort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\\\", \\\"OS::TripleO::CellControllerCompute::Ports::TenantPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\\\", \\\"OS::TripleO::Compute::Ports::ExternalPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\\\", \\\"OS::TripleO::Compute::Ports::InternalApiPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\\\", \\\"OS::TripleO::Compute::Ports::StorageMgmtPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\\\", \\\"OS::TripleO::Compute::Ports::StoragePort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\\\", \\\"OS::TripleO::Compute::Ports::TenantPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\\\", \\\"OS::TripleO::Controller::Ports::ExternalPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\\\", \\\"OS::TripleO::Controller::Ports::InternalApiPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\\\", \\\"OS::TripleO::Controller::Ports::StorageMgmtPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\\\", \\\"OS::TripleO::Controller::Ports::StoragePort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\\\", \\\"OS::TripleO::Controller::Ports::TenantPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\\\", \\\"OS::TripleO::DeployedServer::ControlPlanePort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\\\", \\\"OS::TripleO::OVNMacAddressNetwork\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::OVNMacAddressPort\\\": \\\"OS::Heat::None\\\"}}\", \"file:///home/zuul/cell1-input.yaml\": \"{\\\"parameter_defaults\\\": {\\\"AdminPassword\\\": \\\"bUe66HleZhJpBVjnSHAhIOXaa\\\", \\\"AdminToken\\\": \\\"BiQBw7GX7DmVOFbZmHwIY6J8Y\\\", \\\"AllNodesExtraMapData\\\": {\\\"memcached_node_ips\\\": [\\\"172.17.0.103\\\"], \\\"oslo_messaging_notify_node_names\\\": [\\\"np0000071537.internalapi.ooo.test\\\"], \\\"oslo_messaging_notify_short_bootstrap_node_name\\\": \\\"np0000071537\\\", \\\"oslo_messaging_rpc_node_names\\\": [\\\"np0000071537.internalapi.ooo.test\\\"], \\\"ovn_dbs_node_ips\\\": [\\\"172.17.0.103\\\"], \\\"redis_vip\\\": \\\"192.168.122.110\\\"}, \\\"AodhPassword\\\": \\\"fiWSIxnnC9WYOtXqU72JP76GU\\\", \\\"AuthCloudName\\\": \\\"overcloud\\\", \\\"BarbicanPassword\\\": \\\"K7Zoj1PkYbjg91dE3vqFS0jRG\\\", \\\"BarbicanSimpleCryptoKek\\\": \\\"jl6_PhiYfwAIaDe9L2cR9PbltNy-4NgAAbzrqmi6H8M=\\\", \\\"CeilometerMeteringSecret\\\": \\\"EPgaQlmbDVmqQsiNdVrRly1ai\\\", \\\"CeilometerPassword\\\": \\\"LcRR8yGk8HFbgdc1qmDrKhpIE\\\", \\\"CinderPassword\\\": \\\"GD6nH1mrNie1qXOxmU8IDr1Aa\\\", \\\"CongressPassword\\\": \\\"EZVArYmWw7wqB5zLhRrNzkKjY\\\", \\\"DesignatePassword\\\": \\\"STX6VyzTMRhdUruXvLEhjDhPX\\\", \\\"DesignateRndcKey\\\": \\\"UiRFAnz5T32t+Q8xNydqc4jch6VJo31+Sri/4v4hZI4=\\\", \\\"Ec2ApiPassword\\\": \\\"ZnN87InBFClBp63qODWcZPBfP\\\", \\\"EndpointMapOverride\\\": {\\\"AodhAdmin\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"8042\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.17.0.130:8042\\\", \\\"uri_no_suffix\\\": \\\"http://172.17.0.130:8042\\\"}, \\\"AodhInternal\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"8042\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.17.0.130:8042\\\", \\\"uri_no_suffix\\\": \\\"http://172.17.0.130:8042\\\"}, \\\"AodhPublic\\\": {\\\"host\\\": \\\"172.21.0.80\\\", \\\"host_nobrackets\\\": \\\"172.21.0.80\\\", \\\"port\\\": \\\"8042\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.21.0.80:8042\\\", \\\"uri_no_suffix\\\": \\\"http://172.21.0.80:8042\\\"}, \\\"BarbicanAdmin\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"9311\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.17.0.130:9311\\\", \\\"uri_no_suffix\\\": \\\"http://172.17.0.130:9311\\\"}, \\\"BarbicanInternal\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"9311\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.17.0.130:9311\\\", \\\"uri_no_suffix\\\": \\\"http://172.17.0.130:9311\\\"}, \\\"BarbicanPublic\\\": {\\\"host\\\": \\\"172.21.0.80\\\", \\\"host_nobrackets\\\": \\\"172.21.0.80\\\", \\\"port\\\": \\\"9311\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.21.0.80:9311\\\", \\\"uri_no_suffix\\\": \\\"http://172.21.0.80:9311\\\"}, \\\"CephDashboardInternal\\\": {\\\"host\\\": \\\"192.168.122.90\\\", \\\"host_nobrackets\\\": \\\"192.168.122.90\\\", \\\"port\\\": \\\"8444\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://192.168.122.90:8444\\\", \\\"uri_no_suffix\\\": \\\"http://192.168.122.90:8444\\\"}, \\\"CephGrafanaInternal\\\": {\\\"host\\\": \\\"172.18.0.140\\\", \\\"host_nobrackets\\\": \\\"172.18.0.140\\\", \\\"port\\\": \\\"3100\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.18.0.140:3100\\\", \\\"uri_no_suffix\\\": \\\"http://172.18.0.140:3100\\\"}, \\\"CephRgwAdmin\\\": {\\\"host\\\": \\\"172.18.0.140\\\", \\\"host_nobrackets\\\": \\\"172.18.0.140\\\", \\\"port\\\": \\\"8080\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\\\", \\\"uri_no_suffix\\\": \\\"http://172.18.0.140:8080\\\"}, \\\"CephRgwInternal\\\": {\\\"host\\\": \\\"172.18.0.140\\\", \\\"host_nobrackets\\\": \\\"172.18.0.140\\\", \\\"port\\\": \\\"8080\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.18.0.140:8080/swift/v1/AUTH_%(project_id)s\\\", \\\"uri_no_suffix\\\": \\\"http://172.18.0.140:8080\\\"}, \\\"CephRgwPublic\\\": {\\\"host\\\": \\\"172.21.0.80\\\", \\\"host_nobrackets\\\": \\\"172.21.0.80\\\", \\\"port\\\": \\\"8080\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.21.0.80:8080/swift/v1/AUTH_%(project_id)s\\\", \\\"uri_no_suffix\\\": \\\"http://172.21.0.80:8080\\\"}, \\\"CinderAdmin\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"8776\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.17.0.130:8776/v1/%(tenant_id)s\\\", \\\"uri_no_suffix\\\": \\\"http://172.17.0.130:8776\\\"}, \\\"CinderInternal\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"8776\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.17.0.130:8776/v1/%(tenant_id)s\\\", \\\"uri_no_suffix\\\": \\\"http://172.17.0.130:8776\\\"}, \\\"CinderPublic\\\": {\\\"host\\\": \\\"172.21.0.80\\\", \\\"host_nobrackets\\\": \\\"172.21.0.80\\\", \\\"port\\\": \\\"8776\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.21.0.80:8776/v1/%(tenant_id)s\\\", \\\"uri_no_suffix\\\": \\\"http://172.21.0.80:8776\\\"}, \\\"CinderV2Admin\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"8776\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.17.0.130:8776/v2/%(tenant_id)s\\\", \\\"uri_no_suffix\\\": \\\"http://172.17.0.130:8776\\\"}, \\\"CinderV2Internal\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"8776\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.17.0.130:8776/v2/%(tenant_id)s\\\", \\\"uri_no_suffix\\\": \\\"http://172.17.0.130:8776\\\"}, \\\"CinderV2Public\\\": {\\\"host\\\": \\\"172.21.0.80\\\", \\\"host_nobrackets\\\": \\\"172.21.0.80\\\", \\\"port\\\": \\\"8776\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.21.0.80:8776/v2/%(tenant_id)s\\\", \\\"uri_no_suffix\\\": \\\"http://172.21.0.80:8776\\\"}, \\\"CinderV3Admin\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"8776\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.17.0.130:8776/v3/%(tenant_id)s\\\", \\\"uri_no_suffix\\\": \\\"http://172.17.0.130:8776\\\"}, \\\"CinderV3Internal\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"8776\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.17.0.130:8776/v3/%(tenant_id)s\\\", \\\"uri_no_suffix\\\": \\\"http://172.17.0.130:8776\\\"}, \\\"CinderV3Public\\\": {\\\"host\\\": \\\"172.21.0.80\\\", \\\"host_nobrackets\\\": \\\"172.21.0.80\\\", \\\"port\\\": \\\"8776\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.21.0.80:8776/v3/%(tenant_id)s\\\", \\\"uri_no_suffix\\\": \\\"http://172.21.0.80:8776\\\"}, \\\"DesignateAdmin\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"9001\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.17.0.130:9001/v2\\\", \\\"uri_no_suffix\\\": \\\"http://172.17.0.130:9001\\\"}, \\\"DesignateInternal\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"9001\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.17.0.130:9001/v2\\\", \\\"uri_no_suffix\\\": \\\"http://172.17.0.130:9001\\\"}, \\\"DesignatePublic\\\": {\\\"host\\\": \\\"172.21.0.80\\\", \\\"host_nobrackets\\\": \\\"172.21.0.80\\\", \\\"port\\\": \\\"9001\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.21.0.80:9001/v2\\\", \\\"uri_no_suffix\\\": \\\"http://172.21.0.80:9001\\\"}, \\\"DockerRegistryInternal\\\": {\\\"host\\\": \\\"192.168.122.90\\\", \\\"host_nobrackets\\\": \\\"192.168.122.90\\\", \\\"port\\\": \\\"8787\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://192.168.122.90:8787\\\", \\\"uri_no_suffix\\\": \\\"http://192.168.122.90:8787\\\"}, \\\"GaneshaInternal\\\": {\\\"host\\\": \\\"172.21.0.80\\\", \\\"host_nobrackets\\\": \\\"172.21.0.80\\\", \\\"port\\\": \\\"2049\\\", \\\"protocol\\\": \\\"nfs\\\", \\\"uri\\\": \\\"nfs://172.21.0.80:2049\\\", \\\"uri_no_suffix\\\": \\\"nfs://172.21.0.80:2049\\\"}, \\\"GlanceAdmin\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"9293\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.17.0.130:9293\\\", \\\"uri_no_suffix\\\": \\\"http://172.17.0.130:9293\\\"}, \\\"GlanceInternal\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"9293\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.17.0.130:9293\\\", \\\"uri_no_suffix\\\": \\\"http://172.17.0.130:9293\\\"}, \\\"GlancePublic\\\": {\\\"host\\\": \\\"172.21.0.80\\\", \\\"host_nobrackets\\\": \\\"172.21.0.80\\\", \\\"port\\\": \\\"9292\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.21.0.80:9292\\\", \\\"uri_no_suffix\\\": \\\"http://172.21.0.80:9292\\\"}, \\\"GnocchiAdmin\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"8041\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.17.0.130:8041\\\", \\\"uri_no_suffix\\\": \\\"http://172.17.0.130:8041\\\"}, \\\"GnocchiInternal\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"8041\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.17.0.130:8041\\\", \\\"uri_no_suffix\\\": \\\"http://172.17.0.130:8041\\\"}, \\\"GnocchiPublic\\\": {\\\"host\\\": \\\"172.21.0.80\\\", \\\"host_nobrackets\\\": \\\"172.21.0.80\\\", \\\"port\\\": \\\"8041\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.21.0.80:8041\\\", \\\"uri_no_suffix\\\": \\\"http://172.21.0.80:8041\\\"}, \\\"HeatAdmin\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"8004\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.17.0.130:8004/v1/%(tenant_id)s\\\", \\\"uri_no_suffix\\\": \\\"http://172.17.0.130:8004\\\"}, \\\"HeatCfnAdmin\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"8000\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.17.0.130:8000/v1\\\", \\\"uri_no_suffix\\\": \\\"http://172.17.0.130:8000\\\"}, \\\"HeatCfnInternal\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"8000\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.17.0.130:8000/v1\\\", \\\"uri_no_suffix\\\": \\\"http://172.17.0.130:8000\\\"}, \\\"HeatCfnPublic\\\": {\\\"host\\\": \\\"172.21.0.80\\\", \\\"host_nobrackets\\\": \\\"172.21.0.80\\\", \\\"port\\\": \\\"8000\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.21.0.80:8000/v1\\\", \\\"uri_no_suffix\\\": \\\"http://172.21.0.80:8000\\\"}, \\\"HeatInternal\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"8004\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.17.0.130:8004/v1/%(tenant_id)s\\\", \\\"uri_no_suffix\\\": \\\"http://172.17.0.130:8004\\\"}, \\\"HeatPublic\\\": {\\\"host\\\": \\\"172.21.0.80\\\", \\\"host_nobrackets\\\": \\\"172.21.0.80\\\", \\\"port\\\": \\\"8004\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.21.0.80:8004/v1/%(tenant_id)s\\\", \\\"uri_no_suffix\\\": \\\"http://172.21.0.80:8004\\\"}, \\\"HorizonPublic\\\": {\\\"host\\\": \\\"172.21.0.80\\\", \\\"host_nobrackets\\\": \\\"172.21.0.80\\\", \\\"port\\\": \\\"80\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.21.0.80:80/dashboard\\\", \\\"uri_no_suffix\\\": \\\"http://172.21.0.80:80\\\"}, \\\"IronicAdmin\\\": {\\\"host\\\": \\\"192.168.122.90\\\", \\\"host_nobrackets\\\": \\\"192.168.122.90\\\", \\\"port\\\": \\\"6385\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://192.168.122.90:6385/v1\\\", \\\"uri_no_suffix\\\": \\\"http://192.168.122.90:6385\\\"}, \\\"IronicInspectorAdmin\\\": {\\\"host\\\": \\\"192.168.122.90\\\", \\\"host_nobrackets\\\": \\\"192.168.122.90\\\", \\\"port\\\": \\\"5050\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://192.168.122.90:5050\\\", \\\"uri_no_suffix\\\": \\\"http://192.168.122.90:5050\\\"}, \\\"IronicInspectorInternal\\\": {\\\"host\\\": \\\"192.168.122.90\\\", \\\"host_nobrackets\\\": \\\"192.168.122.90\\\", \\\"port\\\": \\\"5050\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://192.168.122.90:5050\\\", \\\"uri_no_suffix\\\": \\\"http://192.168.122.90:5050\\\"}, \\\"IronicInspectorPublic\\\": {\\\"host\\\": \\\"172.21.0.80\\\", \\\"host_nobrackets\\\": \\\"172.21.0.80\\\", \\\"port\\\": \\\"5050\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.21.0.80:5050\\\", \\\"uri_no_suffix\\\": \\\"http://172.21.0.80:5050\\\"}, \\\"IronicInternal\\\": {\\\"host\\\": \\\"192.168.122.90\\\", \\\"host_nobrackets\\\": \\\"192.168.122.90\\\", \\\"port\\\": \\\"6385\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://192.168.122.90:6385/v1\\\", \\\"uri_no_suffix\\\": \\\"http://192.168.122.90:6385\\\"}, \\\"IronicPublic\\\": {\\\"host\\\": \\\"172.21.0.80\\\", \\\"host_nobrackets\\\": \\\"172.21.0.80\\\", \\\"port\\\": \\\"6385\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.21.0.80:6385/v1\\\", \\\"uri_no_suffix\\\": \\\"http://172.21.0.80:6385\\\"}, \\\"KeystoneAdmin\\\": {\\\"host\\\": \\\"192.168.122.90\\\", \\\"host_nobrackets\\\": \\\"192.168.122.90\\\", \\\"port\\\": \\\"35357\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://192.168.122.90:35357/\\\", \\\"uri_no_suffix\\\": \\\"http://192.168.122.90:35357\\\"}, \\\"KeystoneInternal\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"5000\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.17.0.130:5000/\\\", \\\"uri_no_suffix\\\": \\\"http://172.17.0.130:5000\\\"}, \\\"KeystonePublic\\\": {\\\"host\\\": \\\"172.21.0.80\\\", \\\"host_nobrackets\\\": \\\"172.21.0.80\\\", \\\"port\\\": \\\"5000\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.21.0.80:5000/\\\", \\\"uri_no_suffix\\\": \\\"http://172.21.0.80:5000\\\"}, \\\"KeystoneV3Admin\\\": {\\\"host\\\": \\\"192.168.122.90\\\", \\\"host_nobrackets\\\": \\\"192.168.122.90\\\", \\\"port\\\": \\\"35357\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://192.168.122.90:35357/v3\\\", \\\"uri_no_suffix\\\": \\\"http://192.168.122.90:35357\\\"}, \\\"KeystoneV3Internal\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"5000\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.17.0.130:5000/v3\\\", \\\"uri_no_suffix\\\": \\\"http://172.17.0.130:5000\\\"}, \\\"KeystoneV3Public\\\": {\\\"host\\\": \\\"172.21.0.80\\\", \\\"host_nobrackets\\\": \\\"172.21.0.80\\\", \\\"port\\\": \\\"5000\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.21.0.80:5000/v3\\\", \\\"uri_no_suffix\\\": \\\"http://172.21.0.80:5000\\\"}, \\\"ManilaAdmin\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"8786\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.17.0.130:8786/v2\\\", \\\"uri_no_suffix\\\": \\\"http://172.17.0.130:8786\\\"}, \\\"ManilaInternal\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"8786\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.17.0.130:8786/v2\\\", \\\"uri_no_suffix\\\": \\\"http://172.17.0.130:8786\\\"}, \\\"ManilaPublic\\\": {\\\"host\\\": \\\"172.21.0.80\\\", \\\"host_nobrackets\\\": \\\"172.21.0.80\\\", \\\"port\\\": \\\"8786\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.21.0.80:8786/v2\\\", \\\"uri_no_suffix\\\": \\\"http://172.21.0.80:8786\\\"}, \\\"ManilaV1Admin\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"8786\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.17.0.130:8786/v1/%(tenant_id)s\\\", \\\"uri_no_suffix\\\": \\\"http://172.17.0.130:8786\\\"}, \\\"ManilaV1Internal\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"8786\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.17.0.130:8786/v1/%(tenant_id)s\\\", \\\"uri_no_suffix\\\": \\\"http://172.17.0.130:8786\\\"}, \\\"ManilaV1Public\\\": {\\\"host\\\": \\\"172.21.0.80\\\", \\\"host_nobrackets\\\": \\\"172.21.0.80\\\", \\\"port\\\": \\\"8786\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.21.0.80:8786/v1/%(tenant_id)s\\\", \\\"uri_no_suffix\\\": \\\"http://172.21.0.80:8786\\\"}, \\\"MetricsQdrPublic\\\": {\\\"host\\\": \\\"172.21.0.80\\\", \\\"host_nobrackets\\\": \\\"172.21.0.80\\\", \\\"port\\\": \\\"5666\\\", \\\"protocol\\\": \\\"amqp\\\", \\\"uri\\\": \\\"amqp://172.21.0.80:5666\\\", \\\"uri_no_suffix\\\": \\\"amqp://172.21.0.80:5666\\\"}, \\\"MysqlCellInternal\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"3306\\\", \\\"protocol\\\": \\\"mysql+pymysql\\\", \\\"uri\\\": \\\"mysql+pymysql://172.17.0.130:3306\\\", \\\"uri_no_suffix\\\": \\\"mysql+pymysql://172.17.0.130:3306\\\"}, \\\"MysqlInternal\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"3306\\\", \\\"protocol\\\": \\\"mysql+pymysql\\\", \\\"uri\\\": \\\"mysql+pymysql://172.17.0.130:3306\\\", \\\"uri_no_suffix\\\": \\\"mysql+pymysql://172.17.0.130:3306\\\"}, \\\"NeutronAdmin\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"9696\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.17.0.130:9696\\\", \\\"uri_no_suffix\\\": \\\"http://172.17.0.130:9696\\\"}, \\\"NeutronInternal\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"9696\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.17.0.130:9696\\\", \\\"uri_no_suffix\\\": \\\"http://172.17.0.130:9696\\\"}, \\\"NeutronPublic\\\": {\\\"host\\\": \\\"172.21.0.80\\\", \\\"host_nobrackets\\\": \\\"172.21.0.80\\\", \\\"port\\\": \\\"9696\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.21.0.80:9696\\\", \\\"uri_no_suffix\\\": \\\"http://172.21.0.80:9696\\\"}, \\\"NovaAdmin\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"8774\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.17.0.130:8774/v2.1\\\", \\\"uri_no_suffix\\\": \\\"http://172.17.0.130:8774\\\"}, \\\"NovaInternal\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"8774\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.17.0.130:8774/v2.1\\\", \\\"uri_no_suffix\\\": \\\"http://172.17.0.130:8774\\\"}, \\\"NovaMetadataCellInternal\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"8775\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.17.0.130:8775\\\", \\\"uri_no_suffix\\\": \\\"http://172.17.0.130:8775\\\"}, \\\"NovaMetadataInternal\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"8775\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.17.0.130:8775\\\", \\\"uri_no_suffix\\\": \\\"http://172.17.0.130:8775\\\"}, \\\"NovaPublic\\\": {\\\"host\\\": \\\"172.21.0.80\\\", \\\"host_nobrackets\\\": \\\"172.21.0.80\\\", \\\"port\\\": \\\"8774\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.21.0.80:8774/v2.1\\\", \\\"uri_no_suffix\\\": \\\"http://172.21.0.80:8774\\\"}, \\\"NovaVNCProxyAdmin\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"6080\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.17.0.130:6080\\\", \\\"uri_no_suffix\\\": \\\"http://172.17.0.130:6080\\\"}, \\\"NovaVNCProxyCellPublic\\\": {\\\"host\\\": \\\"172.21.0.80\\\", \\\"host_nobrackets\\\": \\\"172.21.0.80\\\", \\\"port\\\": \\\"6080\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.21.0.80:6080\\\", \\\"uri_no_suffix\\\": \\\"http://172.21.0.80:6080\\\"}, \\\"NovaVNCProxyInternal\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"6080\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.17.0.130:6080\\\", \\\"uri_no_suffix\\\": \\\"http://172.17.0.130:6080\\\"}, \\\"NovaVNCProxyPublic\\\": {\\\"host\\\": \\\"172.21.0.80\\\", \\\"host_nobrackets\\\": \\\"172.21.0.80\\\", \\\"port\\\": \\\"6080\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.21.0.80:6080\\\", \\\"uri_no_suffix\\\": \\\"http://172.21.0.80:6080\\\"}, \\\"NovajoinAdmin\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"9090\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.17.0.130:9090/v1\\\", \\\"uri_no_suffix\\\": \\\"http://172.17.0.130:9090\\\"}, \\\"NovajoinInternal\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"9090\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.17.0.130:9090/v1\\\", \\\"uri_no_suffix\\\": \\\"http://172.17.0.130:9090\\\"}, \\\"NovajoinPublic\\\": {\\\"host\\\": \\\"172.21.0.80\\\", \\\"host_nobrackets\\\": \\\"172.21.0.80\\\", \\\"port\\\": \\\"9090\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.21.0.80:9090/v1\\\", \\\"uri_no_suffix\\\": \\\"http://172.21.0.80:9090\\\"}, \\\"OctaviaAdmin\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"9876\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.17.0.130:9876\\\", \\\"uri_no_suffix\\\": \\\"http://172.17.0.130:9876\\\"}, \\\"OctaviaInternal\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"9876\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.17.0.130:9876\\\", \\\"uri_no_suffix\\\": \\\"http://172.17.0.130:9876\\\"}, \\\"OctaviaPublic\\\": {\\\"host\\\": \\\"172.21.0.80\\\", \\\"host_nobrackets\\\": \\\"172.21.0.80\\\", \\\"port\\\": \\\"9876\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.21.0.80:9876\\\", \\\"uri_no_suffix\\\": \\\"http://172.21.0.80:9876\\\"}, \\\"PlacementAdmin\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"8778\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.17.0.130:8778/placement\\\", \\\"uri_no_suffix\\\": \\\"http://172.17.0.130:8778\\\"}, \\\"PlacementInternal\\\": {\\\"host\\\": \\\"172.17.0.130\\\", \\\"host_nobrackets\\\": \\\"172.17.0.130\\\", \\\"port\\\": \\\"8778\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.17.0.130:8778/placement\\\", \\\"uri_no_suffix\\\": \\\"http://172.17.0.130:8778\\\"}, \\\"PlacementPublic\\\": {\\\"host\\\": \\\"172.21.0.80\\\", \\\"host_nobrackets\\\": \\\"172.21.0.80\\\", \\\"port\\\": \\\"8778\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.21.0.80:8778/placement\\\", \\\"uri_no_suffix\\\": \\\"http://172.21.0.80:8778\\\"}, \\\"SwiftAdmin\\\": {\\\"host\\\": \\\"172.18.0.140\\\", \\\"host_nobrackets\\\": \\\"172.18.0.140\\\", \\\"port\\\": \\\"8080\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.18.0.140:8080\\\", \\\"uri_no_suffix\\\": \\\"http://172.18.0.140:8080\\\"}, \\\"SwiftInternal\\\": {\\\"host\\\": \\\"172.18.0.140\\\", \\\"host_nobrackets\\\": \\\"172.18.0.140\\\", \\\"port\\\": \\\"8080\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.18.0.140:8080/v1/AUTH_%(tenant_id)s\\\", \\\"uri_no_suffix\\\": \\\"http://172.18.0.140:8080\\\"}, \\\"SwiftPublic\\\": {\\\"host\\\": \\\"172.21.0.80\\\", \\\"host_nobrackets\\\": \\\"172.21.0.80\\\", \\\"port\\\": \\\"8080\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.21.0.80:8080/v1/AUTH_%(tenant_id)s\\\", \\\"uri_no_suffix\\\": \\\"http://172.21.0.80:8080\\\"}, \\\"SwiftS3Admin\\\": {\\\"host\\\": \\\"172.18.0.140\\\", \\\"host_nobrackets\\\": \\\"172.18.0.140\\\", \\\"port\\\": \\\"8080\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.18.0.140:8080\\\", \\\"uri_no_suffix\\\": \\\"http://172.18.0.140:8080\\\"}, \\\"SwiftS3Internal\\\": {\\\"host\\\": \\\"172.18.0.140\\\", \\\"host_nobrackets\\\": \\\"172.18.0.140\\\", \\\"port\\\": \\\"8080\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.18.0.140:8080\\\", \\\"uri_no_suffix\\\": \\\"http://172.18.0.140:8080\\\"}, \\\"SwiftS3Public\\\": {\\\"host\\\": \\\"172.21.0.80\\\", \\\"host_nobrackets\\\": \\\"172.21.0.80\\\", \\\"port\\\": \\\"8080\\\", \\\"protocol\\\": \\\"http\\\", \\\"uri\\\": \\\"http://172.21.0.80:8080\\\", \\\"uri_no_suffix\\\": \\\"http://172.21.0.80:8080\\\"}}, \\\"EtcdInitialClusterToken\\\": \\\"Lu2gC4kePlkOY9feZzCBpUdup\\\", \\\"ExtraHostFileEntries\\\": [\\\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\\\", \\\"192.168.122.90  multicell.ctlplane.localdomain\\\", \\\"172.18.0.140  multicell.storage.localdomain\\\", \\\"172.20.0.150  multicell.storagemgmt.localdomain\\\", \\\"172.17.0.130  multicell.internalapi.localdomain\\\", \\\"172.21.0.80  multicell.ooo.test\\\", \\\"172.17.0.103 np0000071537.ooo.test np0000071537\\\", \\\"172.18.0.103 np0000071537.storage.ooo.test np0000071537.storage\\\", \\\"172.20.0.103 np0000071537.storagemgmt.ooo.test np0000071537.storagemgmt\\\", \\\"172.17.0.103 np0000071537.internalapi.ooo.test np0000071537.internalapi\\\", \\\"172.19.0.103 np0000071537.tenant.ooo.test np0000071537.tenant\\\", \\\"192.168.122.103 np0000071537.ctlplane.ooo.test np0000071537.ctlplane\\\"], \\\"GlancePassword\\\": \\\"J200o48UisGSxwI0LqyJ9SKOW\\\", \\\"GlobalConfigExtraMapData\\\": {\\\"memcached_authtoken_port\\\": 11211, \\\"memcached_port\\\": 11211, \\\"oslo_messaging_notify_password\\\": \\\"ezCMjhKa1U6SzsSlqK3G7UGxC\\\", \\\"oslo_messaging_notify_port\\\": 5672, \\\"oslo_messaging_notify_scheme\\\": \\\"rabbit\\\", \\\"oslo_messaging_notify_use_ssl\\\": \\\"False\\\", \\\"oslo_messaging_notify_user_name\\\": \\\"guest\\\", \\\"oslo_messaging_rpc_password\\\": \\\"ezCMjhKa1U6SzsSlqK3G7UGxC\\\", \\\"oslo_messaging_rpc_port\\\": 5672, \\\"oslo_messaging_rpc_scheme\\\": \\\"rabbit\\\", \\\"oslo_messaging_rpc_use_ssl\\\": \\\"False\\\", \\\"oslo_messaging_rpc_user_name\\\": \\\"guest\\\", \\\"ovn_db_clustered\\\": true}, \\\"GnocchiPassword\\\": \\\"zdZlUKoNQfYnZkPhlIJyX3L1r\\\", \\\"HAProxyStatsPassword\\\": \\\"MUfjd43QRvJhihQtc3FyU3ZcN\\\", \\\"HeatAuthEncryptionKey\\\": \\\"i4LZ6G2MXcSBhcQLA5O8Pd9qWs3JgiaE\\\", \\\"HeatPassword\\\": \\\"WU8n16xtnWLSyaokXBXP0O3v3\\\", \\\"HeatStackDomainAdminPassword\\\": \\\"YvwP7a3Kpz2xnnoxHiPGU2HfW\\\", \\\"HorizonSecret\\\": \\\"qjsk85XMGV\\\", \\\"IronicPassword\\\": \\\"uAlKuVAeobbBn8JonakywlHzr\\\", \\\"KeystoneCredential0\\\": \\\"zqMaYBIuD_kTfCr40wGp8xd-4ktaaxFw5fXgDU-jmoA=\\\", \\\"KeystoneCredential1\\\": \\\"r7REmf3xn6uL3R27wMKrAxhrkUHdo81MTnlutsUhovo=\\\", \\\"KeystoneFernetKey0\\\": \\\"ItJM0NBSZ-8j1S6tdyAz2xrW0ye0fIAhbJt_TLpyNwQ=\\\", \\\"KeystoneFernetKey1\\\": \\\"HXHrOqjdnV8nWFk2vpd-XGi-dYZfTca5R1HxotZRqLY=\\\", \\\"KeystoneFernetKeys\\\": {\\\"/etc/keystone/fernet-keys/0\\\": {\\\"content\\\": \\\"PM3chMNQx1M23AD22klBwyQA19LgeWw2e2WJVR0wZww=\\\"}, \\\"/etc/keystone/fernet-keys/1\\\": {\\\"content\\\": \\\"w_PliztpzZgOzBqlwk5JfwGIQnJ3mm4izttxiUEwFfk=\\\"}}, \\\"LibvirtTLSPassword\\\": \\\"2CigqEmSelPTodxLFsXPpqGIh\\\", \\\"ManilaPassword\\\": \\\"auGoVpyu2MEiNV30leSb4snLG\\\", \\\"MigrationSshKey\\\": {\\\"private_key\\\": \\\"-----BEGIN RSA PRIVATE KEY-----\\\\nMIIEowIBAAKCAQEAx7OJOLUh7uP1iFvGNxIt7TBz50pfxHvSdisfQgt/Qf64FRZ3\\\\nhSpucam/BGC5ZWr23lhFXpHTGGjdMfNNveJ+X8GT51cvPuE4NDnKZp4lFir9YMWn\\\\nGDiltZj5QIPS5QzOrIcj52CzglqvdfZ7U+ATbTpQQVElV1Pfe9oMWKuqz8Khiw6j\\\\npxe9KONdTxH3yGVH95t/Hw5vljAucOAGcwAsJWLfKfKkHeUFcn3Q7icwNUcuR1wJ\\\\n5HgL3nKBZNxsX34wRdRLJxf0tsx6qWfcaV40+41J7Ul5hOLCE0J9l4+LafiJW+Pp\\\\ntFd1TAq4/GwPYocjSBVOfi+YMIsma5jumfUCVwIDAQABAoIBABX5GDEoJPqvFHYT\\\\newTWOD1v5mDdmxn4cdjUt9TBhRgS2dhgJ3h8ibhx7/WgWuXg1hby6XcVXn/CEgyL\\\\n89Lf1/3bQ9Xhju5BQ7jjXvTZk8UTp9t9A/yzRvBrS4mgt5TCSv9Kw1WTG01Ngx7c\\\\npwc8kYakMu5s6knojZ+IB3G+OcYwNzaotlurZUwwrI+pVMOIV6WT4aeO6lXnR9d1\\\\n1kCKWCraNe8mbPeHsetTRNURwz8FGpZjgRrUZZRZZ/qCJJ30eiYw+KGG+Tnbmv3V\\\\n5b8Io+wYYs/oXTzqVMyX+drO79SjAus5/pNYeu1V3UWdp05OEjVIT5pBjNMr7fAk\\\\nzz1vihECgYEAzqT6fS6CKrG2Mni0SmvTl5RYLpbLzC4X8Icxz/YTkHSWkY5vUP2J\\\\nveCdVBkFfxDwe/2VJ/yJeSGxX9gCxRc9ZzjRK9q70MIaPcjHiWK52Io7o5H+TJpD\\\\nwXMqWgUcZ8FSsG8EagEhEBDzOfcxkdylG1+7vYcULyw3cZsrLFh6mj8CgYEA92YH\\\\nMRKG1xqyTly+Az5+5wbw1jbxKqM3z8Lsq3ynkYe+v81qQbJirvLuSsOAeCJx1ViT\\\\n4pGTLaN6XYPUHFyyz9fl4B+thKrcBzgkFaWIPuEjHGNYoBKleUwI/92K3fMHWYnB\\\\npjT3wuzjyOGxvfWXmhbov0Y77TK8ZVL53m9joekCgYEApdV8OE3EpGKtpt97QGY8\\\\nDl88TVczAg7To3G7pfsDRGBsHS/DYam2iqzhVYYnBQwhEkA1HTvrT0ycvh/qSSUX\\\\nX+kW5CzLoQLEcGTazQRvxLlalzAodm0uhubXTBrh6toYdAMD9dYmJHCV4SThoP8D\\\\neW5gif8HUbwYWpF+Gj5/VZ0CgYBoRYJmdm6Knt/kE0aqy15lNRGw17tRwzU0xe1G\\\\nYeWmetY0tPlB81OQdSdmL3woJixgRVMfPUgRBkP+wh9WTOO4okBq9C8IKZNPH6Rl\\\\n0zzXc8B+qIij/vfrZdatMMzkuxev71XFHbIHYBypgCaP78ET2vACHjIHyUiKVCyo\\\\nSb5ucQKBgG8csUOr1aqF0FYvxNg6DMrcSDSKzNwh6mPFtBv0s28QexuI4dKxu6FZ\\\\noeS1UUv0Ik1m9MnT+NoUnlx2OeYGG4cHpZ6cVqVNY7dB40Mdx50GBERFpxwFNPTV\\\\nAOaGFnWR0XlSSusiaVRacvgewcPqoxt/ZJNdsgZh2N665KRoPydt\\\\n-----END RSA PRIVATE KEY-----\\\\n\\\", \\\"public_key\\\": \\\"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDHs4k4tSHu4/WIW8Y3Ei3tMHPnSl/Ee9J2Kx9CC39B/rgVFneFKm5xqb8EYLllavbeWEVekdMYaN0x80294n5fwZPnVy8+4Tg0OcpmniUWKv1gxacYOKW1mPlAg9LlDM6shyPnYLOCWq919ntT4BNtOlBBUSVXU9972gxYq6rPwqGLDqOnF70o411PEffIZUf3m38fDm+WMC5w4AZzACwlYt8p8qQd5QVyfdDuJzA1Ry5HXAnkeAvecoFk3GxffjBF1EsnF/S2zHqpZ9xpXjT7jUntSXmE4sITQn2Xj4tp+Ilb4+m0V3VMCrj8bA9ihyNIFU5+L5gwiyZrmO6Z9QJX Generated by TripleO\\\"}, \\\"MysqlClustercheckPassword\\\": \\\"qVfKhK3S4eoAhDlTRZhbii2Z9\\\", \\\"MysqlMariabackupPassword\\\": \\\"zgFej84GkeJYRMxOd5txIKJHX\\\", \\\"MysqlRootPassword\\\": \\\"lewodgEGks\\\", \\\"NeutronMetadataProxySharedSecret\\\": \\\"8w93bMk7ykp2VXaxsdJErpmNY\\\", \\\"NeutronPassword\\\": \\\"qnvMdngIoyiS9ntQpzmg868ob\\\", \\\"NotifyPassword\\\": \\\"P1tv7vGOxYqa82YvPivN7nCmS\\\", \\\"NovaPassword\\\": \\\"1Ii49H1EfmLUfEWsgfy9vla3q\\\", \\\"NovajoinPassword\\\": \\\"lgr1Ha8NlbTu69W3S512jkIRE\\\", \\\"OctaviaCaKeyPassphrase\\\": \\\"BFiYF2wyc26XgT7g8KbGBrfVS\\\", \\\"OctaviaHeartbeatKey\\\": \\\"qzlb8AXveNyiQA84TVFR9nXri\\\", \\\"OctaviaPassword\\\": \\\"obLqJzGdUG63w0NRu0HjlPJbQ\\\", \\\"OctaviaServerCertsKeyPassphrase\\\": \\\"VrPJN4UV84DenH3WQUZbg7LJlMdRR5c5\\\", \\\"PacemakerRemoteAuthkey\\\": \\\" \\\", \\\"PankoPassword\\\": \\\"D1zHfGQ0L8W7eywLqFT1IwHwC\\\", \\\"PcsdPassword\\\": \\\"NvleZPciNHzWAChh\\\", \\\"PlacementPassword\\\": \\\"f10sfIlDF9m1IGLZ9AeeMIXIv\\\", \\\"RabbitCookie\\\": \\\"2ljqdppvti5CXNoMTl6c\\\", \\\"RabbitPassword\\\": \\\"IBD6qNR8tM6oqdPBU1tpCvaKF\\\", \\\"RedisPassword\\\": \\\"zTfbzAZoNB6iKueE7EslkZpK7\\\", \\\"RpcPassword\\\": \\\"ezCMjhKa1U6SzsSlqK3G7UGxC\\\", \\\"SaharaPassword\\\": \\\"Iv8GArANAjqjy5OFEkNsDoF28\\\", \\\"SnmpdReadonlyUserPassword\\\": \\\"KjPkLxPsqu3qjdbO0SJ0shPX\\\", \\\"SwiftHashSuffix\\\": \\\"dF7eJe9aaQv02P7wDZQuDq78C\\\", \\\"SwiftPassword\\\": \\\"QN915NTjnlQknPxmrojB6rIqt\\\"}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Deployed VIP port on the Control Plane network.\\\\n\\\", \\\"parameters\\\": {\\\"name\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"dns_name\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"network\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"fixed_ips\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"replacement_policy\\\": {\\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"tags\\\": {\\\"default\\\": [], \\\"type\\\": \\\"comma_delimited_list\\\"}, \\\"ControlPlaneVipData\\\": {\\\"description\\\": \\\"Control Plane Virtual IP data\\\\n\\\", \\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}}, \\\"outputs\\\": {\\\"name\\\": {\\\"value\\\": {\\\"get_param\\\": [\\\"ControlPlaneVipData\\\", \\\"name\\\"]}}, \\\"fixed_ips\\\": {\\\"value\\\": {\\\"get_param\\\": [\\\"ControlPlaneVipData\\\", \\\"fixed_ips\\\"]}}, \\\"network\\\": {\\\"value\\\": {\\\"get_param\\\": [\\\"ControlPlaneVipData\\\", \\\"network\\\"]}}, \\\"subnets\\\": {\\\"value\\\": {\\\"get_param\\\": [\\\"ControlPlaneVipData\\\", \\\"subnets\\\"]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Deployed VIP port on the External network.\\\\n\\\", \\\"parameters\\\": {\\\"StackName\\\": {\\\"description\\\": \\\"Name of the overcloud heat stack\\\", \\\"default\\\": \\\"overcloud\\\", \\\"type\\\": \\\"string\\\"}, \\\"PortName\\\": {\\\"description\\\": \\\"Name of the port\\\", \\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"DnsName\\\": {\\\"description\\\": \\\"DNS name of the port\\\", \\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneIP\\\": {\\\"description\\\": \\\"IP address on the control plane\\\", \\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneSubnetCidr\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneNetwork\\\": {\\\"description\\\": \\\"The name of the undercloud Neutron control plane\\\", \\\"default\\\": \\\"ctlplane\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneSubnet\\\": {\\\"description\\\": \\\"The name of the undercloud Neutron control plane subnet\\\", \\\"default\\\": \\\"ctlplane-subnet\\\", \\\"type\\\": \\\"string\\\"}, \\\"FixedIPs\\\": {\\\"description\\\": \\\"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\\\n\\\", \\\"default\\\": [], \\\"type\\\": \\\"json\\\"}, \\\"IPPool\\\": {\\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}, \\\"NodeIndex\\\": {\\\"default\\\": 0, \\\"type\\\": \\\"number\\\"}, \\\"IsVirtualIP\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"VipPortMap\\\": {\\\"description\\\": \\\"A map of deployed port data\\\\n\\\", \\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}}, \\\"outputs\\\": {\\\"ip_address\\\": {\\\"description\\\": \\\"External network VIP\\\", \\\"value\\\": {\\\"get_param\\\": [\\\"VipPortMap\\\", \\\"external\\\", \\\"ip_address\\\"]}}, \\\"ip_address_uri\\\": {\\\"description\\\": \\\"External network VIP (with brackets for IPv6 URLs)\\\", \\\"value\\\": {\\\"get_param\\\": [\\\"VipPortMap\\\", \\\"external\\\", \\\"ip_address_uri\\\"]}}, \\\"ip_subnet\\\": {\\\"description\\\": \\\"IP/Subnet CIDR for the External network VIP\\\", \\\"value\\\": {\\\"get_param\\\": [\\\"VipPortMap\\\", \\\"external\\\", \\\"ip_subnet\\\"]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Deployed VIP port on the InternalApi network.\\\\n\\\", \\\"parameters\\\": {\\\"StackName\\\": {\\\"description\\\": \\\"Name of the overcloud heat stack\\\", \\\"default\\\": \\\"overcloud\\\", \\\"type\\\": \\\"string\\\"}, \\\"PortName\\\": {\\\"description\\\": \\\"Name of the port\\\", \\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"DnsName\\\": {\\\"description\\\": \\\"DNS name of the port\\\", \\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneIP\\\": {\\\"description\\\": \\\"IP address on the control plane\\\", \\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneSubnetCidr\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneNetwork\\\": {\\\"description\\\": \\\"The name of the undercloud Neutron control plane\\\", \\\"default\\\": \\\"ctlplane\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneSubnet\\\": {\\\"description\\\": \\\"The name of the undercloud Neutron control plane subnet\\\", \\\"default\\\": \\\"ctlplane-subnet\\\", \\\"type\\\": \\\"string\\\"}, \\\"FixedIPs\\\": {\\\"description\\\": \\\"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\\\n\\\", \\\"default\\\": [], \\\"type\\\": \\\"json\\\"}, \\\"IPPool\\\": {\\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}, \\\"NodeIndex\\\": {\\\"default\\\": 0, \\\"type\\\": \\\"number\\\"}, \\\"IsVirtualIP\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"VipPortMap\\\": {\\\"description\\\": \\\"A map of deployed port data\\\\n\\\", \\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}}, \\\"outputs\\\": {\\\"ip_address\\\": {\\\"description\\\": \\\"InternalApi network VIP\\\", \\\"value\\\": {\\\"get_param\\\": [\\\"VipPortMap\\\", \\\"internal_api\\\", \\\"ip_address\\\"]}}, \\\"ip_address_uri\\\": {\\\"description\\\": \\\"InternalApi network VIP (with brackets for IPv6 URLs)\\\", \\\"value\\\": {\\\"get_param\\\": [\\\"VipPortMap\\\", \\\"internal_api\\\", \\\"ip_address_uri\\\"]}}, \\\"ip_subnet\\\": {\\\"description\\\": \\\"IP/Subnet CIDR for the InternalApi network VIP\\\", \\\"value\\\": {\\\"get_param\\\": [\\\"VipPortMap\\\", \\\"internal_api\\\", \\\"ip_subnet\\\"]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Deployed VIP port on the StorageMgmt network.\\\\n\\\", \\\"parameters\\\": {\\\"StackName\\\": {\\\"description\\\": \\\"Name of the overcloud heat stack\\\", \\\"default\\\": \\\"overcloud\\\", \\\"type\\\": \\\"string\\\"}, \\\"PortName\\\": {\\\"description\\\": \\\"Name of the port\\\", \\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"DnsName\\\": {\\\"description\\\": \\\"DNS name of the port\\\", \\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneIP\\\": {\\\"description\\\": \\\"IP address on the control plane\\\", \\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneSubnetCidr\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneNetwork\\\": {\\\"description\\\": \\\"The name of the undercloud Neutron control plane\\\", \\\"default\\\": \\\"ctlplane\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneSubnet\\\": {\\\"description\\\": \\\"The name of the undercloud Neutron control plane subnet\\\", \\\"default\\\": \\\"ctlplane-subnet\\\", \\\"type\\\": \\\"string\\\"}, \\\"FixedIPs\\\": {\\\"description\\\": \\\"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\\\n\\\", \\\"default\\\": [], \\\"type\\\": \\\"json\\\"}, \\\"IPPool\\\": {\\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}, \\\"NodeIndex\\\": {\\\"default\\\": 0, \\\"type\\\": \\\"number\\\"}, \\\"IsVirtualIP\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"VipPortMap\\\": {\\\"description\\\": \\\"A map of deployed port data\\\\n\\\", \\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}}, \\\"outputs\\\": {\\\"ip_address\\\": {\\\"description\\\": \\\"StorageMgmt network VIP\\\", \\\"value\\\": {\\\"get_param\\\": [\\\"VipPortMap\\\", \\\"storage_mgmt\\\", \\\"ip_address\\\"]}}, \\\"ip_address_uri\\\": {\\\"description\\\": \\\"StorageMgmt network VIP (with brackets for IPv6 URLs)\\\", \\\"value\\\": {\\\"get_param\\\": [\\\"VipPortMap\\\", \\\"storage_mgmt\\\", \\\"ip_address_uri\\\"]}}, \\\"ip_subnet\\\": {\\\"description\\\": \\\"IP/Subnet CIDR for the StorageMgmt network VIP\\\", \\\"value\\\": {\\\"get_param\\\": [\\\"VipPortMap\\\", \\\"storage_mgmt\\\", \\\"ip_subnet\\\"]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Deployed VIP port on the Storage network.\\\\n\\\", \\\"parameters\\\": {\\\"StackName\\\": {\\\"description\\\": \\\"Name of the overcloud heat stack\\\", \\\"default\\\": \\\"overcloud\\\", \\\"type\\\": \\\"string\\\"}, \\\"PortName\\\": {\\\"description\\\": \\\"Name of the port\\\", \\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"DnsName\\\": {\\\"description\\\": \\\"DNS name of the port\\\", \\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneIP\\\": {\\\"description\\\": \\\"IP address on the control plane\\\", \\\"default\\\": \\\"\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneSubnetCidr\\\": {\\\"default\\\": \\\"\\\", \\\"description\\\": \\\"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\\\n\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneNetwork\\\": {\\\"description\\\": \\\"The name of the undercloud Neutron control plane\\\", \\\"default\\\": \\\"ctlplane\\\", \\\"type\\\": \\\"string\\\"}, \\\"ControlPlaneSubnet\\\": {\\\"description\\\": \\\"The name of the undercloud Neutron control plane subnet\\\", \\\"default\\\": \\\"ctlplane-subnet\\\", \\\"type\\\": \\\"string\\\"}, \\\"FixedIPs\\\": {\\\"description\\\": \\\"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\\\n\\\", \\\"default\\\": [], \\\"type\\\": \\\"json\\\"}, \\\"IPPool\\\": {\\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}, \\\"NodeIndex\\\": {\\\"default\\\": 0, \\\"type\\\": \\\"number\\\"}, \\\"IsVirtualIP\\\": {\\\"type\\\": \\\"boolean\\\", \\\"default\\\": false}, \\\"VipPortMap\\\": {\\\"description\\\": \\\"A map of deployed port data\\\\n\\\", \\\"default\\\": {}, \\\"type\\\": \\\"json\\\"}}, \\\"outputs\\\": {\\\"ip_address\\\": {\\\"description\\\": \\\"Storage network VIP\\\", \\\"value\\\": {\\\"get_param\\\": [\\\"VipPortMap\\\", \\\"storage\\\", \\\"ip_address\\\"]}}, \\\"ip_address_uri\\\": {\\\"description\\\": \\\"Storage network VIP (with brackets for IPv6 URLs)\\\", \\\"value\\\": {\\\"get_param\\\": [\\\"VipPortMap\\\", \\\"storage\\\", \\\"ip_address_uri\\\"]}}, \\\"ip_subnet\\\": {\\\"description\\\": \\\"IP/Subnet CIDR for the Storage network VIP\\\", \\\"value\\\": {\\\"get_param\\\": [\\\"VipPortMap\\\", \\\"storage\\\", \\\"ip_subnet\\\"]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/env-vips_provision_out1-rmmfo_ec.yaml\": \"{\\\"parameter_defaults\\\": {\\\"ControlPlaneVipData\\\": {\\\"fixed_ips\\\": [{\\\"ip_address\\\": \\\"192.168.122.93\\\"}], \\\"name\\\": \\\"ctlplane_vip\\\", \\\"network\\\": {\\\"tags\\\": [\\\"192.168.122.0/24\\\"]}, \\\"subnets\\\": [{\\\"ip_version\\\": 4}]}, \\\"VipPortMap\\\": {\\\"external\\\": {\\\"ip_address\\\": \\\"172.21.0.83\\\", \\\"ip_address_uri\\\": \\\"172.21.0.83\\\", \\\"ip_subnet\\\": \\\"172.21.0.83/24\\\"}, \\\"internal_api\\\": {\\\"ip_address\\\": \\\"172.17.0.133\\\", \\\"ip_address_uri\\\": \\\"172.17.0.133\\\", \\\"ip_subnet\\\": \\\"172.17.0.133/24\\\"}, \\\"storage\\\": {\\\"ip_address\\\": \\\"172.18.0.143\\\", \\\"ip_address_uri\\\": \\\"172.18.0.143\\\", \\\"ip_subnet\\\": \\\"172.18.0.143/24\\\"}, \\\"storage_mgmt\\\": {\\\"ip_address\\\": \\\"172.20.0.153\\\", \\\"ip_address_uri\\\": \\\"172.20.0.153\\\", \\\"ip_subnet\\\": \\\"172.20.0.153/24\\\"}}}, \\\"resource_registry\\\": {\\\"OS::TripleO::Network::Ports::ControlPlaneVipPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\\\", \\\"OS::TripleO::Network::Ports::ExternalVipPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\\\", \\\"OS::TripleO::Network::Ports::InternalApiVipPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\\\", \\\"OS::TripleO::Network::Ports::StorageMgmtVipPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\\\", \\\"OS::TripleO::Network::Ports::StorageVipPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\\\"}}\", \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"description\\\": \\\"Create networks to split out Overcloud traffic\\\", \\\"parameters\\\": {\\\"DeployedNetworkEnvironment\\\": {\\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"Deployed network environment\\\"}, \\\"CtlplaneNetworkCidrs\\\": {\\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"Cidrs for the ctlplane network.\\\"}, \\\"CtlplaneNetworkAttributes\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {}, \\\"description\\\": \\\"A map containing attributes of the undercloud ctlplane network and subnets. NOTE: The value for this parameter is automatically populated in the plan environment by tripleoclient.\\\\n\\\"}}, \\\"resources\\\": {\\\"NetworkExtraConfig\\\": {\\\"type\\\": \\\"OS::TripleO::Network::ExtraConfig\\\"}, \\\"NetworkAttributesMap\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"value\\\": {\\\"map_merge\\\": [{\\\"ctlplane\\\": {\\\"get_param\\\": \\\"CtlplaneNetworkAttributes\\\"}}, {\\\"get_param\\\": [\\\"DeployedNetworkEnvironment\\\", \\\"net_attributes_map\\\"]}]}}}, \\\"NetworkCidrMap\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"value\\\": {\\\"map_merge\\\": [{\\\"ctlplane\\\": {\\\"get_param\\\": \\\"CtlplaneNetworkCidrs\\\"}}, {\\\"get_param\\\": [\\\"DeployedNetworkEnvironment\\\", \\\"net_cidr_map\\\"]}]}}}, \\\"NetworkIpVersionMap\\\": {\\\"type\\\": \\\"OS::Heat::Value\\\", \\\"properties\\\": {\\\"value\\\": {\\\"map_merge\\\": [{\\\"ctlplane\\\": {\\\"yaql\\\": {\\\"expression\\\": \\\"$.data.items().first().last().ip_version\\\", \\\"data\\\": {\\\"get_param\\\": [\\\"CtlplaneNetworkAttributes\\\", \\\"subnets\\\"]}}}}, {\\\"get_param\\\": [\\\"DeployedNetworkEnvironment\\\", \\\"net_ip_version_map\\\"]}]}}}}, \\\"outputs\\\": {\\\"net_cidr_map\\\": {\\\"value\\\": {\\\"get_attr\\\": [\\\"NetworkCidrMap\\\", \\\"value\\\"]}}, \\\"net_ip_version_map\\\": {\\\"value\\\": {\\\"get_attr\\\": [\\\"NetworkIpVersionMap\\\", \\\"value\\\"]}}, \\\"net_attributes_map\\\": {\\\"value\\\": {\\\"get_attr\\\": [\\\"NetworkAttributesMap\\\", \\\"value\\\"]}}}}\", \"file:///home/zuul/network_provision_out1.yaml\": \"{\\\"parameter_defaults\\\": {\\\"DeployedNetworkEnvironment\\\": {\\\"net_attributes_map\\\": {\\\"external\\\": {\\\"network\\\": {\\\"dns_domain\\\": \\\"external.ooo.test.\\\", \\\"mtu\\\": 1500, \\\"name\\\": \\\"external\\\", \\\"tags\\\": [\\\"tripleo_network_name=External\\\", \\\"tripleo_net_idx=4\\\", \\\"tripleo_service_net_map_replace=external\\\", \\\"tripleo_vip=true\\\"]}, \\\"subnets\\\": {\\\"external_subnet\\\": {\\\"cidr\\\": \\\"172.21.0.0/24\\\", \\\"dns_nameservers\\\": [], \\\"gateway_ip\\\": \\\"172.21.0.1\\\", \\\"host_routes\\\": [], \\\"ip_version\\\": 4, \\\"name\\\": \\\"external_subnet\\\", \\\"tags\\\": [\\\"tripleo_vlan_id=44\\\"]}}}, \\\"internal_api\\\": {\\\"network\\\": {\\\"dns_domain\\\": \\\"internal-api.ooo.test.\\\", \\\"mtu\\\": 1500, \\\"name\\\": \\\"internal_api\\\", \\\"tags\\\": [\\\"tripleo_network_name=InternalApi\\\", \\\"tripleo_net_idx=2\\\", \\\"tripleo_service_net_map_replace=internal_api\\\", \\\"tripleo_vip=true\\\"]}, \\\"subnets\\\": {\\\"internal_api_subnet\\\": {\\\"cidr\\\": \\\"172.17.0.0/24\\\", \\\"dns_nameservers\\\": [], \\\"gateway_ip\\\": null, \\\"host_routes\\\": [], \\\"ip_version\\\": 4, \\\"name\\\": \\\"internal_api_subnet\\\", \\\"tags\\\": [\\\"tripleo_vlan_id=20\\\"]}}}, \\\"storage\\\": {\\\"network\\\": {\\\"dns_domain\\\": \\\"storage.ooo.test.\\\", \\\"mtu\\\": 1500, \\\"name\\\": \\\"storage\\\", \\\"tags\\\": [\\\"tripleo_network_name=Storage\\\", \\\"tripleo_net_idx=0\\\", \\\"tripleo_service_net_map_replace=storage\\\", \\\"tripleo_vip=true\\\"]}, \\\"subnets\\\": {\\\"storage_subnet\\\": {\\\"cidr\\\": \\\"172.18.0.0/24\\\", \\\"dns_nameservers\\\": [], \\\"gateway_ip\\\": null, \\\"host_routes\\\": [], \\\"ip_version\\\": 4, \\\"name\\\": \\\"storage_subnet\\\", \\\"tags\\\": [\\\"tripleo_vlan_id=21\\\"]}}}, \\\"storage_mgmt\\\": {\\\"network\\\": {\\\"dns_domain\\\": \\\"storagemgmt.ooo.test.\\\", \\\"mtu\\\": 1500, \\\"name\\\": \\\"storage_mgmt\\\", \\\"tags\\\": [\\\"tripleo_network_name=StorageMgmt\\\", \\\"tripleo_net_idx=1\\\", \\\"tripleo_service_net_map_replace=storage_mgmt\\\", \\\"tripleo_vip=true\\\"]}, \\\"subnets\\\": {\\\"storage_mgmt_subnet\\\": {\\\"cidr\\\": \\\"172.20.0.0/24\\\", \\\"dns_nameservers\\\": [], \\\"gateway_ip\\\": null, \\\"host_routes\\\": [], \\\"ip_version\\\": 4, \\\"name\\\": \\\"storage_mgmt_subnet\\\", \\\"tags\\\": [\\\"tripleo_vlan_id=23\\\"]}}}, \\\"tenant\\\": {\\\"network\\\": {\\\"dns_domain\\\": \\\"tenant.ooo.test.\\\", \\\"mtu\\\": 1500, \\\"name\\\": \\\"tenant\\\", \\\"tags\\\": [\\\"tripleo_network_name=Tenant\\\", \\\"tripleo_net_idx=3\\\", \\\"tripleo_service_net_map_replace=tenant\\\"]}, \\\"subnets\\\": {\\\"tenant_subnet\\\": {\\\"cidr\\\": \\\"172.19.0.0/24\\\", \\\"dns_nameservers\\\": [], \\\"gateway_ip\\\": null, \\\"host_routes\\\": [], \\\"ip_version\\\": 4, \\\"name\\\": \\\"tenant_subnet\\\", \\\"tags\\\": [\\\"tripleo_vlan_id=22\\\"]}}}}, \\\"net_cidr_map\\\": {\\\"external\\\": [\\\"172.21.0.0/24\\\"], \\\"internal_api\\\": [\\\"172.17.0.0/24\\\"], \\\"storage\\\": [\\\"172.18.0.0/24\\\"], \\\"storage_mgmt\\\": [\\\"172.20.0.0/24\\\"], \\\"tenant\\\": [\\\"172.19.0.0/24\\\"]}, \\\"net_ip_version_map\\\": {\\\"external\\\": 4, \\\"internal_api\\\": 4, \\\"storage\\\": 4, \\\"storage_mgmt\\\": 4, \\\"tenant\\\": 4}}}, \\\"resource_registry\\\": {\\\"OS::TripleO::Network\\\": \\\"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\\\"}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/user-environments/tripleoclient-parameters.yaml\": \"{\\\"parameter_defaults\\\": {\\\"AdminPassword\\\": \\\"HmXexyLi08QZogEekmC36kfFy\\\", \\\"AdminToken\\\": \\\"eekZJjLtHXBTegIXyerHQdiCK\\\", \\\"AlertManagerContainerImage\\\": \\\"registry.redhat.io/openshift4/ose-prometheus-alertmanager:v4.12\\\", \\\"AodhPassword\\\": \\\"kA8SxpMSOhLQSpVJqBddUTC8A\\\", \\\"BarbicanPassword\\\": \\\"zaGX27Ti3i3pOGgmtuOmCsRpj\\\", \\\"BarbicanSimpleCryptoKek\\\": \\\"YtaGxXs1IMmALC6Hbm6M6D3Jp_akPFomp9CVy2_Hjow=\\\", \\\"BlockStorageServices\\\": [], \\\"CeilometerMeteringSecret\\\": \\\"f9sheptN8gBNFPtfNjBjUIUzG\\\", \\\"CeilometerPassword\\\": \\\"qbl62NddTmoBEMgPykjZL2yB0\\\", \\\"CellControllerComputeServices\\\": [], \\\"CellControllerServices\\\": [\\\"OS::TripleO::Services::BootParams\\\", \\\"OS::TripleO::Services::CACerts\\\", \\\"OS::TripleO::Services::Clustercheck\\\", \\\"OS::TripleO::Services::Collectd\\\", \\\"OS::TripleO::Services::ContainerImagePrepare\\\", \\\"OS::TripleO::Services::ContainersLogrotateCrond\\\", \\\"OS::TripleO::Services::HAproxy\\\", \\\"OS::TripleO::Services::Iscsid\\\", \\\"OS::TripleO::Services::Kernel\\\", \\\"OS::TripleO::Services::MetricsQdr\\\", \\\"OS::TripleO::Services::MySQL\\\", \\\"OS::TripleO::Services::MySQLClient\\\", \\\"OS::TripleO::Services::NovaConductor\\\", \\\"OS::TripleO::Services::NovaMetadata\\\", \\\"OS::TripleO::Services::NovaVncProxy\\\", \\\"OS::TripleO::Services::OsloMessagingRpc\\\", \\\"OS::TripleO::Services::Pacemaker\\\", \\\"OS::TripleO::Services::Podman\\\", \\\"OS::TripleO::Services::Rsyslog\\\", \\\"OS::TripleO::Services::Snmp\\\", \\\"OS::TripleO::Services::Sshd\\\", \\\"OS::TripleO::Services::Timesync\\\", \\\"OS::TripleO::Services::Timezone\\\", \\\"OS::TripleO::Services::TripleoFirewall\\\", \\\"OS::TripleO::Services::TripleoPackages\\\", \\\"OS::TripleO::Services::Tuned\\\"], \\\"CephClientKey\\\": \\\"AQBrwitqAAAAABAAxHvyiS6grJqY50Im4clPJg==\\\", \\\"CephClusterFSID\\\": \\\"b845fa31-b08e-44fd-ab60-5226bad3e713\\\", \\\"CephDashboardAdminPassword\\\": \\\"u0KTor49xMFNvwnZTUzkbV09F\\\", \\\"CephGrafanaAdminPassword\\\": \\\"qr4s1drj2pwo2s45BNtG913Of\\\", \\\"CephManilaClientKey\\\": \\\"AQBrwitqAAAAABAAZvUP19KAYghZUDJ8oyZZCg==\\\", \\\"CephRgwKey\\\": \\\"AQBrwitqAAAAABAA0HLrE1fOrOSjqWcrsnGzng==\\\", \\\"CephStorageServices\\\": [], \\\"CinderPassword\\\": \\\"qMYipEszf8YYzegOIcZXUKSlV\\\", \\\"ComputeServices\\\": [\\\"OS::TripleO::Services::BootParams\\\", \\\"OS::TripleO::Services::CACerts\\\", \\\"OS::TripleO::Services::Collectd\\\", \\\"OS::TripleO::Services::ComputeCeilometerAgent\\\", \\\"OS::TripleO::Services::CeilometerAgentIpmi\\\", \\\"OS::TripleO::Services::Iscsid\\\", \\\"OS::TripleO::Services::Kernel\\\", \\\"OS::TripleO::Services::MetricsQdr\\\", \\\"OS::TripleO::Services::MySQLClient\\\", \\\"OS::TripleO::Services::NovaCompute\\\", \\\"OS::TripleO::Services::NovaLibvirt\\\", \\\"OS::TripleO::Services::NovaLibvirtGuests\\\", \\\"OS::TripleO::Services::NovaMigrationTarget\\\", \\\"OS::TripleO::Services::ContainersLogrotateCrond\\\", \\\"OS::TripleO::Services::Podman\\\", \\\"OS::TripleO::Services::Rsyslog\\\", \\\"OS::TripleO::Services::Snmp\\\", \\\"OS::TripleO::Services::Sshd\\\", \\\"OS::TripleO::Services::Timesync\\\", \\\"OS::TripleO::Services::Timezone\\\", \\\"OS::TripleO::Services::TripleoFirewall\\\", \\\"OS::TripleO::Services::TripleoPackages\\\", \\\"OS::TripleO::Services::Tuned\\\", \\\"OS::TripleO::Services::OVNController\\\", \\\"OS::TripleO::Services::OVNMetadataAgent\\\"], \\\"CongressPassword\\\": \\\"Vr4THJN40yNjjo4qHKA76Ni8M\\\", \\\"ContainerAodhApiImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\\\", \\\"ContainerAodhConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-aodh-api:17.1\\\", \\\"ContainerAodhEvaluatorImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-aodh-evaluator:17.1\\\", \\\"ContainerAodhListenerImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-aodh-listener:17.1\\\", \\\"ContainerAodhNotifierImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-aodh-notifier:17.1\\\", \\\"ContainerBarbicanApiImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\\\", \\\"ContainerBarbicanConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\\\", \\\"ContainerBarbicanKeystoneListenerConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-barbican-keystone-listener:17.1\\\", \\\"ContainerBarbicanKeystoneListenerImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-barbican-keystone-listener:17.1\\\", \\\"ContainerBarbicanWorkerConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-barbican-worker:17.1\\\", \\\"ContainerBarbicanWorkerImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-barbican-worker:17.1\\\", \\\"ContainerCeilometerCentralImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\\\", \\\"ContainerCeilometerComputeImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\\\", \\\"ContainerCeilometerConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\\\", \\\"ContainerCeilometerIpmiImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\\\", \\\"ContainerCeilometerNotificationImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\\\", \\\"ContainerCephDaemonImage\\\": \\\"registry.redhat.io/rhceph/rhceph-6-rhel9:latest\\\", \\\"ContainerCinderApiImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\\\", \\\"ContainerCinderBackupImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\\\", \\\"ContainerCinderConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\\\", \\\"ContainerCinderSchedulerImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\\\", \\\"ContainerCinderVolumeImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\\\", \\\"ContainerClustercheckConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\\\", \\\"ContainerClustercheckImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\\\", \\\"ContainerCollectdConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\\\", \\\"ContainerCollectdImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\\\", \\\"ContainerCrondConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\\\", \\\"ContainerCrondImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\\\", \\\"ContainerDesignateApiConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-designate-api:17.1\\\", \\\"ContainerDesignateApiImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-designate-api:17.1\\\", \\\"ContainerDesignateBackendBIND9Image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-designate-backend-bind9:17.1\\\", \\\"ContainerDesignateCentralImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-designate-central:17.1\\\", \\\"ContainerDesignateConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-designate-base:17.1\\\", \\\"ContainerDesignateMDNSImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-designate-mdns:17.1\\\", \\\"ContainerDesignateProducerImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-designate-producer:17.1\\\", \\\"ContainerDesignateSinkImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-designate-sink:17.1\\\", \\\"ContainerDesignateWorkerImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-designate-worker:17.1\\\", \\\"ContainerEtcdConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-etcd:17.1\\\", \\\"ContainerEtcdImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-etcd:17.1\\\", \\\"ContainerFrrImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-frr:17.1\\\", \\\"ContainerGlanceApiConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\\\", \\\"ContainerGlanceApiImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\\\", \\\"ContainerGlanceApiInternalConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\\\", \\\"ContainerGnocchiApiImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\\\", \\\"ContainerGnocchiConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-api:17.1\\\", \\\"ContainerGnocchiMetricdImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-metricd:17.1\\\", \\\"ContainerGnocchiStatsdImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-gnocchi-statsd:17.1\\\", \\\"ContainerHAProxyConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\\\", \\\"ContainerHAProxyImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\\\", \\\"ContainerHeatAllImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-heat-all:17.1\\\", \\\"ContainerHeatApiCfnConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\\\", \\\"ContainerHeatApiCfnImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\\\", \\\"ContainerHeatApiConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\\\", \\\"ContainerHeatApiImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\\\", \\\"ContainerHeatConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\\\", \\\"ContainerHeatEngineImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\\\", \\\"ContainerHorizonConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\\\", \\\"ContainerHorizonImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\\\", \\\"ContainerIronicApiConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ironic-api:17.1\\\", \\\"ContainerIronicApiImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ironic-api:17.1\\\", \\\"ContainerIronicConductorImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ironic-conductor:17.1\\\", \\\"ContainerIronicConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ironic-pxe:17.1\\\", \\\"ContainerIronicInspectorConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ironic-inspector:17.1\\\", \\\"ContainerIronicInspectorImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ironic-inspector:17.1\\\", \\\"ContainerIronicNeutronAgentImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ironic-neutron-agent:17.1\\\", \\\"ContainerIronicPxeImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ironic-pxe:17.1\\\", \\\"ContainerIscsidConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\\\", \\\"ContainerIscsidImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\\\", \\\"ContainerKeystoneConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\\\", \\\"ContainerKeystoneImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\\\", \\\"ContainerManilaApiImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\\\", \\\"ContainerManilaConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\\\", \\\"ContainerManilaSchedulerImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\\\", \\\"ContainerManilaShareImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\\\", \\\"ContainerMemcachedConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\\\", \\\"ContainerMemcachedImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\\\", \\\"ContainerMetricsQdrConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\\\", \\\"ContainerMetricsQdrImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\\\", \\\"ContainerMultipathdConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-multipathd:17.1\\\", \\\"ContainerMultipathdImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-multipathd:17.1\\\", \\\"ContainerMysqlClientConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\\\", \\\"ContainerMysqlConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\\\", \\\"ContainerMysqlImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\\\", \\\"ContainerNeutronApiImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\\\", \\\"ContainerNeutronConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\\\", \\\"ContainerNeutronDHCPImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-neutron-dhcp-agent:17.1\\\", \\\"ContainerNeutronL3AgentImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-neutron-l3-agent:17.1\\\", \\\"ContainerNeutronMetadataImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent:17.1\\\", \\\"ContainerNeutronMlnxImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-neutron-mlnx-agent:17.1\\\", \\\"ContainerNeutronSriovImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-neutron-sriov-agent:17.1\\\", \\\"ContainerNovaApiImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\\\", \\\"ContainerNovaComputeImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\\\", \\\"ContainerNovaComputeIronicImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-compute-ironic:17.1\\\", \\\"ContainerNovaConductorImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\\\", \\\"ContainerNovaConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\\\", \\\"ContainerNovaLibvirtConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"ContainerNovaLibvirtImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"ContainerNovaMetadataConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\\\", \\\"ContainerNovaMetadataImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\\\", \\\"ContainerNovaSchedulerImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\\\", \\\"ContainerNovaVncProxyImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\\\", \\\"ContainerNovajoinConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-novajoin-server:17.1\\\", \\\"ContainerNovajoinNotifierImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-novajoin-notifier:17.1\\\", \\\"ContainerNovajoinServerImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-novajoin-server:17.1\\\", \\\"ContainerOctaviaApiImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-octavia-api:17.1\\\", \\\"ContainerOctaviaConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-octavia-api:17.1\\\", \\\"ContainerOctaviaDriverAgentConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-octavia-api:17.1\\\", \\\"ContainerOctaviaDriverAgentImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-octavia-api:17.1\\\", \\\"ContainerOctaviaHealthManagerImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-octavia-health-manager:17.1\\\", \\\"ContainerOctaviaHousekeepingImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-octavia-housekeeping:17.1\\\", \\\"ContainerOctaviaRsyslogImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\\\", \\\"ContainerOctaviaWorkerImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-octavia-worker:17.1\\\", \\\"ContainerOpenvswitchImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-neutron-openvswitch-agent:17.1\\\", \\\"ContainerOvnBgpAgentImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-bgp-agent:17.1\\\", \\\"ContainerOvnControllerConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\", \\\"ContainerOvnControllerImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\", \\\"ContainerOvnDbsConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\\\", \\\"ContainerOvnDbsImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\\\", \\\"ContainerOvnMetadataImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\\\", \\\"ContainerOvnNbDbImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\\\", \\\"ContainerOvnNorthdImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\\\", \\\"ContainerOvnSbDbImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\\\", \\\"ContainerPlacementConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\\\", \\\"ContainerPlacementImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\\\", \\\"ContainerQdrouterdConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\\\", \\\"ContainerQdrouterdImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\\\", \\\"ContainerRabbitmqConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\\\", \\\"ContainerRabbitmqImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\\\", \\\"ContainerRedisConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\\\", \\\"ContainerRedisImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\\\", \\\"ContainerRsyslogConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\\\", \\\"ContainerRsyslogImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\\\", \\\"ContainerRsyslogSidecarConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\\\", \\\"ContainerRsyslogSidecarImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\\\", \\\"ContainerSwiftAccountImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\\\", \\\"ContainerSwiftConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\\\", \\\"ContainerSwiftContainerImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\\\", \\\"ContainerSwiftObjectImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\\\", \\\"ContainerSwiftProxyImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\\\", \\\"ContainerTempestImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-tempest:17.1\\\", \\\"ContainerTripleoClientImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-tripleoclient:17.1\\\", \\\"ContainerUnboundConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-unbound:17.1\\\", \\\"ContainerUnboundImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-unbound:17.1\\\", \\\"ControllerServices\\\": [], \\\"CtlplaneNetworkAttributes\\\": {\\\"network\\\": {\\\"dns_domain\\\": \\\"ctlplane.ooo.test.\\\", \\\"mtu\\\": 1450, \\\"name\\\": \\\"ctlplane\\\", \\\"tags\\\": [\\\"192.168.122.0/24\\\"]}, \\\"subnets\\\": {\\\"ctlplane-subnet\\\": {\\\"cidr\\\": \\\"192.168.122.0/24\\\", \\\"dns_nameservers\\\": [\\\"192.168.122.10\\\"], \\\"gateway_ip\\\": \\\"192.168.122.10\\\", \\\"host_routes\\\": [], \\\"ip_version\\\": 4, \\\"name\\\": \\\"ctlplane-subnet\\\"}}}, \\\"DeployIdentifier\\\": 1781252715, \\\"DesignatePassword\\\": \\\"OlYZhpAoM1Vp87tPLEtrUcZc0\\\", \\\"DesignateRndcKey\\\": \\\"wFIOx63DytPdBgw5Yg2VzYP5dsYjzGFFK16oyIGuK8o=\\\", \\\"Ec2ApiPassword\\\": \\\"q8ZM1Yd9b87n7PdEJfn16y6Nr\\\", \\\"EtcdInitialClusterToken\\\": \\\"VEeAGD062AfwCHIxlknSQRfiq\\\", \\\"GlancePassword\\\": \\\"cIsppw1Aum3ETzdsifE2C6Rtu\\\", \\\"GnocchiPassword\\\": \\\"HdSGspdH5D2LRe5nAtUW2M3cr\\\", \\\"GrafanaContainerImage\\\": \\\"registry.redhat.io/rhceph/rhceph-6-dashboard-rhel9:latest\\\", \\\"HAProxyStatsPassword\\\": \\\"9vRKKTFF2kkxOwUnidNpqREXc\\\", \\\"HeatAuthEncryptionKey\\\": \\\"gLE7s5Sj03kfqFVmS8dt3fr1vV26PW9b\\\", \\\"HeatPassword\\\": \\\"bBwSYpUotp5mhkJpXzxxlbFPE\\\", \\\"HeatStackDomainAdminPassword\\\": \\\"d8RK1hW7lbIg3VpbTZexxh1bl\\\", \\\"HorizonSecret\\\": \\\"dGAlh7USQr\\\", \\\"IronicPassword\\\": \\\"fxqle2mZ3MnX44L6LlMAo9x7s\\\", \\\"KeystoneCredential0\\\": \\\"T4GwFraLjqMp-QE0X4yJsM2_9lpbMmQZqvhiYB4ho6c=\\\", \\\"KeystoneCredential1\\\": \\\"sMmQSW8nJwmMlYg3cNEUVfQyqOdT89ixpuNuDKlNnlo=\\\", \\\"KeystoneFernetKey0\\\": \\\"q0UfBEy5CAaWU7YJDVrr-nuMWJhZqX0GqEHBLO8UnnI=\\\", \\\"KeystoneFernetKey1\\\": \\\"tM_chaLv1i4lYTwLMfwiYdJXLPsYZMBXvTnxQHmVYXk=\\\", \\\"KeystoneFernetKeys\\\": {\\\"/etc/keystone/fernet-keys/0\\\": {\\\"content\\\": \\\"Asm4xmsJIYt54YnYhs1EjPaomkgrv81hwT8tUNsI8ks=\\\"}, \\\"/etc/keystone/fernet-keys/1\\\": {\\\"content\\\": \\\"x0VsHdf-ts1AbN8YbMH-VNrpoZFaju1UkzpSNQcEwoM=\\\"}}, \\\"LibvirtTLSPassword\\\": \\\"53rQ9zntU64jTSkK4m2ImikXr\\\", \\\"ManilaPassword\\\": \\\"XcM2ji2YZQEnyc0rdLS01HfsU\\\", \\\"MigrationSshKey\\\": {\\\"private_key\\\": \\\"-----BEGIN RSA PRIVATE KEY-----\\\\nMIIEpAIBAAKCAQEA1UEIFcONSRrLf8YhEP+mDs7c54PfaQ0Vg2GxJJ1CEtjzK+ac\\\\nb0G7GrhqQ90+U2W/f+Whz6zs2F7DlrUn3t8yCVDhoHRKWEYGpD1xIXkUC8mujQ/7\\\\nOzkltx7EC3ubcIBUr66xXa9XQ2zlOqfjwL63/sMrtwYe1oaif6br8gHkYK2RK9AS\\\\niNTtT4ZHAuiyRiPfRee5MmiRtfRdTsRoYVk8uUACr3xUKBFcVro4RKaAGiiUNQhN\\\\nB/TklZetSE373XA3XbvVdmIongGq5qVYrS26Ov82Sto/KwksegUJ5yIW7Q0tAbWH\\\\nlL7WEct3yYNyR99dS448anBcuquycMe334S8rQIDAQABAoIBAA/6o3nIrAQs9yVH\\\\n2fUayCfr5YQ4zrthuO7zRFa+AdQaYCjgoBrQuLhegSKR/WLlCN2zKIDAha62IGm2\\\\ngUT4lxiORZnER53TAW8Pu4kKjYSkmWkF0t6z1YOh0TFwaEvxvGa9lu9c0r5r9nEt\\\\nYKocoE99SFVFJs0O9uDMcnmGcsUGQ/XWblUJ3+uHcss7vnOXVO67tjb4qbLxoUbr\\\\nGs/0KLHJ27ZqG9cc8ercpsoDA3xzCc7GTvn/1z4HDFyNzYw7KP4tQEj9zcUP8OfZ\\\\nThgwF0aD3VV4qu8SjA7G1t3ZjqGY0886X0iBfkSa7yW/WBYOlNTS7KjJmSgTcPNJ\\\\n9Gvl/QECgYEA2lBskkfZjMa36a92e6hSIjhs/s1aJ55Zgi2H3zkR3ZxGi+pA0cXy\\\\neWGgGGPhpDgI30egi6YigoPk8eA7Yq9DoIunlYiwsmn9UDZwfphEWIGvFZdFXaym\\\\nPtPOVYsUJA/n+yHz+sKml0czGdVdd1WH3X//5uLVhhIl2CYlVtqZyD0CgYEA+hD+\\\\nfwfD/5D4tpL70mt4vYBGIVYIDd/2qk5lqgOzkAPjSC98UBCdnc512/fkD0cyWzx/\\\\n/fo/B5xRXXOjItcc0P/ErFB+ty7sVzlNFBzuIuQs00TR0Zb8Gdtx+qqTukIrYJS2\\\\nTDx4yX2WJ9csI/QCjFZyYkPJKzuAlgfkxlXonTECgYEAlqliBCGptUl+qrr4naYv\\\\n6IXgUogNa8IQK5KYbijId5Pd67kiOqLND4+cGLj1g4tYNB8OYNGqhz/WxEXnNdeW\\\\naDl40e2fY8FZm/217OfQYvQ8jD31FQyNPlaV0ttEbw67Hcj0w12J8mSkk3N4KV7R\\\\ngL9RL1nj2b60d1L7+dCqyFECgYEArVpKktVXUju1rxuF5wEJ2pSqCUISo0u3O6jN\\\\nYWbfe962GLySeQ6LtXIC0lKujsjUZ9sw/2gTebsrzJT1apmlKF2mga3rqiGlRXI7\\\\ntM25aAa17F+w9JKugV5XTWYisuRcHb/6AC+LrGKbTVMlDmeBvLfQ474KHyZIpbkj\\\\nJzs23oECgYBn9ecOD3iMyzdkgH72jrvjqRpPFEMll/FFua8ww3fgj9JzBLq3aVRx\\\\naF0SxJGbbkv9X5gli+2I5wJDLUiRv8lZlHLNL88jLBZkTC+VkNn9EL4G/s6Ilz6h\\\\nYhgUeNu40WUkYxjoSt9K4YTWKl2ys/2KIamy9GnUVFj9NxII/uEGIQ==\\\\n-----END RSA PRIVATE KEY-----\\\\n\\\", \\\"public_key\\\": \\\"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDVQQgVw41JGst/xiEQ/6YOztzng99pDRWDYbEknUIS2PMr5pxvQbsauGpD3T5TZb9/5aHPrOzYXsOWtSfe3zIJUOGgdEpYRgakPXEheRQLya6ND/s7OSW3HsQLe5twgFSvrrFdr1dDbOU6p+PAvrf+wyu3Bh7WhqJ/puvyAeRgrZEr0BKI1O1PhkcC6LJGI99F57kyaJG19F1OxGhhWTy5QAKvfFQoEVxWujhEpoAaKJQ1CE0H9OSVl61ITfvdcDddu9V2YiieAarmpVitLbo6/zZK2j8rCSx6BQnnIhbtDS0BtYeUvtYRy3fJg3JH311LjjxqcFy6q7Jwx7ffhLyt Generated by TripleO\\\"}, \\\"MysqlClustercheckPassword\\\": \\\"onDwWyOgBIAVPNFnNkDa2UtWc\\\", \\\"MysqlMariabackupPassword\\\": \\\"0odLFyInGgmhbWwKab1TPlvX0\\\", \\\"MysqlRootPassword\\\": \\\"SDgQzbiCGM\\\", \\\"NetworkerServices\\\": [], \\\"NeutronMetadataProxySharedSecret\\\": \\\"P6gbMtcBjSZwXXATC7YNuiJEv\\\", \\\"NeutronPassword\\\": \\\"EJSZkPd6GbX05q3YpUTPvyPln\\\", \\\"NodeExporterContainerImage\\\": \\\"registry.redhat.io/openshift4/ose-prometheus-node-exporter:v4.12\\\", \\\"NotifyPassword\\\": \\\"QaYaNF8MAADwQx0BrUiSoJUzI\\\", \\\"NovaComputeLibvirtType\\\": \\\"qemu\\\", \\\"NovaPassword\\\": \\\"V9NGETfEBAQV3j3MdsXIIJESX\\\", \\\"NovajoinPassword\\\": \\\"hLYKY88fDDKRYpuc1U7eJm891\\\", \\\"NtpServer\\\": \\\"pool.ntp.org\\\", \\\"ObjectStorageServices\\\": [], \\\"OctaviaCaKeyPassphrase\\\": \\\"GSQJ8DExWBlw3f8fkep0NwYj6\\\", \\\"OctaviaHeartbeatKey\\\": \\\"Y0EUvob6iepQ5WaMWGnwOkNBR\\\", \\\"OctaviaPassword\\\": \\\"0HWayzjoh8thQCNV0hzo80k5G\\\", \\\"OctaviaServerCertsKeyPassphrase\\\": \\\"QV6r33ddi4WG6auFPY6m85FELM42WV2d\\\", \\\"PacemakerRemoteAuthkey\\\": \\\" \\\", \\\"PankoPassword\\\": \\\"rBnRfIyppdQMBjPjXky9DtyDg\\\", \\\"PcsdPassword\\\": \\\"HRzf9hfUVv2xyGVJ\\\", \\\"PlacementPassword\\\": \\\"k2MAW87JedUpIQHnFU4okAiux\\\", \\\"PrometheusContainerImage\\\": \\\"registry.redhat.io/openshift4/ose-prometheus:v4.12\\\", \\\"RabbitCookie\\\": \\\"DX6sgwWSL88yhQ89wA7B\\\", \\\"RabbitPassword\\\": \\\"520BvAu8N2LW2UCheRX5alhLI\\\", \\\"RedisPassword\\\": \\\"iA1YyfsvCwHpNjYswgE9aRjrn\\\", \\\"RootStackName\\\": \\\"cell1\\\", \\\"RpcPassword\\\": \\\"OCIHSVV1GSDlveVWbJFb76ljy\\\", \\\"SaharaPassword\\\": \\\"Z9RuVLDI2I5HWcCanoCRiBtvx\\\", \\\"SnmpdReadonlyUserPassword\\\": \\\"lAwYZ7oSnUXohSg35oYekrG0\\\", \\\"SwiftHashSuffix\\\": \\\"aI07qnnhtl43Lmsihb2Q8DRMP\\\", \\\"SwiftPassword\\\": \\\"m7JxFBTOj2UnUlHZFZbaAg477\\\", \\\"UndercloudHostsEntries\\\": [\\\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\\\"]}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\": \"{\\\"heat_template_version\\\": \\\"wallaby\\\", \\\"parameters\\\": {\\\"RootStackName\\\": {\\\"description\\\": \\\"The name of the stack/plan.\\\", \\\"type\\\": \\\"string\\\"}, \\\"image\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"unused\\\"}, \\\"flavor\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"unused\\\"}, \\\"key_name\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"unused\\\", \\\"description\\\": \\\"Name of keypair to assign to servers\\\"}, \\\"security_groups\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": []}, \\\"user_data_format\\\": {\\\"type\\\": \\\"string\\\"}, \\\"user_data\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\"}, \\\"name\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"deployed-server\\\"}, \\\"image_update_policy\\\": {\\\"type\\\": \\\"string\\\", \\\"default\\\": \\\"\\\"}, \\\"networks\\\": {\\\"type\\\": \\\"comma_delimited_list\\\", \\\"default\\\": \\\"\\\"}, \\\"metadata\\\": {\\\"type\\\": \\\"json\\\", \\\"default\\\": {}}, \\\"software_config_transport\\\": {\\\"default\\\": \\\"POLL_SERVER_CFN\\\", \\\"type\\\": \\\"string\\\"}, \\\"scheduler_hints\\\": {\\\"type\\\": \\\"json\\\", \\\"description\\\": \\\"Optional scheduler hints to pass to nova\\\", \\\"default\\\": {}}, \\\"UpgradeInitCommand\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Command or script snippet to run on all overcloud nodes to\\\\ninitialize the upgrade process. E.g. a repository switch.\\\\n\\\", \\\"default\\\": \\\"\\\", \\\"tags\\\": [\\\"role_specific\\\"]}, \\\"UpgradeInitCommonCommand\\\": {\\\"type\\\": \\\"string\\\", \\\"description\\\": \\\"Common commands required by the upgrades process. This should not\\\\nnormally be modified by the operator and is set and unset in the\\\\nmajor-upgrade-composable-steps.yaml and major-upgrade-converge.yaml\\\\nenvironment files.\\\\n\\\", \\\"default\\\": \\\"\\\"}, \\\"ControlPlaneSubnet\\\": {\\\"default\\\": \\\"ctlplane-subnet\\\", \\\"description\\\": \\\"The name of the undercloud Neutron control plane subnet\\\", \\\"type\\\": \\\"string\\\"}}, \\\"resources\\\": {\\\"deployed-server\\\": {\\\"type\\\": \\\"OS::Heat::DeployedServer\\\", \\\"properties\\\": {\\\"name\\\": {\\\"get_param\\\": \\\"name\\\"}, \\\"software_config_transport\\\": {\\\"get_param\\\": \\\"software_config_transport\\\"}}}, \\\"ControlPlanePort\\\": {\\\"type\\\": \\\"OS::TripleO::DeployedServer::ControlPlanePort\\\", \\\"properties\\\": {\\\"network\\\": \\\"ctlplane\\\", \\\"fixed_ips\\\": [{\\\"subnet\\\": {\\\"get_param\\\": \\\"ControlPlaneSubnet\\\"}}], \\\"name\\\": {\\\"list_join\\\": [\\\"-\\\", [{\\\"get_param\\\": \\\"name\\\"}, \\\"ctlplane\\\"]]}, \\\"replacement_policy\\\": \\\"AUTO\\\", \\\"tags\\\": [{\\\"str_replace\\\": {\\\"template\\\": \\\"tripleo_stack_name=$STACK_NAME\\\", \\\"params\\\": {\\\"$STACK_NAME\\\": {\\\"get_param\\\": \\\"RootStackName\\\"}}}}]}}}, \\\"outputs\\\": {\\\"OS::stack_id\\\": {\\\"value\\\": {\\\"get_resource\\\": \\\"deployed-server\\\"}}, \\\"networks\\\": {\\\"value\\\": {\\\"ctlplane\\\": [{\\\"get_attr\\\": [\\\"ControlPlanePort\\\", \\\"fixed_ips\\\", 0, \\\"ip_address\\\"]}]}}, \\\"addresses\\\": {\\\"value\\\": {\\\"ctlplane\\\": [{\\\"subnets\\\": {\\\"get_attr\\\": [\\\"ControlPlanePort\\\", \\\"subnets\\\"]}}]}}, \\\"name\\\": {\\\"value\\\": {\\\"get_param\\\": \\\"name\\\"}}, \\\"os_collect_config\\\": {\\\"value\\\": {\\\"get_attr\\\": [\\\"deployed-server\\\", \\\"os_collect_config\\\"]}}}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/environments/deployed-server-environment.yaml\": \"{\\\"resource_registry\\\": {\\\"OS::TripleO::Server\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-server.yaml\\\", \\\"OS::TripleO::DeployedServer::ControlPlanePort\\\": \\\"OS::Neutron::Port\\\", \\\"OS::TripleO::Controller::Net::SoftwareConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::CellController::Net::SoftwareConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Compute::Net::SoftwareConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::BlockStorage::Net::SoftwareConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::ObjectStorage::Net::SoftwareConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::CephStorage::Net::SoftwareConfig\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::Networker::Net::SoftwareConfig\\\": \\\"OS::Heat::None\\\"}, \\\"parameter_defaults\\\": {\\\"EnablePackageInstall\\\": true, \\\"ControllerNetworkConfigTemplate\\\": \\\"templates/net_config_static_bridge.j2\\\", \\\"CellControllerNetworkConfigTemplate\\\": \\\"templates/net_config_static_bridge.j2\\\", \\\"CellControllerComputeNetworkConfigTemplate\\\": \\\"templates/net_config_static_bridge.j2\\\", \\\"ComputeNetworkConfigTemplate\\\": \\\"templates/net_config_static_bridge.j2\\\", \\\"BlockStorageNetworkConfigTemplate\\\": \\\"templates/net_config_static_bridge.j2\\\", \\\"ObjectStorageNetworkConfigTemplate\\\": \\\"templates/net_config_static_bridge.j2\\\", \\\"CephStorageNetworkConfigTemplate\\\": \\\"templates/net_config_static_bridge.j2\\\", \\\"NetworkerNetworkConfigTemplate\\\": \\\"templates/net_config_static_bridge.j2\\\"}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/env-config-download-cell1-pf36x3z7.yaml\": \"{\\\"parameter_defaults\\\": {\\\"CtlplaneNetworkAttributes\\\": {\\\"network\\\": {\\\"dns_domain\\\": \\\"localdomain\\\", \\\"mtu\\\": 1500, \\\"name\\\": \\\"ctlplane\\\", \\\"tags\\\": [\\\"192.168.122.0/24\\\"]}, \\\"subnets\\\": {\\\"ctlplane-subnet\\\": {\\\"cidr\\\": \\\"192.168.122.0/24\\\", \\\"dns_nameservers\\\": [\\\"192.168.122.10\\\", \\\"192.168.122.1\\\"], \\\"gateway_ip\\\": \\\"192.168.122.10\\\", \\\"host_routes\\\": [], \\\"ip_version\\\": 4, \\\"name\\\": \\\"ctlplane-subnet\\\"}}}, \\\"DeployedServerPortMap\\\": {\\\"compute-2-ctlplane\\\": {\\\"fixed_ips\\\": [{\\\"ip_address\\\": \\\"192.168.122.109\\\"}], \\\"network\\\": {\\\"tags\\\": [\\\"192.168.122.0/24\\\"]}, \\\"subnets\\\": [{\\\"cidr\\\": \\\"192.168.122.0/24\\\"}]}, \\\"controller-0-ctlplane\\\": {\\\"fixed_ips\\\": [{\\\"ip_address\\\": \\\"192.168.122.103\\\"}], \\\"network\\\": {\\\"tags\\\": [\\\"192.168.122.0/24\\\"]}, \\\"subnets\\\": [{\\\"cidr\\\": \\\"192.168.122.0/24\\\"}]}, \\\"np0000071538-ctlplane\\\": {\\\"fixed_ips\\\": [{\\\"ip_address\\\": \\\"192.168.122.106\\\"}], \\\"network\\\": {\\\"tags\\\": [\\\"192.168.122.0/24\\\"]}, \\\"subnets\\\": [{\\\"cidr\\\": \\\"192.168.122.0/24\\\"}]}, \\\"np0000071539-ctlplane\\\": {\\\"fixed_ips\\\": [{\\\"ip_address\\\": \\\"192.168.122.107\\\"}], \\\"network\\\": {\\\"tags\\\": [\\\"192.168.122.0/24\\\"]}, \\\"subnets\\\": [{\\\"cidr\\\": \\\"192.168.122.0/24\\\"}]}}, \\\"NodePortMap\\\": {\\\"compute-2\\\": {\\\"ctlplane\\\": {\\\"ip_address\\\": \\\"192.168.122.109\\\", \\\"ip_address_uri\\\": \\\"192.168.122.109\\\", \\\"ip_subnet\\\": \\\"192.168.122.0/24\\\"}, \\\"external\\\": {\\\"ip_address\\\": \\\"172.21.0.109\\\", \\\"ip_address_uri\\\": \\\"172.21.0.109\\\", \\\"ip_subnet\\\": \\\"172.21.0.0/24\\\"}, \\\"internal_api\\\": {\\\"ip_address\\\": \\\"172.17.0.109\\\", \\\"ip_address_uri\\\": \\\"172.17.0.109\\\", \\\"ip_subnet\\\": \\\"172.17.0.0/24\\\"}, \\\"storage\\\": {\\\"ip_address\\\": \\\"172.18.0.109\\\", \\\"ip_address_uri\\\": \\\"172.18.0.109\\\", \\\"ip_subnet\\\": \\\"172.18.0.0/24\\\"}, \\\"storage_mgmt\\\": {\\\"ip_address\\\": \\\"172.20.0.109\\\", \\\"ip_address_uri\\\": \\\"172.20.0.109\\\", \\\"ip_subnet\\\": \\\"172.20.0.0/24\\\"}, \\\"tenant\\\": {\\\"ip_address\\\": \\\"172.19.0.109\\\", \\\"ip_address_uri\\\": \\\"172.19.0.109\\\", \\\"ip_subnet\\\": \\\"172.19.0.0/24\\\"}}, \\\"controller-0\\\": {\\\"ctlplane\\\": {\\\"ip_address\\\": \\\"192.168.122.103\\\", \\\"ip_address_uri\\\": \\\"192.168.122.103\\\", \\\"ip_subnet\\\": \\\"192.168.122.0/24\\\"}, \\\"external\\\": {\\\"ip_address\\\": \\\"172.21.0.103\\\", \\\"ip_address_uri\\\": \\\"172.21.0.103\\\", \\\"ip_subnet\\\": \\\"172.21.0.0/24\\\"}, \\\"internal_api\\\": {\\\"ip_address\\\": \\\"172.17.0.103\\\", \\\"ip_address_uri\\\": \\\"172.17.0.103\\\", \\\"ip_subnet\\\": \\\"172.17.0.0/24\\\"}, \\\"storage\\\": {\\\"ip_address\\\": \\\"172.18.0.103\\\", \\\"ip_address_uri\\\": \\\"172.18.0.103\\\", \\\"ip_subnet\\\": \\\"172.18.0.0/24\\\"}, \\\"storage_mgmt\\\": {\\\"ip_address\\\": \\\"172.20.0.103\\\", \\\"ip_address_uri\\\": \\\"172.20.0.103\\\", \\\"ip_subnet\\\": \\\"172.20.0.0/24\\\"}, \\\"tenant\\\": {\\\"ip_address\\\": \\\"172.19.0.103\\\", \\\"ip_address_uri\\\": \\\"172.19.0.103\\\", \\\"ip_subnet\\\": \\\"172.19.0.0/24\\\"}}, \\\"np0000071538\\\": {\\\"ctlplane\\\": {\\\"ip_address\\\": \\\"192.168.122.106\\\", \\\"ip_address_uri\\\": \\\"192.168.122.106\\\", \\\"ip_subnet\\\": \\\"192.168.122.0/24\\\"}, \\\"external\\\": {\\\"ip_address\\\": \\\"172.21.0.106\\\", \\\"ip_address_uri\\\": \\\"172.21.0.106\\\", \\\"ip_subnet\\\": \\\"172.21.0.0/24\\\"}, \\\"internal_api\\\": {\\\"ip_address\\\": \\\"172.17.0.106\\\", \\\"ip_address_uri\\\": \\\"172.17.0.106\\\", \\\"ip_subnet\\\": \\\"172.17.0.0/24\\\"}, \\\"storage\\\": {\\\"ip_address\\\": \\\"172.18.0.106\\\", \\\"ip_address_uri\\\": \\\"172.18.0.106\\\", \\\"ip_subnet\\\": \\\"172.18.0.0/24\\\"}, \\\"storage_mgmt\\\": {\\\"ip_address\\\": \\\"172.20.0.106\\\", \\\"ip_address_uri\\\": \\\"172.20.0.106\\\", \\\"ip_subnet\\\": \\\"172.20.0.0/24\\\"}, \\\"tenant\\\": {\\\"ip_address\\\": \\\"172.19.0.106\\\", \\\"ip_address_uri\\\": \\\"172.19.0.106\\\", \\\"ip_subnet\\\": \\\"172.19.0.0/24\\\"}}, \\\"np0000071539\\\": {\\\"ctlplane\\\": {\\\"ip_address\\\": \\\"192.168.122.107\\\", \\\"ip_address_uri\\\": \\\"192.168.122.107\\\", \\\"ip_subnet\\\": \\\"192.168.122.0/24\\\"}, \\\"external\\\": {\\\"ip_address\\\": \\\"172.21.0.107\\\", \\\"ip_address_uri\\\": \\\"172.21.0.107\\\", \\\"ip_subnet\\\": \\\"172.21.0.0/24\\\"}, \\\"internal_api\\\": {\\\"ip_address\\\": \\\"172.17.0.107\\\", \\\"ip_address_uri\\\": \\\"172.17.0.107\\\", \\\"ip_subnet\\\": \\\"172.17.0.0/24\\\"}, \\\"storage\\\": {\\\"ip_address\\\": \\\"172.18.0.107\\\", \\\"ip_address_uri\\\": \\\"172.18.0.107\\\", \\\"ip_subnet\\\": \\\"172.18.0.0/24\\\"}, \\\"storage_mgmt\\\": {\\\"ip_address\\\": \\\"172.20.0.107\\\", \\\"ip_address_uri\\\": \\\"172.20.0.107\\\", \\\"ip_subnet\\\": \\\"172.20.0.0/24\\\"}, \\\"tenant\\\": {\\\"ip_address\\\": \\\"172.19.0.107\\\", \\\"ip_address_uri\\\": \\\"172.19.0.107\\\", \\\"ip_subnet\\\": \\\"172.19.0.0/24\\\"}}}}, \\\"resource_registry\\\": {\\\"OS::TripleO::CellController::Ports::ExternalPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\\\", \\\"OS::TripleO::CellController::Ports::InternalApiPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\\\", \\\"OS::TripleO::CellController::Ports::StorageMgmtPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\\\", \\\"OS::TripleO::CellController::Ports::StoragePort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\\\", \\\"OS::TripleO::CellController::Ports::TenantPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\\\", \\\"OS::TripleO::CellControllerCompute::Ports::ExternalPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\\\", \\\"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\\\", \\\"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\\\", \\\"OS::TripleO::CellControllerCompute::Ports::StoragePort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\\\", \\\"OS::TripleO::CellControllerCompute::Ports::TenantPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\\\", \\\"OS::TripleO::Compute::Ports::ExternalPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\\\", \\\"OS::TripleO::Compute::Ports::InternalApiPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\\\", \\\"OS::TripleO::Compute::Ports::StorageMgmtPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\\\", \\\"OS::TripleO::Compute::Ports::StoragePort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\\\", \\\"OS::TripleO::Compute::Ports::TenantPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\\\", \\\"OS::TripleO::Controller::Ports::ExternalPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_external.yaml\\\", \\\"OS::TripleO::Controller::Ports::InternalApiPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\\\", \\\"OS::TripleO::Controller::Ports::StorageMgmtPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\\\", \\\"OS::TripleO::Controller::Ports::StoragePort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_storage.yaml\\\", \\\"OS::TripleO::Controller::Ports::TenantPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_tenant.yaml\\\", \\\"OS::TripleO::DeployedServer::ControlPlanePort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\\\", \\\"OS::TripleO::OVNMacAddressNetwork\\\": \\\"OS::Heat::None\\\", \\\"OS::TripleO::OVNMacAddressPort\\\": \\\"OS::Heat::None\\\"}}\", \"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/env-vips_provision_out1-8wx7506o.yaml\": \"{\\\"parameter_defaults\\\": {\\\"ControlPlaneVipData\\\": {\\\"fixed_ips\\\": [{\\\"ip_address\\\": \\\"192.168.122.93\\\"}], \\\"name\\\": \\\"ctlplane_vip\\\", \\\"network\\\": {\\\"tags\\\": [\\\"192.168.122.0/24\\\"]}, \\\"subnets\\\": [{\\\"ip_version\\\": 4}]}, \\\"VipPortMap\\\": {\\\"external\\\": {\\\"ip_address\\\": \\\"172.21.0.83\\\", \\\"ip_address_uri\\\": \\\"172.21.0.83\\\", \\\"ip_subnet\\\": \\\"172.21.0.83/24\\\"}, \\\"internal_api\\\": {\\\"ip_address\\\": \\\"172.17.0.133\\\", \\\"ip_address_uri\\\": \\\"172.17.0.133\\\", \\\"ip_subnet\\\": \\\"172.17.0.133/24\\\"}, \\\"storage\\\": {\\\"ip_address\\\": \\\"172.18.0.143\\\", \\\"ip_address_uri\\\": \\\"172.18.0.143\\\", \\\"ip_subnet\\\": \\\"172.18.0.143/24\\\"}, \\\"storage_mgmt\\\": {\\\"ip_address\\\": \\\"172.20.0.153\\\", \\\"ip_address_uri\\\": \\\"172.20.0.153\\\", \\\"ip_subnet\\\": \\\"172.20.0.153/24\\\"}}}, \\\"resource_registry\\\": {\\\"OS::TripleO::Network::Ports::ControlPlaneVipPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\\\", \\\"OS::TripleO::Network::Ports::ExternalVipPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\\\", \\\"OS::TripleO::Network::Ports::InternalApiVipPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\\\", \\\"OS::TripleO::Network::Ports::StorageMgmtVipPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\\\", \\\"OS::TripleO::Network::Ports::StorageVipPort\\\": \\\"file:///home/zuul/overcloud-deploy/cell1/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\\\"}}\"}','2026-06-12 08:25:34',NULL);
/*!40000 ALTER TABLE `raw_template_files` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `resource`
--

DROP TABLE IF EXISTS `resource`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `resource` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `uuid` varchar(36) DEFAULT NULL,
  `nova_instance` varchar(255) DEFAULT NULL,
  `name` varchar(255) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `action` varchar(255) DEFAULT NULL,
  `status` varchar(255) DEFAULT NULL,
  `status_reason` text DEFAULT NULL,
  `stack_id` varchar(36) NOT NULL,
  `rsrc_metadata` longtext DEFAULT NULL,
  `properties_data` longtext DEFAULT NULL,
  `engine_id` varchar(36) DEFAULT NULL,
  `atomic_key` int(11) DEFAULT NULL,
  `needed_by` longtext DEFAULT NULL,
  `requires` longtext DEFAULT NULL,
  `replaces` int(11) DEFAULT NULL,
  `replaced_by` int(11) DEFAULT NULL,
  `current_template_id` int(11) DEFAULT NULL,
  `properties_data_encrypted` tinyint(1) DEFAULT NULL,
  `root_stack_id` varchar(36) DEFAULT NULL,
  `rsrc_prop_data_id` int(11) DEFAULT NULL,
  `attr_data_id` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `uuid` (`uuid`),
  KEY `stack_id` (`stack_id`),
  KEY `current_template_id` (`current_template_id`),
  KEY `ix_resource_root_stack_id` (`root_stack_id`),
  KEY `rsrc_rsrc_prop_data_ref` (`rsrc_prop_data_id`),
  KEY `rsrc_attr_data_ref` (`attr_data_id`),
  CONSTRAINT `resource_ibfk_1` FOREIGN KEY (`stack_id`) REFERENCES `stack` (`id`),
  CONSTRAINT `resource_ibfk_2` FOREIGN KEY (`current_template_id`) REFERENCES `raw_template` (`id`),
  CONSTRAINT `rsrc_attr_data_ref` FOREIGN KEY (`attr_data_id`) REFERENCES `resource_properties_data` (`id`),
  CONSTRAINT `rsrc_rsrc_prop_data_ref` FOREIGN KEY (`rsrc_prop_data_id`) REFERENCES `resource_properties_data` (`id`),
  CONSTRAINT `CONSTRAINT_1` CHECK (`properties_data_encrypted` in (0,1))
) ENGINE=InnoDB AUTO_INCREMENT=668 DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `resource`
--

LOCK TABLES `resource` WRITE;
/*!40000 ALTER TABLE `resource` DISABLE KEYS */;
INSERT INTO `resource` VALUES (1,'8f95a53c-f987-4aa6-aa05-4920ee8c9109','cell1-CephStorageConfigData-vjxzq6hzljj4','CephStorageConfigData','2026-06-12 08:25:35',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[111, 58, 2]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1046,1163),(2,'d45471a4-13c4-42c2-bedf-6c183d27dfad','cell1-CephStorageServiceConfigSettings-fqqtytkfi4ne','CephStorageServiceConfigSettings','2026-06-12 08:25:35',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[118, 116, 114, 113, 112, 111, 110, 109, 58]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1042,1044),(3,'d0cbde5f-3e47-4f76-925c-e162d25b9b6c','cell1-NetworkerGroupVars-65r6i7imxxs7','NetworkerGroupVars','2026-06-12 08:25:35',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[137, 110, 105, 86]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1071,1164),(4,'9df85b01-5fc6-44ad-a162-ef40347cc5e7','cell1-BlockStorageGroupVars-jlk7y2o7qwyb','BlockStorageGroupVars','2026-06-12 08:25:35',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[137, 109, 105, 9]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1077,1165),(5,'d8cad99f-f1b5-498d-9da6-47a19c5a1e33','cell1-CellControllerComputeGroupVars-tdprwxmmvwm7','CellControllerComputeGroupVars','2026-06-12 08:25:35',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[137, 112, 105, 21]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1076,1166),(6,'ebe9b979-f2f7-4e1e-aef9-92741973ad86','eb51d9bf-7120-406e-8c6c-5325c3703725','CellControllerNetworkConfig','2026-06-12 08:25:35',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[137]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',NULL,1154),(7,'b1335683-e0ea-44b0-82f2-6c035889718c','7c785d97-b839-4f30-a1ea-8bcdc99ab460','CellControllerComputeNetworkConfig','2026-06-12 08:25:35',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[137]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',NULL,1155),(8,'55b60b97-9b45-4548-934a-daedbe395f2d','80f2ace2-f881-4110-bcea-a8e8c1c6ca4d','BlockStorageIpListMap','2026-06-12 08:25:35',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[64, 63, 10, 9]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',540,1158),(9,'657d43f8-fd3c-41eb-9abd-27169134b988','cell1-BlockStorageServiceNetMapLower-d275hrsx2q7y','BlockStorageServiceNetMapLower','2026-06-12 08:25:35',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[139]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',13,19),(10,'0068cae5-7cca-442b-be68-2a0cb5b901c5','cell1-BlockStorageNetworkHostnameMap-ik34ziagrsxf','BlockStorageNetworkHostnameMap','2026-06-12 08:25:35',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[63]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',533,535),(11,'e76b151a-1b29-4060-b086-ade299e48429','cell1-CephStorageGroupVars-aya3fhtwwfi2','CephStorageGroupVars','2026-06-12 08:25:35',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[137, 111, 105, 44]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1069,1167),(12,'029ee048-f14d-47a2-aac0-64aed3e30eab','cell1-CellControllerComputeConfigData-pixrjubj5yci','CellControllerComputeConfigData','2026-06-12 08:25:35',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[112, 61, 13]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1051,1168),(13,'83c22d92-2de6-4fe8-bdd0-5358d4ad2e62','cell1-CellControllerComputeServiceConfigSettings-72bn42b4elms','CellControllerComputeServiceConfigSettings','2026-06-12 08:25:35',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[118, 116, 114, 113, 112, 111, 110, 109, 61]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1045,1049),(14,'02b8453a-b69d-4e5f-bc86-c6657451243c','cell1-CellControllerGroupVars-4x5wtublqrj2','CellControllerGroupVars','2026-06-12 08:25:35',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[137, 114, 105, 95]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1072,1169),(15,'684eb473-31e8-4f23-be5a-78ddfc3e6399','cell1-ServerIdMap-6izr5bue5ndt','ServerIdMap','2026-06-12 08:25:35',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[94, 88, 68, 63, 62, 60, 59, 57]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1133,1180),(16,'52a132ff-df71-4c47-93db-b130f0cd755d','cell1-BlacklistedIpAddresses-yr67ofjkcmx7','BlacklistedIpAddresses','2026-06-12 08:25:35',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[94, 88, 68, 63, 62, 60, 59, 57]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1135,1181),(17,'57d168b3-ee82-4fad-bda1-8eea2eca1454','cell1-ControllerConfigData-7lpoqjl5c2ft','ControllerConfigData','2026-06-12 08:25:35',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[116, 73, 18]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1057,1170),(18,'9343dc30-d805-4155-86b0-18fdd9394bd7','cell1-ControllerServiceConfigSettings-cvoyawjuhxbq','ControllerServiceConfigSettings','2026-06-12 08:25:35',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[118, 116, 114, 113, 112, 111, 110, 109, 73]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1052,1054),(19,'a8e00da0-b05f-4705-af1f-c8c6f397ca19','cell1-ControllerGroupVars-obnql6uoadna','ControllerGroupVars','2026-06-12 08:25:35',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[137, 116, 105, 39]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1070,1171),(20,'dbfae2a3-e84a-4cf4-b702-f41ed85e3561','33071ff6-11f7-4e05-9afb-d1cb49009351','CellControllerComputeIpListMap','2026-06-12 08:25:35',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[61, 60, 22, 21]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',586,1184),(21,'8b5bce50-b6e6-4272-8e51-5ffd16caabe7','cell1-CellControllerComputeServiceNetMapLower-e4vw42fvxtsq','CellControllerComputeServiceNetMapLower','2026-06-12 08:25:35',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[139]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',18,20),(22,'e397bdba-4439-4726-9c63-008038ef0970','cell1-CellControllerComputeNetworkHostnameMap-ojsehhrzppn2','CellControllerComputeNetworkHostnameMap','2026-06-12 08:25:35',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[60]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',572,583),(23,'52057531-9baa-47d8-b4dd-fd03edbdfbd3','cell1-BlockStorageConfigData-pwe3vjjak5jr','BlockStorageConfigData','2026-06-12 08:25:35',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[109, 64, 24]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1053,1172),(24,'a43bb311-822e-415b-832d-b5bf8d878219','cell1-BlockStorageServiceConfigSettings-cw4cf2sdxmyr','BlockStorageServiceConfigSettings','2026-06-12 08:25:35',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[118, 116, 114, 113, 112, 111, 110, 109, 64]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1048,1050),(25,'28e68ba4-1bc4-4b8e-9ecb-5f3273a6fab5','cell1-CellControllerConfigData-xdq3yquonc5e','CellControllerConfigData','2026-06-12 08:25:35',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[114, 102, 26]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1060,1173),(26,'a2a5bf6a-d4c2-47fa-8314-4b8c7de95fe1','cell1-CellControllerServiceConfigSettings-p6wuykrklp3k','CellControllerServiceConfigSettings','2026-06-12 08:25:35',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[118, 116, 114, 113, 112, 111, 110, 109, 102]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1055,1056),(27,'b2be21e8-9113-47b4-8bfc-252df3fe0ebb','e07a6867-11cb-4e48-b7e6-f6bbf0eda32a','ObjectStorageIpListMap','2026-06-12 08:25:35',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[117, 106, 59, 28]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',620,1161),(28,'4d9634aa-3e7f-4202-883a-0699b0a040c7','cell1-ObjectStorageNetworkHostnameMap-ear6p5gzmnfk','ObjectStorageNetworkHostnameMap','2026-06-12 08:25:35',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[59]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',614,617),(29,'5e8220ce-ad9d-45bd-8fcf-d71942ac755a','cell1-BlacklistedHostnames-lpnntvpieigo','BlacklistedHostnames','2026-06-12 08:25:35',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[94, 88, 68, 63, 62, 60, 59, 57]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1130,1185),(30,'27bb4d44-b8da-43be-abfd-6d46f9fff860','cell1-ComputeGroupVars-hpvy3it3wtke','ComputeGroupVars','2026-06-12 08:25:35',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[137, 113, 105, 35]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1073,1174),(31,'93144206-f1be-4ce6-8eb9-9d219c6e1fc2','cell1-AnsibleHostVars-zzxrx2jriqqg','AnsibleHostVars','2026-06-12 08:25:35',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[94, 88, 68, 63, 62, 60, 59, 57]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1134,1186),(32,'afc37a11-9d96-45c1-a697-242b82eb7490','5a423e0c-5d78-4074-8a44-4cfd1d162b5b','ControllerNetworkConfig','2026-06-12 08:25:35',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[137]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',NULL,1162),(33,'c64562a1-5a0a-4286-a03d-78e8949a9256','620da531-8651-4d32-9af9-2963023b0223','ObjectStorageNetworkConfig','2026-06-12 08:25:35',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[137]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',NULL,1175),(34,'f50dd4f1-89fb-4550-93d1-c066ddfdd3b2','2cfa992e-d0c6-4a3f-91d2-52ea9e6fcba3','ComputeIpListMap','2026-06-12 08:25:35',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[84, 68, 36, 35]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1089,1178),(35,'e1d06498-9e8f-4897-a752-3d9c45be7a33','cell1-ComputeServiceNetMapLower-rf46r7q5azey','ComputeServiceNetMapLower','2026-06-12 08:25:35',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[139]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',9,14),(36,'00097446-0c5d-46d3-8847-7b06a4f6962c','cell1-ComputeNetworkHostnameMap-nuymluaas5cg','ComputeNetworkHostnameMap','2026-06-12 08:25:35',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[68]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1086,1087),(37,'886072b4-dc54-4d85-9958-d70fc782e4eb','cell1-GlobalConfig-3bo4ksega4vu','GlobalConfig','2026-06-12 08:25:35',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[118, 116, 114, 113, 112, 111, 110, 109]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1058,1179),(38,'4ecb9edb-1884-4e84-99e6-3a997f0a7c3c','3ea5f60c-c110-4771-96e6-ffd95c93bbdd','ControllerIpListMap','2026-06-12 08:25:35',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[73, 62, 40, 39]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',593,1189),(39,'7570f626-23d0-49b3-acf9-a580adac0ae7','cell1-ControllerServiceNetMapLower-tmzd2b2xb5rg','ControllerServiceNetMapLower','2026-06-12 08:25:35',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[139]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',11,16),(40,'24206d6d-ad8c-4ba8-94c6-d93d488d4eaf','cell1-ControllerNetworkHostnameMap-xkfnrqsca3ln','ControllerNetworkHostnameMap','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[62]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',582,587),(41,'f63a4c41-a0b3-4cce-b921-a21e077bb2e8','cell1-NetworkerConfigData-ztvawp3dutcb','NetworkerConfigData','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[110, 91, 42]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1067,1190),(42,'2ae1017e-0e11-4e4d-9e01-5b3f7337b135','cell1-NetworkerServiceConfigSettings-4tiocevocal6','NetworkerServiceConfigSettings','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[118, 116, 114, 113, 112, 111, 110, 109, 91]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1063,1065),(43,'ed1484f3-864a-4a91-aeee-645e7168e33b','5c998268-8060-4729-b055-5c45de716e21','CephStorageIpListMap','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[58, 57, 45, 44]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',575,1193),(44,'3e1332e0-ded7-4eb3-a71f-052dd39ad3d5','cell1-CephStorageServiceNetMapLower-5m66247bgmxa','CephStorageServiceNetMapLower','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[139]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',8,10),(45,'469774dc-585d-4435-bc30-ad4a0619c5c3','cell1-CephStorageNetworkHostnameMap-inkylvdjo5g4','CephStorageNetworkHostnameMap','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[57]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',561,571),(46,'c86372d3-6360-44cd-aa9f-370c023e6540','910c56fe-55bb-4a6c-a9ef-f5db3a808aeb','AllNodesDeploySteps','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[139, 138, 137, 130, 127, 126, 118, 117, 116, 114, 113, 112, 111, 110, 109, 102, 94, 91, 88, 84, 77, 73, 68, 67, 64, 63, 62, 61, 60, 59, 58, 57, 56, 55, 54, 53, 52, 51, 50, 49, 48, 47]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1141,1201),(47,'1799be84-d3bc-419a-a6b2-b4aefd8aa163','86332ec9-c563-4499-9c3f-03b835849666','AllNodesExtraConfig','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,2,'[]','[55, 54, 53, 52, 51, 50, 49, 48]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',NULL,NULL),(48,'87f0ca5c-c843-42a2-bac8-3e204a1c1ee5','cell1-CellControllerServers-fiwiiod7bss4','CellControllerServers','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[94]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1129,1138),(49,'84eb593d-838b-4423-a402-cc76d3ca75f8','cell1-ObjectStorageServers-ii4drocowwj5','ObjectStorageServers','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[59]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',618,624),(50,'b0fd8e5d-1d32-432a-8fa8-577f681dc95b','cell1-CephStorageServers-gkq5gkyp3ds5','CephStorageServers','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[57]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',545,558),(51,'077a3ef2-fa63-49df-8c08-3bcda4480d6d','cell1-NetworkerServers-tx72mmdxupxs','NetworkerServers','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[88]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',536,566),(52,'d98e1cbd-97cd-420e-aade-344ab84f6783','cell1-ControllerServers-eduxzxmy4hf5','ControllerServers','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[62]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',581,594),(53,'2101578f-6ca3-4fc1-8b8c-1e913e1b532a','cell1-CellControllerComputeServers-7qlmumqqcv4p','CellControllerComputeServers','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[60]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',569,577),(54,'423ab08f-43a5-40ce-9d2d-a766ad7b4eb3','cell1-BlockStorageServers-btsduvbdvmep','BlockStorageServers','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[63]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',539,552),(55,'f4e2ed3f-455c-454e-a0fb-df43c9b50685','cell1-ComputeServers-ktsflt2of3j7','ComputeServers','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[68]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1085,1088),(56,'f5b0eb03-34ea-4f56-ba56-f88edc376aec','cell1-HostsEntryValue-6vru5l23b2yd','HostsEntryValue','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[94, 88, 68, 67, 63, 62, 60, 59, 57]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1128,1136),(57,'16bed310-8f97-479d-a7e4-10ea49158b9b','5befeaa1-dc7f-4614-b1b8-c00bb4b633af','CephStorage','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[139, 137, 126, 111, 96, 78, 58]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',484,557),(58,'ca0532b1-4513-4c84-918b-b8bab28bf067','cell1-CephStorageServiceNames-zbcfcpfakmvr','CephStorageServiceNames','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[121, 111]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',469,493),(59,'50f85e42-fe8a-4b46-b4fb-efdef7967e57','7585cd69-d480-470b-983f-9e7db34c857f','ObjectStorage','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[139, 137, 126, 118, 117, 96, 71]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',547,616),(60,'a7b413f6-0739-4004-8a12-0475b28d56ba','ac9109b8-accc-4549-bf53-f6d0802e55c3','CellControllerCompute','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[139, 137, 126, 112, 96, 72, 61]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',526,576),(61,'32f1fac3-53c3-43f1-8e4a-fed7f63fd7d5','cell1-CellControllerComputeServiceNames-h4ktymzpd6wd','CellControllerComputeServiceNames','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[125, 112]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',486,527),(62,'d39459f6-7d06-46a1-8348-c9568ec2944f','20e5f319-308e-4d54-8aa6-2e65c7e250a0','Controller','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[139, 137, 126, 116, 96, 75, 73]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',517,580),(63,'e86c9060-3d0d-44e2-aa5f-0260a46c0109','1ff3e92f-9b0f-4f8d-84ca-b1b090a3706e','BlockStorage','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[139, 137, 126, 109, 96, 65, 64]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',470,534),(64,'b51fb175-e7ae-4566-acc9-b8d5ea3f7cbe','cell1-BlockStorageServiceNames-kzxhv22r7mlv','BlockStorageServiceNames','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[119, 109]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',425,467),(65,'4a0fece0-9fa7-4889-b5c1-cb74737ac468','b3ca0023-b8d9-4644-ace7-7e45825a3fd8','BlockStorageUserData','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,2,'[]','[100, 99, 98, 66]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',110,NULL),(66,'5ea43e9d-e911-4d0b-b418-5ecdf733da69','1d100aff-0e07-4c2c-9435-35b0a942253c','BlockStorageRoleUserData','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',NULL,23),(67,'6d544d21-b77e-47c3-8d42-470e49a75d3e','cell1-VipHosts-pq5xpzwvitjb','VipHosts','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[130]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',61,62),(68,'d67a4173-adba-4470-b92c-09b39119b6be','d9b1942a-b512-41cf-8930-ff20a5f2f41d','Compute','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[139, 137, 126, 113, 96, 84, 69]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',935,1084),(69,'072b6fa7-dfd6-4b2a-836d-abc0841f6f1a','e6c7f922-11d5-4ad5-b28d-5383f2775679','ComputeUserData','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,2,'[]','[100, 99, 98, 70]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',91,NULL),(70,'4e14c80f-175e-42b2-b813-dc8487ebb38b','5bdeb4aa-f303-4207-9bd1-393ec399a46a','ComputeRoleUserData','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',NULL,80),(71,'7e35a139-4b1e-4f3b-904a-fecb067658b0','31f8fa8d-bf43-41a5-a22a-61fc16c8f882','ObjectStorageUserData','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,2,'[]','[100, 99, 98, 74]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',92,NULL),(72,'7aa1329b-21f0-4269-bb98-c89d5fae5239','9fb16131-79c8-4342-b300-7905233f7a70','CellControllerComputeUserData','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,2,'[]','[100, 99, 98, 80]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',100,NULL),(73,'bd467f5d-e03f-4c23-b154-01039bff9a7c','cell1-ControllerServiceNames-yi7ah66um725','ControllerServiceNames','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[122, 116]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',474,500),(74,'7dafe417-24b8-4659-ad60-3d9d5b5a9942','0a8c9f8c-59ce-49a0-bd86-da18f38bb157','ObjectStorageRoleUserData','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',NULL,26),(75,'bdf8e669-3692-4349-9098-2c77afd34d07','e8aa603a-c31c-4f4e-b47f-3a39060b577d','ControllerUserData','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,2,'[]','[100, 99, 98, 76]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',102,NULL),(76,'9fea99f5-70ba-45e8-9b95-6876358e1bf3','7cfeddf9-35ae-475e-9333-0c409e1797c0','ControllerRoleUserData','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',NULL,51),(77,'1af8bf19-2c95-424d-8da3-2b8b7c71328e','cell1-CloudNames-etjmsunprpyz','CloudNames','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',55,56),(78,'c026f4c1-2072-4b21-a108-1e5059e873a2','cc0153a5-92ca-483a-9913-47644b63fa8c','CephStorageUserData','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,2,'[]','[100, 99, 98, 79]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',109,NULL),(79,'a7f89c82-df40-42c4-9d9a-cc1641a6141b','ceeab98a-92b6-42cf-812a-4cf6e496797b','CephStorageRoleUserData','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',NULL,57),(80,'a0df54e9-bc56-41a1-8a58-78e68d8fb481','8e8116df-6e99-4dc5-a82f-bda55327c1f8','CellControllerComputeRoleUserData','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',NULL,28),(81,'b45be521-79fd-4714-bf3d-c30ab19993a6','26c5a9b0-676e-4faa-80a5-36db4aa8c2f4','NetworkerNetworkConfig','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[137]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',NULL,1202),(82,'e0ba1816-649c-4edb-b312-80769ab89387','cell1-ComputeConfigData-5w3ettqlugaw','ComputeConfigData','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[113, 84, 83]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1043,1203),(83,'cddc5885-e658-4df0-b06e-83d19a2d3b83','cell1-ComputeServiceConfigSettings-34hgldg5ywef','ComputeServiceConfigSettings','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[118, 116, 114, 113, 112, 111, 110, 109, 84]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1039,1040),(84,'12894d9d-94e1-42c2-9cda-02c299347ef8','cell1-ComputeServiceNames-fquu4ejistm5','ComputeServiceNames','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[120, 113]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',933,934),(85,'44de478c-3a3f-4277-b955-88a52da40665','df5a343b-39ae-4424-a5b0-1cd4bf3907dc','NetworkerIpListMap','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[91, 88, 87, 86]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',550,1206),(86,'4bda3711-068d-47fe-89d0-cddb2d9a5280','cell1-NetworkerServiceNetMapLower-p7qgrvf5unyr','NetworkerServiceNetMapLower','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[139]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',6,7),(87,'26181eea-d7b9-4e3e-8acd-6c542f22952d','cell1-NetworkerNetworkHostnameMap-4pwxxetbqhxk','NetworkerNetworkHostnameMap','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[88]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',537,546),(88,'e48376d9-38e4-45f4-89f4-19f39665e629','dd6d9b23-be82-4983-93db-b99c31d045fc','Networker','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[139, 137, 126, 110, 96, 91, 89]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',485,538),(89,'41651386-3bd5-4079-a458-2e33979ce951','552179ed-299f-444c-9a74-d5624bafad92','NetworkerUserData','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,2,'[]','[100, 99, 98, 90]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',117,NULL),(90,'c8eb4ab1-7c48-4baf-9741-1c73f97def30','16a8b4a4-8a35-410a-a962-172fc2321672','NetworkerRoleUserData','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',NULL,30),(91,'8de221e2-ae7b-435c-8441-c1d8e9b7f4be','cell1-NetworkerServiceNames-gxfopog6eipc','NetworkerServiceNames','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[123, 110]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',460,481),(92,'765462d5-6286-4cd2-8df3-d802df0600db','01cb1dfa-a250-4ece-bd9c-eef5bd565ab4','CellControllerIpListMap','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[102, 95, 94, 93]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1139,1209),(93,'b0edb1ba-be74-450c-8f9a-ac914162a17f','cell1-CellControllerNetworkHostnameMap-kdf6osyo3mn2','CellControllerNetworkHostnameMap','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[94]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1132,1137),(94,'82ca85ad-2824-4081-8d38-4b8ba01bb99f','981ae83c-ed43-46a9-98c5-2e054d3f88ab','CellController','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[139, 137, 126, 114, 102, 97, 96]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1064,1131),(95,'9f3a7f48-a5cc-4c4e-be3f-e6894c8cd72e','cell1-CellControllerServiceNetMapLower-ytvfzsptu72i','CellControllerServiceNetMapLower','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[139]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',3,4),(96,'81694fe3-eb0f-40ce-bf11-599cd9e4eb42','cell1-DeploymentServerBlacklistDict-btxlb6awst7d','DeploymentServerBlacklistDict','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',21,22),(97,'eed81b41-5ae7-4caa-802f-c39cd2abf49d','143aaca9-8b31-4027-a27f-38df24607525','CellControllerUserData','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,2,'[]','[101, 100, 99, 98]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',99,NULL),(98,'d0da3026-5018-4b51-b2a9-9eb28d90e3c6','843d34c1-98be-4115-b358-95b2ec5a83fd','NodeAdminUserData','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',NULL,45),(99,'f6b7545b-57da-46f2-b55a-82a8151644db','814fc223-61c1-48ef-b79e-01e4b51bb3b9','NodeTimesyncUserData','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',NULL,81),(100,'fb15e903-ff54-4bb8-9c60-63f258f1ba31','16caa853-8215-4ecc-8d67-4f5607e32e5f','NodeUserData','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',NULL,105),(101,'78336080-619d-4409-912f-db6f1abd47d6','71baf353-0cfa-48e8-bbff-45da8b6c1ef4','CellControllerRoleUserData','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',NULL,33),(102,'f70a0d49-2245-4c75-8c1c-90a76c75808c','cell1-CellControllerServiceNames-y5jcix3qudkj','CellControllerServiceNames','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[115, 114]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1041,1047),(103,'5ce94ee9-7a02-4adc-abf8-2244ef6e809b','d0f23f3e-a326-4a76-b7d8-f2195c5a64eb','BlockStorageNetworkConfig','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[137]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',NULL,1210),(104,'4b0be679-9e7c-475c-9a4a-c48d34aa990d','cell1-ObjectStorageGroupVars-oxe6prfqxztz','ObjectStorageGroupVars','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[137, 118, 106, 105]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1074,1211),(105,'dd4f255a-f437-4f40-8f7c-9634613b1f96','cell1-FirewallFrontendRules-6qhug7ou6jk2','FirewallFrontendRules','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[118, 116, 114, 113, 112, 111, 110, 109]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1068,1075),(106,'a8cf820e-63ce-45f7-8e94-c56a9be40054','cell1-ObjectStorageServiceNetMapLower-l53dz2um7aqo','ObjectStorageServiceNetMapLower','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[139]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',5,12),(107,'e98ce143-ae6a-489b-8fb8-2797c3f1466d','cell1-ObjectStorageConfigData-rg5onluyzykd','ObjectStorageConfigData','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[118, 117, 108]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1062,1212),(108,'5f180a73-d059-4c2b-8b6a-790be54654bc','cell1-ObjectStorageServiceConfigSettings-yk6qlfprqctt','ObjectStorageServiceConfigSettings','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[118, 117, 116, 114, 113, 112, 111, 110, 109]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1059,1061),(109,'bc19ca55-814d-42a6-917a-a3e7382bd0df','cell1-BlockStorageServiceChainRoleData-fjubjw6btssv','BlockStorageServiceChainRoleData','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[119]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',379,472),(110,'aa809404-9d17-46b9-81ba-dc804eef61ca','cell1-NetworkerServiceChainRoleData-nom5c6vibfae','NetworkerServiceChainRoleData','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[123]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',419,479),(111,'cacbd427-106a-4d82-8229-5ea805517584','cell1-CephStorageServiceChainRoleData-3aqqnlfmxvbh','CephStorageServiceChainRoleData','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[121]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',464,494),(112,'5430d855-114a-49a3-81b1-27293422586c','cell1-CellControllerComputeServiceChainRoleData-tiyrjjkdbwcv','CellControllerComputeServiceChainRoleData','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[125]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',465,504),(113,'2b77028b-a342-45f2-8614-5799b6f01dbb','cell1-ComputeServiceChainRoleData-l4vdiivxoaul','ComputeServiceChainRoleData','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[120]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',932,936),(114,'608f9d56-1c21-40f6-91ba-e41c55306238','cell1-CellControllerServiceChainRoleData-b5q4efqi7hkw','CellControllerServiceChainRoleData','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[115]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1032,1066),(115,'90c011a7-2f6c-4917-ac20-cf52d1ad5718','30720dfb-21ea-49b3-a244-ecd4aa95b259','CellControllerServiceChain','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[139, 130, 128, 127, 126]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',74,1027),(116,'73a712ed-3f9d-49df-afc1-2cee7414b83f','cell1-ControllerServiceChainRoleData-txz7tvz2oexn','ControllerServiceChainRoleData','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[122]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',461,468),(117,'075b5b14-c9ec-43f7-9aa6-16478087247a','cell1-ObjectStorageServiceNames-h56j5qdvwwyu','ObjectStorageServiceNames','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[124, 118]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',530,542),(118,'404e598c-f51a-4a65-81ac-762c7a68853f','cell1-ObjectStorageServiceChainRoleData-uzpvdjae4wmm','ObjectStorageServiceChainRoleData','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[124]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',529,531),(119,'ffb4f08e-ac2b-4b87-b984-85953c0d4c3e','0292a578-a91f-4468-b72e-e0d581ff796d','BlockStorageServiceChain','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[139, 130, 128, 127, 126]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',68,368),(120,'c8d85dbc-375c-421b-a700-9a7747b5a350','145e1916-db5b-4baa-b2e0-d4a4af571da7','ComputeServiceChain','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[139, 130, 128, 127, 126]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',72,931),(121,'6f6a9bc6-02b7-4bc1-9a48-29aef30f1404','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','CephStorageServiceChain','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[139, 130, 128, 127, 126]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',69,459),(122,'f99eb9bf-60e5-4c84-b07f-a1dc4f6e111c','f3979da4-1312-4314-a6b6-ac051d536f13','ControllerServiceChain','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[139, 130, 128, 127, 126]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',70,463),(123,'a57f3b54-72e0-4b7a-ba12-bceb2cb1aae1','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','NetworkerServiceChain','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[139, 130, 128, 127, 126]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',66,401),(124,'f3a7354a-d0f0-4ad2-91e5-81c7a97aa214','fe37e76b-9935-4130-aa62-8b87c49e18f6','ObjectStorageServiceChain','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[139, 130, 128, 127, 126]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',67,528),(125,'10f7605b-881e-4048-9959-7dbbbf8bf8bd','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','CellControllerComputeServiceChain','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[139, 130, 128, 127, 126]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',71,462),(126,'8fca917a-1d1c-41f1-96b8-e55883cadd46','cell1-EndpointMapData-d4i5dsh4vel2','EndpointMapData','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[129]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',65,73),(127,'431f60df-6cef-414f-a0b4-e797ffc39097','cell1-NetCidrMapValue-ct3m55br6yg7','NetCidrMapValue','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[138, 137]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',42,48),(128,'d0871e21-d2b9-46e6-aad7-594335ab8416','cell1-NetIpVersionMapValue-nzwsxhiiohrb','NetIpVersionMapValue','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[138, 137]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',39,47),(129,'0c5de0be-b56a-4e83-944c-4054a9563399','cbbba4ee-a688-41dd-aec3-704e5bc2fbf6','EndpointMap','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[139, 130]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',60,64),(130,'a5541fdd-f62d-4bc2-8cba-08d925e60aaf','a1c2adbf-89dd-4b85-8054-7a05a9663bfa','VipMap','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[139, 138, 137, 134, 133, 132, 131]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',53,59),(131,'e02e6bd0-8b69-40ee-a3cf-6974dc3c685b','00c74abd-5661-446a-8bad-82e704b72c1f','StorageMgmtVirtualIP','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[139, 138, 137]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',46,52),(132,'9af1fdac-4c64-4747-b60c-cc69b49b0036','c246d8af-c2cf-4b38-bb7e-20b423b8a52f','PublicVirtualIP','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[139, 138, 137]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',40,44),(133,'b30ceaf8-8a08-43a9-b5a8-f92680fb257c','39f83ad6-187e-44a1-be76-5a4bc402fc0b','InternalApiVirtualIP','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[139, 138, 137]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',38,49),(134,'0b1863c1-50c8-456e-97ae-691355576b81','cbcec78d-4798-4473-86f5-eafc687dfc2f','StorageVirtualIP','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[139, 138, 137]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',41,50),(135,'f681d306-a9a0-4471-9baf-54d0cacc80f4','61aa862d-ac54-49f1-a86f-25d1f41d7057','CephStorageNetworkConfig','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[137]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',NULL,1213),(136,'1f931c72-5b2d-4807-a27f-4a24a734b804','f66389a6-fae5-4676-97b6-f7809f2b6616','ComputeNetworkConfig','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[137]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',NULL,1214),(137,'48e6f794-651e-4368-9d46-33ee1dca8337','2156e4c7-1622-4775-abf0-5881662899de','Networks','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[139, 138]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',24,43),(138,'70581d25-c708-48e1-b13e-8288d2871bfa','cc583229-e4ca-49d7-82b3-6ec36ef562d6','ControlVirtualIP','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[139]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',17,25),(139,'6cca642d-688a-4761-aada-0e2aec8bd37a','51d8cdba-b9a7-424c-884c-37ea3f5b3bb6','ServiceNetMap','2026-06-12 08:25:36',NULL,'CREATE','COMPLETE','state changed','1033da2e-3eba-4d68-a67d-e4deed5ac6ee','{}','null',NULL,3,'[]','[]',NULL,NULL,1,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',NULL,15),(140,'fcebc621-b92e-44f3-8c69-01a800a4bcdf','cell1-ServiceNetMap-oylirjwmuzbn-ServiceNetMapValue-j45zf36oxrrb','ServiceNetMapValue','2026-06-12 08:25:37',NULL,'CREATE','COMPLETE','state changed','51d8cdba-b9a7-424c-884c-37ea3f5b3bb6','{}','null',NULL,3,'[]','[]',NULL,NULL,2,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',1,2),(141,'ce7e1753-463d-4810-b6d8-54254801dd50','ca5c1ea4-69c0-4658-a611-b1ff6e4a6b3c','userdata','2026-06-12 08:25:38',NULL,'CREATE','COMPLETE','state changed','1d100aff-0e07-4c2c-9435-35b0a942253c','{}','null',NULL,2,'[]','[]',NULL,NULL,3,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',NULL,NULL),(142,'f6da4956-7270-4785-acfc-986bca118a56','159a907b-e20e-4759-9570-51a2f14bac21','userdata','2026-06-12 08:25:40',NULL,'CREATE','COMPLETE','state changed','0a8c9f8c-59ce-49a0-bd86-da18f38bb157','{}','null',NULL,2,'[]','[]',NULL,NULL,5,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',NULL,NULL),(143,'05d41974-faa1-45be-b039-c207f44d7c08','cell1-Networks-g2dfdzeon54u-NetworkIpVersionMap-lpx2uec5iglu','NetworkIpVersionMap','2026-06-12 08:25:40',NULL,'CREATE','COMPLETE','state changed','2156e4c7-1622-4775-abf0-5881662899de','{}','null',NULL,3,'[]','[]',NULL,NULL,6,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',29,35),(144,'59eed00c-2292-4cd1-a1ad-be0ab2cfbc0c','0b73875a-c57e-4b9f-8a68-d36c915cb933','NetworkExtraConfig','2026-06-12 08:25:40',NULL,'CREATE','COMPLETE','state changed','2156e4c7-1622-4775-abf0-5881662899de','{}','null',NULL,2,'[]','[]',NULL,NULL,6,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',NULL,NULL),(145,'b196e304-3d5d-41d4-86fc-677e34ff48de','cell1-Networks-g2dfdzeon54u-NetworkAttributesMap-dvb5lwyznyye','NetworkAttributesMap','2026-06-12 08:25:40',NULL,'CREATE','COMPLETE','state changed','2156e4c7-1622-4775-abf0-5881662899de','{}','null',NULL,3,'[]','[]',NULL,NULL,6,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',27,36),(146,'414b7f1a-212f-415d-9a01-b8f8fc12a62c','cell1-Networks-g2dfdzeon54u-NetworkCidrMap-cxjbf5auw7y2','NetworkCidrMap','2026-06-12 08:25:40',NULL,'CREATE','COMPLETE','state changed','2156e4c7-1622-4775-abf0-5881662899de','{}','null',NULL,3,'[]','[]',NULL,NULL,6,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',31,37),(147,'8d61162a-32c0-4777-b9cd-2a19b47952b6','daa065b1-15b9-45c0-a288-7fcfd92ebf5c','userdata','2026-06-12 08:25:41',NULL,'CREATE','COMPLETE','state changed','8e8116df-6e99-4dc5-a82f-bda55327c1f8','{}','null',NULL,2,'[]','[]',NULL,NULL,7,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',NULL,NULL),(148,'5b56a3d0-f6e8-495f-92ec-c4ef82b95c89','cd1e58d8-4afa-4a63-82d9-92551fe42070','userdata','2026-06-12 08:25:42',NULL,'CREATE','COMPLETE','state changed','16a8b4a4-8a35-410a-a962-172fc2321672','{}','null',NULL,2,'[]','[]',NULL,NULL,8,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',NULL,NULL),(149,'d77e310d-da60-4620-9eb2-9d5ca3693d8d','ab3ab164-85c5-4ce6-b45f-96c96bd6b9a7','userdata','2026-06-12 08:25:43',NULL,'CREATE','COMPLETE','state changed','71baf353-0cfa-48e8-bbff-45da8b6c1ef4','{}','null',NULL,2,'[]','[]',NULL,NULL,9,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',NULL,NULL),(150,'2b623b68-55c3-4c25-b889-db8c42a131e2','9e79f8a0-8d18-4ab5-8d15-8d7c1496cc29','userdata','2026-06-12 08:25:44',NULL,'CREATE','COMPLETE','state changed','843d34c1-98be-4115-b358-95b2ec5a83fd','{}','null',NULL,2,'[]','[151]',NULL,NULL,10,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',34,NULL),(151,'49502be3-6b1d-4ef5-aabe-be036c13982d','d8598f48-442e-4187-abe1-3de1781ddada','user_config','2026-06-12 08:25:44',NULL,'CREATE','COMPLETE','state changed','843d34c1-98be-4115-b358-95b2ec5a83fd','{}','null',NULL,2,'[]','[]',NULL,NULL,10,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',32,NULL),(152,'8544613c-3678-4890-a7fd-2de76f963d95','9b0e9607-fa6f-42f6-81d0-2fc264dd9342','userdata','2026-06-12 08:25:45',NULL,'CREATE','COMPLETE','state changed','7cfeddf9-35ae-475e-9333-0c409e1797c0','{}','null',NULL,2,'[]','[]',NULL,NULL,13,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',NULL,NULL),(153,'d40e6753-85c6-4cff-8943-2fc6c1d798ee','ad458520-d703-4682-a3b2-c2a3725b2679','userdata','2026-06-12 08:25:46',NULL,'CREATE','COMPLETE','state changed','ceeab98a-92b6-42cf-812a-4cf6e496797b','{}','null',NULL,2,'[]','[]',NULL,NULL,16,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',NULL,NULL),(154,'d1d1157e-3314-4291-bbaf-27fa7212513d','cell1-VipMap-xqxwfwsvih65-NetIpMapValue-fejtcti5cfl6','NetIpMapValue','2026-06-12 08:25:46',NULL,'CREATE','COMPLETE','state changed','a1c2adbf-89dd-4b85-8054-7a05a9663bfa','{}','null',NULL,3,'[]','[]',NULL,NULL,17,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',54,58),(155,'56a7d91c-b573-4909-9c7a-5b863836abd8','265d72a5-61cc-4d33-af71-10d16d2db2f5','userdata','2026-06-12 08:25:48',NULL,'CREATE','COMPLETE','state changed','814fc223-61c1-48ef-b79e-01e4b51bb3b9','{}','null',NULL,2,'[]','[157, 156]',NULL,NULL,19,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',76,NULL),(156,'b9649fbe-9e42-4aa7-8589-209a9ed60501','e6d28eb3-7f06-42b4-9a6e-bd245cd08dab','timesync_sync','2026-06-12 08:25:48',NULL,'CREATE','COMPLETE','state changed','814fc223-61c1-48ef-b79e-01e4b51bb3b9','{}','null',NULL,2,'[]','[]',NULL,NULL,19,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',63,NULL),(157,'70cefad5-b523-49bd-8f7f-3b52f291ddc7','fb5ab309-7c16-4ccb-b6fd-062398ea6769','timesync_chrony','2026-06-12 08:25:48',NULL,'CREATE','COMPLETE','state changed','814fc223-61c1-48ef-b79e-01e4b51bb3b9','{}','null',NULL,2,'[]','[]',NULL,NULL,19,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',75,NULL),(158,'4f804af8-6010-4e8e-87e1-02b79b33ab39','9a7a5fe2-51a7-4c57-866d-bd7a2d4d3571','userdata','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','5bdeb4aa-f303-4207-9bd1-393ec399a46a','{}','null',NULL,2,'[]','[]',NULL,NULL,24,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',NULL,NULL),(159,'523101f9-fe55-4c24-a613-5b42bb5059e2','cell1-NetworkerServiceChain-w6ts4csx6o2u-FirewallRules-yjh6kvjdcapz','FirewallRules','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','{}','null',NULL,3,'[]','[244]',NULL,NULL,20,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',115,309),(160,'6609386f-3278-4424-8303-d939f3cf5fad','cell1-NetworkerServiceChain-w6ts4csx6o2u-ServiceNames-ijbspbtasodp','ServiceNames','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','{}','null',NULL,3,'[]','[244]',NULL,NULL,20,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',165,311),(161,'3d067616-f6ac-4391-8605-b6707ec763f6','cell1-NetworkerServiceChain-w6ts4csx6o2u-ExternalPostDeployTasks-hepwvq6qm5qw','ExternalPostDeployTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','{}','null',NULL,3,'[]','[244]',NULL,NULL,20,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',126,313),(162,'4893bbf2-47ab-4f9c-a8ae-f7265adc1de8','cell1-NetworkerServiceChain-w6ts4csx6o2u-AnsibleGroupVars-7hchvnejho7s','AnsibleGroupVars','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','{}','null',NULL,3,'[]','[244]',NULL,NULL,20,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',177,315),(163,'bf52fc20-a45b-4686-b825-180a7c2e6ed4','cell1-NetworkerServiceChain-w6ts4csx6o2u-DockerConfigScripts-nbvelo7vf7ba','DockerConfigScripts','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','{}','null',NULL,3,'[]','[244]',NULL,NULL,20,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',135,317),(164,'a4148a70-3a38-4a8b-9cfe-5781f6db695a','cell1-NetworkerServiceChain-w6ts4csx6o2u-UpgradeBatchTasks-vcz2hcsbjctq','UpgradeBatchTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','{}','null',NULL,3,'[]','[244]',NULL,NULL,20,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',199,319),(165,'a9a0accb-b944-48ea-9ca2-e6595aed831d','cell1-NetworkerServiceChain-w6ts4csx6o2u-PuppetStepConfig-r2vzisu2blgl','PuppetStepConfig','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','{}','null',NULL,3,'[]','[244]',NULL,NULL,20,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',147,321),(166,'d3fd47b2-f8b1-4227-ab7b-2648078448ee','cell1-NetworkerServiceChain-w6ts4csx6o2u-PreDeployStepTasks-ej7ywhj72r5s','PreDeployStepTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','{}','null',NULL,3,'[]','[244]',NULL,NULL,20,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',89,322),(167,'6c87226a-8690-4e4b-af07-3e3a86489975','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-FirewallRules-4s4gsbwioitk','FirewallRules','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','fe37e76b-9935-4130-aa62-8b87c49e18f6','{}','null',NULL,3,'[]','[279]',NULL,NULL,21,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',255,473),(168,'480cec47-7217-4a8f-8783-3c39f489d51b','cell1-NetworkerServiceChain-w6ts4csx6o2u-PostUpgradeTasks-vd3sc5eaz3ch','PostUpgradeTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','{}','null',NULL,3,'[]','[244]',NULL,NULL,20,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',106,324),(169,'6ea65132-ef13-42b3-9c54-3a65fcb5fbec','cell1-NetworkerServiceChain-w6ts4csx6o2u-MonitoringSubscriptionsConfig-fm7pcnxkmujs','MonitoringSubscriptionsConfig','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','{}','null',NULL,3,'[]','[244]',NULL,NULL,20,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',156,325),(170,'d345905d-63ef-4e42-9c9e-6e7dac995b08','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-ServiceNames-4qtd57julec5','ServiceNames','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','fe37e76b-9935-4130-aa62-8b87c49e18f6','{}','null',NULL,3,'[]','[279]',NULL,NULL,21,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',120,476),(171,'3ee8e3d4-c1b6-4193-b7ac-7ee7eb1dddd4','cell1-NetworkerServiceChain-w6ts4csx6o2u-HostPrepTasks-de6bwy7ory6u','HostPrepTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','{}','null',NULL,3,'[]','[244]',NULL,NULL,20,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',167,327),(172,'024133d9-c1fb-48ef-b48e-419145c8810b','cell1-NetworkerServiceChain-w6ts4csx6o2u-PuppetConfig-r36b7mbecm6z','PuppetConfig','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','{}','null',NULL,3,'[]','[244]',NULL,NULL,20,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',131,328),(173,'b1e48633-4281-45cd-9ca2-f62ffe940f73','cell1-NetworkerServiceChain-w6ts4csx6o2u-HostFirewallTasks-ltkcqgy6jbrt','HostFirewallTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','{}','null',NULL,3,'[]','[244]',NULL,NULL,20,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',181,330),(174,'44197217-89d4-4f17-ac35-0ecedac6b69b','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-ExternalPostDeployTasks-6f4j2rcbs4qx','ExternalPostDeployTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','fe37e76b-9935-4130-aa62-8b87c49e18f6','{}','null',NULL,3,'[]','[279]',NULL,NULL,21,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',172,477),(175,'7ab477f0-6bf8-4c48-a078-47ff8b1eb9bf','cell1-NetworkerServiceChain-w6ts4csx6o2u-PreUpgradeRollingTasks-ysdl7b5li57q','PreUpgradeRollingTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','{}','null',NULL,3,'[]','[244]',NULL,NULL,20,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',207,332),(176,'3726160d-1094-41cc-ba94-ae179b81ea24','cell1-NetworkerServiceChain-w6ts4csx6o2u-PostUpdateTasks-dtaqsq3smfqn','PostUpdateTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','{}','null',NULL,3,'[]','[244]',NULL,NULL,20,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',149,333),(177,'bcc8526a-5099-40c3-b8b2-4468f6095feb','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-AnsibleGroupVars-bq2qtg6mqutk','AnsibleGroupVars','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','fe37e76b-9935-4130-aa62-8b87c49e18f6','{}','null',NULL,3,'[]','[279]',NULL,NULL,21,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',97,480),(178,'b222bd1f-7a51-47b0-8ab3-148fe18447b7','cell1-NetworkerServiceChain-w6ts4csx6o2u-GlobalConfigSettings-pmd2kgzcfpi7','GlobalConfigSettings','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','{}','null',NULL,3,'[]','[244]',NULL,NULL,20,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',153,336),(179,'29bdfc12-3b28-4e16-b16a-89dca9710d5c','cell1-NetworkerServiceChain-w6ts4csx6o2u-UpdateTasks-4fr3fau337as','UpdateTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','{}','null',NULL,3,'[]','[244]',NULL,NULL,20,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',112,337),(180,'264d5e8d-3bd6-4b8e-ae76-1402c538c3a3','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-DockerConfigScripts-xdr32yte2xun','DockerConfigScripts','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','fe37e76b-9935-4130-aa62-8b87c49e18f6','{}','null',NULL,3,'[]','[279]',NULL,NULL,21,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',263,487),(181,'6b739cca-6b77-4306-bd04-31f47f1ae4e1','cell1-NetworkerServiceChain-w6ts4csx6o2u-KeystoneResourcesConfigs-gbtlo5vxhhgk','KeystoneResourcesConfigs','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','{}','null',NULL,3,'[]','[244]',NULL,NULL,20,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',108,338),(182,'9fa9f06d-9aad-454e-8a63-1049036c5e43','cell1-NetworkerServiceChain-w6ts4csx6o2u-ExternalDeployTasks-ktu2vwp2t4dn','ExternalDeployTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','{}','null',NULL,3,'[]','[244]',NULL,NULL,20,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',171,340),(183,'9de5e2dd-68c2-486a-a67a-af13b62ee3bb','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-UpgradeBatchTasks-q2tiyko6lyw5','UpgradeBatchTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','fe37e76b-9935-4130-aa62-8b87c49e18f6','{}','null',NULL,3,'[]','[279]',NULL,NULL,21,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',142,491),(184,'19f80105-1471-474b-b498-e82748193c02','cell1-NetworkerServiceChain-w6ts4csx6o2u-ScaleTasks-osyuoem7qaif','ScaleTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','{}','null',NULL,3,'[]','[244]',NULL,NULL,20,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',214,341),(185,'00084a92-b9de-4870-8852-faeaafc85250','cell1-ControllerServiceChain-zbda4x4z5on7-FirewallRules-q4fz3yaaqsus','FirewallRules','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','f3979da4-1312-4314-a6b6-ac051d536f13','{}','null',NULL,3,'[]','[289]',NULL,NULL,25,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',160,346),(186,'7837a0e0-aced-43f1-919e-5034887841d3','cell1-NetworkerServiceChain-w6ts4csx6o2u-ExternalUpdateTasks-h4nm5v4dpiha','ExternalUpdateTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','{}','null',NULL,3,'[]','[244]',NULL,NULL,20,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',205,342),(187,'a92ba493-e963-4ee7-90c5-45bf3a2a533b','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-PuppetStepConfig-5z7jmousxjet','PuppetStepConfig','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','fe37e76b-9935-4130-aa62-8b87c49e18f6','{}','null',NULL,3,'[]','[279]',NULL,NULL,21,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',217,492),(188,'c08baba8-4d6a-48de-a3cd-6627dbd6c8d1','cell1-ControllerServiceChain-zbda4x4z5on7-ServiceNames-rxsnnlaixk5i','ServiceNames','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','f3979da4-1312-4314-a6b6-ac051d536f13','{}','null',NULL,3,'[]','[289]',NULL,NULL,25,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',87,351),(189,'4945f0a1-f425-4129-80d2-db2f1baabba1','cell1-NetworkerServiceChain-w6ts4csx6o2u-ContainerPuppetTasks-ckpueveul4fb','ContainerPuppetTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','{}','null',NULL,3,'[]','[244]',NULL,NULL,20,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',151,343),(190,'c9013883-ef62-46cd-8fd4-31183cc728e2','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-PreDeployStepTasks-ntppmleqcoed','PreDeployStepTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','fe37e76b-9935-4130-aa62-8b87c49e18f6','{}','null',NULL,3,'[]','[279]',NULL,NULL,21,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',122,495),(191,'2cd663ac-6cd3-4cbf-aab8-26e9da069018','cell1-ControllerServiceChain-zbda4x4z5on7-ExternalPostDeployTasks-zp3m2mwnmy5m','ExternalPostDeployTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','f3979da4-1312-4314-a6b6-ac051d536f13','{}','null',NULL,3,'[]','[289]',NULL,NULL,25,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',221,353),(192,'bf75eefb-97d3-44a0-a4f5-7f8f5881b716','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-PostUpgradeTasks-jiex2o7xl3x3','PostUpgradeTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','fe37e76b-9935-4130-aa62-8b87c49e18f6','{}','null',NULL,3,'[]','[279]',NULL,NULL,21,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',136,496),(193,'a1bf36c5-fd1e-4982-96fb-bd4c7a36fe5a','cell1-CephStorageServiceChain-xqicw5xwvg6g-FirewallRules-tax5d2q36nwf','FirewallRules','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','{}','null',NULL,3,'[]','[335]',NULL,NULL,23,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',190,345),(194,'082c3cbf-884b-4871-995c-37e35d945617','cell1-ControllerServiceChain-zbda4x4z5on7-AnsibleGroupVars-q4mijmecypf7','AnsibleGroupVars','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','f3979da4-1312-4314-a6b6-ac051d536f13','{}','null',NULL,3,'[]','[289]',NULL,NULL,25,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',145,357),(195,'77cae30b-d64f-4b5a-9271-40183c1e072d','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-MonitoringSubscriptionsConfig-wwwwj534vyyl','MonitoringSubscriptionsConfig','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','fe37e76b-9935-4130-aa62-8b87c49e18f6','{}','null',NULL,3,'[]','[279]',NULL,NULL,21,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',276,497),(196,'ab983543-7e4a-40e4-a7d2-6db164f2462d','cell1-ControllerServiceChain-zbda4x4z5on7-DockerConfigScripts-bzd6jkvzqnkd','DockerConfigScripts','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','f3979da4-1312-4314-a6b6-ac051d536f13','{}','null',NULL,3,'[]','[289]',NULL,NULL,25,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',186,360),(197,'5ff82200-333a-422a-8319-cdc8c9ff0590','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-HostPrepTasks-ekrthjp7qiqa','HostPrepTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','fe37e76b-9935-4130-aa62-8b87c49e18f6','{}','null',NULL,3,'[]','[279]',NULL,NULL,21,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',280,498),(198,'cfb7fcee-d414-412c-8a29-37d08d8b917a','cell1-ControllerServiceChain-zbda4x4z5on7-UpgradeBatchTasks-clgucth3p7ho','UpgradeBatchTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','f3979da4-1312-4314-a6b6-ac051d536f13','{}','null',NULL,3,'[]','[289]',NULL,NULL,25,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',188,364),(199,'c97ff55a-8375-4b8b-b5db-be1c0f8795e2','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-PuppetConfig-xc4doxex75k2','PuppetConfig','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','fe37e76b-9935-4130-aa62-8b87c49e18f6','{}','null',NULL,3,'[]','[279]',NULL,NULL,21,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',98,499),(200,'0b123c53-7a55-403c-b9ef-7b0ad1b3792f','cell1-CephStorageServiceChain-xqicw5xwvg6g-ServiceNames-apd2kufrepct','ServiceNames','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','{}','null',NULL,3,'[]','[335]',NULL,NULL,23,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',174,350),(201,'d587283c-be0a-48ec-b9d2-2a6c388bf1ef','cell1-ControllerServiceChain-zbda4x4z5on7-PuppetStepConfig-r3f6blkyokb4','PuppetStepConfig','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','f3979da4-1312-4314-a6b6-ac051d536f13','{}','null',NULL,3,'[]','[289]',NULL,NULL,25,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',103,367),(202,'2c69a945-35ec-42bb-8510-a9bee0122688','cell1-NetworkerServiceChain-w6ts4csx6o2u-DockerConfig-fozv5qwgtkkf','DockerConfig','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','{}','null',NULL,3,'[]','[244]',NULL,NULL,20,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',157,347),(203,'ee3fd78d-54a4-407a-b7ca-ef790513748a','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-HostFirewallTasks-a6suutxd7v4n','HostFirewallTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','fe37e76b-9935-4130-aa62-8b87c49e18f6','{}','null',NULL,3,'[]','[279]',NULL,NULL,21,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',127,501),(204,'70355ce3-6058-4523-b6eb-e44de7365494','cell1-ControllerServiceChain-zbda4x4z5on7-PreDeployStepTasks-ki3albydkxhd','PreDeployStepTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','f3979da4-1312-4314-a6b6-ac051d536f13','{}','null',NULL,3,'[]','[289]',NULL,NULL,25,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',218,375),(205,'2b7958cc-9b6f-4c7c-b1a0-2087442bc20b','cell1-CephStorageServiceChain-xqicw5xwvg6g-ExternalPostDeployTasks-y7e3n4vxswgm','ExternalPostDeployTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','{}','null',NULL,3,'[]','[335]',NULL,NULL,23,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',158,355),(206,'618b48af-82c7-4e7a-be6b-3ed187aab527','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-PreUpgradeRollingTasks-46ucy5qywsfp','PreUpgradeRollingTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','fe37e76b-9935-4130-aa62-8b87c49e18f6','{}','null',NULL,3,'[]','[279]',NULL,NULL,21,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',277,502),(207,'a3f3d9e5-ed3c-4538-a51c-73f57782ae74','cell1-NetworkerServiceChain-w6ts4csx6o2u-KollaConfig-kohnhsr7hwpf','KollaConfig','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','{}','null',NULL,3,'[]','[244]',NULL,NULL,20,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',138,348),(208,'9cf8e5d1-e61d-493a-a4f9-cfb3b44e2f43','cell1-ControllerServiceChain-zbda4x4z5on7-PostUpgradeTasks-soxgdwoprzor','PostUpgradeTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','f3979da4-1312-4314-a6b6-ac051d536f13','{}','null',NULL,3,'[]','[289]',NULL,NULL,25,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',242,378),(209,'d7af76cf-9b44-4d6f-bd69-d6496381b3ef','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-PostUpdateTasks-2343itl265wp','PostUpdateTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','fe37e76b-9935-4130-aa62-8b87c49e18f6','{}','null',NULL,3,'[]','[279]',NULL,NULL,21,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',219,503),(210,'7e5e9703-15b9-4e03-b978-c68615b7e3dd','cell1-NetworkerServiceChain-w6ts4csx6o2u-ServiceConfigSettings-4ayvxf7f5fyd','ServiceConfigSettings','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','{}','null',NULL,3,'[]','[244]',NULL,NULL,20,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',90,352),(211,'cac681c0-36e8-4a9f-8e3b-81f9439ab015','cell1-CellControllerComputeServiceChain-aseidyipoyc3-FirewallRules-vhzw5dfmnaoa','FirewallRules','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','{}','null',NULL,3,'[]','[340]',NULL,NULL,27,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',282,397),(212,'65c0ae81-1008-4767-ae18-bf9a8c106d76','cell1-ControllerServiceChain-zbda4x4z5on7-MonitoringSubscriptionsConfig-ozyqbbs4blub','MonitoringSubscriptionsConfig','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','f3979da4-1312-4314-a6b6-ac051d536f13','{}','null',NULL,3,'[]','[289]',NULL,NULL,25,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',95,382),(213,'0c59257a-54f2-480a-b8f6-d6d139621227','cell1-CephStorageServiceChain-xqicw5xwvg6g-AnsibleGroupVars-qcsu6igfsjl2','AnsibleGroupVars','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','{}','null',NULL,3,'[]','[335]',NULL,NULL,23,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',187,358),(214,'16acc411-a361-4967-b1bb-9910f1d2e388','cell1-NetworkerServiceChain-w6ts4csx6o2u-FirewallFrontendRules-sz5dmelkzrar','FirewallFrontendRules','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','{}','null',NULL,3,'[]','[244]',NULL,NULL,20,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',116,354),(215,'0f300dac-3ba0-4d3f-b9ed-be5570abf7ff','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-GlobalConfigSettings-2pz3uahtadnm','GlobalConfigSettings','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','fe37e76b-9935-4130-aa62-8b87c49e18f6','{}','null',NULL,3,'[]','[279]',NULL,NULL,21,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',269,505),(216,'38ae07fb-858b-418f-903c-5182f6ac6035','cell1-CellControllerComputeServiceChain-aseidyipoyc3-ServiceNames-dd4frm4k4b73','ServiceNames','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','{}','null',NULL,3,'[]','[340]',NULL,NULL,27,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',250,399),(217,'320cd77f-071c-47ee-ac7d-78ea414ccf22','cell1-ControllerServiceChain-zbda4x4z5on7-HostPrepTasks-p3qhdqzazv37','HostPrepTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','f3979da4-1312-4314-a6b6-ac051d536f13','{}','null',NULL,3,'[]','[289]',NULL,NULL,25,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',237,384),(218,'829811b6-1447-4dc6-92ee-100a6f6329be','cell1-CephStorageServiceChain-xqicw5xwvg6g-DockerConfigScripts-3rqui6bjqenw','DockerConfigScripts','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','{}','null',NULL,3,'[]','[335]',NULL,NULL,23,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',146,361),(219,'ad3d6c54-a28d-43e9-ad8b-6d0a0b95c555','cell1-NetworkerServiceChain-w6ts4csx6o2u-ExternalUpgradeTasks-h2ncrwwt23cu','ExternalUpgradeTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','{}','null',NULL,3,'[]','[244]',NULL,NULL,20,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',196,359),(220,'ec33bdba-d1b2-44ec-82f3-dd9f01e6ab9e','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-UpdateTasks-j3grwlwdhpn2','UpdateTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','fe37e76b-9935-4130-aa62-8b87c49e18f6','{}','null',NULL,3,'[]','[279]',NULL,NULL,21,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',233,506),(221,'bd34772c-d49b-49e7-8a7b-fa960c1d2624','cell1-CellControllerComputeServiceChain-aseidyipoyc3-ExternalPostDeployTasks-tz6uto6ti5zm','ExternalPostDeployTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','{}','null',NULL,3,'[]','[340]',NULL,NULL,27,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',125,402),(222,'dddf1905-bea8-4ccf-a230-4e8729a98bdf','cell1-ControllerServiceChain-zbda4x4z5on7-PuppetConfig-zt56vdo56gif','PuppetConfig','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','f3979da4-1312-4314-a6b6-ac051d536f13','{}','null',NULL,3,'[]','[289]',NULL,NULL,25,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',197,387),(223,'51965765-69ab-4fd8-a8c4-3f518da84ab1','cell1-NetworkerServiceChain-w6ts4csx6o2u-DeployStepsTasks-7wdjvnizmv3f','DeployStepsTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','{}','null',NULL,3,'[]','[244]',NULL,NULL,20,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',107,362),(224,'b197f2d4-90d4-4410-a10b-70211e3bdaf5','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-KeystoneResourcesConfigs-ieeq2syzp4wu','KeystoneResourcesConfigs','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','fe37e76b-9935-4130-aa62-8b87c49e18f6','{}','null',NULL,3,'[]','[279]',NULL,NULL,21,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',265,507),(225,'37b876e9-c4bc-466e-adc2-48640a4f7709','cell1-CephStorageServiceChain-xqicw5xwvg6g-UpgradeBatchTasks-m3wexq33q5xj','UpgradeBatchTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','{}','null',NULL,3,'[]','[335]',NULL,NULL,23,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',139,363),(226,'ab1cd779-e7ec-4e20-8486-1d2c9dde1778','cell1-ControllerServiceChain-zbda4x4z5on7-HostFirewallTasks-4ihh5svrzv3z','HostFirewallTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','f3979da4-1312-4314-a6b6-ac051d536f13','{}','null',NULL,3,'[]','[289]',NULL,NULL,25,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',223,390),(227,'f45b7c69-8de0-43a4-ab9b-b553454f3eea','cell1-CellControllerComputeServiceChain-aseidyipoyc3-AnsibleGroupVars-hjen4d2fw7dj','AnsibleGroupVars','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','{}','null',NULL,3,'[]','[340]',NULL,NULL,27,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',241,403),(228,'22bb8d3c-1009-41c4-9d4e-6e536986c7e9','cell1-NetworkerServiceChain-w6ts4csx6o2u-IpaRegistrationTasks-draqberlxdj4','IpaRegistrationTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','{}','null',NULL,3,'[]','[244]',NULL,NULL,20,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',182,365),(229,'afc34e18-2fbf-4504-80a1-a3fb9106f992','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-ExternalDeployTasks-kbbpx6x4gtqy','ExternalDeployTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','fe37e76b-9935-4130-aa62-8b87c49e18f6','{}','null',NULL,3,'[]','[279]',NULL,NULL,21,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',189,508),(230,'e5c7047c-bed1-4e9e-bd72-6a6729deae27','cell1-CephStorageServiceChain-xqicw5xwvg6g-PuppetStepConfig-5hv62hs4obd4','PuppetStepConfig','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','{}','null',NULL,3,'[]','[335]',NULL,NULL,23,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',175,366),(231,'34bbb0be-38e6-4c2e-b5cd-b973b37a14e3','cell1-ControllerServiceChain-zbda4x4z5on7-PreUpgradeRollingTasks-ylry4y2lxmf6','PreUpgradeRollingTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','f3979da4-1312-4314-a6b6-ac051d536f13','{}','null',NULL,3,'[]','[289]',NULL,NULL,25,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',173,392),(232,'5cd1b03d-9fa4-493a-b21d-cde618d8064e','cell1-NetworkerServiceChain-w6ts4csx6o2u-DockerPuppetTasks-sou7urondmb5','DockerPuppetTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','{}','null',NULL,3,'[]','[244]',NULL,NULL,20,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',93,380),(233,'598dab9d-4dd6-4a96-aae1-d59ebc841423','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-ScaleTasks-vfsn2zmy3k45','ScaleTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','fe37e76b-9935-4130-aa62-8b87c49e18f6','{}','null',NULL,3,'[]','[279]',NULL,NULL,21,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',257,509),(234,'a12993cd-1079-4626-8238-91724dbb95d0','cell1-CellControllerComputeServiceChain-aseidyipoyc3-DockerConfigScripts-mjqqpgqste6n','DockerConfigScripts','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','{}','null',NULL,3,'[]','[340]',NULL,NULL,27,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',162,404),(235,'464d2f2f-dee6-4c06-a6aa-900732ea4687','cell1-ControllerServiceChain-zbda4x4z5on7-PostUpdateTasks-ybw64zde2lzp','PostUpdateTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','f3979da4-1312-4314-a6b6-ac051d536f13','{}','null',NULL,3,'[]','[289]',NULL,NULL,25,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',227,394),(236,'0befb038-94f3-45bc-903c-3e06fd267d8f','cell1-NetworkerServiceChain-w6ts4csx6o2u-UpgradeTasks-lpeu6mf67mby','UpgradeTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','{}','null',NULL,3,'[]','[244]',NULL,NULL,20,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',118,385),(237,'3757ae11-31f5-4cf3-acf1-392ad4460684','cell1-CephStorageServiceChain-xqicw5xwvg6g-PreDeployStepTasks-z4zr6u3vplqr','PreDeployStepTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','{}','null',NULL,3,'[]','[335]',NULL,NULL,23,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',209,369),(238,'12c2f6ac-b673-4535-96e1-030a35fae015','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-ExternalUpdateTasks-knnwomjmf5vm','ExternalUpdateTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','fe37e76b-9935-4130-aa62-8b87c49e18f6','{}','null',NULL,3,'[]','[279]',NULL,NULL,21,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',155,510),(239,'118e1f75-3340-4ca8-b35e-deb86eb06e1b','03c9fa6d-46b4-4d9a-aea2-ba0217793f32','ServiceServerMetadataHook','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','{}','null',NULL,3,'[]','[244]',NULL,NULL,20,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',NULL,388),(240,'423e4b89-47df-4b3c-9803-3c7cb34b3baf','cell1-ControllerServiceChain-zbda4x4z5on7-GlobalConfigSettings-wpch35bd4s4j','GlobalConfigSettings','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','f3979da4-1312-4314-a6b6-ac051d536f13','{}','null',NULL,3,'[]','[289]',NULL,NULL,25,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',166,396),(241,'2b0620a6-b6e4-4b2e-abe2-ef787246a06c','cell1-CephStorageServiceChain-xqicw5xwvg6g-PostUpgradeTasks-wlvw4qvqmifg','PostUpgradeTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','06bf047f-ed20-4dbe-9e6e-a004ef9e5e2d','{}','null',NULL,3,'[]','[335]',NULL,NULL,23,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',243,370),(242,'837363e5-8158-4a38-a0d2-18b42dfd81c1','cell1-ObjectStorageServiceChain-vuwq6dz2onkk-ContainerPuppetTasks-uoeblcbxgy7f','ContainerPuppetTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','fe37e76b-9935-4130-aa62-8b87c49e18f6','{}','null',NULL,3,'[]','[279]',NULL,NULL,21,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',244,511),(243,'d3688d40-182a-4d7b-bd32-92ba6e0837dd','cell1-CellControllerComputeServiceChain-aseidyipoyc3-UpgradeBatchTasks-26yyfljwrdka','UpgradeBatchTasks','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','7f9926a2-5885-45d9-9c30-7b8f375a0e0a','{}','null',NULL,3,'[]','[340]',NULL,NULL,27,NULL,'1033da2e-3eba-4d68-a67d-e4deed5ac6ee',133,405),(244,'aacc789a-cb3b-4f5c-a334-24d18c87d606','1a8dc641-365a-42c4-9969-7f9b2ccb777b','ServiceChain','2026-06-12 08:25:49',NULL,'CREATE','COMPLETE','state changed','39b14fca-66b5-41bb-9eb8-05bc3bda7e3d','{}','null',NULL,3,'[]','[]',NULL,NUL